.kt-wizard-v3 .kt-wizard-v3__nav {
  padding: 4rem;
  border-bottom: 1px solid #eeeef4; }
  @media (max-width: 1399px) {
    .kt-wizard-v3 .kt-wizard-v3__nav {
      padding: 2rem 1rem; } }
  .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-line {
    height: 3px;
    background-color: #f6f6f9;
    transform: translateY(1.7rem);
    margin: 0 10%;
    position: relative;
    z-index: 0; }
    @media (max-width: 576px) {
      .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-line {
        display: none; } }
  .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items {
    display: flex;
    flex-direction: row;
    justify-content: space-between;
    position: relative;
    z-index: 1; }
    @media (max-width: 576px) {
      .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items {
        flex-direction: column; } }
    .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item {
      display: flex;
      flex-direction: column;
      align-items: center;
      flex-wrap: wrap;
      flex-basis: auto;
      flex: 1;
      flex-basis: auto;
      font-weight: 500;
      font-size: 1.1rem; }
      @media (max-width: 576px) {
        .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item {
          flex-direction: row;
          margin-bottom: 2rem; } }
      .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item span {
        width: 3.5rem;
        height: 3.5rem;
        font-size: 1.5rem;
        border-radius: 50%;
        display: flex;
        align-items: center;
        justify-content: center;
        margin: 0 1rem; }
      .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item i {
        display: none;
        width: 3.5rem;
        height: 3.5rem;
        font-size: 1.1rem;
        border-radius: 50%;
        align-items: center;
        justify-content: center;
        margin: 0 1rem; }
      .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item .kt-wizard-v3__nav-label {
        margin-top: 1rem;
        color: #74788d;
        text-align: center; }
        @media (max-width: 576px) {
          .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item .kt-wizard-v3__nav-label {
            text-align: left;
            margin-top: 0; } }
      .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item[data-ktwizard-state="current"] {
        color: #385aeb; }
        .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item[data-ktwizard-state="current"] span {
          background-color: #385aeb;
          color: #ffffff; }
      .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item[data-ktwizard-state="pending"] {
        color: #a2a5b9; }
        .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item[data-ktwizard-state="pending"] span {
          background-color: #f6f6f9;
          color: #a2a5b9; }
      .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item[data-ktwizard-state="done"] {
        color: #1dc9b7; }
        .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item[data-ktwizard-state="done"] span {
          display: none; }
        .kt-wizard-v3 .kt-wizard-v3__nav .kt-wizard-v3__nav-items .kt-wizard-v3__nav-item[data-ktwizard-state="done"] i {
          display: flex;
          background-color: #1dc9b7;
          color: #ffffff; }

.kt-wizard-v3 .kt-form {
  padding: 2rem 4rem 4rem; }
  @media (max-width: 576px) {
    .kt-wizard-v3 .kt-form {
      padding: 2rem 1rem 4rem; } }
  .kt-wizard-v3 .kt-form .kt-wizard-v3__content {
    padding-bottom: 1.3rem;
    border-bottom: 1px solid #eeeef4;
    margin: 0 auto 2rem;
    width: 630px; }
    @media (max-width: 1399px) {
      .kt-wizard-v3 .kt-form .kt-wizard-v3__content {
        width: 100%;
        margin: 0 0 1.5rem 0; } }
  .kt-wizard-v3 .kt-form .kt-form__actions {
    display: flex;
    flex-direction: row;
    justify-content: space-between;
    width: 630px;
    margin: 0 auto; }
    @media (max-width: 1399px) {
      .kt-wizard-v3 .kt-form .kt-form__actions {
        width: 100%;
        margin: 0; } }
    @media (max-width: 576px) {
      .kt-wizard-v3 .kt-form .kt-form__actions {
        flex-wrap: wrap;
        justify-content: center; } }
    @media (max-width: 576px) {
      .kt-wizard-v3 .kt-form .kt-form__actions .btn {
        margin: 0 0.5rem 1rem; } }
    .kt-wizard-v3 .kt-form .kt-form__actions [data-ktwizard-type="action-prev"] {
      margin-right: auto; }
      @media (max-width: 576px) {
        .kt-wizard-v3 .kt-form .kt-form__actions [data-ktwizard-type="action-prev"] {
          margin-right: 0.5rem; } }
    .kt-wizard-v3 .kt-form .kt-form__actions [data-ktwizard-type="action-next"] {
      margin: auto 0 auto auto; }
      @media (max-width: 576px) {
        .kt-wizard-v3 .kt-form .kt-form__actions [data-ktwizard-type="action-next"] {
          margin: 0 0 1rem; } }

.kt-wizard-v3 [data-ktwizard-type="step-info"] {
  display: none; }
  .kt-wizard-v3 [data-ktwizard-type="step-info"][data-ktwizard-state="current"] {
    display: block; }

.kt-wizard-v3 [data-ktwizard-type="step-content"] {
  display: none; }
  .kt-wizard-v3 [data-ktwizard-type="step-content"][data-ktwizard-state="current"] {
    display: block; }

.kt-wizard-v3 [data-ktwizard-type="action-prev"] {
  display: none; }

.kt-wizard-v3 [data-ktwizard-type="action-next"] {
  display: inline-block; }

.kt-wizard-v3 [data-ktwizard-type="action-submit"] {
  display: none; }

.kt-wizard-v3[data-ktwizard-state="first"] [data-ktwizard-type="action-prev"] {
  display: none; }

.kt-wizard-v3[data-ktwizard-state="first"] [data-ktwizard-type="action-next"] {
  display: inline-block; }

.kt-wizard-v3[data-ktwizard-state="first"] [data-ktwizard-type="action-submit"] {
  display: none; }

.kt-wizard-v3[data-ktwizard-state="between"] [data-ktwizard-type="action-prev"] {
  display: inline-block; }

.kt-wizard-v3[data-ktwizard-state="between"] [data-ktwizard-type="action-next"] {
  display: inline-block; }

.kt-wizard-v3[data-ktwizard-state="between"] [data-ktwizard-type="action-submit"] {
  display: none; }

.kt-wizard-v3[data-ktwizard-state="last"] [data-ktwizard-type="action-prev"] {
  display: inline-block; }

.kt-wizard-v3[data-ktwizard-state="last"] [data-ktwizard-type="action-next"] {
  display: none; }

.kt-wizard-v3[data-ktwizard-state="last"] [data-ktwizard-type="action-submit"] {
  display: inline-block; }

@media (min-width: 1400px) {
  .kt-wizard-v3 .kt-wizard-v3__aside {
    width: 400px;
    border-right: 1px solid #eeeef4;
    padding: 1.5rem; }
  .kt-wizard-v3 .kt-wizard-v3__wrapper {
    padding: 1.5rem; } }

@media (min-width: 1025px) and (max-width: 1399px) {
  .kt-wizard-v3 .kt-wizard-v3__aside {
    border-bottom: 1px solid #eeeef4;
    padding: 1rem; }
  .kt-wizard-v3 .kt-wizard-v3__wrapper {
    padding: 1rem; } }

@media (max-width: 1024px) {
  .kt-wizard-v3 .kt-wizard-v3__aside {
    padding: 1rem; }
  .kt-wizard-v3 .kt-wizard-v3__wrapper {
    padding: 1rem; } }

