.kt-invoice-1 {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px; }
  .kt-invoice-1 .kt-invoice__container {
    width: 100%;
    margin: 0;
    padding: 0 30px; }
  .kt-invoice-1 .kt-invoice__head {
    background-size: cover;
    background-repeat: no-repeat;
    padding: 8rem 0;
    border-top-left-radius: 4px;
    border-top-right-radius: 4px;
    background-size: cover;
    background-position: center; }
    .kt-invoice-1 .kt-invoice__head .kt-invoice__brand {
      margin-bottom: 5rem;
      border-bottom: 1px solid rgba(255, 255, 255, 0.11); }
      .kt-invoice-1 .kt-invoice__head .kt-invoice__brand .kt-invoice__title {
        font-size: 5.5rem;
        font-weight: 700;
        margin-bottom: 5rem;
        color: #ffffff;
        text-align: center; }
      .kt-invoice-1 .kt-invoice__head .kt-invoice__brand .kt-invoice__logo {
        display: flex;
        padding-bottom: 5rem;
        justify-content: center;
        align-items: center; }
        .kt-invoice-1 .kt-invoice__head .kt-invoice__brand .kt-invoice__logo img {
          display: block;
          width: 9rem;
          margin-right: 2rem; }
        .kt-invoice-1 .kt-invoice__head .kt-invoice__brand .kt-invoice__logo .kt-invoice__desc {
          color: #aaabf7;
          font-size: 1.25rem;
          font-weight: 500;
          display: flex;
          flex-direction: column; }
    .kt-invoice-1 .kt-invoice__head .kt-invoice__items {
      display: flex;
      flex-wrap: wrap;
      align-items: center;
      justify-content: space-between; }
      .kt-invoice-1 .kt-invoice__head .kt-invoice__items .kt-invoice__item .kt-invoice__subtitle {
        font-weight: 700;
        font-size: 1.25rem;
        color: #ffffff;
        margin-bottom: 1.25rem; }
      .kt-invoice-1 .kt-invoice__head .kt-invoice__items .kt-invoice__item .kt-invoice__desc {
        display: flex;
        flex-direction: column;
        color: #aaabf7;
        font-size: 1.25rem;
        font-weight: 500;
        padding-top: 1.5rem; }
      .kt-invoice-1 .kt-invoice__head .kt-invoice__items .kt-invoice__item .kt-invoice__text {
        color: #aaabf7;
        font-size: 1.25rem;
        font-weight: 500; }
      .kt-invoice-1 .kt-invoice__head .kt-invoice__items .kt-invoice__item .kt-invoice__info .kt-invoice__text {
        float: right;
        padding-left: 4rem; }
      .kt-invoice-1 .kt-invoice__head .kt-invoice__items .kt-invoice__item .kt-invoice__info:last-child {
        padding-top: 1.7rem; }
      .kt-invoice-1 .kt-invoice__head .kt-invoice__items .kt-invoice__item:first-child {
        margin-right: 1rem; }
  .kt-invoice-1 .kt-invoice__body {
    padding: 4rem 0; }
    .kt-invoice-1 .kt-invoice__body table {
      background-color: transparent; }
      .kt-invoice-1 .kt-invoice__body table thead tr th {
        background-color: transparent;
        padding: 1rem 1rem 0.5rem 0;
        border-top: none;
        color: #595d6e;
        border-bottom: 1px solid #eaebec;
        font-weight: 500; }
        .kt-invoice-1 .kt-invoice__body table thead tr th:not(:first-child) {
          text-align: right; }
        .kt-invoice-1 .kt-invoice__body table thead tr th:last-child {
          padding-right: 0; }
      .kt-invoice-1 .kt-invoice__body table tbody tr td {
        background-color: transparent;
        padding: 1rem 1rem 1rem 0;
        border-top: none;
        font-weight: 700;
        font-size: 1.1rem;
        color: #595d6e; }
        .kt-invoice-1 .kt-invoice__body table tbody tr td:not(:first-child) {
          text-align: right; }
        .kt-invoice-1 .kt-invoice__body table tbody tr td:last-child {
          color: #385aeb;
          font-size: 1.2rem;
          padding-right: 0; }
      .kt-invoice-1 .kt-invoice__body table tbody tr:first-child td {
        padding-top: 1.8rem; }
  .kt-invoice-1 .kt-invoice__footer {
    padding: 3rem 0; }
    .kt-invoice-1 .kt-invoice__footer .kt-invoice__container {
      display: flex;
      flex-direction: row;
      justify-content: space-between;
      flex-wrap: wrap; }
    .kt-invoice-1 .kt-invoice__footer .kt-invoice__bank {
      margin-right: 10px;
      display: flex;
      flex-direction: column;
      flex-wrap: wrap; }
      .kt-invoice-1 .kt-invoice__footer .kt-invoice__bank .kt-invoice__title {
        font-size: 1.2rem;
        text-transform: capitalize;
        font-weight: 600;
        color: #74788d; }
      .kt-invoice-1 .kt-invoice__footer .kt-invoice__bank .kt-invoice__item {
        display: flex;
        flex-wrap: wrap;
        justify-content: space-between;
        margin-top: 10px; }
        .kt-invoice-1 .kt-invoice__footer .kt-invoice__bank .kt-invoice__item .kt-invoice__label {
          font-size: 1.1rem;
          font-weight: 500;
          margin-right: 40px;
          color: #595d6e;
          text-align: left; }
        .kt-invoice-1 .kt-invoice__footer .kt-invoice__bank .kt-invoice__item .kt-invoice__value {
          font-size: 1.1rem;
          font-weight: 400;
          color: #74788d;
          text-align: right; }
        .kt-invoice-1 .kt-invoice__footer .kt-invoice__bank .kt-invoice__item:first-child {
          margin-right: 1rem; }
    .kt-invoice-1 .kt-invoice__footer .kt-invoice__total {
      display: flex;
      flex-direction: column;
      text-align: right; }
      .kt-invoice-1 .kt-invoice__footer .kt-invoice__total .kt-invoice__title {
        font-size: 1.2rem;
        text-transform: capitalize;
        font-weight: 600;
        color: #74788d; }
      .kt-invoice-1 .kt-invoice__footer .kt-invoice__total .kt-invoice__price {
        color: #385aeb;
        font-weight: 700;
        font-size: 24px; }
      .kt-invoice-1 .kt-invoice__footer .kt-invoice__total .kt-invoice__notice {
        font-size: 1rem;
        font-weight: 500;
        color: #74788d; }
  .kt-invoice-1 .kt-invoice__actions {
    padding: 2rem 0;
    background-color: #f7f8fa; }
    .kt-invoice-1 .kt-invoice__actions .kt-invoice__container {
      display: flex;
      flex-direction: row;
      justify-content: space-between; }

@media (min-width: 1025px) {
  .kt-invoice-1 .kt-invoice__container {
    width: 80%;
    margin: 0 auto; } }

@media (max-width: 1024px) {
  .kt-invoice-1 .kt-invoice__head {
    padding: 3rem 0; }
    .kt-invoice-1 .kt-invoice__head .kt-invoice__container {
      width: 100%;
      margin: 0;
      padding: 40px 20px; }
    .kt-invoice-1 .kt-invoice__head .kt-invoice__brand .kt-invoice__title {
      font-size: 4rem; }
    .kt-invoice-1 .kt-invoice__head .kt-invoice__items .kt-invoice__item:last-child {
      padding-top: 2rem; }
  .kt-invoice-1 .kt-invoice__body {
    padding: 30px 20px; }
  .kt-invoice-1 .kt-invoice__footer {
    padding: 20px; }
    .kt-invoice-1 .kt-invoice__footer .kt-invoice__container {
      flex-direction: column; }
    .kt-invoice-1 .kt-invoice__footer .kt-invoice__bank {
      margin-right: 0; }
      .kt-invoice-1 .kt-invoice__footer .kt-invoice__bank .kt-invoice__item .kt-invoice__label {
        margin-right: 20px; }
    .kt-invoice-1 .kt-invoice__footer .kt-invoice__total {
      margin-top: 30px;
      text-align: left; }
  .kt-invoice-1 .kt-invoice__actions {
    padding: 2rem 20px; }
    .kt-invoice-1 .kt-invoice__actions .kt-invoice__container {
      display: flex;
      flex-direction: row;
      justify-content: space-between; } }

@media print {
  .kt-header,
  .kt-header-mobile,
  .kt-aside,
  .kt-aside-secondary,
  .kt-footer,
  .kt-subheader,
  .kt-scrolltop,
  .kt-quick-panel,
  .kt-demo-panel,
  .kt-sticky-toolbar {
    display: none !important; }
  body,
  .kt-wrapper,
  .kt-body,
  .kt-content {
    background: transparent !important;
    padding: 0 !important;
    margin: 0 !important; }
  .kt-invoice-1 {
    border-top-left-radius: 0;
    border-top-right-radius: 0; }
    .kt-invoice-1 .kt-invoice__head {
      border-top-left-radius: 0;
      border-top-right-radius: 0; }
      .kt-invoice-1 .kt-invoice__head .kt-invoice__container {
        border-top-left-radius: 0;
        border-top-right-radius: 0; }
    .kt-invoice-1 .kt-invoice__actions {
      display: none !important; }
    .kt-invoice-1 .kt-invoice__container {
      width: 100%;
      padding: 0 10px; } }

