
    <div>{{ percentage }} %</div>
    <div>
        <div class="progress">
            <div class="progress-bar
             {% if not color %}
         {% if percentage > 80 %}
         bg-success
         {% elif percentage > 50 %}
         bg-info
         {% elif percentage > 25 %}
         bg-warning
         {% else %}
         bg-danger
         {% endif %}
     {% else %}
        {{ color }}
     {% endif %}
" role="progressbar"
                 style="width: {{ percentage }}%;" aria-valuenow="{{ percentage }}"
                 aria-valuemin="0" aria-valuemax="100"></div>
        </div>
    </div>
