.kt-invoice-2 {
  border-top-left-radius: 4px;
  border-top-right-radius: 4px; }
  .kt-invoice-2 .kt-invoice__container {
    width: 100%;
    margin: 0;
    padding: 0 30px; }
  .kt-invoice-2 .kt-invoice__head {
    border-top-left-radius: 4px;
    border-top-right-radius: 4px;
    background-size: cover;
    background-repeat: no-repeat;
    padding: 80px 0; }
    .kt-invoice-2 .kt-invoice__head .kt-invoice__container {
      border-top-left-radius: 4px;
      border-top-right-radius: 4px; }
    .kt-invoice-2 .kt-invoice__head .kt-invoice__brand {
      display: flex;
      justify-content: space-between;
      flex-wrap: wrap; }
      .kt-invoice-2 .kt-invoice__head .kt-invoice__brand .kt-invoice__title {
        font-weight: 700;
        font-size: 3rem;
        margin-right: 10px;
        margin-top: 5px;
        color: #48465b;
        vertical-align: top; }
      .kt-invoice-2 .kt-invoice__head .kt-invoice__brand .kt-invoice__logo {
        display: flex;
        flex-direction: column;
        margin-top: 5px;
        text-align: right; }
        .kt-invoice-2 .kt-invoice__head .kt-invoice__brand .kt-invoice__logo img {
          text-align: right;
          width: 9rem; }
        .kt-invoice-2 .kt-invoice__head .kt-invoice__brand .kt-invoice__logo .kt-invoice__desc {
          display: flex;
          flex-direction: column;
          text-align: right;
          font-weight: 400;
          padding: 1rem 0 1rem 0;
          color: #74788d; }
    .kt-invoice-2 .kt-invoice__head .kt-invoice__items {
      display: flex;
      flex-wrap: wrap;
      justify-content: space-between;
      margin-top: 50px;
      width: 100%;
      border-top: 1px solid #ebedf2; }
      .kt-invoice-2 .kt-invoice__head .kt-invoice__items .kt-invoice__item {
        color: #595d6e;
        margin-right: 10px;
        margin-top: 20px; }
        .kt-invoice-2 .kt-invoice__head .kt-invoice__items .kt-invoice__item:last-child {
          margin-right: 0; }
        .kt-invoice-2 .kt-invoice__head .kt-invoice__items .kt-invoice__item .kt-invoice__subtitle {
          font-weight: 500;
          padding-bottom: 0.5rem; }
        .kt-invoice-2 .kt-invoice__head .kt-invoice__items .kt-invoice__item .kt-invoice__text {
          font-weight: 400;
          color: #74788d; }
        .kt-invoice-2 .kt-invoice__head .kt-invoice__items .kt-invoice__item span {
          display: block; }
  .kt-invoice-2 .kt-invoice__body {
    padding: 3rem 0; }
    .kt-invoice-2 .kt-invoice__body table {
      background-color: transparent; }
      .kt-invoice-2 .kt-invoice__body table thead tr td {
        background-color: transparent;
        padding: 1rem 1rem 0.5rem 0;
        color: #74788d;
        border-top: 0;
        border-bottom: 1px solid #ebedf2; }
        .kt-invoice-2 .kt-invoice__body table thead tr td:not(:first-child) {
          text-align: right; }
        .kt-invoice-2 .kt-invoice__body table thead tr td:last-child {
          padding-right: 0; }
      .kt-invoice-2 .kt-invoice__body table tbody tr td {
        background-color: transparent;
        padding: 1rem 1rem 1rem 0;
        border-top: none;
        font-weight: 700;
        font-size: 1.1rem;
        color: #595d6e; }
        .kt-invoice-2 .kt-invoice__body table tbody tr td:not(:first-child) {
          text-align: right; }
        .kt-invoice-2 .kt-invoice__body table tbody tr td:last-child {
          padding-right: 0; }
      .kt-invoice-2 .kt-invoice__body table tbody tr:first-child td {
        padding-top: 1.8rem; }
  .kt-invoice-2 .kt-invoice__footer {
    padding: 3rem 0;
    background-color: #f7f8fa; }
    .kt-invoice-2 .kt-invoice__footer .kt-invoice__container {
      display: flex;
      flex-direction: row;
      justify-content: space-between;
      flex-wrap: wrap; }
    .kt-invoice-2 .kt-invoice__footer .table {
      background-color: transparent;
      padding: 0; }
      .kt-invoice-2 .kt-invoice__footer .table th {
        font-size: 1.1rem;
        text-transform: capitalize;
        font-weight: 500;
        color: #74788d;
        border-top: 0;
        border-bottom: 1px solid #ebedf2;
        padding: 10px 10px 10px 0;
        background-color: transparent; }
        .kt-invoice-2 .kt-invoice__footer .table th:last-child {
          padding-right: 0;
          text-align: right; }
      .kt-invoice-2 .kt-invoice__footer .table td {
        font-size: 1.1rem;
        text-transform: capitalize;
        background-color: transparent;
        font-weight: 500;
        color: #595d6e;
        padding: 10px 10px 10px 0; }
        .kt-invoice-2 .kt-invoice__footer .table td:last-child {
          padding-right: 0;
          text-align: right; }
  .kt-invoice-2 .kt-invoice__actions {
    padding: 2rem 0; }
    .kt-invoice-2 .kt-invoice__actions .kt-invoice__container {
      display: flex;
      flex-direction: row;
      justify-content: space-between; }
      .kt-invoice-2 .kt-invoice__actions .kt-invoice__container .btn:last-child {
        margin-left: 1rem; }

@media (min-width: 1025px) {
  .kt-invoice-2 .kt-invoice__container {
    width: 80%;
    margin: 0 auto; } }

@media (max-width: 768px) {
  .kt-invoice-2 .kt-invoice__container {
    width: 100%;
    margin: 0;
    padding: 0 20px; }
  .kt-invoice-2 .kt-invoice__head {
    padding: 20px 0; }
    .kt-invoice-2 .kt-invoice__head .kt-invoice__brand {
      display: flex;
      flex-direction: column; }
      .kt-invoice-2 .kt-invoice__head .kt-invoice__brand .kt-invoice__title {
        font-weight: 700;
        font-size: 2rem;
        margin-bottom: 30px; }
      .kt-invoice-2 .kt-invoice__head .kt-invoice__brand .kt-invoice__logo {
        text-align: left; }
        .kt-invoice-2 .kt-invoice__head .kt-invoice__brand .kt-invoice__logo img {
          text-align: left; }
        .kt-invoice-2 .kt-invoice__head .kt-invoice__brand .kt-invoice__logo .kt-invoice__desc {
          text-align: left; }
    .kt-invoice-2 .kt-invoice__head .kt-invoice__items {
      margin-top: 20px; }
  .kt-invoice-2 .kt-invoice__body {
    padding: 2rem 0; }
  .kt-invoice-2 .kt-invoice__footer {
    padding: 2rem 0; } }

@media print {
  .kt-header,
  .kt-header-mobile,
  .kt-aside,
  .kt-aside-secondary,
  .kt-footer,
  .kt-subheader,
  .kt-scrolltop,
  .kt-quick-panel,
  .kt-demo-panel,
  .kt-sticky-toolbar {
    display: none !important; }
  body,
  .kt-wrapper,
  .kt-body,
  .kt-content {
    background: transparent !important;
    padding: 0 !important;
    margin: 0 !important; }
  .kt-invoice-2 {
    border-top-left-radius: 0;
    border-top-right-radius: 0; }
    .kt-invoice-2 .kt-invoice__head {
      border-top-left-radius: 0;
      border-top-right-radius: 0; }
      .kt-invoice-2 .kt-invoice__head .kt-invoice__container {
        border-top-left-radius: 0;
        border-top-right-radius: 0; }
    .kt-invoice-2 .kt-invoice__actions {
      display: none !important; }
    .kt-invoice-2 .kt-invoice__footer {
      background-color: transparent !important; }
    .kt-invoice-2 .kt-invoice__container {
      width: 100%;
      padding: 0 10px; } }

