/******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, { enumerable: true, get: getter });
/******/ 		}
/******/ 	};
/******/
/******/ 	// define __esModule on exports
/******/ 	__webpack_require__.r = function(exports) {
/******/ 		if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 			Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 		}
/******/ 		Object.defineProperty(exports, '__esModule', { value: true });
/******/ 	};
/******/
/******/ 	// create a fake namespace object
/******/ 	// mode & 1: value is a module id, require it
/******/ 	// mode & 2: merge all properties of value into the ns
/******/ 	// mode & 4: return value when already ns object
/******/ 	// mode & 8|1: behave like require
/******/ 	__webpack_require__.t = function(value, mode) {
/******/ 		if(mode & 1) value = __webpack_require__(value);
/******/ 		if(mode & 8) return value;
/******/ 		if((mode & 4) && typeof value === 'object' && value && value.__esModule) return value;
/******/ 		var ns = Object.create(null);
/******/ 		__webpack_require__.r(ns);
/******/ 		Object.defineProperty(ns, 'default', { enumerable: true, value: value });
/******/ 		if(mode & 2 && typeof value != 'string') for(var key in value) __webpack_require__.d(ns, key, function(key) { return value[key]; }.bind(null, key));
/******/ 		return ns;
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = "../src/assets/js/pages/custom/inbox/inbox.js");
/******/ })
/************************************************************************/
/******/ ({

/***/ "../src/assets/js/pages/custom/inbox/inbox.js":
/*!****************************************************!*\
  !*** ../src/assets/js/pages/custom/inbox/inbox.js ***!
  \****************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\r\n\r\n// Class definition\r\nvar KTAppInbox = function() {\r\n    var asideEl = KTUtil.getByID('kt_inbox_aside');\r\n    var listEl = KTUtil.getByID('kt_inbox_list');\r\n    var viewEl = KTUtil.getByID('kt_inbox_view');\r\n    var composeEl = KTUtil.getByID('kt_inbox_compose');\r\n\r\n    var asideOffcanvas;\r\n\r\n    var initEditor = function(editor) {\r\n        // init editor\r\n        var options = {\r\n            modules: {\r\n                toolbar: {}\r\n            },\r\n            placeholder: 'Type message...',\r\n            theme: 'snow'\r\n        };\r\n\r\n        var editor = new Quill('#' + editor, options);\r\n    }\r\n\r\n    var initForm = function(formEl) {\r\n        var formEl = KTUtil.getByID(formEl);\r\n\r\n        // Init autocompletes\r\n        var toEl = KTUtil.find(formEl, '[name=compose_to]');\r\n        var tagifyTo = new Tagify(toEl, {\r\n            delimiters: \", \", // add new tags when a comma or a space character is entered\r\n            maxTags: 10,\r\n            blacklist: [\"fuck\", \"shit\", \"pussy\"],\r\n            keepInvalidTags: true, // do not remove invalid tags (but keep them marked as invalid)\r\n            whitelist: [{\r\n                value: 'Chris Muller',\r\n                email: 'chris.muller@wix.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_11.jpg',\r\n                class: 'tagify__tag--brand'\r\n            }, {\r\n                value: 'Nick Bold',\r\n                email: 'nick.seo@gmail.com',\r\n                initials: 'SS',\r\n                initialsState: 'warning',\r\n                pic: ''\r\n            }, {\r\n                value: 'Alon Silko',\r\n                email: 'alon@keenthemes.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_6.jpg'\r\n            }, {\r\n                value: 'Sam Seanic',\r\n                email: 'sam.senic@loop.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_8.jpg'\r\n            }, {\r\n                value: 'Sara Loran',\r\n                email: 'sara.loran@tilda.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_9.jpg'\r\n            }, {\r\n                value: 'Eric Davok',\r\n                email: 'davok@mix.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_13.jpg'\r\n            }, {\r\n                value: 'Sam Seanic',\r\n                email: 'sam.senic@loop.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_13.jpg'\r\n            }, {\r\n                value: 'Lina Nilson',\r\n                email: 'lina.nilson@loop.com',\r\n                initials: 'LN',\r\n                initialsState: 'danger',\r\n                pic: './assets/media/users/100_15.jpg'\r\n            }],\r\n            templates: {\r\n                dropdownItem: function(tagData) {\r\n                    try {\r\n                        var html = '';\r\n\r\n                        html += '<div class=\"tagify__dropdown__item\">';\r\n                        html += '   <div class=\"kt-media-card\">';\r\n                        html += '       <span class=\"kt-media kt-media--' + (tagData.initialsState ? tagData.initialsState : '') + '\" style=\"background-image: url(\\''+ (tagData.pic ? tagData.pic : '') + '\\')\">';\r\n                        html += '           <span>' + (tagData.initials ? tagData.initials : '') + '</span>';\r\n                        html += '       </span>';\r\n                        html += '       <div class=\"kt-media-card__info\">';\r\n                        html += '           <a href=\"#\" class=\"kt-media-card__title\">'+ (tagData.value ? tagData.value : '') + '</a>';\r\n                        html += '           <span class=\"kt-media-card__desc\">' + (tagData.email ? tagData.email : '') + '</span>';\r\n                        html += '       </div>';\r\n                        html += '   </div>';\r\n                        html += '</div>';\r\n\r\n                        return html;\r\n                    } catch (err) {}\r\n                }\r\n            },\r\n            transformTag: function(tagData) {\r\n                tagData.class = 'tagify__tag tagify__tag--brand';\r\n            },\r\n            dropdown: {\r\n                classname: \"color-blue\",\r\n                enabled: 1,\r\n                maxItems: 5\r\n            }\r\n        });\r\n\r\n        var ccEl = KTUtil.find(formEl, '[name=compose_cc]');\r\n        var tagifyC = new Tagify(ccEl, {\r\n            delimiters: \", \", // add new tags when a comma or a space character is entered\r\n            maxTags: 10,\r\n            blacklist: [\"fuck\", \"shit\", \"pussy\"],\r\n            keepInvalidTags: true, // do not remove invalid tags (but keep them marked as invalid)\r\n            whitelist: [{\r\n                value: 'Chris Muller',\r\n                email: 'chris.muller@wix.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_11.jpg',\r\n                class: 'tagify__tag--brand'\r\n            }, {\r\n                value: 'Nick Bold',\r\n                email: 'nick.seo@gmail.com',\r\n                initials: 'SS',\r\n                initialsState: 'warning',\r\n                pic: ''\r\n            }, {\r\n                value: 'Alon Silko',\r\n                email: 'alon@keenthemes.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_6.jpg'\r\n            }, {\r\n                value: 'Sam Seanic',\r\n                email: 'sam.senic@loop.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_8.jpg'\r\n            }, {\r\n                value: 'Sara Loran',\r\n                email: 'sara.loran@tilda.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_9.jpg'\r\n            }, {\r\n                value: 'Eric Davok',\r\n                email: 'davok@mix.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_13.jpg'\r\n            }, {\r\n                value: 'Sam Seanic',\r\n                email: 'sam.senic@loop.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_13.jpg'\r\n            }, {\r\n                value: 'Lina Nilson',\r\n                email: 'lina.nilson@loop.com',\r\n                initials: 'LN',\r\n                initialsState: 'danger',\r\n                pic: './assets/media/users/100_15.jpg'\r\n            }],\r\n            templates: {\r\n                dropdownItem: function(tagData) {\r\n                    try {\r\n                        var html = '';\r\n\r\n                        html += '<div class=\"tagify__dropdown__item\">';\r\n                        html += '   <div class=\"kt-media-card\">';\r\n                        html += '       <span class=\"kt-media kt-media--' + (tagData.initialsState ? tagData.initialsState : '') + '\" style=\"background-image: url(\\''+ (tagData.pic ? tagData.pic : '') + '\\')\">';\r\n                        html += '           <span>' + (tagData.initials ? tagData.initials : '') + '</span>';\r\n                        html += '       </span>';\r\n                        html += '       <div class=\"kt-media-card__info\">';\r\n                        html += '           <a href=\"#\" class=\"kt-media-card__title\">'+ (tagData.value ? tagData.value : '') + '</a>';\r\n                        html += '           <span class=\"kt-media-card__desc\">' + (tagData.email ? tagData.email : '') + '</span>';\r\n                        html += '       </div>';\r\n                        html += '   </div>';\r\n                        html += '</div>';\r\n\r\n                        return html;\r\n                    } catch (err) {}\r\n                }\r\n            },\r\n            transformTag: function(tagData) {\r\n                tagData.class = 'tagify__tag tagify__tag--brand';\r\n            },\r\n            dropdown: {\r\n                classname: \"color-blue\",\r\n                enabled: 1,\r\n                maxItems: 5\r\n            }\r\n        });\r\n\r\n        var bccEl = KTUtil.find(formEl, '[name=compose_bcc]');\r\n        var tagifyBcc = new Tagify(bccEl, {\r\n            delimiters: \", \", // add new tags when a comma or a space character is entered\r\n            maxTags: 10,\r\n            blacklist: [\"fuck\", \"shit\", \"pussy\"],\r\n            keepInvalidTags: true, // do not remove invalid tags (but keep them marked as invalid)\r\n            whitelist: [{\r\n                value: 'Chris Muller',\r\n                email: 'chris.muller@wix.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_11.jpg',\r\n                class: 'tagify__tag--brand'\r\n            }, {\r\n                value: 'Nick Bold',\r\n                email: 'nick.seo@gmail.com',\r\n                initials: 'SS',\r\n                initialsState: 'warning',\r\n                pic: ''\r\n            }, {\r\n                value: 'Alon Silko',\r\n                email: 'alon@keenthemes.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_6.jpg'\r\n            }, {\r\n                value: 'Sam Seanic',\r\n                email: 'sam.senic@loop.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_8.jpg'\r\n            }, {\r\n                value: 'Sara Loran',\r\n                email: 'sara.loran@tilda.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_9.jpg'\r\n            }, {\r\n                value: 'Eric Davok',\r\n                email: 'davok@mix.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_13.jpg'\r\n            }, {\r\n                value: 'Sam Seanic',\r\n                email: 'sam.senic@loop.com',\r\n                initials: '',\r\n                initialsState: '',\r\n                pic: './assets/media/users/100_13.jpg'\r\n            }, {\r\n                value: 'Lina Nilson',\r\n                email: 'lina.nilson@loop.com',\r\n                initials: 'LN',\r\n                initialsState: 'danger',\r\n                pic: './assets/media/users/100_15.jpg'\r\n            }],\r\n            templates: {\r\n                dropdownItem: function(tagData) {\r\n                    try {\r\n                        var html = '';\r\n\r\n                        html += '<div class=\"tagify__dropdown__item\">';\r\n                        html += '   <div class=\"kt-media-card\">';\r\n                        html += '       <span class=\"kt-media kt-media--' + (tagData.initialsState ? tagData.initialsState : '') + '\" style=\"background-image: url(\\''+ (tagData.pic ? tagData.pic : '') + '\\')\">';\r\n                        html += '           <span>' + (tagData.initials ? tagData.initials : '') + '</span>';\r\n                        html += '       </span>';\r\n                        html += '       <div class=\"kt-media-card__info\">';\r\n                        html += '           <a href=\"#\" class=\"kt-media-card__title\">'+ (tagData.value ? tagData.value : '') + '</a>';\r\n                        html += '           <span class=\"kt-media-card__desc\">' + (tagData.email ? tagData.email : '') + '</span>';\r\n                        html += '       </div>';\r\n                        html += '   </div>';\r\n                        html += '</div>';\r\n\r\n                        return html;\r\n                    } catch (err) {}\r\n                }\r\n            },\r\n            transformTag: function(tagData) {\r\n                tagData.class = 'tagify__tag tagify__tag--brand';\r\n            },\r\n            dropdown: {\r\n                classname: \"color-blue\",\r\n                enabled: 1,\r\n                maxItems: 5\r\n            }\r\n        });\r\n\r\n        // CC input display\r\n        KTUtil.on(formEl, '.kt-inbox__to .kt-inbox__tool.kt-inbox__tool--cc', 'click', function(e) {\r\n            var inputEl = KTUtil.find(formEl, '.kt-inbox__to');\r\n            KTUtil.addClass(inputEl, 'kt-inbox__to--cc');\r\n            KTUtil.find(formEl, \"[name=compose_cc]\").focus();\r\n        });\r\n\r\n        // CC input hide\r\n        KTUtil.on(formEl, '.kt-inbox__to .kt-inbox__field.kt-inbox__field--cc .kt-inbox__icon--delete', 'click', function(e) {\r\n            var inputEl = KTUtil.find(formEl, '.kt-inbox__to');\r\n            KTUtil.removeClass(inputEl, 'kt-inbox__to--cc');\r\n        });\r\n\r\n        // BCC input display\r\n        KTUtil.on(formEl, '.kt-inbox__to .kt-inbox__tool.kt-inbox__tool--bcc', 'click', function(e) {\r\n            var inputEl = KTUtil.find(formEl, '.kt-inbox__to');\r\n            KTUtil.addClass(inputEl, 'kt-inbox__to--bcc');\r\n            KTUtil.find(formEl, \"[name=compose_bcc]\").focus();\r\n        });\r\n\r\n        // BCC input hide\r\n        KTUtil.on(formEl, '.kt-inbox__to .kt-inbox__field.kt-inbox__field--bcc .kt-inbox__icon--delete', 'click', function(e) {\r\n            var inputEl = KTUtil.find(formEl, '.kt-inbox__to');\r\n            KTUtil.removeClass(inputEl, 'kt-inbox__to--bcc');\r\n        });\r\n    }\r\n\r\n    var initAttachments = function(elemId) {\r\n        var id = \"#\" + elemId;\r\n        var previewNode = $(id + \" .dropzone-item\");\r\n        previewNode.id = \"\";\r\n        var previewTemplate = previewNode.parent('.dropzone-items').html();\r\n        previewNode.remove();\r\n\r\n        var myDropzone = new Dropzone(id, { // Make the whole body a dropzone\r\n            url: \"https://keenthemes.com/scripts/void.php\", // Set the url for your upload script location\r\n            parallelUploads: 20,\r\n            maxFilesize: 1, // Max filesize in MB\r\n            previewTemplate: previewTemplate,\r\n            previewsContainer: id + \" .dropzone-items\", // Define the container to display the previews\r\n            clickable: id + \"_select\" // Define the element that should be used as click trigger to select files.\r\n        });\r\n\r\n        myDropzone.on(\"addedfile\", function(file) {\r\n            // Hookup the start button\r\n            $(document).find(id + ' .dropzone-item').css('display', '');\r\n        });\r\n\r\n        // Update the total progress bar\r\n        myDropzone.on(\"totaluploadprogress\", function(progress) {\r\n            document.querySelector(id + \" .progress-bar\").style.width = progress + \"%\";\r\n        });\r\n\r\n        myDropzone.on(\"sending\", function(file) {\r\n            // Show the total progress bar when upload starts\r\n            document.querySelector(id + \" .progress-bar\").style.opacity = \"1\";\r\n        });\r\n\r\n        // Hide the total progress bar when nothing's uploading anymore\r\n        myDropzone.on(\"complete\", function(progress) {\r\n            var thisProgressBar = id + \" .dz-complete\";\r\n            setTimeout(function() {\r\n                $(thisProgressBar + \" .progress-bar, \" + thisProgressBar + \" .progress\").css('opacity', '0');\r\n            }, 300)\r\n        });\r\n    }\r\n\r\n    return {\r\n        // public functions\r\n        init: function() {\r\n            // init\r\n            KTAppInbox.initAside();\r\n            KTAppInbox.initList();\r\n            KTAppInbox.initView();\r\n            KTAppInbox.initReply();\r\n            KTAppInbox.initCompose();\r\n        },\r\n\r\n        initAside: function() {\r\n            // Mobile offcanvas for mobile mode\r\n            asideOffcanvas = new KTOffcanvas(asideEl, {\r\n                overlay: true,\r\n                baseClass: 'kt-inbox__aside',\r\n                closeBy: 'kt_inbox_aside_close',\r\n                toggleBy: 'kt_subheader_mobile_toggle'\r\n            });\r\n\r\n            // View list\r\n            KTUtil.on(asideEl, '.kt-nav__item .kt-nav__link[data-action=\"list\"]', 'click', function(e) {\r\n                var type = KTUtil.attr(this, 'data-type');\r\n                var listItemsEl = KTUtil.find(listEl, '.kt-inbox__items');\r\n                var navItemEl = this.closest('.kt-nav__item');\r\n                var navItemActiveEl = KTUtil.find(asideEl, '.kt-nav__item.kt-nav__item--active');\r\n\r\n                // demo loading\r\n                var loading = new KTDialog({\r\n                    'type': 'loader',\r\n                    'placement': 'top center',\r\n                    'message': 'Loading ...'\r\n                });\r\n                loading.show();\r\n\r\n                setTimeout(function() {\r\n                    loading.hide();\r\n\r\n                    KTUtil.css(listEl, 'display', 'flex'); // show list\r\n                    KTUtil.css(viewEl, 'display', 'none'); // hide view\r\n\r\n                    KTUtil.addClass(navItemEl, 'kt-nav__item--active');\r\n                    KTUtil.removeClass(navItemActiveEl, 'kt-nav__item--active');\r\n\r\n                    KTUtil.attr(listItemsEl, 'data-type', type);\r\n                }, 600);\r\n            });\r\n        },\r\n\r\n        initList: function() {\r\n            // View message\r\n            KTUtil.on(listEl, '.kt-inbox__item', 'click', function(e) {\r\n                var actionsEl = KTUtil.find(this, '.kt-inbox__actions');\r\n\r\n                // skip actions click\r\n                if (e.target === actionsEl || (actionsEl && actionsEl.contains(e.target) === true)) {\r\n                    return false;\r\n                }\r\n\r\n                // demo loading\r\n                var loading = new KTDialog({\r\n                    'type': 'loader',\r\n                    'placement': 'top center',\r\n                    'message': 'Loading ...'\r\n                });\r\n                loading.show();\r\n\r\n                setTimeout(function() {\r\n                    loading.hide();\r\n\r\n                    KTUtil.css(listEl, 'display', 'none');\r\n                    KTUtil.css(viewEl, 'display', 'flex');\r\n                }, 800);\r\n            });\r\n\r\n            // Group selection\r\n            KTUtil.on(listEl, '.kt-inbox__toolbar .kt-inbox__check .kt-checkbox input', 'click', function() {\r\n                var items = KTUtil.findAll(listEl, '.kt-inbox__items .kt-inbox__item');\r\n\r\n                for (var i = 0, j = items.length; i < j; i++) {\r\n                    var item = items[i];\r\n                    var checkbox = KTUtil.find(item, '.kt-inbox__actions .kt-checkbox input');\r\n                    checkbox.checked = this.checked;\r\n\r\n                    if (this.checked) {\r\n                        KTUtil.addClass(item, 'kt-inbox__item--selected');\r\n                    } else {\r\n                        KTUtil.removeClass(item, 'kt-inbox__item--selected');\r\n                    }\r\n                }\r\n            });\r\n\r\n            // Individual selection\r\n            KTUtil.on(listEl, '.kt-inbox__item .kt-checkbox input', 'click', function() {\r\n                var item = this.closest('.kt-inbox__item');\r\n\r\n                if (item && this.checked) {\r\n                    KTUtil.addClass(item, 'kt-inbox__item--selected');\r\n                } else {\r\n                    KTUtil.removeClass(item, 'kt-inbox__item--selected');\r\n                }\r\n            });\r\n        },\r\n\r\n        initView: function() {\r\n            // Back to listing\r\n            KTUtil.on(viewEl, '.kt-inbox__toolbar .kt-inbox__icon.kt-inbox__icon--back', 'click', function() {\r\n                // demo loading\r\n                var loading = new KTDialog({\r\n                    'type': 'loader',\r\n                    'placement': 'top center',\r\n                    'message': 'Loading ...'\r\n                });\r\n                loading.show();\r\n\r\n                setTimeout(function() {\r\n                    loading.hide();\r\n\r\n                    KTUtil.css(listEl, 'display', 'flex');\r\n                    KTUtil.css(viewEl, 'display', 'none');\r\n                }, 1000);\r\n            });\r\n\r\n            // Expand/Collapse reply\r\n            KTUtil.on(viewEl, '.kt-inbox__messages .kt-inbox__message .kt-inbox__head', 'click', function(e) {\r\n                var dropdownToggleEl = KTUtil.find(this, '.kt-inbox__details .kt-inbox__tome .kt-inbox__label');\r\n                var groupActionsEl = KTUtil.find(this, '.kt-inbox__actions .kt-inbox__group');\r\n\r\n                // skip dropdown toggle click\r\n                if (e.target === dropdownToggleEl || (dropdownToggleEl && dropdownToggleEl.contains(e.target) === true)) {\r\n                    return false;\r\n                }\r\n\r\n                // skip group actions click\r\n                if (e.target === groupActionsEl || (groupActionsEl && groupActionsEl.contains(e.target) === true)) {\r\n                    return false;\r\n                }\r\n\r\n                var message = this.closest('.kt-inbox__message');\r\n\r\n                if (KTUtil.hasClass(message, 'kt-inbox__message--expanded')) {\r\n                    KTUtil.removeClass(message, 'kt-inbox__message--expanded');\r\n                } else {\r\n                    KTUtil.addClass(message, 'kt-inbox__message--expanded');\r\n                }\r\n            });\r\n        },\r\n\r\n        initReply: function() {\r\n            initEditor('kt_inbox_reply_editor');\r\n            initAttachments('kt_inbox_reply_attachments');\r\n            initForm('kt_inbox_reply_form');\r\n\r\n            // Show/Hide reply form\r\n            KTUtil.on(viewEl, '.kt-inbox__reply .kt-inbox__actions .btn', 'click', function(e) {\r\n                var reply = this.closest('.kt-inbox__reply');\r\n\r\n                if (KTUtil.hasClass(reply, 'kt-inbox__reply--on')) {\r\n                    KTUtil.removeClass(reply, 'kt-inbox__reply--on');\r\n                } else {\r\n                    KTUtil.addClass(reply, 'kt-inbox__reply--on');\r\n                }\r\n            });\r\n\r\n            // Show reply form for messages\r\n            KTUtil.on(viewEl, '.kt-inbox__message .kt-inbox__actions .kt-inbox__group .kt-inbox__icon.kt-inbox__icon--reply', 'click', function(e) {\r\n                var reply = KTUtil.find(viewEl, '.kt-inbox__reply');\r\n                KTUtil.addClass(reply, 'kt-inbox__reply--on');\r\n            });\r\n\r\n            // Remove reply form\r\n            KTUtil.on(viewEl, '.kt-inbox__reply .kt-inbox__foot .kt-inbox__icon--remove', 'click', function(e) {\r\n                var reply = this.closest('.kt-inbox__reply');\r\n\r\n                swal.fire({\r\n                    text: \"Are you sure to discard this reply ?\",\r\n                    //type: \"error\",\r\n                    buttonsStyling: false,\r\n\r\n                    confirmButtonText: \"Discard reply\",\r\n                    confirmButtonClass: \"btn btn-danger\",\r\n\r\n                    showCancelButton: true,\r\n                    cancelButtonText: \"Cancel\",\r\n                    cancelButtonClass: \"btn btn-label-brand\"\r\n                }).then(function(result) {\r\n                    if (KTUtil.hasClass(reply, 'kt-inbox__reply--on')) {\r\n                        KTUtil.removeClass(reply, 'kt-inbox__reply--on');\r\n                    }\r\n                });\r\n            });\r\n        },\r\n\r\n        initCompose: function() {\r\n            initEditor('kt_inbox_compose_editor');\r\n            initAttachments('kt_inbox_compose_attachments');\r\n            initForm('kt_inbox_compose_form');\r\n\r\n            // Remove reply form\r\n            KTUtil.on(composeEl, '.kt-inbox__form .kt-inbox__foot .kt-inbox__secondary .kt-inbox__icon.kt-inbox__icon--remove', 'click', function(e) {\r\n                swal.fire({\r\n                    text: \"Are you sure to discard this message ?\",\r\n                    type: \"danger\",\r\n                    buttonsStyling: false,\r\n\r\n                    confirmButtonText: \"Discard draft\",\r\n                    confirmButtonClass: \"btn btn-danger\",\r\n\r\n                    showCancelButton: true,\r\n                    cancelButtonText: \"Cancel\",\r\n                    cancelButtonClass: \"btn btn-label-brand\"\r\n                }).then(function(result) {\r\n                    $(composeEl).modal('hide');\r\n                });\r\n            });\r\n        }\r\n    };\r\n}();\r\n\r\nKTUtil.ready(function() {\r\n    KTAppInbox.init();\r\n});\r\n\n\n//# sourceURL=webpack:///../src/assets/js/pages/custom/inbox/inbox.js?");

/***/ })

/******/ });