<div class="kt-widget__cont">
    <div class="kt-widget__stat">
        <span class="kt-widget__caption">{{ label }}</span>
        <span class="kt-widget__value">{{ percentage }} % </span>
    </div>
    <div class="progress mr-3">
        <div class="progress-bar progress-sm
        {% if not color %}
         {% if percentage > 80 %}
         bg-success
         {% elif percentage > 50 %}
         bg-info
         {% elif percentage > 25 %}
         bg-warning
         {% else %}
         bg-danger
         {% endif %}
     {% else %}
        {{ color }}
     {% endif %}" role="progressbar"
             style="width: {{ percentage }}%" aria-valuenow="{{ percentage }}" aria-valuemin="0"
             aria-valuemax="100"></div>
    </div>
</div>