.kt-error404-v3--enabled {
  background-size: cover;
  background-position: center;
  background-repeat: no-repeat; }

.kt-error404-v3 {
  display: flex;
  flex: 1;
  justify-content: center;
  align-items: flex-end; }
  @media (max-width: 768px) {
    .kt-error404-v3 {
      padding: 2rem; } }
  .kt-error404-v3 .kt-error404-v3__content {
    margin-bottom: 7rem;
    display: flex;
    justify-content: center;
    flex-direction: column;
    align-items: center;
    text-align: center; }
    .kt-error404-v3 .kt-error404-v3__content .kt-error404-v3__title {
      font-size: 2rem;
      color: #ffffff;
      font-weight: 400;
      margin-bottom: 3rem; }
    .kt-error404-v3 .kt-error404-v3__content .kt-error404-v3__button {
      color: #ffffff;
      background-color: #f7098f; }
      .kt-error404-v3 .kt-error404-v3__content .kt-error404-v3__button:hover {
        color: #ffffff; }

.kt-bg-error404-v3 {
  background-image: url(../../../media/404-bg3.jpg); }
  @media (max-width: 768px) {
    .kt-bg-error404-v3 {
      background-image: url(../../../media/bg-mobile-3.jpg); } }

