/******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId]) {
/******/ 			return installedModules[moduleId].exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			i: moduleId,
/******/ 			l: false,
/******/ 			exports: {}
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.l = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// define getter function for harmony exports
/******/ 	__webpack_require__.d = function(exports, name, getter) {
/******/ 		if(!__webpack_require__.o(exports, name)) {
/******/ 			Object.defineProperty(exports, name, { enumerable: true, get: getter });
/******/ 		}
/******/ 	};
/******/
/******/ 	// define __esModule on exports
/******/ 	__webpack_require__.r = function(exports) {
/******/ 		if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 			Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 		}
/******/ 		Object.defineProperty(exports, '__esModule', { value: true });
/******/ 	};
/******/
/******/ 	// create a fake namespace object
/******/ 	// mode & 1: value is a module id, require it
/******/ 	// mode & 2: merge all properties of value into the ns
/******/ 	// mode & 4: return value when already ns object
/******/ 	// mode & 8|1: behave like require
/******/ 	__webpack_require__.t = function(value, mode) {
/******/ 		if(mode & 1) value = __webpack_require__(value);
/******/ 		if(mode & 8) return value;
/******/ 		if((mode & 4) && typeof value === 'object' && value && value.__esModule) return value;
/******/ 		var ns = Object.create(null);
/******/ 		__webpack_require__.r(ns);
/******/ 		Object.defineProperty(ns, 'default', { enumerable: true, value: value });
/******/ 		if(mode & 2 && typeof value != 'string') for(var key in value) __webpack_require__.d(ns, key, function(key) { return value[key]; }.bind(null, key));
/******/ 		return ns;
/******/ 	};
/******/
/******/ 	// getDefaultExport function for compatibility with non-harmony modules
/******/ 	__webpack_require__.n = function(module) {
/******/ 		var getter = module && module.__esModule ?
/******/ 			function getDefault() { return module['default']; } :
/******/ 			function getModuleExports() { return module; };
/******/ 		__webpack_require__.d(getter, 'a', getter);
/******/ 		return getter;
/******/ 	};
/******/
/******/ 	// Object.prototype.hasOwnProperty.call
/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(__webpack_require__.s = "./webpack/vendors/custom/fullcalendar.js");
/******/ })
/************************************************************************/
/******/ ({

/***/ "./node_modules/@fullcalendar/core/main.css":
/*!**************************************************!*\
  !*** ./node_modules/@fullcalendar/core/main.css ***!
  \**************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// extracted by mini-css-extract-plugin\n\n//# sourceURL=webpack:///./node_modules/@fullcalendar/core/main.css?");

/***/ }),

/***/ "./node_modules/@fullcalendar/core/main.esm.js":
/*!*****************************************************!*\
  !*** ./node_modules/@fullcalendar/core/main.esm.js ***!
  \*****************************************************/
/*! exports provided: Calendar, Component, ComponentContext, DateComponent, DateEnv, DateProfileGenerator, DayHeader, DaySeries, DayTable, ElementDragging, ElementScrollController, EmitterMixin, EventApi, FgEventRenderer, FillRenderer, Interaction, Mixin, NamedTimeZoneImpl, PositionCache, ScrollComponent, ScrollController, Slicer, Splitter, Theme, View, WindowScrollController, addDays, addDurations, addMs, addWeeks, allowContextMenu, allowSelection, appendToElement, applyAll, applyMutationToEventStore, applyStyle, applyStyleProp, asRoughMinutes, asRoughMs, asRoughSeconds, buildGotoAnchorHtml, buildSegCompareObj, capitaliseFirstLetter, combineEventUis, compareByFieldSpec, compareByFieldSpecs, compareNumbers, compensateScroll, computeClippingRect, computeEdges, computeEventDraggable, computeEventEndResizable, computeEventStartResizable, computeFallbackHeaderFormat, computeHeightAndMargins, computeInnerRect, computeRect, computeVisibleDayRange, config, constrainPoint, createDuration, createElement, createEmptyEventStore, createEventInstance, createFormatter, createPlugin, cssToStr, debounce, diffDates, diffDayAndTime, diffDays, diffPoints, diffWeeks, diffWholeDays, diffWholeWeeks, disableCursor, distributeHeight, elementClosest, elementMatches, enableCursor, eventTupleToStore, filterEventStoreDefs, filterHash, findChildren, findElements, flexibleCompare, forceClassName, formatDate, formatIsoTimeString, formatRange, getAllDayHtml, getClippingParents, getDayClasses, getElSeg, getRectCenter, getRelevantEvents, globalDefaults, greatestDurationDenominator, hasBgRendering, htmlEscape, htmlToElement, insertAfterElement, interactionSettingsStore, interactionSettingsToStore, intersectRanges, intersectRects, isArraysEqual, isDateSpansEqual, isInt, isInteractionValid, isMultiDayRange, isPropsEqual, isPropsValid, isSingleDay, isValidDate, listenBySelector, mapHash, matchCellWidths, memoize, memoizeOutput, memoizeRendering, mergeEventStores, multiplyDuration, padStart, parseBusinessHours, parseDragMeta, parseEventDef, parseFieldSpecs, parseMarker, pointInsideRect, prependToElement, preventContextMenu, preventDefault, preventSelection, processScopedUiProps, rangeContainsMarker, rangeContainsRange, rangesEqual, rangesIntersect, refineProps, removeElement, removeExact, renderDateCell, requestJson, sliceEventStore, startOfDay, subtractInnerElHeight, translateRect, uncompensateScroll, undistributeHeight, unpromisify, version, whenTransitionDone, wholeDivideDurations */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"Calendar\", function() { return Calendar; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"Component\", function() { return Component; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"ComponentContext\", function() { return ComponentContext; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"DateComponent\", function() { return DateComponent; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"DateEnv\", function() { return DateEnv; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"DateProfileGenerator\", function() { return DateProfileGenerator; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"DayHeader\", function() { return DayHeader; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"DaySeries\", function() { return DaySeries; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"DayTable\", function() { return DayTable; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"ElementDragging\", function() { return ElementDragging; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"ElementScrollController\", function() { return ElementScrollController; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"EmitterMixin\", function() { return EmitterMixin; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"EventApi\", function() { return EventApi; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"FgEventRenderer\", function() { return FgEventRenderer; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"FillRenderer\", function() { return FillRenderer; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"Interaction\", function() { return Interaction; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"Mixin\", function() { return Mixin; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"NamedTimeZoneImpl\", function() { return NamedTimeZoneImpl; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"PositionCache\", function() { return PositionCache; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"ScrollComponent\", function() { return ScrollComponent; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"ScrollController\", function() { return ScrollController; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"Slicer\", function() { return Slicer; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"Splitter\", function() { return Splitter; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"Theme\", function() { return Theme; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"View\", function() { return View; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"WindowScrollController\", function() { return WindowScrollController; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"addDays\", function() { return addDays; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"addDurations\", function() { return addDurations; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"addMs\", function() { return addMs; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"addWeeks\", function() { return addWeeks; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"allowContextMenu\", function() { return allowContextMenu; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"allowSelection\", function() { return allowSelection; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"appendToElement\", function() { return appendToElement; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"applyAll\", function() { return applyAll; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"applyMutationToEventStore\", function() { return applyMutationToEventStore; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"applyStyle\", function() { return applyStyle; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"applyStyleProp\", function() { return applyStyleProp; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"asRoughMinutes\", function() { return asRoughMinutes; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"asRoughMs\", function() { return asRoughMs; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"asRoughSeconds\", function() { return asRoughSeconds; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"buildGotoAnchorHtml\", function() { return buildGotoAnchorHtml; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"buildSegCompareObj\", function() { return buildSegCompareObj; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"capitaliseFirstLetter\", function() { return capitaliseFirstLetter; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"combineEventUis\", function() { return combineEventUis; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"compareByFieldSpec\", function() { return compareByFieldSpec; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"compareByFieldSpecs\", function() { return compareByFieldSpecs; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"compareNumbers\", function() { return compareNumbers; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"compensateScroll\", function() { return compensateScroll; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"computeClippingRect\", function() { return computeClippingRect; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"computeEdges\", function() { return computeEdges; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"computeEventDraggable\", function() { return computeEventDraggable; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"computeEventEndResizable\", function() { return computeEventEndResizable; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"computeEventStartResizable\", function() { return computeEventStartResizable; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"computeFallbackHeaderFormat\", function() { return computeFallbackHeaderFormat; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"computeHeightAndMargins\", function() { return computeHeightAndMargins; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"computeInnerRect\", function() { return computeInnerRect; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"computeRect\", function() { return computeRect; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"computeVisibleDayRange\", function() { return computeVisibleDayRange; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"config\", function() { return config; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"constrainPoint\", function() { return constrainPoint; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"createDuration\", function() { return createDuration; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"createElement\", function() { return createElement; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"createEmptyEventStore\", function() { return createEmptyEventStore; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"createEventInstance\", function() { return createEventInstance; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"createFormatter\", function() { return createFormatter; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"createPlugin\", function() { return createPlugin; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"cssToStr\", function() { return cssToStr; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"debounce\", function() { return debounce; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"diffDates\", function() { return diffDates; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"diffDayAndTime\", function() { return diffDayAndTime; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"diffDays\", function() { return diffDays; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"diffPoints\", function() { return diffPoints; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"diffWeeks\", function() { return diffWeeks; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"diffWholeDays\", function() { return diffWholeDays; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"diffWholeWeeks\", function() { return diffWholeWeeks; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"disableCursor\", function() { return disableCursor; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"distributeHeight\", function() { return distributeHeight; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"elementClosest\", function() { return elementClosest; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"elementMatches\", function() { return elementMatches; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"enableCursor\", function() { return enableCursor; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"eventTupleToStore\", function() { return eventTupleToStore; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"filterEventStoreDefs\", function() { return filterEventStoreDefs; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"filterHash\", function() { return filterHash; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"findChildren\", function() { return findChildren; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"findElements\", function() { return findElements; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"flexibleCompare\", function() { return flexibleCompare; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"forceClassName\", function() { return forceClassName; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"formatDate\", function() { return formatDate; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"formatIsoTimeString\", function() { return formatIsoTimeString; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"formatRange\", function() { return formatRange; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getAllDayHtml\", function() { return getAllDayHtml; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getClippingParents\", function() { return getClippingParents; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getDayClasses\", function() { return getDayClasses; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getElSeg\", function() { return getElSeg; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getRectCenter\", function() { return getRectCenter; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"getRelevantEvents\", function() { return getRelevantEvents; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"globalDefaults\", function() { return globalDefaults; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"greatestDurationDenominator\", function() { return greatestDurationDenominator; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"hasBgRendering\", function() { return hasBgRendering; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"htmlEscape\", function() { return htmlEscape; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"htmlToElement\", function() { return htmlToElement; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"insertAfterElement\", function() { return insertAfterElement; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"interactionSettingsStore\", function() { return interactionSettingsStore; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"interactionSettingsToStore\", function() { return interactionSettingsToStore; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"intersectRanges\", function() { return intersectRanges; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"intersectRects\", function() { return intersectRects; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"isArraysEqual\", function() { return isArraysEqual; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"isDateSpansEqual\", function() { return isDateSpansEqual; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"isInt\", function() { return isInt; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"isInteractionValid\", function() { return isInteractionValid; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"isMultiDayRange\", function() { return isMultiDayRange; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"isPropsEqual\", function() { return isPropsEqual; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"isPropsValid\", function() { return isPropsValid; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"isSingleDay\", function() { return isSingleDay; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"isValidDate\", function() { return isValidDate; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"listenBySelector\", function() { return listenBySelector; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"mapHash\", function() { return mapHash; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"matchCellWidths\", function() { return matchCellWidths; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"memoize\", function() { return memoize; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"memoizeOutput\", function() { return memoizeOutput; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"memoizeRendering\", function() { return memoizeRendering; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"mergeEventStores\", function() { return mergeEventStores; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"multiplyDuration\", function() { return multiplyDuration; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"padStart\", function() { return padStart; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"parseBusinessHours\", function() { return parseBusinessHours; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"parseDragMeta\", function() { return parseDragMeta; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"parseEventDef\", function() { return parseEventDef; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"parseFieldSpecs\", function() { return parseFieldSpecs; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"parseMarker\", function() { return parse; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"pointInsideRect\", function() { return pointInsideRect; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"prependToElement\", function() { return prependToElement; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"preventContextMenu\", function() { return preventContextMenu; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"preventDefault\", function() { return preventDefault; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"preventSelection\", function() { return preventSelection; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"processScopedUiProps\", function() { return processScopedUiProps; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"rangeContainsMarker\", function() { return rangeContainsMarker; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"rangeContainsRange\", function() { return rangeContainsRange; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"rangesEqual\", function() { return rangesEqual; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"rangesIntersect\", function() { return rangesIntersect; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"refineProps\", function() { return refineProps; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"removeElement\", function() { return removeElement; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"removeExact\", function() { return removeExact; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"renderDateCell\", function() { return renderDateCell; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"requestJson\", function() { return requestJson; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"sliceEventStore\", function() { return sliceEventStore; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"startOfDay\", function() { return startOfDay; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"subtractInnerElHeight\", function() { return subtractInnerElHeight; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"translateRect\", function() { return translateRect; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"uncompensateScroll\", function() { return uncompensateScroll; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"undistributeHeight\", function() { return undistributeHeight; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"unpromisify\", function() { return unpromisify; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"version\", function() { return version; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"whenTransitionDone\", function() { return whenTransitionDone; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"wholeDivideDurations\", function() { return wholeDivideDurations; });\n/*!\nFullCalendar Core Package v4.4.2\nDocs & License: https://fullcalendar.io/\n(c) 2019 Adam Shaw\n*/\n\n// Creating\n// ----------------------------------------------------------------------------------------------------------------\nvar elementPropHash = {\n    className: true,\n    colSpan: true,\n    rowSpan: true\n};\nvar containerTagHash = {\n    '<tr': 'tbody',\n    '<td': 'tr'\n};\nfunction createElement(tagName, attrs, content) {\n    var el = document.createElement(tagName);\n    if (attrs) {\n        for (var attrName in attrs) {\n            if (attrName === 'style') {\n                applyStyle(el, attrs[attrName]);\n            }\n            else if (elementPropHash[attrName]) {\n                el[attrName] = attrs[attrName];\n            }\n            else {\n                el.setAttribute(attrName, attrs[attrName]);\n            }\n        }\n    }\n    if (typeof content === 'string') {\n        el.innerHTML = content; // shortcut. no need to process HTML in any way\n    }\n    else if (content != null) {\n        appendToElement(el, content);\n    }\n    return el;\n}\nfunction htmlToElement(html) {\n    html = html.trim();\n    var container = document.createElement(computeContainerTag(html));\n    container.innerHTML = html;\n    return container.firstChild;\n}\nfunction htmlToElements(html) {\n    return Array.prototype.slice.call(htmlToNodeList(html));\n}\nfunction htmlToNodeList(html) {\n    html = html.trim();\n    var container = document.createElement(computeContainerTag(html));\n    container.innerHTML = html;\n    return container.childNodes;\n}\n// assumes html already trimmed and tag names are lowercase\nfunction computeContainerTag(html) {\n    return containerTagHash[html.substr(0, 3) // faster than using regex\n    ] || 'div';\n}\nfunction appendToElement(el, content) {\n    var childNodes = normalizeContent(content);\n    for (var i = 0; i < childNodes.length; i++) {\n        el.appendChild(childNodes[i]);\n    }\n}\nfunction prependToElement(parent, content) {\n    var newEls = normalizeContent(content);\n    var afterEl = parent.firstChild || null; // if no firstChild, will append to end, but that's okay, b/c there were no children\n    for (var i = 0; i < newEls.length; i++) {\n        parent.insertBefore(newEls[i], afterEl);\n    }\n}\nfunction insertAfterElement(refEl, content) {\n    var newEls = normalizeContent(content);\n    var afterEl = refEl.nextSibling || null;\n    for (var i = 0; i < newEls.length; i++) {\n        refEl.parentNode.insertBefore(newEls[i], afterEl);\n    }\n}\nfunction normalizeContent(content) {\n    var els;\n    if (typeof content === 'string') {\n        els = htmlToElements(content);\n    }\n    else if (content instanceof Node) {\n        els = [content];\n    }\n    else { // Node[] or NodeList\n        els = Array.prototype.slice.call(content);\n    }\n    return els;\n}\nfunction removeElement(el) {\n    if (el.parentNode) {\n        el.parentNode.removeChild(el);\n    }\n}\n// Querying\n// ----------------------------------------------------------------------------------------------------------------\n// from https://developer.mozilla.org/en-US/docs/Web/API/Element/closest\nvar matchesMethod = Element.prototype.matches ||\n    Element.prototype.matchesSelector ||\n    Element.prototype.msMatchesSelector;\nvar closestMethod = Element.prototype.closest || function (selector) {\n    // polyfill\n    var el = this;\n    if (!document.documentElement.contains(el)) {\n        return null;\n    }\n    do {\n        if (elementMatches(el, selector)) {\n            return el;\n        }\n        el = el.parentElement || el.parentNode;\n    } while (el !== null && el.nodeType === 1);\n    return null;\n};\nfunction elementClosest(el, selector) {\n    return closestMethod.call(el, selector);\n}\nfunction elementMatches(el, selector) {\n    return matchesMethod.call(el, selector);\n}\n// accepts multiple subject els\n// returns a real array. good for methods like forEach\nfunction findElements(container, selector) {\n    var containers = container instanceof HTMLElement ? [container] : container;\n    var allMatches = [];\n    for (var i = 0; i < containers.length; i++) {\n        var matches = containers[i].querySelectorAll(selector);\n        for (var j = 0; j < matches.length; j++) {\n            allMatches.push(matches[j]);\n        }\n    }\n    return allMatches;\n}\n// accepts multiple subject els\n// only queries direct child elements\nfunction findChildren(parent, selector) {\n    var parents = parent instanceof HTMLElement ? [parent] : parent;\n    var allMatches = [];\n    for (var i = 0; i < parents.length; i++) {\n        var childNodes = parents[i].children; // only ever elements\n        for (var j = 0; j < childNodes.length; j++) {\n            var childNode = childNodes[j];\n            if (!selector || elementMatches(childNode, selector)) {\n                allMatches.push(childNode);\n            }\n        }\n    }\n    return allMatches;\n}\n// Attributes\n// ----------------------------------------------------------------------------------------------------------------\nfunction forceClassName(el, className, bool) {\n    if (bool) {\n        el.classList.add(className);\n    }\n    else {\n        el.classList.remove(className);\n    }\n}\n// Style\n// ----------------------------------------------------------------------------------------------------------------\nvar PIXEL_PROP_RE = /(top|left|right|bottom|width|height)$/i;\nfunction applyStyle(el, props) {\n    for (var propName in props) {\n        applyStyleProp(el, propName, props[propName]);\n    }\n}\nfunction applyStyleProp(el, name, val) {\n    if (val == null) {\n        el.style[name] = '';\n    }\n    else if (typeof val === 'number' && PIXEL_PROP_RE.test(name)) {\n        el.style[name] = val + 'px';\n    }\n    else {\n        el.style[name] = val;\n    }\n}\n\nfunction pointInsideRect(point, rect) {\n    return point.left >= rect.left &&\n        point.left < rect.right &&\n        point.top >= rect.top &&\n        point.top < rect.bottom;\n}\n// Returns a new rectangle that is the intersection of the two rectangles. If they don't intersect, returns false\nfunction intersectRects(rect1, rect2) {\n    var res = {\n        left: Math.max(rect1.left, rect2.left),\n        right: Math.min(rect1.right, rect2.right),\n        top: Math.max(rect1.top, rect2.top),\n        bottom: Math.min(rect1.bottom, rect2.bottom)\n    };\n    if (res.left < res.right && res.top < res.bottom) {\n        return res;\n    }\n    return false;\n}\nfunction translateRect(rect, deltaX, deltaY) {\n    return {\n        left: rect.left + deltaX,\n        right: rect.right + deltaX,\n        top: rect.top + deltaY,\n        bottom: rect.bottom + deltaY\n    };\n}\n// Returns a new point that will have been moved to reside within the given rectangle\nfunction constrainPoint(point, rect) {\n    return {\n        left: Math.min(Math.max(point.left, rect.left), rect.right),\n        top: Math.min(Math.max(point.top, rect.top), rect.bottom)\n    };\n}\n// Returns a point that is the center of the given rectangle\nfunction getRectCenter(rect) {\n    return {\n        left: (rect.left + rect.right) / 2,\n        top: (rect.top + rect.bottom) / 2\n    };\n}\n// Subtracts point2's coordinates from point1's coordinates, returning a delta\nfunction diffPoints(point1, point2) {\n    return {\n        left: point1.left - point2.left,\n        top: point1.top - point2.top\n    };\n}\n\n// Logic for determining if, when the element is right-to-left, the scrollbar appears on the left side\nvar isRtlScrollbarOnLeft = null;\nfunction getIsRtlScrollbarOnLeft() {\n    if (isRtlScrollbarOnLeft === null) {\n        isRtlScrollbarOnLeft = computeIsRtlScrollbarOnLeft();\n    }\n    return isRtlScrollbarOnLeft;\n}\nfunction computeIsRtlScrollbarOnLeft() {\n    var outerEl = createElement('div', {\n        style: {\n            position: 'absolute',\n            top: -1000,\n            left: 0,\n            border: 0,\n            padding: 0,\n            overflow: 'scroll',\n            direction: 'rtl'\n        }\n    }, '<div></div>');\n    document.body.appendChild(outerEl);\n    var innerEl = outerEl.firstChild;\n    var res = innerEl.getBoundingClientRect().left > outerEl.getBoundingClientRect().left;\n    removeElement(outerEl);\n    return res;\n}\n// The scrollbar width computations in computeEdges are sometimes flawed when it comes to\n// retina displays, rounding, and IE11. Massage them into a usable value.\nfunction sanitizeScrollbarWidth(width) {\n    width = Math.max(0, width); // no negatives\n    width = Math.round(width);\n    return width;\n}\n\nfunction computeEdges(el, getPadding) {\n    if (getPadding === void 0) { getPadding = false; }\n    var computedStyle = window.getComputedStyle(el);\n    var borderLeft = parseInt(computedStyle.borderLeftWidth, 10) || 0;\n    var borderRight = parseInt(computedStyle.borderRightWidth, 10) || 0;\n    var borderTop = parseInt(computedStyle.borderTopWidth, 10) || 0;\n    var borderBottom = parseInt(computedStyle.borderBottomWidth, 10) || 0;\n    // must use offset(Width|Height) because compatible with client(Width|Height)\n    var scrollbarLeftRight = sanitizeScrollbarWidth(el.offsetWidth - el.clientWidth - borderLeft - borderRight);\n    var scrollbarBottom = sanitizeScrollbarWidth(el.offsetHeight - el.clientHeight - borderTop - borderBottom);\n    var res = {\n        borderLeft: borderLeft,\n        borderRight: borderRight,\n        borderTop: borderTop,\n        borderBottom: borderBottom,\n        scrollbarBottom: scrollbarBottom,\n        scrollbarLeft: 0,\n        scrollbarRight: 0\n    };\n    if (getIsRtlScrollbarOnLeft() && computedStyle.direction === 'rtl') { // is the scrollbar on the left side?\n        res.scrollbarLeft = scrollbarLeftRight;\n    }\n    else {\n        res.scrollbarRight = scrollbarLeftRight;\n    }\n    if (getPadding) {\n        res.paddingLeft = parseInt(computedStyle.paddingLeft, 10) || 0;\n        res.paddingRight = parseInt(computedStyle.paddingRight, 10) || 0;\n        res.paddingTop = parseInt(computedStyle.paddingTop, 10) || 0;\n        res.paddingBottom = parseInt(computedStyle.paddingBottom, 10) || 0;\n    }\n    return res;\n}\nfunction computeInnerRect(el, goWithinPadding) {\n    if (goWithinPadding === void 0) { goWithinPadding = false; }\n    var outerRect = computeRect(el);\n    var edges = computeEdges(el, goWithinPadding);\n    var res = {\n        left: outerRect.left + edges.borderLeft + edges.scrollbarLeft,\n        right: outerRect.right - edges.borderRight - edges.scrollbarRight,\n        top: outerRect.top + edges.borderTop,\n        bottom: outerRect.bottom - edges.borderBottom - edges.scrollbarBottom\n    };\n    if (goWithinPadding) {\n        res.left += edges.paddingLeft;\n        res.right -= edges.paddingRight;\n        res.top += edges.paddingTop;\n        res.bottom -= edges.paddingBottom;\n    }\n    return res;\n}\nfunction computeRect(el) {\n    var rect = el.getBoundingClientRect();\n    return {\n        left: rect.left + window.pageXOffset,\n        top: rect.top + window.pageYOffset,\n        right: rect.right + window.pageXOffset,\n        bottom: rect.bottom + window.pageYOffset\n    };\n}\nfunction computeViewportRect() {\n    return {\n        left: window.pageXOffset,\n        right: window.pageXOffset + document.documentElement.clientWidth,\n        top: window.pageYOffset,\n        bottom: window.pageYOffset + document.documentElement.clientHeight\n    };\n}\nfunction computeHeightAndMargins(el) {\n    return el.getBoundingClientRect().height + computeVMargins(el);\n}\nfunction computeVMargins(el) {\n    var computed = window.getComputedStyle(el);\n    return parseInt(computed.marginTop, 10) +\n        parseInt(computed.marginBottom, 10);\n}\n// does not return window\nfunction getClippingParents(el) {\n    var parents = [];\n    while (el instanceof HTMLElement) { // will stop when gets to document or null\n        var computedStyle = window.getComputedStyle(el);\n        if (computedStyle.position === 'fixed') {\n            break;\n        }\n        if ((/(auto|scroll)/).test(computedStyle.overflow + computedStyle.overflowY + computedStyle.overflowX)) {\n            parents.push(el);\n        }\n        el = el.parentNode;\n    }\n    return parents;\n}\nfunction computeClippingRect(el) {\n    return getClippingParents(el)\n        .map(function (el) {\n        return computeInnerRect(el);\n    })\n        .concat(computeViewportRect())\n        .reduce(function (rect0, rect1) {\n        return intersectRects(rect0, rect1) || rect1; // should always intersect\n    });\n}\n\n// Stops a mouse/touch event from doing it's native browser action\nfunction preventDefault(ev) {\n    ev.preventDefault();\n}\n// Event Delegation\n// ----------------------------------------------------------------------------------------------------------------\nfunction listenBySelector(container, eventType, selector, handler) {\n    function realHandler(ev) {\n        var matchedChild = elementClosest(ev.target, selector);\n        if (matchedChild) {\n            handler.call(matchedChild, ev, matchedChild);\n        }\n    }\n    container.addEventListener(eventType, realHandler);\n    return function () {\n        container.removeEventListener(eventType, realHandler);\n    };\n}\nfunction listenToHoverBySelector(container, selector, onMouseEnter, onMouseLeave) {\n    var currentMatchedChild;\n    return listenBySelector(container, 'mouseover', selector, function (ev, matchedChild) {\n        if (matchedChild !== currentMatchedChild) {\n            currentMatchedChild = matchedChild;\n            onMouseEnter(ev, matchedChild);\n            var realOnMouseLeave_1 = function (ev) {\n                currentMatchedChild = null;\n                onMouseLeave(ev, matchedChild);\n                matchedChild.removeEventListener('mouseleave', realOnMouseLeave_1);\n            };\n            // listen to the next mouseleave, and then unattach\n            matchedChild.addEventListener('mouseleave', realOnMouseLeave_1);\n        }\n    });\n}\n// Animation\n// ----------------------------------------------------------------------------------------------------------------\nvar transitionEventNames = [\n    'webkitTransitionEnd',\n    'otransitionend',\n    'oTransitionEnd',\n    'msTransitionEnd',\n    'transitionend'\n];\n// triggered only when the next single subsequent transition finishes\nfunction whenTransitionDone(el, callback) {\n    var realCallback = function (ev) {\n        callback(ev);\n        transitionEventNames.forEach(function (eventName) {\n            el.removeEventListener(eventName, realCallback);\n        });\n    };\n    transitionEventNames.forEach(function (eventName) {\n        el.addEventListener(eventName, realCallback); // cross-browser way to determine when the transition finishes\n    });\n}\n\nvar DAY_IDS = ['sun', 'mon', 'tue', 'wed', 'thu', 'fri', 'sat'];\n// Adding\nfunction addWeeks(m, n) {\n    var a = dateToUtcArray(m);\n    a[2] += n * 7;\n    return arrayToUtcDate(a);\n}\nfunction addDays(m, n) {\n    var a = dateToUtcArray(m);\n    a[2] += n;\n    return arrayToUtcDate(a);\n}\nfunction addMs(m, n) {\n    var a = dateToUtcArray(m);\n    a[6] += n;\n    return arrayToUtcDate(a);\n}\n// Diffing (all return floats)\nfunction diffWeeks(m0, m1) {\n    return diffDays(m0, m1) / 7;\n}\nfunction diffDays(m0, m1) {\n    return (m1.valueOf() - m0.valueOf()) / (1000 * 60 * 60 * 24);\n}\nfunction diffHours(m0, m1) {\n    return (m1.valueOf() - m0.valueOf()) / (1000 * 60 * 60);\n}\nfunction diffMinutes(m0, m1) {\n    return (m1.valueOf() - m0.valueOf()) / (1000 * 60);\n}\nfunction diffSeconds(m0, m1) {\n    return (m1.valueOf() - m0.valueOf()) / 1000;\n}\nfunction diffDayAndTime(m0, m1) {\n    var m0day = startOfDay(m0);\n    var m1day = startOfDay(m1);\n    return {\n        years: 0,\n        months: 0,\n        days: Math.round(diffDays(m0day, m1day)),\n        milliseconds: (m1.valueOf() - m1day.valueOf()) - (m0.valueOf() - m0day.valueOf())\n    };\n}\n// Diffing Whole Units\nfunction diffWholeWeeks(m0, m1) {\n    var d = diffWholeDays(m0, m1);\n    if (d !== null && d % 7 === 0) {\n        return d / 7;\n    }\n    return null;\n}\nfunction diffWholeDays(m0, m1) {\n    if (timeAsMs(m0) === timeAsMs(m1)) {\n        return Math.round(diffDays(m0, m1));\n    }\n    return null;\n}\n// Start-Of\nfunction startOfDay(m) {\n    return arrayToUtcDate([\n        m.getUTCFullYear(),\n        m.getUTCMonth(),\n        m.getUTCDate()\n    ]);\n}\nfunction startOfHour(m) {\n    return arrayToUtcDate([\n        m.getUTCFullYear(),\n        m.getUTCMonth(),\n        m.getUTCDate(),\n        m.getUTCHours()\n    ]);\n}\nfunction startOfMinute(m) {\n    return arrayToUtcDate([\n        m.getUTCFullYear(),\n        m.getUTCMonth(),\n        m.getUTCDate(),\n        m.getUTCHours(),\n        m.getUTCMinutes()\n    ]);\n}\nfunction startOfSecond(m) {\n    return arrayToUtcDate([\n        m.getUTCFullYear(),\n        m.getUTCMonth(),\n        m.getUTCDate(),\n        m.getUTCHours(),\n        m.getUTCMinutes(),\n        m.getUTCSeconds()\n    ]);\n}\n// Week Computation\nfunction weekOfYear(marker, dow, doy) {\n    var y = marker.getUTCFullYear();\n    var w = weekOfGivenYear(marker, y, dow, doy);\n    if (w < 1) {\n        return weekOfGivenYear(marker, y - 1, dow, doy);\n    }\n    var nextW = weekOfGivenYear(marker, y + 1, dow, doy);\n    if (nextW >= 1) {\n        return Math.min(w, nextW);\n    }\n    return w;\n}\nfunction weekOfGivenYear(marker, year, dow, doy) {\n    var firstWeekStart = arrayToUtcDate([year, 0, 1 + firstWeekOffset(year, dow, doy)]);\n    var dayStart = startOfDay(marker);\n    var days = Math.round(diffDays(firstWeekStart, dayStart));\n    return Math.floor(days / 7) + 1; // zero-indexed\n}\n// start-of-first-week - start-of-year\nfunction firstWeekOffset(year, dow, doy) {\n    // first-week day -- which january is always in the first week (4 for iso, 1 for other)\n    var fwd = 7 + dow - doy;\n    // first-week day local weekday -- which local weekday is fwd\n    var fwdlw = (7 + arrayToUtcDate([year, 0, fwd]).getUTCDay() - dow) % 7;\n    return -fwdlw + fwd - 1;\n}\n// Array Conversion\nfunction dateToLocalArray(date) {\n    return [\n        date.getFullYear(),\n        date.getMonth(),\n        date.getDate(),\n        date.getHours(),\n        date.getMinutes(),\n        date.getSeconds(),\n        date.getMilliseconds()\n    ];\n}\nfunction arrayToLocalDate(a) {\n    return new Date(a[0], a[1] || 0, a[2] == null ? 1 : a[2], // day of month\n    a[3] || 0, a[4] || 0, a[5] || 0);\n}\nfunction dateToUtcArray(date) {\n    return [\n        date.getUTCFullYear(),\n        date.getUTCMonth(),\n        date.getUTCDate(),\n        date.getUTCHours(),\n        date.getUTCMinutes(),\n        date.getUTCSeconds(),\n        date.getUTCMilliseconds()\n    ];\n}\nfunction arrayToUtcDate(a) {\n    // according to web standards (and Safari), a month index is required.\n    // massage if only given a year.\n    if (a.length === 1) {\n        a = a.concat([0]);\n    }\n    return new Date(Date.UTC.apply(Date, a));\n}\n// Other Utils\nfunction isValidDate(m) {\n    return !isNaN(m.valueOf());\n}\nfunction timeAsMs(m) {\n    return m.getUTCHours() * 1000 * 60 * 60 +\n        m.getUTCMinutes() * 1000 * 60 +\n        m.getUTCSeconds() * 1000 +\n        m.getUTCMilliseconds();\n}\n\nvar INTERNAL_UNITS = ['years', 'months', 'days', 'milliseconds'];\nvar PARSE_RE = /^(-?)(?:(\\d+)\\.)?(\\d+):(\\d\\d)(?::(\\d\\d)(?:\\.(\\d\\d\\d))?)?/;\n// Parsing and Creation\nfunction createDuration(input, unit) {\n    var _a;\n    if (typeof input === 'string') {\n        return parseString(input);\n    }\n    else if (typeof input === 'object' && input) { // non-null object\n        return normalizeObject(input);\n    }\n    else if (typeof input === 'number') {\n        return normalizeObject((_a = {}, _a[unit || 'milliseconds'] = input, _a));\n    }\n    else {\n        return null;\n    }\n}\nfunction parseString(s) {\n    var m = PARSE_RE.exec(s);\n    if (m) {\n        var sign = m[1] ? -1 : 1;\n        return {\n            years: 0,\n            months: 0,\n            days: sign * (m[2] ? parseInt(m[2], 10) : 0),\n            milliseconds: sign * ((m[3] ? parseInt(m[3], 10) : 0) * 60 * 60 * 1000 + // hours\n                (m[4] ? parseInt(m[4], 10) : 0) * 60 * 1000 + // minutes\n                (m[5] ? parseInt(m[5], 10) : 0) * 1000 + // seconds\n                (m[6] ? parseInt(m[6], 10) : 0) // ms\n            )\n        };\n    }\n    return null;\n}\nfunction normalizeObject(obj) {\n    return {\n        years: obj.years || obj.year || 0,\n        months: obj.months || obj.month || 0,\n        days: (obj.days || obj.day || 0) +\n            getWeeksFromInput(obj) * 7,\n        milliseconds: (obj.hours || obj.hour || 0) * 60 * 60 * 1000 + // hours\n            (obj.minutes || obj.minute || 0) * 60 * 1000 + // minutes\n            (obj.seconds || obj.second || 0) * 1000 + // seconds\n            (obj.milliseconds || obj.millisecond || obj.ms || 0) // ms\n    };\n}\nfunction getWeeksFromInput(obj) {\n    return obj.weeks || obj.week || 0;\n}\n// Equality\nfunction durationsEqual(d0, d1) {\n    return d0.years === d1.years &&\n        d0.months === d1.months &&\n        d0.days === d1.days &&\n        d0.milliseconds === d1.milliseconds;\n}\nfunction isSingleDay(dur) {\n    return dur.years === 0 && dur.months === 0 && dur.days === 1 && dur.milliseconds === 0;\n}\n// Simple Math\nfunction addDurations(d0, d1) {\n    return {\n        years: d0.years + d1.years,\n        months: d0.months + d1.months,\n        days: d0.days + d1.days,\n        milliseconds: d0.milliseconds + d1.milliseconds\n    };\n}\nfunction subtractDurations(d1, d0) {\n    return {\n        years: d1.years - d0.years,\n        months: d1.months - d0.months,\n        days: d1.days - d0.days,\n        milliseconds: d1.milliseconds - d0.milliseconds\n    };\n}\nfunction multiplyDuration(d, n) {\n    return {\n        years: d.years * n,\n        months: d.months * n,\n        days: d.days * n,\n        milliseconds: d.milliseconds * n\n    };\n}\n// Conversions\n// \"Rough\" because they are based on average-case Gregorian months/years\nfunction asRoughYears(dur) {\n    return asRoughDays(dur) / 365;\n}\nfunction asRoughMonths(dur) {\n    return asRoughDays(dur) / 30;\n}\nfunction asRoughDays(dur) {\n    return asRoughMs(dur) / 864e5;\n}\nfunction asRoughMinutes(dur) {\n    return asRoughMs(dur) / (1000 * 60);\n}\nfunction asRoughSeconds(dur) {\n    return asRoughMs(dur) / 1000;\n}\nfunction asRoughMs(dur) {\n    return dur.years * (365 * 864e5) +\n        dur.months * (30 * 864e5) +\n        dur.days * 864e5 +\n        dur.milliseconds;\n}\n// Advanced Math\nfunction wholeDivideDurations(numerator, denominator) {\n    var res = null;\n    for (var i = 0; i < INTERNAL_UNITS.length; i++) {\n        var unit = INTERNAL_UNITS[i];\n        if (denominator[unit]) {\n            var localRes = numerator[unit] / denominator[unit];\n            if (!isInt(localRes) || (res !== null && res !== localRes)) {\n                return null;\n            }\n            res = localRes;\n        }\n        else if (numerator[unit]) {\n            // needs to divide by something but can't!\n            return null;\n        }\n    }\n    return res;\n}\nfunction greatestDurationDenominator(dur, dontReturnWeeks) {\n    var ms = dur.milliseconds;\n    if (ms) {\n        if (ms % 1000 !== 0) {\n            return { unit: 'millisecond', value: ms };\n        }\n        if (ms % (1000 * 60) !== 0) {\n            return { unit: 'second', value: ms / 1000 };\n        }\n        if (ms % (1000 * 60 * 60) !== 0) {\n            return { unit: 'minute', value: ms / (1000 * 60) };\n        }\n        if (ms) {\n            return { unit: 'hour', value: ms / (1000 * 60 * 60) };\n        }\n    }\n    if (dur.days) {\n        if (!dontReturnWeeks && dur.days % 7 === 0) {\n            return { unit: 'week', value: dur.days / 7 };\n        }\n        return { unit: 'day', value: dur.days };\n    }\n    if (dur.months) {\n        return { unit: 'month', value: dur.months };\n    }\n    if (dur.years) {\n        return { unit: 'year', value: dur.years };\n    }\n    return { unit: 'millisecond', value: 0 };\n}\n\n/* FullCalendar-specific DOM Utilities\n----------------------------------------------------------------------------------------------------------------------*/\n// Given the scrollbar widths of some other container, create borders/margins on rowEls in order to match the left\n// and right space that was offset by the scrollbars. A 1-pixel border first, then margin beyond that.\nfunction compensateScroll(rowEl, scrollbarWidths) {\n    if (scrollbarWidths.left) {\n        applyStyle(rowEl, {\n            borderLeftWidth: 1,\n            marginLeft: scrollbarWidths.left - 1\n        });\n    }\n    if (scrollbarWidths.right) {\n        applyStyle(rowEl, {\n            borderRightWidth: 1,\n            marginRight: scrollbarWidths.right - 1\n        });\n    }\n}\n// Undoes compensateScroll and restores all borders/margins\nfunction uncompensateScroll(rowEl) {\n    applyStyle(rowEl, {\n        marginLeft: '',\n        marginRight: '',\n        borderLeftWidth: '',\n        borderRightWidth: ''\n    });\n}\n// Make the mouse cursor express that an event is not allowed in the current area\nfunction disableCursor() {\n    document.body.classList.add('fc-not-allowed');\n}\n// Returns the mouse cursor to its original look\nfunction enableCursor() {\n    document.body.classList.remove('fc-not-allowed');\n}\n// Given a total available height to fill, have `els` (essentially child rows) expand to accomodate.\n// By default, all elements that are shorter than the recommended height are expanded uniformly, not considering\n// any other els that are already too tall. if `shouldRedistribute` is on, it considers these tall rows and\n// reduces the available height.\nfunction distributeHeight(els, availableHeight, shouldRedistribute) {\n    // *FLOORING NOTE*: we floor in certain places because zoom can give inaccurate floating-point dimensions,\n    // and it is better to be shorter than taller, to avoid creating unnecessary scrollbars.\n    var minOffset1 = Math.floor(availableHeight / els.length); // for non-last element\n    var minOffset2 = Math.floor(availableHeight - minOffset1 * (els.length - 1)); // for last element *FLOORING NOTE*\n    var flexEls = []; // elements that are allowed to expand. array of DOM nodes\n    var flexOffsets = []; // amount of vertical space it takes up\n    var flexHeights = []; // actual css height\n    var usedHeight = 0;\n    undistributeHeight(els); // give all elements their natural height\n    // find elements that are below the recommended height (expandable).\n    // important to query for heights in a single first pass (to avoid reflow oscillation).\n    els.forEach(function (el, i) {\n        var minOffset = i === els.length - 1 ? minOffset2 : minOffset1;\n        var naturalHeight = el.getBoundingClientRect().height;\n        var naturalOffset = naturalHeight + computeVMargins(el);\n        if (naturalOffset < minOffset) {\n            flexEls.push(el);\n            flexOffsets.push(naturalOffset);\n            flexHeights.push(naturalHeight);\n        }\n        else {\n            // this element stretches past recommended height (non-expandable). mark the space as occupied.\n            usedHeight += naturalOffset;\n        }\n    });\n    // readjust the recommended height to only consider the height available to non-maxed-out rows.\n    if (shouldRedistribute) {\n        availableHeight -= usedHeight;\n        minOffset1 = Math.floor(availableHeight / flexEls.length);\n        minOffset2 = Math.floor(availableHeight - minOffset1 * (flexEls.length - 1)); // *FLOORING NOTE*\n    }\n    // assign heights to all expandable elements\n    flexEls.forEach(function (el, i) {\n        var minOffset = i === flexEls.length - 1 ? minOffset2 : minOffset1;\n        var naturalOffset = flexOffsets[i];\n        var naturalHeight = flexHeights[i];\n        var newHeight = minOffset - (naturalOffset - naturalHeight); // subtract the margin/padding\n        if (naturalOffset < minOffset) { // we check this again because redistribution might have changed things\n            el.style.height = newHeight + 'px';\n        }\n    });\n}\n// Undoes distrubuteHeight, restoring all els to their natural height\nfunction undistributeHeight(els) {\n    els.forEach(function (el) {\n        el.style.height = '';\n    });\n}\n// Given `els`, a set of <td> cells, find the cell with the largest natural width and set the widths of all the\n// cells to be that width.\n// PREREQUISITE: if you want a cell to take up width, it needs to have a single inner element w/ display:inline\nfunction matchCellWidths(els) {\n    var maxInnerWidth = 0;\n    els.forEach(function (el) {\n        var innerEl = el.firstChild; // hopefully an element\n        if (innerEl instanceof HTMLElement) {\n            var innerWidth_1 = innerEl.getBoundingClientRect().width;\n            if (innerWidth_1 > maxInnerWidth) {\n                maxInnerWidth = innerWidth_1;\n            }\n        }\n    });\n    maxInnerWidth++; // sometimes not accurate of width the text needs to stay on one line. insurance\n    els.forEach(function (el) {\n        el.style.width = maxInnerWidth + 'px';\n    });\n    return maxInnerWidth;\n}\n// Given one element that resides inside another,\n// Subtracts the height of the inner element from the outer element.\nfunction subtractInnerElHeight(outerEl, innerEl) {\n    // effin' IE8/9/10/11 sometimes returns 0 for dimensions. this weird hack was the only thing that worked\n    var reflowStyleProps = {\n        position: 'relative',\n        left: -1 // ensure reflow in case the el was already relative. negative is less likely to cause new scroll\n    };\n    applyStyle(outerEl, reflowStyleProps);\n    applyStyle(innerEl, reflowStyleProps);\n    var diff = // grab the dimensions\n     outerEl.getBoundingClientRect().height -\n        innerEl.getBoundingClientRect().height;\n    // undo hack\n    var resetStyleProps = { position: '', left: '' };\n    applyStyle(outerEl, resetStyleProps);\n    applyStyle(innerEl, resetStyleProps);\n    return diff;\n}\n/* Selection\n----------------------------------------------------------------------------------------------------------------------*/\nfunction preventSelection(el) {\n    el.classList.add('fc-unselectable');\n    el.addEventListener('selectstart', preventDefault);\n}\nfunction allowSelection(el) {\n    el.classList.remove('fc-unselectable');\n    el.removeEventListener('selectstart', preventDefault);\n}\n/* Context Menu\n----------------------------------------------------------------------------------------------------------------------*/\nfunction preventContextMenu(el) {\n    el.addEventListener('contextmenu', preventDefault);\n}\nfunction allowContextMenu(el) {\n    el.removeEventListener('contextmenu', preventDefault);\n}\n/* Object Ordering by Field\n----------------------------------------------------------------------------------------------------------------------*/\nfunction parseFieldSpecs(input) {\n    var specs = [];\n    var tokens = [];\n    var i;\n    var token;\n    if (typeof input === 'string') {\n        tokens = input.split(/\\s*,\\s*/);\n    }\n    else if (typeof input === 'function') {\n        tokens = [input];\n    }\n    else if (Array.isArray(input)) {\n        tokens = input;\n    }\n    for (i = 0; i < tokens.length; i++) {\n        token = tokens[i];\n        if (typeof token === 'string') {\n            specs.push(token.charAt(0) === '-' ?\n                { field: token.substring(1), order: -1 } :\n                { field: token, order: 1 });\n        }\n        else if (typeof token === 'function') {\n            specs.push({ func: token });\n        }\n    }\n    return specs;\n}\nfunction compareByFieldSpecs(obj0, obj1, fieldSpecs) {\n    var i;\n    var cmp;\n    for (i = 0; i < fieldSpecs.length; i++) {\n        cmp = compareByFieldSpec(obj0, obj1, fieldSpecs[i]);\n        if (cmp) {\n            return cmp;\n        }\n    }\n    return 0;\n}\nfunction compareByFieldSpec(obj0, obj1, fieldSpec) {\n    if (fieldSpec.func) {\n        return fieldSpec.func(obj0, obj1);\n    }\n    return flexibleCompare(obj0[fieldSpec.field], obj1[fieldSpec.field])\n        * (fieldSpec.order || 1);\n}\nfunction flexibleCompare(a, b) {\n    if (!a && !b) {\n        return 0;\n    }\n    if (b == null) {\n        return -1;\n    }\n    if (a == null) {\n        return 1;\n    }\n    if (typeof a === 'string' || typeof b === 'string') {\n        return String(a).localeCompare(String(b));\n    }\n    return a - b;\n}\n/* String Utilities\n----------------------------------------------------------------------------------------------------------------------*/\nfunction capitaliseFirstLetter(str) {\n    return str.charAt(0).toUpperCase() + str.slice(1);\n}\nfunction padStart(val, len) {\n    var s = String(val);\n    return '000'.substr(0, len - s.length) + s;\n}\n/* Number Utilities\n----------------------------------------------------------------------------------------------------------------------*/\nfunction compareNumbers(a, b) {\n    return a - b;\n}\nfunction isInt(n) {\n    return n % 1 === 0;\n}\n/* Weird Utilities\n----------------------------------------------------------------------------------------------------------------------*/\nfunction applyAll(functions, thisObj, args) {\n    if (typeof functions === 'function') { // supplied a single function\n        functions = [functions];\n    }\n    if (functions) {\n        var i = void 0;\n        var ret = void 0;\n        for (i = 0; i < functions.length; i++) {\n            ret = functions[i].apply(thisObj, args) || ret;\n        }\n        return ret;\n    }\n}\nfunction firstDefined() {\n    var args = [];\n    for (var _i = 0; _i < arguments.length; _i++) {\n        args[_i] = arguments[_i];\n    }\n    for (var i = 0; i < args.length; i++) {\n        if (args[i] !== undefined) {\n            return args[i];\n        }\n    }\n}\n// Returns a function, that, as long as it continues to be invoked, will not\n// be triggered. The function will be called after it stops being called for\n// N milliseconds. If `immediate` is passed, trigger the function on the\n// leading edge, instead of the trailing.\n// https://github.com/jashkenas/underscore/blob/1.6.0/underscore.js#L714\nfunction debounce(func, wait) {\n    var timeout;\n    var args;\n    var context;\n    var timestamp;\n    var result;\n    var later = function () {\n        var last = new Date().valueOf() - timestamp;\n        if (last < wait) {\n            timeout = setTimeout(later, wait - last);\n        }\n        else {\n            timeout = null;\n            result = func.apply(context, args);\n            context = args = null;\n        }\n    };\n    return function () {\n        context = this;\n        args = arguments;\n        timestamp = new Date().valueOf();\n        if (!timeout) {\n            timeout = setTimeout(later, wait);\n        }\n        return result;\n    };\n}\n// Number and Boolean are only types that defaults or not computed for\n// TODO: write more comments\nfunction refineProps(rawProps, processors, defaults, leftoverProps) {\n    if (defaults === void 0) { defaults = {}; }\n    var refined = {};\n    for (var key in processors) {\n        var processor = processors[key];\n        if (rawProps[key] !== undefined) {\n            // found\n            if (processor === Function) {\n                refined[key] = typeof rawProps[key] === 'function' ? rawProps[key] : null;\n            }\n            else if (processor) { // a refining function?\n                refined[key] = processor(rawProps[key]);\n            }\n            else {\n                refined[key] = rawProps[key];\n            }\n        }\n        else if (defaults[key] !== undefined) {\n            // there's an explicit default\n            refined[key] = defaults[key];\n        }\n        else {\n            // must compute a default\n            if (processor === String) {\n                refined[key] = ''; // empty string is default for String\n            }\n            else if (!processor || processor === Number || processor === Boolean || processor === Function) {\n                refined[key] = null; // assign null for other non-custom processor funcs\n            }\n            else {\n                refined[key] = processor(null); // run the custom processor func\n            }\n        }\n    }\n    if (leftoverProps) {\n        for (var key in rawProps) {\n            if (processors[key] === undefined) {\n                leftoverProps[key] = rawProps[key];\n            }\n        }\n    }\n    return refined;\n}\n/* Date stuff that doesn't belong in datelib core\n----------------------------------------------------------------------------------------------------------------------*/\n// given a timed range, computes an all-day range that has the same exact duration,\n// but whose start time is aligned with the start of the day.\nfunction computeAlignedDayRange(timedRange) {\n    var dayCnt = Math.floor(diffDays(timedRange.start, timedRange.end)) || 1;\n    var start = startOfDay(timedRange.start);\n    var end = addDays(start, dayCnt);\n    return { start: start, end: end };\n}\n// given a timed range, computes an all-day range based on how for the end date bleeds into the next day\n// TODO: give nextDayThreshold a default arg\nfunction computeVisibleDayRange(timedRange, nextDayThreshold) {\n    if (nextDayThreshold === void 0) { nextDayThreshold = createDuration(0); }\n    var startDay = null;\n    var endDay = null;\n    if (timedRange.end) {\n        endDay = startOfDay(timedRange.end);\n        var endTimeMS = timedRange.end.valueOf() - endDay.valueOf(); // # of milliseconds into `endDay`\n        // If the end time is actually inclusively part of the next day and is equal to or\n        // beyond the next day threshold, adjust the end to be the exclusive end of `endDay`.\n        // Otherwise, leaving it as inclusive will cause it to exclude `endDay`.\n        if (endTimeMS && endTimeMS >= asRoughMs(nextDayThreshold)) {\n            endDay = addDays(endDay, 1);\n        }\n    }\n    if (timedRange.start) {\n        startDay = startOfDay(timedRange.start); // the beginning of the day the range starts\n        // If end is within `startDay` but not past nextDayThreshold, assign the default duration of one day.\n        if (endDay && endDay <= startDay) {\n            endDay = addDays(startDay, 1);\n        }\n    }\n    return { start: startDay, end: endDay };\n}\n// spans from one day into another?\nfunction isMultiDayRange(range) {\n    var visibleRange = computeVisibleDayRange(range);\n    return diffDays(visibleRange.start, visibleRange.end) > 1;\n}\nfunction diffDates(date0, date1, dateEnv, largeUnit) {\n    if (largeUnit === 'year') {\n        return createDuration(dateEnv.diffWholeYears(date0, date1), 'year');\n    }\n    else if (largeUnit === 'month') {\n        return createDuration(dateEnv.diffWholeMonths(date0, date1), 'month');\n    }\n    else {\n        return diffDayAndTime(date0, date1); // returns a duration\n    }\n}\n\n/*! *****************************************************************************\r\nCopyright (c) Microsoft Corporation.\r\n\r\nPermission to use, copy, modify, and/or distribute this software for any\r\npurpose with or without fee is hereby granted.\r\n\r\nTHE SOFTWARE IS PROVIDED \"AS IS\" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH\r\nREGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY\r\nAND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,\r\nINDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM\r\nLOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR\r\nOTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR\r\nPERFORMANCE OF THIS SOFTWARE.\r\n***************************************************************************** */\r\n/* global Reflect, Promise */\r\n\r\nvar extendStatics = function(d, b) {\r\n    extendStatics = Object.setPrototypeOf ||\r\n        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||\r\n        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };\r\n    return extendStatics(d, b);\r\n};\r\n\r\nfunction __extends(d, b) {\r\n    extendStatics(d, b);\r\n    function __() { this.constructor = d; }\r\n    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());\r\n}\r\n\r\nvar __assign = function() {\r\n    __assign = Object.assign || function __assign(t) {\r\n        for (var s, i = 1, n = arguments.length; i < n; i++) {\r\n            s = arguments[i];\r\n            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];\r\n        }\r\n        return t;\r\n    };\r\n    return __assign.apply(this, arguments);\r\n};\n\nfunction parseRecurring(eventInput, allDayDefault, dateEnv, recurringTypes, leftovers) {\n    for (var i = 0; i < recurringTypes.length; i++) {\n        var localLeftovers = {};\n        var parsed = recurringTypes[i].parse(eventInput, localLeftovers, dateEnv);\n        if (parsed) {\n            var allDay = localLeftovers.allDay;\n            delete localLeftovers.allDay; // remove from leftovers\n            if (allDay == null) {\n                allDay = allDayDefault;\n                if (allDay == null) {\n                    allDay = parsed.allDayGuess;\n                    if (allDay == null) {\n                        allDay = false;\n                    }\n                }\n            }\n            __assign(leftovers, localLeftovers);\n            return {\n                allDay: allDay,\n                duration: parsed.duration,\n                typeData: parsed.typeData,\n                typeId: i\n            };\n        }\n    }\n    return null;\n}\n/*\nEvent MUST have a recurringDef\n*/\nfunction expandRecurringRanges(eventDef, duration, framingRange, dateEnv, recurringTypes) {\n    var typeDef = recurringTypes[eventDef.recurringDef.typeId];\n    var markers = typeDef.expand(eventDef.recurringDef.typeData, {\n        start: dateEnv.subtract(framingRange.start, duration),\n        end: framingRange.end\n    }, dateEnv);\n    // the recurrence plugins don't guarantee that all-day events are start-of-day, so we have to\n    if (eventDef.allDay) {\n        markers = markers.map(startOfDay);\n    }\n    return markers;\n}\n\nvar hasOwnProperty = Object.prototype.hasOwnProperty;\n// Merges an array of objects into a single object.\n// The second argument allows for an array of property names who's object values will be merged together.\nfunction mergeProps(propObjs, complexProps) {\n    var dest = {};\n    var i;\n    var name;\n    var complexObjs;\n    var j;\n    var val;\n    var props;\n    if (complexProps) {\n        for (i = 0; i < complexProps.length; i++) {\n            name = complexProps[i];\n            complexObjs = [];\n            // collect the trailing object values, stopping when a non-object is discovered\n            for (j = propObjs.length - 1; j >= 0; j--) {\n                val = propObjs[j][name];\n                if (typeof val === 'object' && val) { // non-null object\n                    complexObjs.unshift(val);\n                }\n                else if (val !== undefined) {\n                    dest[name] = val; // if there were no objects, this value will be used\n                    break;\n                }\n            }\n            // if the trailing values were objects, use the merged value\n            if (complexObjs.length) {\n                dest[name] = mergeProps(complexObjs);\n            }\n        }\n    }\n    // copy values into the destination, going from last to first\n    for (i = propObjs.length - 1; i >= 0; i--) {\n        props = propObjs[i];\n        for (name in props) {\n            if (!(name in dest)) { // if already assigned by previous props or complex props, don't reassign\n                dest[name] = props[name];\n            }\n        }\n    }\n    return dest;\n}\nfunction filterHash(hash, func) {\n    var filtered = {};\n    for (var key in hash) {\n        if (func(hash[key], key)) {\n            filtered[key] = hash[key];\n        }\n    }\n    return filtered;\n}\nfunction mapHash(hash, func) {\n    var newHash = {};\n    for (var key in hash) {\n        newHash[key] = func(hash[key], key);\n    }\n    return newHash;\n}\nfunction arrayToHash(a) {\n    var hash = {};\n    for (var _i = 0, a_1 = a; _i < a_1.length; _i++) {\n        var item = a_1[_i];\n        hash[item] = true;\n    }\n    return hash;\n}\nfunction hashValuesToArray(obj) {\n    var a = [];\n    for (var key in obj) {\n        a.push(obj[key]);\n    }\n    return a;\n}\nfunction isPropsEqual(obj0, obj1) {\n    for (var key in obj0) {\n        if (hasOwnProperty.call(obj0, key)) {\n            if (!(key in obj1)) {\n                return false;\n            }\n        }\n    }\n    for (var key in obj1) {\n        if (hasOwnProperty.call(obj1, key)) {\n            if (obj0[key] !== obj1[key]) {\n                return false;\n            }\n        }\n    }\n    return true;\n}\n\nfunction parseEvents(rawEvents, sourceId, calendar, allowOpenRange) {\n    var eventStore = createEmptyEventStore();\n    for (var _i = 0, rawEvents_1 = rawEvents; _i < rawEvents_1.length; _i++) {\n        var rawEvent = rawEvents_1[_i];\n        var tuple = parseEvent(rawEvent, sourceId, calendar, allowOpenRange);\n        if (tuple) {\n            eventTupleToStore(tuple, eventStore);\n        }\n    }\n    return eventStore;\n}\nfunction eventTupleToStore(tuple, eventStore) {\n    if (eventStore === void 0) { eventStore = createEmptyEventStore(); }\n    eventStore.defs[tuple.def.defId] = tuple.def;\n    if (tuple.instance) {\n        eventStore.instances[tuple.instance.instanceId] = tuple.instance;\n    }\n    return eventStore;\n}\nfunction expandRecurring(eventStore, framingRange, calendar) {\n    var dateEnv = calendar.dateEnv;\n    var defs = eventStore.defs, instances = eventStore.instances;\n    // remove existing recurring instances\n    instances = filterHash(instances, function (instance) {\n        return !defs[instance.defId].recurringDef;\n    });\n    for (var defId in defs) {\n        var def = defs[defId];\n        if (def.recurringDef) {\n            var duration = def.recurringDef.duration;\n            if (!duration) {\n                duration = def.allDay ?\n                    calendar.defaultAllDayEventDuration :\n                    calendar.defaultTimedEventDuration;\n            }\n            var starts = expandRecurringRanges(def, duration, framingRange, calendar.dateEnv, calendar.pluginSystem.hooks.recurringTypes);\n            for (var _i = 0, starts_1 = starts; _i < starts_1.length; _i++) {\n                var start = starts_1[_i];\n                var instance = createEventInstance(defId, {\n                    start: start,\n                    end: dateEnv.add(start, duration)\n                });\n                instances[instance.instanceId] = instance;\n            }\n        }\n    }\n    return { defs: defs, instances: instances };\n}\n// retrieves events that have the same groupId as the instance specified by `instanceId`\n// or they are the same as the instance.\n// why might instanceId not be in the store? an event from another calendar?\nfunction getRelevantEvents(eventStore, instanceId) {\n    var instance = eventStore.instances[instanceId];\n    if (instance) {\n        var def_1 = eventStore.defs[instance.defId];\n        // get events/instances with same group\n        var newStore = filterEventStoreDefs(eventStore, function (lookDef) {\n            return isEventDefsGrouped(def_1, lookDef);\n        });\n        // add the original\n        // TODO: wish we could use eventTupleToStore or something like it\n        newStore.defs[def_1.defId] = def_1;\n        newStore.instances[instance.instanceId] = instance;\n        return newStore;\n    }\n    return createEmptyEventStore();\n}\nfunction isEventDefsGrouped(def0, def1) {\n    return Boolean(def0.groupId && def0.groupId === def1.groupId);\n}\nfunction transformRawEvents(rawEvents, eventSource, calendar) {\n    var calEachTransform = calendar.opt('eventDataTransform');\n    var sourceEachTransform = eventSource ? eventSource.eventDataTransform : null;\n    if (sourceEachTransform) {\n        rawEvents = transformEachRawEvent(rawEvents, sourceEachTransform);\n    }\n    if (calEachTransform) {\n        rawEvents = transformEachRawEvent(rawEvents, calEachTransform);\n    }\n    return rawEvents;\n}\nfunction transformEachRawEvent(rawEvents, func) {\n    var refinedEvents;\n    if (!func) {\n        refinedEvents = rawEvents;\n    }\n    else {\n        refinedEvents = [];\n        for (var _i = 0, rawEvents_2 = rawEvents; _i < rawEvents_2.length; _i++) {\n            var rawEvent = rawEvents_2[_i];\n            var refinedEvent = func(rawEvent);\n            if (refinedEvent) {\n                refinedEvents.push(refinedEvent);\n            }\n            else if (refinedEvent == null) {\n                refinedEvents.push(rawEvent);\n            } // if a different falsy value, do nothing\n        }\n    }\n    return refinedEvents;\n}\nfunction createEmptyEventStore() {\n    return { defs: {}, instances: {} };\n}\nfunction mergeEventStores(store0, store1) {\n    return {\n        defs: __assign({}, store0.defs, store1.defs),\n        instances: __assign({}, store0.instances, store1.instances)\n    };\n}\nfunction filterEventStoreDefs(eventStore, filterFunc) {\n    var defs = filterHash(eventStore.defs, filterFunc);\n    var instances = filterHash(eventStore.instances, function (instance) {\n        return defs[instance.defId]; // still exists?\n    });\n    return { defs: defs, instances: instances };\n}\n\nfunction parseRange(input, dateEnv) {\n    var start = null;\n    var end = null;\n    if (input.start) {\n        start = dateEnv.createMarker(input.start);\n    }\n    if (input.end) {\n        end = dateEnv.createMarker(input.end);\n    }\n    if (!start && !end) {\n        return null;\n    }\n    if (start && end && end < start) {\n        return null;\n    }\n    return { start: start, end: end };\n}\n// SIDE-EFFECT: will mutate ranges.\n// Will return a new array result.\nfunction invertRanges(ranges, constraintRange) {\n    var invertedRanges = [];\n    var start = constraintRange.start; // the end of the previous range. the start of the new range\n    var i;\n    var dateRange;\n    // ranges need to be in order. required for our date-walking algorithm\n    ranges.sort(compareRanges);\n    for (i = 0; i < ranges.length; i++) {\n        dateRange = ranges[i];\n        // add the span of time before the event (if there is any)\n        if (dateRange.start > start) { // compare millisecond time (skip any ambig logic)\n            invertedRanges.push({ start: start, end: dateRange.start });\n        }\n        if (dateRange.end > start) {\n            start = dateRange.end;\n        }\n    }\n    // add the span of time after the last event (if there is any)\n    if (start < constraintRange.end) { // compare millisecond time (skip any ambig logic)\n        invertedRanges.push({ start: start, end: constraintRange.end });\n    }\n    return invertedRanges;\n}\nfunction compareRanges(range0, range1) {\n    return range0.start.valueOf() - range1.start.valueOf(); // earlier ranges go first\n}\nfunction intersectRanges(range0, range1) {\n    var start = range0.start;\n    var end = range0.end;\n    var newRange = null;\n    if (range1.start !== null) {\n        if (start === null) {\n            start = range1.start;\n        }\n        else {\n            start = new Date(Math.max(start.valueOf(), range1.start.valueOf()));\n        }\n    }\n    if (range1.end != null) {\n        if (end === null) {\n            end = range1.end;\n        }\n        else {\n            end = new Date(Math.min(end.valueOf(), range1.end.valueOf()));\n        }\n    }\n    if (start === null || end === null || start < end) {\n        newRange = { start: start, end: end };\n    }\n    return newRange;\n}\nfunction rangesEqual(range0, range1) {\n    return (range0.start === null ? null : range0.start.valueOf()) === (range1.start === null ? null : range1.start.valueOf()) &&\n        (range0.end === null ? null : range0.end.valueOf()) === (range1.end === null ? null : range1.end.valueOf());\n}\nfunction rangesIntersect(range0, range1) {\n    return (range0.end === null || range1.start === null || range0.end > range1.start) &&\n        (range0.start === null || range1.end === null || range0.start < range1.end);\n}\nfunction rangeContainsRange(outerRange, innerRange) {\n    return (outerRange.start === null || (innerRange.start !== null && innerRange.start >= outerRange.start)) &&\n        (outerRange.end === null || (innerRange.end !== null && innerRange.end <= outerRange.end));\n}\nfunction rangeContainsMarker(range, date) {\n    return (range.start === null || date >= range.start) &&\n        (range.end === null || date < range.end);\n}\n// If the given date is not within the given range, move it inside.\n// (If it's past the end, make it one millisecond before the end).\nfunction constrainMarkerToRange(date, range) {\n    if (range.start != null && date < range.start) {\n        return range.start;\n    }\n    if (range.end != null && date >= range.end) {\n        return new Date(range.end.valueOf() - 1);\n    }\n    return date;\n}\n\nfunction removeExact(array, exactVal) {\n    var removeCnt = 0;\n    var i = 0;\n    while (i < array.length) {\n        if (array[i] === exactVal) {\n            array.splice(i, 1);\n            removeCnt++;\n        }\n        else {\n            i++;\n        }\n    }\n    return removeCnt;\n}\nfunction isArraysEqual(a0, a1) {\n    var len = a0.length;\n    var i;\n    if (len !== a1.length) { // not array? or not same length?\n        return false;\n    }\n    for (i = 0; i < len; i++) {\n        if (a0[i] !== a1[i]) {\n            return false;\n        }\n    }\n    return true;\n}\n\nfunction memoize(workerFunc) {\n    var args;\n    var res;\n    return function () {\n        if (!args || !isArraysEqual(args, arguments)) {\n            args = arguments;\n            res = workerFunc.apply(this, arguments);\n        }\n        return res;\n    };\n}\n/*\nalways executes the workerFunc, but if the result is equal to the previous result,\nreturn the previous result instead.\n*/\nfunction memoizeOutput(workerFunc, equalityFunc) {\n    var cachedRes = null;\n    return function () {\n        var newRes = workerFunc.apply(this, arguments);\n        if (cachedRes === null || !(cachedRes === newRes || equalityFunc(cachedRes, newRes))) {\n            cachedRes = newRes;\n        }\n        return cachedRes;\n    };\n}\n\nvar EXTENDED_SETTINGS_AND_SEVERITIES = {\n    week: 3,\n    separator: 0,\n    omitZeroMinute: 0,\n    meridiem: 0,\n    omitCommas: 0\n};\nvar STANDARD_DATE_PROP_SEVERITIES = {\n    timeZoneName: 7,\n    era: 6,\n    year: 5,\n    month: 4,\n    day: 2,\n    weekday: 2,\n    hour: 1,\n    minute: 1,\n    second: 1\n};\nvar MERIDIEM_RE = /\\s*([ap])\\.?m\\.?/i; // eats up leading spaces too\nvar COMMA_RE = /,/g; // we need re for globalness\nvar MULTI_SPACE_RE = /\\s+/g;\nvar LTR_RE = /\\u200e/g; // control character\nvar UTC_RE = /UTC|GMT/;\nvar NativeFormatter = /** @class */ (function () {\n    function NativeFormatter(formatSettings) {\n        var standardDateProps = {};\n        var extendedSettings = {};\n        var severity = 0;\n        for (var name_1 in formatSettings) {\n            if (name_1 in EXTENDED_SETTINGS_AND_SEVERITIES) {\n                extendedSettings[name_1] = formatSettings[name_1];\n                severity = Math.max(EXTENDED_SETTINGS_AND_SEVERITIES[name_1], severity);\n            }\n            else {\n                standardDateProps[name_1] = formatSettings[name_1];\n                if (name_1 in STANDARD_DATE_PROP_SEVERITIES) {\n                    severity = Math.max(STANDARD_DATE_PROP_SEVERITIES[name_1], severity);\n                }\n            }\n        }\n        this.standardDateProps = standardDateProps;\n        this.extendedSettings = extendedSettings;\n        this.severity = severity;\n        this.buildFormattingFunc = memoize(buildFormattingFunc);\n    }\n    NativeFormatter.prototype.format = function (date, context) {\n        return this.buildFormattingFunc(this.standardDateProps, this.extendedSettings, context)(date);\n    };\n    NativeFormatter.prototype.formatRange = function (start, end, context) {\n        var _a = this, standardDateProps = _a.standardDateProps, extendedSettings = _a.extendedSettings;\n        var diffSeverity = computeMarkerDiffSeverity(start.marker, end.marker, context.calendarSystem);\n        if (!diffSeverity) {\n            return this.format(start, context);\n        }\n        var biggestUnitForPartial = diffSeverity;\n        if (biggestUnitForPartial > 1 && // the two dates are different in a way that's larger scale than time\n            (standardDateProps.year === 'numeric' || standardDateProps.year === '2-digit') &&\n            (standardDateProps.month === 'numeric' || standardDateProps.month === '2-digit') &&\n            (standardDateProps.day === 'numeric' || standardDateProps.day === '2-digit')) {\n            biggestUnitForPartial = 1; // make it look like the dates are only different in terms of time\n        }\n        var full0 = this.format(start, context);\n        var full1 = this.format(end, context);\n        if (full0 === full1) {\n            return full0;\n        }\n        var partialDateProps = computePartialFormattingOptions(standardDateProps, biggestUnitForPartial);\n        var partialFormattingFunc = buildFormattingFunc(partialDateProps, extendedSettings, context);\n        var partial0 = partialFormattingFunc(start);\n        var partial1 = partialFormattingFunc(end);\n        var insertion = findCommonInsertion(full0, partial0, full1, partial1);\n        var separator = extendedSettings.separator || '';\n        if (insertion) {\n            return insertion.before + partial0 + separator + partial1 + insertion.after;\n        }\n        return full0 + separator + full1;\n    };\n    NativeFormatter.prototype.getLargestUnit = function () {\n        switch (this.severity) {\n            case 7:\n            case 6:\n            case 5:\n                return 'year';\n            case 4:\n                return 'month';\n            case 3:\n                return 'week';\n            default:\n                return 'day';\n        }\n    };\n    return NativeFormatter;\n}());\nfunction buildFormattingFunc(standardDateProps, extendedSettings, context) {\n    var standardDatePropCnt = Object.keys(standardDateProps).length;\n    if (standardDatePropCnt === 1 && standardDateProps.timeZoneName === 'short') {\n        return function (date) {\n            return formatTimeZoneOffset(date.timeZoneOffset);\n        };\n    }\n    if (standardDatePropCnt === 0 && extendedSettings.week) {\n        return function (date) {\n            return formatWeekNumber(context.computeWeekNumber(date.marker), context.weekLabel, context.locale, extendedSettings.week);\n        };\n    }\n    return buildNativeFormattingFunc(standardDateProps, extendedSettings, context);\n}\nfunction buildNativeFormattingFunc(standardDateProps, extendedSettings, context) {\n    standardDateProps = __assign({}, standardDateProps); // copy\n    extendedSettings = __assign({}, extendedSettings); // copy\n    sanitizeSettings(standardDateProps, extendedSettings);\n    standardDateProps.timeZone = 'UTC'; // we leverage the only guaranteed timeZone for our UTC markers\n    var normalFormat = new Intl.DateTimeFormat(context.locale.codes, standardDateProps);\n    var zeroFormat; // needed?\n    if (extendedSettings.omitZeroMinute) {\n        var zeroProps = __assign({}, standardDateProps);\n        delete zeroProps.minute; // seconds and ms were already considered in sanitizeSettings\n        zeroFormat = new Intl.DateTimeFormat(context.locale.codes, zeroProps);\n    }\n    return function (date) {\n        var marker = date.marker;\n        var format;\n        if (zeroFormat && !marker.getUTCMinutes()) {\n            format = zeroFormat;\n        }\n        else {\n            format = normalFormat;\n        }\n        var s = format.format(marker);\n        return postProcess(s, date, standardDateProps, extendedSettings, context);\n    };\n}\nfunction sanitizeSettings(standardDateProps, extendedSettings) {\n    // deal with a browser inconsistency where formatting the timezone\n    // requires that the hour/minute be present.\n    if (standardDateProps.timeZoneName) {\n        if (!standardDateProps.hour) {\n            standardDateProps.hour = '2-digit';\n        }\n        if (!standardDateProps.minute) {\n            standardDateProps.minute = '2-digit';\n        }\n    }\n    // only support short timezone names\n    if (standardDateProps.timeZoneName === 'long') {\n        standardDateProps.timeZoneName = 'short';\n    }\n    // if requesting to display seconds, MUST display minutes\n    if (extendedSettings.omitZeroMinute && (standardDateProps.second || standardDateProps.millisecond)) {\n        delete extendedSettings.omitZeroMinute;\n    }\n}\nfunction postProcess(s, date, standardDateProps, extendedSettings, context) {\n    s = s.replace(LTR_RE, ''); // remove left-to-right control chars. do first. good for other regexes\n    if (standardDateProps.timeZoneName === 'short') {\n        s = injectTzoStr(s, (context.timeZone === 'UTC' || date.timeZoneOffset == null) ?\n            'UTC' : // important to normalize for IE, which does \"GMT\"\n            formatTimeZoneOffset(date.timeZoneOffset));\n    }\n    if (extendedSettings.omitCommas) {\n        s = s.replace(COMMA_RE, '').trim();\n    }\n    if (extendedSettings.omitZeroMinute) {\n        s = s.replace(':00', ''); // zeroFormat doesn't always achieve this\n    }\n    // ^ do anything that might create adjacent spaces before this point,\n    // because MERIDIEM_RE likes to eat up loading spaces\n    if (extendedSettings.meridiem === false) {\n        s = s.replace(MERIDIEM_RE, '').trim();\n    }\n    else if (extendedSettings.meridiem === 'narrow') { // a/p\n        s = s.replace(MERIDIEM_RE, function (m0, m1) {\n            return m1.toLocaleLowerCase();\n        });\n    }\n    else if (extendedSettings.meridiem === 'short') { // am/pm\n        s = s.replace(MERIDIEM_RE, function (m0, m1) {\n            return m1.toLocaleLowerCase() + 'm';\n        });\n    }\n    else if (extendedSettings.meridiem === 'lowercase') { // other meridiem transformers already converted to lowercase\n        s = s.replace(MERIDIEM_RE, function (m0) {\n            return m0.toLocaleLowerCase();\n        });\n    }\n    s = s.replace(MULTI_SPACE_RE, ' ');\n    s = s.trim();\n    return s;\n}\nfunction injectTzoStr(s, tzoStr) {\n    var replaced = false;\n    s = s.replace(UTC_RE, function () {\n        replaced = true;\n        return tzoStr;\n    });\n    // IE11 doesn't include UTC/GMT in the original string, so append to end\n    if (!replaced) {\n        s += ' ' + tzoStr;\n    }\n    return s;\n}\nfunction formatWeekNumber(num, weekLabel, locale, display) {\n    var parts = [];\n    if (display === 'narrow') {\n        parts.push(weekLabel);\n    }\n    else if (display === 'short') {\n        parts.push(weekLabel, ' ');\n    }\n    // otherwise, considered 'numeric'\n    parts.push(locale.simpleNumberFormat.format(num));\n    if (locale.options.isRtl) { // TODO: use control characters instead?\n        parts.reverse();\n    }\n    return parts.join('');\n}\n// Range Formatting Utils\n// 0 = exactly the same\n// 1 = different by time\n// and bigger\nfunction computeMarkerDiffSeverity(d0, d1, ca) {\n    if (ca.getMarkerYear(d0) !== ca.getMarkerYear(d1)) {\n        return 5;\n    }\n    if (ca.getMarkerMonth(d0) !== ca.getMarkerMonth(d1)) {\n        return 4;\n    }\n    if (ca.getMarkerDay(d0) !== ca.getMarkerDay(d1)) {\n        return 2;\n    }\n    if (timeAsMs(d0) !== timeAsMs(d1)) {\n        return 1;\n    }\n    return 0;\n}\nfunction computePartialFormattingOptions(options, biggestUnit) {\n    var partialOptions = {};\n    for (var name_2 in options) {\n        if (!(name_2 in STANDARD_DATE_PROP_SEVERITIES) || // not a date part prop (like timeZone)\n            STANDARD_DATE_PROP_SEVERITIES[name_2] <= biggestUnit) {\n            partialOptions[name_2] = options[name_2];\n        }\n    }\n    return partialOptions;\n}\nfunction findCommonInsertion(full0, partial0, full1, partial1) {\n    var i0 = 0;\n    while (i0 < full0.length) {\n        var found0 = full0.indexOf(partial0, i0);\n        if (found0 === -1) {\n            break;\n        }\n        var before0 = full0.substr(0, found0);\n        i0 = found0 + partial0.length;\n        var after0 = full0.substr(i0);\n        var i1 = 0;\n        while (i1 < full1.length) {\n            var found1 = full1.indexOf(partial1, i1);\n            if (found1 === -1) {\n                break;\n            }\n            var before1 = full1.substr(0, found1);\n            i1 = found1 + partial1.length;\n            var after1 = full1.substr(i1);\n            if (before0 === before1 && after0 === after1) {\n                return {\n                    before: before0,\n                    after: after0\n                };\n            }\n        }\n    }\n    return null;\n}\n\n/*\nTODO: fix the terminology of \"formatter\" vs \"formatting func\"\n*/\n/*\nAt the time of instantiation, this object does not know which cmd-formatting system it will use.\nIt receives this at the time of formatting, as a setting.\n*/\nvar CmdFormatter = /** @class */ (function () {\n    function CmdFormatter(cmdStr, separator) {\n        this.cmdStr = cmdStr;\n        this.separator = separator;\n    }\n    CmdFormatter.prototype.format = function (date, context) {\n        return context.cmdFormatter(this.cmdStr, createVerboseFormattingArg(date, null, context, this.separator));\n    };\n    CmdFormatter.prototype.formatRange = function (start, end, context) {\n        return context.cmdFormatter(this.cmdStr, createVerboseFormattingArg(start, end, context, this.separator));\n    };\n    return CmdFormatter;\n}());\n\nvar FuncFormatter = /** @class */ (function () {\n    function FuncFormatter(func) {\n        this.func = func;\n    }\n    FuncFormatter.prototype.format = function (date, context) {\n        return this.func(createVerboseFormattingArg(date, null, context));\n    };\n    FuncFormatter.prototype.formatRange = function (start, end, context) {\n        return this.func(createVerboseFormattingArg(start, end, context));\n    };\n    return FuncFormatter;\n}());\n\n// Formatter Object Creation\nfunction createFormatter(input, defaultSeparator) {\n    if (typeof input === 'object' && input) { // non-null object\n        if (typeof defaultSeparator === 'string') {\n            input = __assign({ separator: defaultSeparator }, input);\n        }\n        return new NativeFormatter(input);\n    }\n    else if (typeof input === 'string') {\n        return new CmdFormatter(input, defaultSeparator);\n    }\n    else if (typeof input === 'function') {\n        return new FuncFormatter(input);\n    }\n}\n// String Utils\n// timeZoneOffset is in minutes\nfunction buildIsoString(marker, timeZoneOffset, stripZeroTime) {\n    if (stripZeroTime === void 0) { stripZeroTime = false; }\n    var s = marker.toISOString();\n    s = s.replace('.000', '');\n    if (stripZeroTime) {\n        s = s.replace('T00:00:00Z', '');\n    }\n    if (s.length > 10) { // time part wasn't stripped, can add timezone info\n        if (timeZoneOffset == null) {\n            s = s.replace('Z', '');\n        }\n        else if (timeZoneOffset !== 0) {\n            s = s.replace('Z', formatTimeZoneOffset(timeZoneOffset, true));\n        }\n        // otherwise, its UTC-0 and we want to keep the Z\n    }\n    return s;\n}\nfunction formatIsoTimeString(marker) {\n    return padStart(marker.getUTCHours(), 2) + ':' +\n        padStart(marker.getUTCMinutes(), 2) + ':' +\n        padStart(marker.getUTCSeconds(), 2);\n}\nfunction formatTimeZoneOffset(minutes, doIso) {\n    if (doIso === void 0) { doIso = false; }\n    var sign = minutes < 0 ? '-' : '+';\n    var abs = Math.abs(minutes);\n    var hours = Math.floor(abs / 60);\n    var mins = Math.round(abs % 60);\n    if (doIso) {\n        return sign + padStart(hours, 2) + ':' + padStart(mins, 2);\n    }\n    else {\n        return 'GMT' + sign + hours + (mins ? ':' + padStart(mins, 2) : '');\n    }\n}\n// Arg Utils\nfunction createVerboseFormattingArg(start, end, context, separator) {\n    var startInfo = expandZonedMarker(start, context.calendarSystem);\n    var endInfo = end ? expandZonedMarker(end, context.calendarSystem) : null;\n    return {\n        date: startInfo,\n        start: startInfo,\n        end: endInfo,\n        timeZone: context.timeZone,\n        localeCodes: context.locale.codes,\n        separator: separator\n    };\n}\nfunction expandZonedMarker(dateInfo, calendarSystem) {\n    var a = calendarSystem.markerToArray(dateInfo.marker);\n    return {\n        marker: dateInfo.marker,\n        timeZoneOffset: dateInfo.timeZoneOffset,\n        array: a,\n        year: a[0],\n        month: a[1],\n        day: a[2],\n        hour: a[3],\n        minute: a[4],\n        second: a[5],\n        millisecond: a[6]\n    };\n}\n\nvar EventSourceApi = /** @class */ (function () {\n    function EventSourceApi(calendar, internalEventSource) {\n        this.calendar = calendar;\n        this.internalEventSource = internalEventSource;\n    }\n    EventSourceApi.prototype.remove = function () {\n        this.calendar.dispatch({\n            type: 'REMOVE_EVENT_SOURCE',\n            sourceId: this.internalEventSource.sourceId\n        });\n    };\n    EventSourceApi.prototype.refetch = function () {\n        this.calendar.dispatch({\n            type: 'FETCH_EVENT_SOURCES',\n            sourceIds: [this.internalEventSource.sourceId]\n        });\n    };\n    Object.defineProperty(EventSourceApi.prototype, \"id\", {\n        get: function () {\n            return this.internalEventSource.publicId;\n        },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventSourceApi.prototype, \"url\", {\n        // only relevant to json-feed event sources\n        get: function () {\n            return this.internalEventSource.meta.url;\n        },\n        enumerable: true,\n        configurable: true\n    });\n    return EventSourceApi;\n}());\n\nvar EventApi = /** @class */ (function () {\n    function EventApi(calendar, def, instance) {\n        this._calendar = calendar;\n        this._def = def;\n        this._instance = instance || null;\n    }\n    /*\n    TODO: make event struct more responsible for this\n    */\n    EventApi.prototype.setProp = function (name, val) {\n        var _a, _b;\n        if (name in DATE_PROPS) ;\n        else if (name in NON_DATE_PROPS) {\n            if (typeof NON_DATE_PROPS[name] === 'function') {\n                val = NON_DATE_PROPS[name](val);\n            }\n            this.mutate({\n                standardProps: (_a = {}, _a[name] = val, _a)\n            });\n        }\n        else if (name in UNSCOPED_EVENT_UI_PROPS) {\n            var ui = void 0;\n            if (typeof UNSCOPED_EVENT_UI_PROPS[name] === 'function') {\n                val = UNSCOPED_EVENT_UI_PROPS[name](val);\n            }\n            if (name === 'color') {\n                ui = { backgroundColor: val, borderColor: val };\n            }\n            else if (name === 'editable') {\n                ui = { startEditable: val, durationEditable: val };\n            }\n            else {\n                ui = (_b = {}, _b[name] = val, _b);\n            }\n            this.mutate({\n                standardProps: { ui: ui }\n            });\n        }\n    };\n    EventApi.prototype.setExtendedProp = function (name, val) {\n        var _a;\n        this.mutate({\n            extendedProps: (_a = {}, _a[name] = val, _a)\n        });\n    };\n    EventApi.prototype.setStart = function (startInput, options) {\n        if (options === void 0) { options = {}; }\n        var dateEnv = this._calendar.dateEnv;\n        var start = dateEnv.createMarker(startInput);\n        if (start && this._instance) { // TODO: warning if parsed bad\n            var instanceRange = this._instance.range;\n            var startDelta = diffDates(instanceRange.start, start, dateEnv, options.granularity); // what if parsed bad!?\n            if (options.maintainDuration) {\n                this.mutate({ datesDelta: startDelta });\n            }\n            else {\n                this.mutate({ startDelta: startDelta });\n            }\n        }\n    };\n    EventApi.prototype.setEnd = function (endInput, options) {\n        if (options === void 0) { options = {}; }\n        var dateEnv = this._calendar.dateEnv;\n        var end;\n        if (endInput != null) {\n            end = dateEnv.createMarker(endInput);\n            if (!end) {\n                return; // TODO: warning if parsed bad\n            }\n        }\n        if (this._instance) {\n            if (end) {\n                var endDelta = diffDates(this._instance.range.end, end, dateEnv, options.granularity);\n                this.mutate({ endDelta: endDelta });\n            }\n            else {\n                this.mutate({ standardProps: { hasEnd: false } });\n            }\n        }\n    };\n    EventApi.prototype.setDates = function (startInput, endInput, options) {\n        if (options === void 0) { options = {}; }\n        var dateEnv = this._calendar.dateEnv;\n        var standardProps = { allDay: options.allDay };\n        var start = dateEnv.createMarker(startInput);\n        var end;\n        if (!start) {\n            return; // TODO: warning if parsed bad\n        }\n        if (endInput != null) {\n            end = dateEnv.createMarker(endInput);\n            if (!end) { // TODO: warning if parsed bad\n                return;\n            }\n        }\n        if (this._instance) {\n            var instanceRange = this._instance.range;\n            // when computing the diff for an event being converted to all-day,\n            // compute diff off of the all-day values the way event-mutation does.\n            if (options.allDay === true) {\n                instanceRange = computeAlignedDayRange(instanceRange);\n            }\n            var startDelta = diffDates(instanceRange.start, start, dateEnv, options.granularity);\n            if (end) {\n                var endDelta = diffDates(instanceRange.end, end, dateEnv, options.granularity);\n                if (durationsEqual(startDelta, endDelta)) {\n                    this.mutate({ datesDelta: startDelta, standardProps: standardProps });\n                }\n                else {\n                    this.mutate({ startDelta: startDelta, endDelta: endDelta, standardProps: standardProps });\n                }\n            }\n            else { // means \"clear the end\"\n                standardProps.hasEnd = false;\n                this.mutate({ datesDelta: startDelta, standardProps: standardProps });\n            }\n        }\n    };\n    EventApi.prototype.moveStart = function (deltaInput) {\n        var delta = createDuration(deltaInput);\n        if (delta) { // TODO: warning if parsed bad\n            this.mutate({ startDelta: delta });\n        }\n    };\n    EventApi.prototype.moveEnd = function (deltaInput) {\n        var delta = createDuration(deltaInput);\n        if (delta) { // TODO: warning if parsed bad\n            this.mutate({ endDelta: delta });\n        }\n    };\n    EventApi.prototype.moveDates = function (deltaInput) {\n        var delta = createDuration(deltaInput);\n        if (delta) { // TODO: warning if parsed bad\n            this.mutate({ datesDelta: delta });\n        }\n    };\n    EventApi.prototype.setAllDay = function (allDay, options) {\n        if (options === void 0) { options = {}; }\n        var standardProps = { allDay: allDay };\n        var maintainDuration = options.maintainDuration;\n        if (maintainDuration == null) {\n            maintainDuration = this._calendar.opt('allDayMaintainDuration');\n        }\n        if (this._def.allDay !== allDay) {\n            standardProps.hasEnd = maintainDuration;\n        }\n        this.mutate({ standardProps: standardProps });\n    };\n    EventApi.prototype.formatRange = function (formatInput) {\n        var dateEnv = this._calendar.dateEnv;\n        var instance = this._instance;\n        var formatter = createFormatter(formatInput, this._calendar.opt('defaultRangeSeparator'));\n        if (this._def.hasEnd) {\n            return dateEnv.formatRange(instance.range.start, instance.range.end, formatter, {\n                forcedStartTzo: instance.forcedStartTzo,\n                forcedEndTzo: instance.forcedEndTzo\n            });\n        }\n        else {\n            return dateEnv.format(instance.range.start, formatter, {\n                forcedTzo: instance.forcedStartTzo\n            });\n        }\n    };\n    EventApi.prototype.mutate = function (mutation) {\n        var def = this._def;\n        var instance = this._instance;\n        if (instance) {\n            this._calendar.dispatch({\n                type: 'MUTATE_EVENTS',\n                instanceId: instance.instanceId,\n                mutation: mutation,\n                fromApi: true\n            });\n            var eventStore = this._calendar.state.eventStore;\n            this._def = eventStore.defs[def.defId];\n            this._instance = eventStore.instances[instance.instanceId];\n        }\n    };\n    EventApi.prototype.remove = function () {\n        this._calendar.dispatch({\n            type: 'REMOVE_EVENT_DEF',\n            defId: this._def.defId\n        });\n    };\n    Object.defineProperty(EventApi.prototype, \"source\", {\n        get: function () {\n            var sourceId = this._def.sourceId;\n            if (sourceId) {\n                return new EventSourceApi(this._calendar, this._calendar.state.eventSources[sourceId]);\n            }\n            return null;\n        },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"start\", {\n        get: function () {\n            return this._instance ?\n                this._calendar.dateEnv.toDate(this._instance.range.start) :\n                null;\n        },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"end\", {\n        get: function () {\n            return (this._instance && this._def.hasEnd) ?\n                this._calendar.dateEnv.toDate(this._instance.range.end) :\n                null;\n        },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"id\", {\n        // computable props that all access the def\n        // TODO: find a TypeScript-compatible way to do this at scale\n        get: function () { return this._def.publicId; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"groupId\", {\n        get: function () { return this._def.groupId; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"allDay\", {\n        get: function () { return this._def.allDay; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"title\", {\n        get: function () { return this._def.title; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"url\", {\n        get: function () { return this._def.url; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"rendering\", {\n        get: function () { return this._def.rendering; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"startEditable\", {\n        get: function () { return this._def.ui.startEditable; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"durationEditable\", {\n        get: function () { return this._def.ui.durationEditable; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"constraint\", {\n        get: function () { return this._def.ui.constraints[0] || null; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"overlap\", {\n        get: function () { return this._def.ui.overlap; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"allow\", {\n        get: function () { return this._def.ui.allows[0] || null; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"backgroundColor\", {\n        get: function () { return this._def.ui.backgroundColor; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"borderColor\", {\n        get: function () { return this._def.ui.borderColor; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"textColor\", {\n        get: function () { return this._def.ui.textColor; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"classNames\", {\n        // NOTE: user can't modify these because Object.freeze was called in event-def parsing\n        get: function () { return this._def.ui.classNames; },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(EventApi.prototype, \"extendedProps\", {\n        get: function () { return this._def.extendedProps; },\n        enumerable: true,\n        configurable: true\n    });\n    return EventApi;\n}());\n\n/*\nSpecifying nextDayThreshold signals that all-day ranges should be sliced.\n*/\nfunction sliceEventStore(eventStore, eventUiBases, framingRange, nextDayThreshold) {\n    var inverseBgByGroupId = {};\n    var inverseBgByDefId = {};\n    var defByGroupId = {};\n    var bgRanges = [];\n    var fgRanges = [];\n    var eventUis = compileEventUis(eventStore.defs, eventUiBases);\n    for (var defId in eventStore.defs) {\n        var def = eventStore.defs[defId];\n        if (def.rendering === 'inverse-background') {\n            if (def.groupId) {\n                inverseBgByGroupId[def.groupId] = [];\n                if (!defByGroupId[def.groupId]) {\n                    defByGroupId[def.groupId] = def;\n                }\n            }\n            else {\n                inverseBgByDefId[defId] = [];\n            }\n        }\n    }\n    for (var instanceId in eventStore.instances) {\n        var instance = eventStore.instances[instanceId];\n        var def = eventStore.defs[instance.defId];\n        var ui = eventUis[def.defId];\n        var origRange = instance.range;\n        var normalRange = (!def.allDay && nextDayThreshold) ?\n            computeVisibleDayRange(origRange, nextDayThreshold) :\n            origRange;\n        var slicedRange = intersectRanges(normalRange, framingRange);\n        if (slicedRange) {\n            if (def.rendering === 'inverse-background') {\n                if (def.groupId) {\n                    inverseBgByGroupId[def.groupId].push(slicedRange);\n                }\n                else {\n                    inverseBgByDefId[instance.defId].push(slicedRange);\n                }\n            }\n            else {\n                (def.rendering === 'background' ? bgRanges : fgRanges).push({\n                    def: def,\n                    ui: ui,\n                    instance: instance,\n                    range: slicedRange,\n                    isStart: normalRange.start && normalRange.start.valueOf() === slicedRange.start.valueOf(),\n                    isEnd: normalRange.end && normalRange.end.valueOf() === slicedRange.end.valueOf()\n                });\n            }\n        }\n    }\n    for (var groupId in inverseBgByGroupId) { // BY GROUP\n        var ranges = inverseBgByGroupId[groupId];\n        var invertedRanges = invertRanges(ranges, framingRange);\n        for (var _i = 0, invertedRanges_1 = invertedRanges; _i < invertedRanges_1.length; _i++) {\n            var invertedRange = invertedRanges_1[_i];\n            var def = defByGroupId[groupId];\n            var ui = eventUis[def.defId];\n            bgRanges.push({\n                def: def,\n                ui: ui,\n                instance: null,\n                range: invertedRange,\n                isStart: false,\n                isEnd: false\n            });\n        }\n    }\n    for (var defId in inverseBgByDefId) {\n        var ranges = inverseBgByDefId[defId];\n        var invertedRanges = invertRanges(ranges, framingRange);\n        for (var _a = 0, invertedRanges_2 = invertedRanges; _a < invertedRanges_2.length; _a++) {\n            var invertedRange = invertedRanges_2[_a];\n            bgRanges.push({\n                def: eventStore.defs[defId],\n                ui: eventUis[defId],\n                instance: null,\n                range: invertedRange,\n                isStart: false,\n                isEnd: false\n            });\n        }\n    }\n    return { bg: bgRanges, fg: fgRanges };\n}\nfunction hasBgRendering(def) {\n    return def.rendering === 'background' || def.rendering === 'inverse-background';\n}\nfunction filterSegsViaEls(context, segs, isMirror) {\n    var calendar = context.calendar, view = context.view;\n    if (calendar.hasPublicHandlers('eventRender')) {\n        segs = segs.filter(function (seg) {\n            var custom = calendar.publiclyTrigger('eventRender', [\n                {\n                    event: new EventApi(calendar, seg.eventRange.def, seg.eventRange.instance),\n                    isMirror: isMirror,\n                    isStart: seg.isStart,\n                    isEnd: seg.isEnd,\n                    // TODO: include seg.range once all components consistently generate it\n                    el: seg.el,\n                    view: view\n                }\n            ]);\n            if (custom === false) { // means don't render at all\n                return false;\n            }\n            else if (custom && custom !== true) {\n                seg.el = custom;\n            }\n            return true;\n        });\n    }\n    for (var _i = 0, segs_1 = segs; _i < segs_1.length; _i++) {\n        var seg = segs_1[_i];\n        setElSeg(seg.el, seg);\n    }\n    return segs;\n}\nfunction setElSeg(el, seg) {\n    el.fcSeg = seg;\n}\nfunction getElSeg(el) {\n    return el.fcSeg || null;\n}\n// event ui computation\nfunction compileEventUis(eventDefs, eventUiBases) {\n    return mapHash(eventDefs, function (eventDef) {\n        return compileEventUi(eventDef, eventUiBases);\n    });\n}\nfunction compileEventUi(eventDef, eventUiBases) {\n    var uis = [];\n    if (eventUiBases['']) {\n        uis.push(eventUiBases['']);\n    }\n    if (eventUiBases[eventDef.defId]) {\n        uis.push(eventUiBases[eventDef.defId]);\n    }\n    uis.push(eventDef.ui);\n    return combineEventUis(uis);\n}\n// triggers\nfunction triggerRenderedSegs(context, segs, isMirrors) {\n    var calendar = context.calendar, view = context.view;\n    if (calendar.hasPublicHandlers('eventPositioned')) {\n        for (var _i = 0, segs_2 = segs; _i < segs_2.length; _i++) {\n            var seg = segs_2[_i];\n            calendar.publiclyTriggerAfterSizing('eventPositioned', [\n                {\n                    event: new EventApi(calendar, seg.eventRange.def, seg.eventRange.instance),\n                    isMirror: isMirrors,\n                    isStart: seg.isStart,\n                    isEnd: seg.isEnd,\n                    el: seg.el,\n                    view: view\n                }\n            ]);\n        }\n    }\n    if (!calendar.state.eventSourceLoadingLevel) { // avoid initial empty state while pending\n        calendar.afterSizingTriggers._eventsPositioned = [null]; // fire once\n    }\n}\nfunction triggerWillRemoveSegs(context, segs, isMirrors) {\n    var calendar = context.calendar, view = context.view;\n    for (var _i = 0, segs_3 = segs; _i < segs_3.length; _i++) {\n        var seg = segs_3[_i];\n        calendar.trigger('eventElRemove', seg.el);\n    }\n    if (calendar.hasPublicHandlers('eventDestroy')) {\n        for (var _a = 0, segs_4 = segs; _a < segs_4.length; _a++) {\n            var seg = segs_4[_a];\n            calendar.publiclyTrigger('eventDestroy', [\n                {\n                    event: new EventApi(calendar, seg.eventRange.def, seg.eventRange.instance),\n                    isMirror: isMirrors,\n                    el: seg.el,\n                    view: view\n                }\n            ]);\n        }\n    }\n}\n// is-interactable\nfunction computeEventDraggable(context, eventDef, eventUi) {\n    var calendar = context.calendar, view = context.view;\n    var transformers = calendar.pluginSystem.hooks.isDraggableTransformers;\n    var val = eventUi.startEditable;\n    for (var _i = 0, transformers_1 = transformers; _i < transformers_1.length; _i++) {\n        var transformer = transformers_1[_i];\n        val = transformer(val, eventDef, eventUi, view);\n    }\n    return val;\n}\nfunction computeEventStartResizable(context, eventDef, eventUi) {\n    return eventUi.durationEditable && context.options.eventResizableFromStart;\n}\nfunction computeEventEndResizable(context, eventDef, eventUi) {\n    return eventUi.durationEditable;\n}\n\n// applies the mutation to ALL defs/instances within the event store\nfunction applyMutationToEventStore(eventStore, eventConfigBase, mutation, calendar) {\n    var eventConfigs = compileEventUis(eventStore.defs, eventConfigBase);\n    var dest = createEmptyEventStore();\n    for (var defId in eventStore.defs) {\n        var def = eventStore.defs[defId];\n        dest.defs[defId] = applyMutationToEventDef(def, eventConfigs[defId], mutation, calendar.pluginSystem.hooks.eventDefMutationAppliers, calendar);\n    }\n    for (var instanceId in eventStore.instances) {\n        var instance = eventStore.instances[instanceId];\n        var def = dest.defs[instance.defId]; // important to grab the newly modified def\n        dest.instances[instanceId] = applyMutationToEventInstance(instance, def, eventConfigs[instance.defId], mutation, calendar);\n    }\n    return dest;\n}\nfunction applyMutationToEventDef(eventDef, eventConfig, mutation, appliers, calendar) {\n    var standardProps = mutation.standardProps || {};\n    // if hasEnd has not been specified, guess a good value based on deltas.\n    // if duration will change, there's no way the default duration will persist,\n    // and thus, we need to mark the event as having a real end\n    if (standardProps.hasEnd == null &&\n        eventConfig.durationEditable &&\n        (mutation.startDelta || mutation.endDelta)) {\n        standardProps.hasEnd = true; // TODO: is this mutation okay?\n    }\n    var copy = __assign({}, eventDef, standardProps, { ui: __assign({}, eventDef.ui, standardProps.ui) });\n    if (mutation.extendedProps) {\n        copy.extendedProps = __assign({}, copy.extendedProps, mutation.extendedProps);\n    }\n    for (var _i = 0, appliers_1 = appliers; _i < appliers_1.length; _i++) {\n        var applier = appliers_1[_i];\n        applier(copy, mutation, calendar);\n    }\n    if (!copy.hasEnd && calendar.opt('forceEventDuration')) {\n        copy.hasEnd = true;\n    }\n    return copy;\n}\nfunction applyMutationToEventInstance(eventInstance, eventDef, // must first be modified by applyMutationToEventDef\neventConfig, mutation, calendar) {\n    var dateEnv = calendar.dateEnv;\n    var forceAllDay = mutation.standardProps && mutation.standardProps.allDay === true;\n    var clearEnd = mutation.standardProps && mutation.standardProps.hasEnd === false;\n    var copy = __assign({}, eventInstance);\n    if (forceAllDay) {\n        copy.range = computeAlignedDayRange(copy.range);\n    }\n    if (mutation.datesDelta && eventConfig.startEditable) {\n        copy.range = {\n            start: dateEnv.add(copy.range.start, mutation.datesDelta),\n            end: dateEnv.add(copy.range.end, mutation.datesDelta)\n        };\n    }\n    if (mutation.startDelta && eventConfig.durationEditable) {\n        copy.range = {\n            start: dateEnv.add(copy.range.start, mutation.startDelta),\n            end: copy.range.end\n        };\n    }\n    if (mutation.endDelta && eventConfig.durationEditable) {\n        copy.range = {\n            start: copy.range.start,\n            end: dateEnv.add(copy.range.end, mutation.endDelta)\n        };\n    }\n    if (clearEnd) {\n        copy.range = {\n            start: copy.range.start,\n            end: calendar.getDefaultEventEnd(eventDef.allDay, copy.range.start)\n        };\n    }\n    // in case event was all-day but the supplied deltas were not\n    // better util for this?\n    if (eventDef.allDay) {\n        copy.range = {\n            start: startOfDay(copy.range.start),\n            end: startOfDay(copy.range.end)\n        };\n    }\n    // handle invalid durations\n    if (copy.range.end < copy.range.start) {\n        copy.range.end = calendar.getDefaultEventEnd(eventDef.allDay, copy.range.start);\n    }\n    return copy;\n}\n\nfunction reduceEventStore (eventStore, action, eventSources, dateProfile, calendar) {\n    switch (action.type) {\n        case 'RECEIVE_EVENTS': // raw\n            return receiveRawEvents(eventStore, eventSources[action.sourceId], action.fetchId, action.fetchRange, action.rawEvents, calendar);\n        case 'ADD_EVENTS': // already parsed, but not expanded\n            return addEvent(eventStore, action.eventStore, // new ones\n            dateProfile ? dateProfile.activeRange : null, calendar);\n        case 'MERGE_EVENTS': // already parsed and expanded\n            return mergeEventStores(eventStore, action.eventStore);\n        case 'PREV': // TODO: how do we track all actions that affect dateProfile :(\n        case 'NEXT':\n        case 'SET_DATE':\n        case 'SET_VIEW_TYPE':\n            if (dateProfile) {\n                return expandRecurring(eventStore, dateProfile.activeRange, calendar);\n            }\n            else {\n                return eventStore;\n            }\n        case 'CHANGE_TIMEZONE':\n            return rezoneDates(eventStore, action.oldDateEnv, calendar.dateEnv);\n        case 'MUTATE_EVENTS':\n            return applyMutationToRelated(eventStore, action.instanceId, action.mutation, action.fromApi, calendar);\n        case 'REMOVE_EVENT_INSTANCES':\n            return excludeInstances(eventStore, action.instances);\n        case 'REMOVE_EVENT_DEF':\n            return filterEventStoreDefs(eventStore, function (eventDef) {\n                return eventDef.defId !== action.defId;\n            });\n        case 'REMOVE_EVENT_SOURCE':\n            return excludeEventsBySourceId(eventStore, action.sourceId);\n        case 'REMOVE_ALL_EVENT_SOURCES':\n            return filterEventStoreDefs(eventStore, function (eventDef) {\n                return !eventDef.sourceId; // only keep events with no source id\n            });\n        case 'REMOVE_ALL_EVENTS':\n            return createEmptyEventStore();\n        case 'RESET_EVENTS':\n            return {\n                defs: eventStore.defs,\n                instances: eventStore.instances\n            };\n        default:\n            return eventStore;\n    }\n}\nfunction receiveRawEvents(eventStore, eventSource, fetchId, fetchRange, rawEvents, calendar) {\n    if (eventSource && // not already removed\n        fetchId === eventSource.latestFetchId // TODO: wish this logic was always in event-sources\n    ) {\n        var subset = parseEvents(transformRawEvents(rawEvents, eventSource, calendar), eventSource.sourceId, calendar);\n        if (fetchRange) {\n            subset = expandRecurring(subset, fetchRange, calendar);\n        }\n        return mergeEventStores(excludeEventsBySourceId(eventStore, eventSource.sourceId), subset);\n    }\n    return eventStore;\n}\nfunction addEvent(eventStore, subset, expandRange, calendar) {\n    if (expandRange) {\n        subset = expandRecurring(subset, expandRange, calendar);\n    }\n    return mergeEventStores(eventStore, subset);\n}\nfunction rezoneDates(eventStore, oldDateEnv, newDateEnv) {\n    var defs = eventStore.defs;\n    var instances = mapHash(eventStore.instances, function (instance) {\n        var def = defs[instance.defId];\n        if (def.allDay || def.recurringDef) {\n            return instance; // isn't dependent on timezone\n        }\n        else {\n            return __assign({}, instance, { range: {\n                    start: newDateEnv.createMarker(oldDateEnv.toDate(instance.range.start, instance.forcedStartTzo)),\n                    end: newDateEnv.createMarker(oldDateEnv.toDate(instance.range.end, instance.forcedEndTzo))\n                }, forcedStartTzo: newDateEnv.canComputeOffset ? null : instance.forcedStartTzo, forcedEndTzo: newDateEnv.canComputeOffset ? null : instance.forcedEndTzo });\n        }\n    });\n    return { defs: defs, instances: instances };\n}\nfunction applyMutationToRelated(eventStore, instanceId, mutation, fromApi, calendar) {\n    var relevant = getRelevantEvents(eventStore, instanceId);\n    var eventConfigBase = fromApi ?\n        { '': {\n                startEditable: true,\n                durationEditable: true,\n                constraints: [],\n                overlap: null,\n                allows: [],\n                backgroundColor: '',\n                borderColor: '',\n                textColor: '',\n                classNames: []\n            } } :\n        calendar.eventUiBases;\n    relevant = applyMutationToEventStore(relevant, eventConfigBase, mutation, calendar);\n    return mergeEventStores(eventStore, relevant);\n}\nfunction excludeEventsBySourceId(eventStore, sourceId) {\n    return filterEventStoreDefs(eventStore, function (eventDef) {\n        return eventDef.sourceId !== sourceId;\n    });\n}\n// QUESTION: why not just return instances? do a general object-property-exclusion util\nfunction excludeInstances(eventStore, removals) {\n    return {\n        defs: eventStore.defs,\n        instances: filterHash(eventStore.instances, function (instance) {\n            return !removals[instance.instanceId];\n        })\n    };\n}\n\n// high-level segmenting-aware tester functions\n// ------------------------------------------------------------------------------------------------------------------------\nfunction isInteractionValid(interaction, calendar) {\n    return isNewPropsValid({ eventDrag: interaction }, calendar); // HACK: the eventDrag props is used for ALL interactions\n}\nfunction isDateSelectionValid(dateSelection, calendar) {\n    return isNewPropsValid({ dateSelection: dateSelection }, calendar);\n}\nfunction isNewPropsValid(newProps, calendar) {\n    var view = calendar.view;\n    var props = __assign({ businessHours: view ? view.props.businessHours : createEmptyEventStore(), dateSelection: '', eventStore: calendar.state.eventStore, eventUiBases: calendar.eventUiBases, eventSelection: '', eventDrag: null, eventResize: null }, newProps);\n    return (calendar.pluginSystem.hooks.isPropsValid || isPropsValid)(props, calendar);\n}\nfunction isPropsValid(state, calendar, dateSpanMeta, filterConfig) {\n    if (dateSpanMeta === void 0) { dateSpanMeta = {}; }\n    if (state.eventDrag && !isInteractionPropsValid(state, calendar, dateSpanMeta, filterConfig)) {\n        return false;\n    }\n    if (state.dateSelection && !isDateSelectionPropsValid(state, calendar, dateSpanMeta, filterConfig)) {\n        return false;\n    }\n    return true;\n}\n// Moving Event Validation\n// ------------------------------------------------------------------------------------------------------------------------\nfunction isInteractionPropsValid(state, calendar, dateSpanMeta, filterConfig) {\n    var interaction = state.eventDrag; // HACK: the eventDrag props is used for ALL interactions\n    var subjectEventStore = interaction.mutatedEvents;\n    var subjectDefs = subjectEventStore.defs;\n    var subjectInstances = subjectEventStore.instances;\n    var subjectConfigs = compileEventUis(subjectDefs, interaction.isEvent ?\n        state.eventUiBases :\n        { '': calendar.selectionConfig } // if not a real event, validate as a selection\n    );\n    if (filterConfig) {\n        subjectConfigs = mapHash(subjectConfigs, filterConfig);\n    }\n    var otherEventStore = excludeInstances(state.eventStore, interaction.affectedEvents.instances); // exclude the subject events. TODO: exclude defs too?\n    var otherDefs = otherEventStore.defs;\n    var otherInstances = otherEventStore.instances;\n    var otherConfigs = compileEventUis(otherDefs, state.eventUiBases);\n    for (var subjectInstanceId in subjectInstances) {\n        var subjectInstance = subjectInstances[subjectInstanceId];\n        var subjectRange = subjectInstance.range;\n        var subjectConfig = subjectConfigs[subjectInstance.defId];\n        var subjectDef = subjectDefs[subjectInstance.defId];\n        // constraint\n        if (!allConstraintsPass(subjectConfig.constraints, subjectRange, otherEventStore, state.businessHours, calendar)) {\n            return false;\n        }\n        // overlap\n        var overlapFunc = calendar.opt('eventOverlap');\n        if (typeof overlapFunc !== 'function') {\n            overlapFunc = null;\n        }\n        for (var otherInstanceId in otherInstances) {\n            var otherInstance = otherInstances[otherInstanceId];\n            // intersect! evaluate\n            if (rangesIntersect(subjectRange, otherInstance.range)) {\n                var otherOverlap = otherConfigs[otherInstance.defId].overlap;\n                // consider the other event's overlap. only do this if the subject event is a \"real\" event\n                if (otherOverlap === false && interaction.isEvent) {\n                    return false;\n                }\n                if (subjectConfig.overlap === false) {\n                    return false;\n                }\n                if (overlapFunc && !overlapFunc(new EventApi(calendar, otherDefs[otherInstance.defId], otherInstance), // still event\n                new EventApi(calendar, subjectDef, subjectInstance) // moving event\n                )) {\n                    return false;\n                }\n            }\n        }\n        // allow (a function)\n        var calendarEventStore = calendar.state.eventStore; // need global-to-calendar, not local to component (splittable)state\n        for (var _i = 0, _a = subjectConfig.allows; _i < _a.length; _i++) {\n            var subjectAllow = _a[_i];\n            var subjectDateSpan = __assign({}, dateSpanMeta, { range: subjectInstance.range, allDay: subjectDef.allDay });\n            var origDef = calendarEventStore.defs[subjectDef.defId];\n            var origInstance = calendarEventStore.instances[subjectInstanceId];\n            var eventApi = void 0;\n            if (origDef) { // was previously in the calendar\n                eventApi = new EventApi(calendar, origDef, origInstance);\n            }\n            else { // was an external event\n                eventApi = new EventApi(calendar, subjectDef); // no instance, because had no dates\n            }\n            if (!subjectAllow(calendar.buildDateSpanApi(subjectDateSpan), eventApi)) {\n                return false;\n            }\n        }\n    }\n    return true;\n}\n// Date Selection Validation\n// ------------------------------------------------------------------------------------------------------------------------\nfunction isDateSelectionPropsValid(state, calendar, dateSpanMeta, filterConfig) {\n    var relevantEventStore = state.eventStore;\n    var relevantDefs = relevantEventStore.defs;\n    var relevantInstances = relevantEventStore.instances;\n    var selection = state.dateSelection;\n    var selectionRange = selection.range;\n    var selectionConfig = calendar.selectionConfig;\n    if (filterConfig) {\n        selectionConfig = filterConfig(selectionConfig);\n    }\n    // constraint\n    if (!allConstraintsPass(selectionConfig.constraints, selectionRange, relevantEventStore, state.businessHours, calendar)) {\n        return false;\n    }\n    // overlap\n    var overlapFunc = calendar.opt('selectOverlap');\n    if (typeof overlapFunc !== 'function') {\n        overlapFunc = null;\n    }\n    for (var relevantInstanceId in relevantInstances) {\n        var relevantInstance = relevantInstances[relevantInstanceId];\n        // intersect! evaluate\n        if (rangesIntersect(selectionRange, relevantInstance.range)) {\n            if (selectionConfig.overlap === false) {\n                return false;\n            }\n            if (overlapFunc && !overlapFunc(new EventApi(calendar, relevantDefs[relevantInstance.defId], relevantInstance))) {\n                return false;\n            }\n        }\n    }\n    // allow (a function)\n    for (var _i = 0, _a = selectionConfig.allows; _i < _a.length; _i++) {\n        var selectionAllow = _a[_i];\n        var fullDateSpan = __assign({}, dateSpanMeta, selection);\n        if (!selectionAllow(calendar.buildDateSpanApi(fullDateSpan), null)) {\n            return false;\n        }\n    }\n    return true;\n}\n// Constraint Utils\n// ------------------------------------------------------------------------------------------------------------------------\nfunction allConstraintsPass(constraints, subjectRange, otherEventStore, businessHoursUnexpanded, calendar) {\n    for (var _i = 0, constraints_1 = constraints; _i < constraints_1.length; _i++) {\n        var constraint = constraints_1[_i];\n        if (!anyRangesContainRange(constraintToRanges(constraint, subjectRange, otherEventStore, businessHoursUnexpanded, calendar), subjectRange)) {\n            return false;\n        }\n    }\n    return true;\n}\nfunction constraintToRanges(constraint, subjectRange, // for expanding a recurring constraint, or expanding business hours\notherEventStore, // for if constraint is an even group ID\nbusinessHoursUnexpanded, // for if constraint is 'businessHours'\ncalendar // for expanding businesshours\n) {\n    if (constraint === 'businessHours') {\n        return eventStoreToRanges(expandRecurring(businessHoursUnexpanded, subjectRange, calendar));\n    }\n    else if (typeof constraint === 'string') { // an group ID\n        return eventStoreToRanges(filterEventStoreDefs(otherEventStore, function (eventDef) {\n            return eventDef.groupId === constraint;\n        }));\n    }\n    else if (typeof constraint === 'object' && constraint) { // non-null object\n        return eventStoreToRanges(expandRecurring(constraint, subjectRange, calendar));\n    }\n    return []; // if it's false\n}\n// TODO: move to event-store file?\nfunction eventStoreToRanges(eventStore) {\n    var instances = eventStore.instances;\n    var ranges = [];\n    for (var instanceId in instances) {\n        ranges.push(instances[instanceId].range);\n    }\n    return ranges;\n}\n// TODO: move to geom file?\nfunction anyRangesContainRange(outerRanges, innerRange) {\n    for (var _i = 0, outerRanges_1 = outerRanges; _i < outerRanges_1.length; _i++) {\n        var outerRange = outerRanges_1[_i];\n        if (rangeContainsRange(outerRange, innerRange)) {\n            return true;\n        }\n    }\n    return false;\n}\n// Parsing\n// ------------------------------------------------------------------------------------------------------------------------\nfunction normalizeConstraint(input, calendar) {\n    if (Array.isArray(input)) {\n        return parseEvents(input, '', calendar, true); // allowOpenRange=true\n    }\n    else if (typeof input === 'object' && input) { // non-null object\n        return parseEvents([input], '', calendar, true); // allowOpenRange=true\n    }\n    else if (input != null) {\n        return String(input);\n    }\n    else {\n        return null;\n    }\n}\n\nfunction htmlEscape(s) {\n    return (s + '').replace(/&/g, '&amp;')\n        .replace(/</g, '&lt;')\n        .replace(/>/g, '&gt;')\n        .replace(/'/g, '&#039;')\n        .replace(/\"/g, '&quot;')\n        .replace(/\\n/g, '<br />');\n}\n// Given a hash of CSS properties, returns a string of CSS.\n// Uses property names as-is (no camel-case conversion). Will not make statements for null/undefined values.\nfunction cssToStr(cssProps) {\n    var statements = [];\n    for (var name_1 in cssProps) {\n        var val = cssProps[name_1];\n        if (val != null && val !== '') {\n            statements.push(name_1 + ':' + val);\n        }\n    }\n    return statements.join(';');\n}\n// Given an object hash of HTML attribute names to values,\n// generates a string that can be injected between < > in HTML\nfunction attrsToStr(attrs) {\n    var parts = [];\n    for (var name_2 in attrs) {\n        var val = attrs[name_2];\n        if (val != null) {\n            parts.push(name_2 + '=\"' + htmlEscape(val) + '\"');\n        }\n    }\n    return parts.join(' ');\n}\nfunction parseClassName(raw) {\n    if (Array.isArray(raw)) {\n        return raw;\n    }\n    else if (typeof raw === 'string') {\n        return raw.split(/\\s+/);\n    }\n    else {\n        return [];\n    }\n}\n\nvar UNSCOPED_EVENT_UI_PROPS = {\n    editable: Boolean,\n    startEditable: Boolean,\n    durationEditable: Boolean,\n    constraint: null,\n    overlap: null,\n    allow: null,\n    className: parseClassName,\n    classNames: parseClassName,\n    color: String,\n    backgroundColor: String,\n    borderColor: String,\n    textColor: String\n};\nfunction processUnscopedUiProps(rawProps, calendar, leftovers) {\n    var props = refineProps(rawProps, UNSCOPED_EVENT_UI_PROPS, {}, leftovers);\n    var constraint = normalizeConstraint(props.constraint, calendar);\n    return {\n        startEditable: props.startEditable != null ? props.startEditable : props.editable,\n        durationEditable: props.durationEditable != null ? props.durationEditable : props.editable,\n        constraints: constraint != null ? [constraint] : [],\n        overlap: props.overlap,\n        allows: props.allow != null ? [props.allow] : [],\n        backgroundColor: props.backgroundColor || props.color,\n        borderColor: props.borderColor || props.color,\n        textColor: props.textColor,\n        classNames: props.classNames.concat(props.className)\n    };\n}\nfunction processScopedUiProps(prefix, rawScoped, calendar, leftovers) {\n    var rawUnscoped = {};\n    var wasFound = {};\n    for (var key in UNSCOPED_EVENT_UI_PROPS) {\n        var scopedKey = prefix + capitaliseFirstLetter(key);\n        rawUnscoped[key] = rawScoped[scopedKey];\n        wasFound[scopedKey] = true;\n    }\n    if (prefix === 'event') {\n        rawUnscoped.editable = rawScoped.editable; // special case. there is no 'eventEditable', just 'editable'\n    }\n    if (leftovers) {\n        for (var key in rawScoped) {\n            if (!wasFound[key]) {\n                leftovers[key] = rawScoped[key];\n            }\n        }\n    }\n    return processUnscopedUiProps(rawUnscoped, calendar);\n}\nvar EMPTY_EVENT_UI = {\n    startEditable: null,\n    durationEditable: null,\n    constraints: [],\n    overlap: null,\n    allows: [],\n    backgroundColor: '',\n    borderColor: '',\n    textColor: '',\n    classNames: []\n};\n// prevent against problems with <2 args!\nfunction combineEventUis(uis) {\n    return uis.reduce(combineTwoEventUis, EMPTY_EVENT_UI);\n}\nfunction combineTwoEventUis(item0, item1) {\n    return {\n        startEditable: item1.startEditable != null ? item1.startEditable : item0.startEditable,\n        durationEditable: item1.durationEditable != null ? item1.durationEditable : item0.durationEditable,\n        constraints: item0.constraints.concat(item1.constraints),\n        overlap: typeof item1.overlap === 'boolean' ? item1.overlap : item0.overlap,\n        allows: item0.allows.concat(item1.allows),\n        backgroundColor: item1.backgroundColor || item0.backgroundColor,\n        borderColor: item1.borderColor || item0.borderColor,\n        textColor: item1.textColor || item0.textColor,\n        classNames: item0.classNames.concat(item1.classNames)\n    };\n}\n\nvar NON_DATE_PROPS = {\n    id: String,\n    groupId: String,\n    title: String,\n    url: String,\n    rendering: String,\n    extendedProps: null\n};\nvar DATE_PROPS = {\n    start: null,\n    date: null,\n    end: null,\n    allDay: null\n};\nvar uid = 0;\nfunction parseEvent(raw, sourceId, calendar, allowOpenRange) {\n    var allDayDefault = computeIsAllDayDefault(sourceId, calendar);\n    var leftovers0 = {};\n    var recurringRes = parseRecurring(raw, // raw, but with single-event stuff stripped out\n    allDayDefault, calendar.dateEnv, calendar.pluginSystem.hooks.recurringTypes, leftovers0 // will populate with non-recurring props\n    );\n    if (recurringRes) {\n        var def = parseEventDef(leftovers0, sourceId, recurringRes.allDay, Boolean(recurringRes.duration), calendar);\n        def.recurringDef = {\n            typeId: recurringRes.typeId,\n            typeData: recurringRes.typeData,\n            duration: recurringRes.duration\n        };\n        return { def: def, instance: null };\n    }\n    else {\n        var leftovers1 = {};\n        var singleRes = parseSingle(raw, allDayDefault, calendar, leftovers1, allowOpenRange);\n        if (singleRes) {\n            var def = parseEventDef(leftovers1, sourceId, singleRes.allDay, singleRes.hasEnd, calendar);\n            var instance = createEventInstance(def.defId, singleRes.range, singleRes.forcedStartTzo, singleRes.forcedEndTzo);\n            return { def: def, instance: instance };\n        }\n    }\n    return null;\n}\n/*\nWill NOT populate extendedProps with the leftover properties.\nWill NOT populate date-related props.\nThe EventNonDateInput has been normalized (id => publicId, etc).\n*/\nfunction parseEventDef(raw, sourceId, allDay, hasEnd, calendar) {\n    var leftovers = {};\n    var def = pluckNonDateProps(raw, calendar, leftovers);\n    def.defId = String(uid++);\n    def.sourceId = sourceId;\n    def.allDay = allDay;\n    def.hasEnd = hasEnd;\n    for (var _i = 0, _a = calendar.pluginSystem.hooks.eventDefParsers; _i < _a.length; _i++) {\n        var eventDefParser = _a[_i];\n        var newLeftovers = {};\n        eventDefParser(def, leftovers, newLeftovers);\n        leftovers = newLeftovers;\n    }\n    def.extendedProps = __assign(leftovers, def.extendedProps || {});\n    // help out EventApi from having user modify props\n    Object.freeze(def.ui.classNames);\n    Object.freeze(def.extendedProps);\n    return def;\n}\nfunction createEventInstance(defId, range, forcedStartTzo, forcedEndTzo) {\n    return {\n        instanceId: String(uid++),\n        defId: defId,\n        range: range,\n        forcedStartTzo: forcedStartTzo == null ? null : forcedStartTzo,\n        forcedEndTzo: forcedEndTzo == null ? null : forcedEndTzo\n    };\n}\nfunction parseSingle(raw, allDayDefault, calendar, leftovers, allowOpenRange) {\n    var props = pluckDateProps(raw, leftovers);\n    var allDay = props.allDay;\n    var startMeta;\n    var startMarker = null;\n    var hasEnd = false;\n    var endMeta;\n    var endMarker = null;\n    startMeta = calendar.dateEnv.createMarkerMeta(props.start);\n    if (startMeta) {\n        startMarker = startMeta.marker;\n    }\n    else if (!allowOpenRange) {\n        return null;\n    }\n    if (props.end != null) {\n        endMeta = calendar.dateEnv.createMarkerMeta(props.end);\n    }\n    if (allDay == null) {\n        if (allDayDefault != null) {\n            allDay = allDayDefault;\n        }\n        else {\n            // fall back to the date props LAST\n            allDay = (!startMeta || startMeta.isTimeUnspecified) &&\n                (!endMeta || endMeta.isTimeUnspecified);\n        }\n    }\n    if (allDay && startMarker) {\n        startMarker = startOfDay(startMarker);\n    }\n    if (endMeta) {\n        endMarker = endMeta.marker;\n        if (allDay) {\n            endMarker = startOfDay(endMarker);\n        }\n        if (startMarker && endMarker <= startMarker) {\n            endMarker = null;\n        }\n    }\n    if (endMarker) {\n        hasEnd = true;\n    }\n    else if (!allowOpenRange) {\n        hasEnd = calendar.opt('forceEventDuration') || false;\n        endMarker = calendar.dateEnv.add(startMarker, allDay ?\n            calendar.defaultAllDayEventDuration :\n            calendar.defaultTimedEventDuration);\n    }\n    return {\n        allDay: allDay,\n        hasEnd: hasEnd,\n        range: { start: startMarker, end: endMarker },\n        forcedStartTzo: startMeta ? startMeta.forcedTzo : null,\n        forcedEndTzo: endMeta ? endMeta.forcedTzo : null\n    };\n}\nfunction pluckDateProps(raw, leftovers) {\n    var props = refineProps(raw, DATE_PROPS, {}, leftovers);\n    props.start = (props.start !== null) ? props.start : props.date;\n    delete props.date;\n    return props;\n}\nfunction pluckNonDateProps(raw, calendar, leftovers) {\n    var preLeftovers = {};\n    var props = refineProps(raw, NON_DATE_PROPS, {}, preLeftovers);\n    var ui = processUnscopedUiProps(preLeftovers, calendar, leftovers);\n    props.publicId = props.id;\n    delete props.id;\n    props.ui = ui;\n    return props;\n}\nfunction computeIsAllDayDefault(sourceId, calendar) {\n    var res = null;\n    if (sourceId) {\n        var source = calendar.state.eventSources[sourceId];\n        res = source.allDayDefault;\n    }\n    if (res == null) {\n        res = calendar.opt('allDayDefault');\n    }\n    return res;\n}\n\nvar DEF_DEFAULTS = {\n    startTime: '09:00',\n    endTime: '17:00',\n    daysOfWeek: [1, 2, 3, 4, 5],\n    rendering: 'inverse-background',\n    classNames: 'fc-nonbusiness',\n    groupId: '_businessHours' // so multiple defs get grouped\n};\n/*\nTODO: pass around as EventDefHash!!!\n*/\nfunction parseBusinessHours(input, calendar) {\n    return parseEvents(refineInputs(input), '', calendar);\n}\nfunction refineInputs(input) {\n    var rawDefs;\n    if (input === true) {\n        rawDefs = [{}]; // will get DEF_DEFAULTS verbatim\n    }\n    else if (Array.isArray(input)) {\n        // if specifying an array, every sub-definition NEEDS a day-of-week\n        rawDefs = input.filter(function (rawDef) {\n            return rawDef.daysOfWeek;\n        });\n    }\n    else if (typeof input === 'object' && input) { // non-null object\n        rawDefs = [input];\n    }\n    else { // is probably false\n        rawDefs = [];\n    }\n    rawDefs = rawDefs.map(function (rawDef) {\n        return __assign({}, DEF_DEFAULTS, rawDef);\n    });\n    return rawDefs;\n}\n\nfunction memoizeRendering(renderFunc, unrenderFunc, dependencies) {\n    if (dependencies === void 0) { dependencies = []; }\n    var dependents = [];\n    var thisContext;\n    var prevArgs;\n    function unrender() {\n        if (prevArgs) {\n            for (var _i = 0, dependents_1 = dependents; _i < dependents_1.length; _i++) {\n                var dependent = dependents_1[_i];\n                dependent.unrender();\n            }\n            if (unrenderFunc) {\n                unrenderFunc.apply(thisContext, prevArgs);\n            }\n            prevArgs = null;\n        }\n    }\n    function res() {\n        if (!prevArgs || !isArraysEqual(prevArgs, arguments)) {\n            unrender();\n            thisContext = this;\n            prevArgs = arguments;\n            renderFunc.apply(this, arguments);\n        }\n    }\n    res.dependents = dependents;\n    res.unrender = unrender;\n    for (var _i = 0, dependencies_1 = dependencies; _i < dependencies_1.length; _i++) {\n        var dependency = dependencies_1[_i];\n        dependency.dependents.push(res);\n    }\n    return res;\n}\n\nvar EMPTY_EVENT_STORE = createEmptyEventStore(); // for purecomponents. TODO: keep elsewhere\nvar Splitter = /** @class */ (function () {\n    function Splitter() {\n        this.getKeysForEventDefs = memoize(this._getKeysForEventDefs);\n        this.splitDateSelection = memoize(this._splitDateSpan);\n        this.splitEventStore = memoize(this._splitEventStore);\n        this.splitIndividualUi = memoize(this._splitIndividualUi);\n        this.splitEventDrag = memoize(this._splitInteraction);\n        this.splitEventResize = memoize(this._splitInteraction);\n        this.eventUiBuilders = {}; // TODO: typescript protection\n    }\n    Splitter.prototype.splitProps = function (props) {\n        var _this = this;\n        var keyInfos = this.getKeyInfo(props);\n        var defKeys = this.getKeysForEventDefs(props.eventStore);\n        var dateSelections = this.splitDateSelection(props.dateSelection);\n        var individualUi = this.splitIndividualUi(props.eventUiBases, defKeys); // the individual *bases*\n        var eventStores = this.splitEventStore(props.eventStore, defKeys);\n        var eventDrags = this.splitEventDrag(props.eventDrag);\n        var eventResizes = this.splitEventResize(props.eventResize);\n        var splitProps = {};\n        this.eventUiBuilders = mapHash(keyInfos, function (info, key) {\n            return _this.eventUiBuilders[key] || memoize(buildEventUiForKey);\n        });\n        for (var key in keyInfos) {\n            var keyInfo = keyInfos[key];\n            var eventStore = eventStores[key] || EMPTY_EVENT_STORE;\n            var buildEventUi = this.eventUiBuilders[key];\n            splitProps[key] = {\n                businessHours: keyInfo.businessHours || props.businessHours,\n                dateSelection: dateSelections[key] || null,\n                eventStore: eventStore,\n                eventUiBases: buildEventUi(props.eventUiBases[''], keyInfo.ui, individualUi[key]),\n                eventSelection: eventStore.instances[props.eventSelection] ? props.eventSelection : '',\n                eventDrag: eventDrags[key] || null,\n                eventResize: eventResizes[key] || null\n            };\n        }\n        return splitProps;\n    };\n    Splitter.prototype._splitDateSpan = function (dateSpan) {\n        var dateSpans = {};\n        if (dateSpan) {\n            var keys = this.getKeysForDateSpan(dateSpan);\n            for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {\n                var key = keys_1[_i];\n                dateSpans[key] = dateSpan;\n            }\n        }\n        return dateSpans;\n    };\n    Splitter.prototype._getKeysForEventDefs = function (eventStore) {\n        var _this = this;\n        return mapHash(eventStore.defs, function (eventDef) {\n            return _this.getKeysForEventDef(eventDef);\n        });\n    };\n    Splitter.prototype._splitEventStore = function (eventStore, defKeys) {\n        var defs = eventStore.defs, instances = eventStore.instances;\n        var splitStores = {};\n        for (var defId in defs) {\n            for (var _i = 0, _a = defKeys[defId]; _i < _a.length; _i++) {\n                var key = _a[_i];\n                if (!splitStores[key]) {\n                    splitStores[key] = createEmptyEventStore();\n                }\n                splitStores[key].defs[defId] = defs[defId];\n            }\n        }\n        for (var instanceId in instances) {\n            var instance = instances[instanceId];\n            for (var _b = 0, _c = defKeys[instance.defId]; _b < _c.length; _b++) {\n                var key = _c[_b];\n                if (splitStores[key]) { // must have already been created\n                    splitStores[key].instances[instanceId] = instance;\n                }\n            }\n        }\n        return splitStores;\n    };\n    Splitter.prototype._splitIndividualUi = function (eventUiBases, defKeys) {\n        var splitHashes = {};\n        for (var defId in eventUiBases) {\n            if (defId) { // not the '' key\n                for (var _i = 0, _a = defKeys[defId]; _i < _a.length; _i++) {\n                    var key = _a[_i];\n                    if (!splitHashes[key]) {\n                        splitHashes[key] = {};\n                    }\n                    splitHashes[key][defId] = eventUiBases[defId];\n                }\n            }\n        }\n        return splitHashes;\n    };\n    Splitter.prototype._splitInteraction = function (interaction) {\n        var splitStates = {};\n        if (interaction) {\n            var affectedStores_1 = this._splitEventStore(interaction.affectedEvents, this._getKeysForEventDefs(interaction.affectedEvents) // can't use cached. might be events from other calendar\n            );\n            // can't rely on defKeys because event data is mutated\n            var mutatedKeysByDefId = this._getKeysForEventDefs(interaction.mutatedEvents);\n            var mutatedStores_1 = this._splitEventStore(interaction.mutatedEvents, mutatedKeysByDefId);\n            var populate = function (key) {\n                if (!splitStates[key]) {\n                    splitStates[key] = {\n                        affectedEvents: affectedStores_1[key] || EMPTY_EVENT_STORE,\n                        mutatedEvents: mutatedStores_1[key] || EMPTY_EVENT_STORE,\n                        isEvent: interaction.isEvent,\n                        origSeg: interaction.origSeg\n                    };\n                }\n            };\n            for (var key in affectedStores_1) {\n                populate(key);\n            }\n            for (var key in mutatedStores_1) {\n                populate(key);\n            }\n        }\n        return splitStates;\n    };\n    return Splitter;\n}());\nfunction buildEventUiForKey(allUi, eventUiForKey, individualUi) {\n    var baseParts = [];\n    if (allUi) {\n        baseParts.push(allUi);\n    }\n    if (eventUiForKey) {\n        baseParts.push(eventUiForKey);\n    }\n    var stuff = {\n        '': combineEventUis(baseParts)\n    };\n    if (individualUi) {\n        __assign(stuff, individualUi);\n    }\n    return stuff;\n}\n\n// Generates HTML for an anchor to another view into the calendar.\n// Will either generate an <a> tag or a non-clickable <span> tag, depending on enabled settings.\n// `gotoOptions` can either be a DateMarker, or an object with the form:\n// { date, type, forceOff }\n// `type` is a view-type like \"day\" or \"week\". default value is \"day\".\n// `attrs` and `innerHtml` are use to generate the rest of the HTML tag.\nfunction buildGotoAnchorHtml(allOptions, dateEnv, gotoOptions, attrs, innerHtml) {\n    var date;\n    var type;\n    var forceOff;\n    var finalOptions;\n    if (gotoOptions instanceof Date) {\n        date = gotoOptions; // a single date-like input\n    }\n    else {\n        date = gotoOptions.date;\n        type = gotoOptions.type;\n        forceOff = gotoOptions.forceOff;\n    }\n    finalOptions = {\n        date: dateEnv.formatIso(date, { omitTime: true }),\n        type: type || 'day'\n    };\n    if (typeof attrs === 'string') {\n        innerHtml = attrs;\n        attrs = null;\n    }\n    attrs = attrs ? ' ' + attrsToStr(attrs) : ''; // will have a leading space\n    innerHtml = innerHtml || '';\n    if (!forceOff && allOptions.navLinks) {\n        return '<a' + attrs +\n            ' data-goto=\"' + htmlEscape(JSON.stringify(finalOptions)) + '\">' +\n            innerHtml +\n            '</a>';\n    }\n    else {\n        return '<span' + attrs + '>' +\n            innerHtml +\n            '</span>';\n    }\n}\nfunction getAllDayHtml(allOptions) {\n    return allOptions.allDayHtml || htmlEscape(allOptions.allDayText);\n}\n// Computes HTML classNames for a single-day element\nfunction getDayClasses(date, dateProfile, context, noThemeHighlight) {\n    var calendar = context.calendar, options = context.options, theme = context.theme, dateEnv = context.dateEnv;\n    var classes = [];\n    var todayStart;\n    var todayEnd;\n    if (!rangeContainsMarker(dateProfile.activeRange, date)) {\n        classes.push('fc-disabled-day');\n    }\n    else {\n        classes.push('fc-' + DAY_IDS[date.getUTCDay()]);\n        if (options.monthMode &&\n            dateEnv.getMonth(date) !== dateEnv.getMonth(dateProfile.currentRange.start)) {\n            classes.push('fc-other-month');\n        }\n        todayStart = startOfDay(calendar.getNow());\n        todayEnd = addDays(todayStart, 1);\n        if (date < todayStart) {\n            classes.push('fc-past');\n        }\n        else if (date >= todayEnd) {\n            classes.push('fc-future');\n        }\n        else {\n            classes.push('fc-today');\n            if (noThemeHighlight !== true) {\n                classes.push(theme.getClass('today'));\n            }\n        }\n    }\n    return classes;\n}\n\n// given a function that resolves a result asynchronously.\n// the function can either call passed-in success and failure callbacks,\n// or it can return a promise.\n// if you need to pass additional params to func, bind them first.\nfunction unpromisify(func, success, failure) {\n    // guard against success/failure callbacks being called more than once\n    // and guard against a promise AND callback being used together.\n    var isResolved = false;\n    var wrappedSuccess = function () {\n        if (!isResolved) {\n            isResolved = true;\n            success.apply(this, arguments);\n        }\n    };\n    var wrappedFailure = function () {\n        if (!isResolved) {\n            isResolved = true;\n            if (failure) {\n                failure.apply(this, arguments);\n            }\n        }\n    };\n    var res = func(wrappedSuccess, wrappedFailure);\n    if (res && typeof res.then === 'function') {\n        res.then(wrappedSuccess, wrappedFailure);\n    }\n}\n\nvar Mixin = /** @class */ (function () {\n    function Mixin() {\n    }\n    // mix into a CLASS\n    Mixin.mixInto = function (destClass) {\n        this.mixIntoObj(destClass.prototype);\n    };\n    // mix into ANY object\n    Mixin.mixIntoObj = function (destObj) {\n        var _this = this;\n        Object.getOwnPropertyNames(this.prototype).forEach(function (name) {\n            if (!destObj[name]) { // if destination doesn't already define it\n                destObj[name] = _this.prototype[name];\n            }\n        });\n    };\n    /*\n    will override existing methods\n    TODO: remove! not used anymore\n    */\n    Mixin.mixOver = function (destClass) {\n        var _this = this;\n        Object.getOwnPropertyNames(this.prototype).forEach(function (name) {\n            destClass.prototype[name] = _this.prototype[name];\n        });\n    };\n    return Mixin;\n}());\n\n/*\nUSAGE:\n  import { default as EmitterMixin, EmitterInterface } from './EmitterMixin'\nin class:\n  on: EmitterInterface['on']\n  one: EmitterInterface['one']\n  off: EmitterInterface['off']\n  trigger: EmitterInterface['trigger']\n  triggerWith: EmitterInterface['triggerWith']\n  hasHandlers: EmitterInterface['hasHandlers']\nafter class:\n  EmitterMixin.mixInto(TheClass)\n*/\nvar EmitterMixin = /** @class */ (function (_super) {\n    __extends(EmitterMixin, _super);\n    function EmitterMixin() {\n        return _super !== null && _super.apply(this, arguments) || this;\n    }\n    EmitterMixin.prototype.on = function (type, handler) {\n        addToHash(this._handlers || (this._handlers = {}), type, handler);\n        return this; // for chaining\n    };\n    // todo: add comments\n    EmitterMixin.prototype.one = function (type, handler) {\n        addToHash(this._oneHandlers || (this._oneHandlers = {}), type, handler);\n        return this; // for chaining\n    };\n    EmitterMixin.prototype.off = function (type, handler) {\n        if (this._handlers) {\n            removeFromHash(this._handlers, type, handler);\n        }\n        if (this._oneHandlers) {\n            removeFromHash(this._oneHandlers, type, handler);\n        }\n        return this; // for chaining\n    };\n    EmitterMixin.prototype.trigger = function (type) {\n        var args = [];\n        for (var _i = 1; _i < arguments.length; _i++) {\n            args[_i - 1] = arguments[_i];\n        }\n        this.triggerWith(type, this, args);\n        return this; // for chaining\n    };\n    EmitterMixin.prototype.triggerWith = function (type, context, args) {\n        if (this._handlers) {\n            applyAll(this._handlers[type], context, args);\n        }\n        if (this._oneHandlers) {\n            applyAll(this._oneHandlers[type], context, args);\n            delete this._oneHandlers[type]; // will never fire again\n        }\n        return this; // for chaining\n    };\n    EmitterMixin.prototype.hasHandlers = function (type) {\n        return (this._handlers && this._handlers[type] && this._handlers[type].length) ||\n            (this._oneHandlers && this._oneHandlers[type] && this._oneHandlers[type].length);\n    };\n    return EmitterMixin;\n}(Mixin));\nfunction addToHash(hash, type, handler) {\n    (hash[type] || (hash[type] = []))\n        .push(handler);\n}\nfunction removeFromHash(hash, type, handler) {\n    if (handler) {\n        if (hash[type]) {\n            hash[type] = hash[type].filter(function (func) {\n                return func !== handler;\n            });\n        }\n    }\n    else {\n        delete hash[type]; // remove all handler funcs for this type\n    }\n}\n\n/*\nRecords offset information for a set of elements, relative to an origin element.\nCan record the left/right OR the top/bottom OR both.\nProvides methods for querying the cache by position.\n*/\nvar PositionCache = /** @class */ (function () {\n    function PositionCache(originEl, els, isHorizontal, isVertical) {\n        this.originEl = originEl;\n        this.els = els;\n        this.isHorizontal = isHorizontal;\n        this.isVertical = isVertical;\n    }\n    // Queries the els for coordinates and stores them.\n    // Call this method before using and of the get* methods below.\n    PositionCache.prototype.build = function () {\n        var originEl = this.originEl;\n        var originClientRect = this.originClientRect =\n            originEl.getBoundingClientRect(); // relative to viewport top-left\n        if (this.isHorizontal) {\n            this.buildElHorizontals(originClientRect.left);\n        }\n        if (this.isVertical) {\n            this.buildElVerticals(originClientRect.top);\n        }\n    };\n    // Populates the left/right internal coordinate arrays\n    PositionCache.prototype.buildElHorizontals = function (originClientLeft) {\n        var lefts = [];\n        var rights = [];\n        for (var _i = 0, _a = this.els; _i < _a.length; _i++) {\n            var el = _a[_i];\n            var rect = el.getBoundingClientRect();\n            lefts.push(rect.left - originClientLeft);\n            rights.push(rect.right - originClientLeft);\n        }\n        this.lefts = lefts;\n        this.rights = rights;\n    };\n    // Populates the top/bottom internal coordinate arrays\n    PositionCache.prototype.buildElVerticals = function (originClientTop) {\n        var tops = [];\n        var bottoms = [];\n        for (var _i = 0, _a = this.els; _i < _a.length; _i++) {\n            var el = _a[_i];\n            var rect = el.getBoundingClientRect();\n            tops.push(rect.top - originClientTop);\n            bottoms.push(rect.bottom - originClientTop);\n        }\n        this.tops = tops;\n        this.bottoms = bottoms;\n    };\n    // Given a left offset (from document left), returns the index of the el that it horizontally intersects.\n    // If no intersection is made, returns undefined.\n    PositionCache.prototype.leftToIndex = function (leftPosition) {\n        var lefts = this.lefts;\n        var rights = this.rights;\n        var len = lefts.length;\n        var i;\n        for (i = 0; i < len; i++) {\n            if (leftPosition >= lefts[i] && leftPosition < rights[i]) {\n                return i;\n            }\n        }\n    };\n    // Given a top offset (from document top), returns the index of the el that it vertically intersects.\n    // If no intersection is made, returns undefined.\n    PositionCache.prototype.topToIndex = function (topPosition) {\n        var tops = this.tops;\n        var bottoms = this.bottoms;\n        var len = tops.length;\n        var i;\n        for (i = 0; i < len; i++) {\n            if (topPosition >= tops[i] && topPosition < bottoms[i]) {\n                return i;\n            }\n        }\n    };\n    // Gets the width of the element at the given index\n    PositionCache.prototype.getWidth = function (leftIndex) {\n        return this.rights[leftIndex] - this.lefts[leftIndex];\n    };\n    // Gets the height of the element at the given index\n    PositionCache.prototype.getHeight = function (topIndex) {\n        return this.bottoms[topIndex] - this.tops[topIndex];\n    };\n    return PositionCache;\n}());\n\n/*\nAn object for getting/setting scroll-related information for an element.\nInternally, this is done very differently for window versus DOM element,\nso this object serves as a common interface.\n*/\nvar ScrollController = /** @class */ (function () {\n    function ScrollController() {\n    }\n    ScrollController.prototype.getMaxScrollTop = function () {\n        return this.getScrollHeight() - this.getClientHeight();\n    };\n    ScrollController.prototype.getMaxScrollLeft = function () {\n        return this.getScrollWidth() - this.getClientWidth();\n    };\n    ScrollController.prototype.canScrollVertically = function () {\n        return this.getMaxScrollTop() > 0;\n    };\n    ScrollController.prototype.canScrollHorizontally = function () {\n        return this.getMaxScrollLeft() > 0;\n    };\n    ScrollController.prototype.canScrollUp = function () {\n        return this.getScrollTop() > 0;\n    };\n    ScrollController.prototype.canScrollDown = function () {\n        return this.getScrollTop() < this.getMaxScrollTop();\n    };\n    ScrollController.prototype.canScrollLeft = function () {\n        return this.getScrollLeft() > 0;\n    };\n    ScrollController.prototype.canScrollRight = function () {\n        return this.getScrollLeft() < this.getMaxScrollLeft();\n    };\n    return ScrollController;\n}());\nvar ElementScrollController = /** @class */ (function (_super) {\n    __extends(ElementScrollController, _super);\n    function ElementScrollController(el) {\n        var _this = _super.call(this) || this;\n        _this.el = el;\n        return _this;\n    }\n    ElementScrollController.prototype.getScrollTop = function () {\n        return this.el.scrollTop;\n    };\n    ElementScrollController.prototype.getScrollLeft = function () {\n        return this.el.scrollLeft;\n    };\n    ElementScrollController.prototype.setScrollTop = function (top) {\n        this.el.scrollTop = top;\n    };\n    ElementScrollController.prototype.setScrollLeft = function (left) {\n        this.el.scrollLeft = left;\n    };\n    ElementScrollController.prototype.getScrollWidth = function () {\n        return this.el.scrollWidth;\n    };\n    ElementScrollController.prototype.getScrollHeight = function () {\n        return this.el.scrollHeight;\n    };\n    ElementScrollController.prototype.getClientHeight = function () {\n        return this.el.clientHeight;\n    };\n    ElementScrollController.prototype.getClientWidth = function () {\n        return this.el.clientWidth;\n    };\n    return ElementScrollController;\n}(ScrollController));\nvar WindowScrollController = /** @class */ (function (_super) {\n    __extends(WindowScrollController, _super);\n    function WindowScrollController() {\n        return _super !== null && _super.apply(this, arguments) || this;\n    }\n    WindowScrollController.prototype.getScrollTop = function () {\n        return window.pageYOffset;\n    };\n    WindowScrollController.prototype.getScrollLeft = function () {\n        return window.pageXOffset;\n    };\n    WindowScrollController.prototype.setScrollTop = function (n) {\n        window.scroll(window.pageXOffset, n);\n    };\n    WindowScrollController.prototype.setScrollLeft = function (n) {\n        window.scroll(n, window.pageYOffset);\n    };\n    WindowScrollController.prototype.getScrollWidth = function () {\n        return document.documentElement.scrollWidth;\n    };\n    WindowScrollController.prototype.getScrollHeight = function () {\n        return document.documentElement.scrollHeight;\n    };\n    WindowScrollController.prototype.getClientHeight = function () {\n        return document.documentElement.clientHeight;\n    };\n    WindowScrollController.prototype.getClientWidth = function () {\n        return document.documentElement.clientWidth;\n    };\n    return WindowScrollController;\n}(ScrollController));\n\n/*\nEmbodies a div that has potential scrollbars\n*/\nvar ScrollComponent = /** @class */ (function (_super) {\n    __extends(ScrollComponent, _super);\n    function ScrollComponent(overflowX, overflowY) {\n        var _this = _super.call(this, createElement('div', {\n            className: 'fc-scroller'\n        })) || this;\n        _this.overflowX = overflowX;\n        _this.overflowY = overflowY;\n        _this.applyOverflow();\n        return _this;\n    }\n    // sets to natural height, unlocks overflow\n    ScrollComponent.prototype.clear = function () {\n        this.setHeight('auto');\n        this.applyOverflow();\n    };\n    ScrollComponent.prototype.destroy = function () {\n        removeElement(this.el);\n    };\n    // Overflow\n    // -----------------------------------------------------------------------------------------------------------------\n    ScrollComponent.prototype.applyOverflow = function () {\n        applyStyle(this.el, {\n            overflowX: this.overflowX,\n            overflowY: this.overflowY\n        });\n    };\n    // Causes any 'auto' overflow values to resolves to 'scroll' or 'hidden'.\n    // Useful for preserving scrollbar widths regardless of future resizes.\n    // Can pass in scrollbarWidths for optimization.\n    ScrollComponent.prototype.lockOverflow = function (scrollbarWidths) {\n        var overflowX = this.overflowX;\n        var overflowY = this.overflowY;\n        scrollbarWidths = scrollbarWidths || this.getScrollbarWidths();\n        if (overflowX === 'auto') {\n            overflowX = (scrollbarWidths.bottom || // horizontal scrollbars?\n                this.canScrollHorizontally() // OR scrolling pane with massless scrollbars?\n            ) ? 'scroll' : 'hidden';\n        }\n        if (overflowY === 'auto') {\n            overflowY = (scrollbarWidths.left || scrollbarWidths.right || // horizontal scrollbars?\n                this.canScrollVertically() // OR scrolling pane with massless scrollbars?\n            ) ? 'scroll' : 'hidden';\n        }\n        applyStyle(this.el, { overflowX: overflowX, overflowY: overflowY });\n    };\n    ScrollComponent.prototype.setHeight = function (height) {\n        applyStyleProp(this.el, 'height', height);\n    };\n    ScrollComponent.prototype.getScrollbarWidths = function () {\n        var edges = computeEdges(this.el);\n        return {\n            left: edges.scrollbarLeft,\n            right: edges.scrollbarRight,\n            bottom: edges.scrollbarBottom\n        };\n    };\n    return ScrollComponent;\n}(ElementScrollController));\n\nvar Theme = /** @class */ (function () {\n    function Theme(calendarOptions) {\n        this.calendarOptions = calendarOptions;\n        this.processIconOverride();\n    }\n    Theme.prototype.processIconOverride = function () {\n        if (this.iconOverrideOption) {\n            this.setIconOverride(this.calendarOptions[this.iconOverrideOption]);\n        }\n    };\n    Theme.prototype.setIconOverride = function (iconOverrideHash) {\n        var iconClassesCopy;\n        var buttonName;\n        if (typeof iconOverrideHash === 'object' && iconOverrideHash) { // non-null object\n            iconClassesCopy = __assign({}, this.iconClasses);\n            for (buttonName in iconOverrideHash) {\n                iconClassesCopy[buttonName] = this.applyIconOverridePrefix(iconOverrideHash[buttonName]);\n            }\n            this.iconClasses = iconClassesCopy;\n        }\n        else if (iconOverrideHash === false) {\n            this.iconClasses = {};\n        }\n    };\n    Theme.prototype.applyIconOverridePrefix = function (className) {\n        var prefix = this.iconOverridePrefix;\n        if (prefix && className.indexOf(prefix) !== 0) { // if not already present\n            className = prefix + className;\n        }\n        return className;\n    };\n    Theme.prototype.getClass = function (key) {\n        return this.classes[key] || '';\n    };\n    Theme.prototype.getIconClass = function (buttonName) {\n        var className = this.iconClasses[buttonName];\n        if (className) {\n            return this.baseIconClass + ' ' + className;\n        }\n        return '';\n    };\n    Theme.prototype.getCustomButtonIconClass = function (customButtonProps) {\n        var className;\n        if (this.iconOverrideCustomButtonOption) {\n            className = customButtonProps[this.iconOverrideCustomButtonOption];\n            if (className) {\n                return this.baseIconClass + ' ' + this.applyIconOverridePrefix(className);\n            }\n        }\n        return '';\n    };\n    return Theme;\n}());\nTheme.prototype.classes = {};\nTheme.prototype.iconClasses = {};\nTheme.prototype.baseIconClass = '';\nTheme.prototype.iconOverridePrefix = '';\n\nvar guid = 0;\nvar ComponentContext = /** @class */ (function () {\n    function ComponentContext(calendar, theme, dateEnv, options, view) {\n        this.calendar = calendar;\n        this.theme = theme;\n        this.dateEnv = dateEnv;\n        this.options = options;\n        this.view = view;\n        this.isRtl = options.dir === 'rtl';\n        this.eventOrderSpecs = parseFieldSpecs(options.eventOrder);\n        this.nextDayThreshold = createDuration(options.nextDayThreshold);\n    }\n    ComponentContext.prototype.extend = function (options, view) {\n        return new ComponentContext(this.calendar, this.theme, this.dateEnv, options || this.options, view || this.view);\n    };\n    return ComponentContext;\n}());\nvar Component = /** @class */ (function () {\n    function Component() {\n        this.everRendered = false;\n        this.uid = String(guid++);\n    }\n    Component.addEqualityFuncs = function (newFuncs) {\n        this.prototype.equalityFuncs = __assign({}, this.prototype.equalityFuncs, newFuncs);\n    };\n    Component.prototype.receiveProps = function (props, context) {\n        this.receiveContext(context);\n        var _a = recycleProps(this.props || {}, props, this.equalityFuncs), anyChanges = _a.anyChanges, comboProps = _a.comboProps;\n        this.props = comboProps;\n        if (anyChanges) {\n            if (this.everRendered) {\n                this.beforeUpdate();\n            }\n            this.render(comboProps, context);\n            if (this.everRendered) {\n                this.afterUpdate();\n            }\n        }\n        this.everRendered = true;\n    };\n    Component.prototype.receiveContext = function (context) {\n        var oldContext = this.context;\n        this.context = context;\n        if (!oldContext) {\n            this.firstContext(context);\n        }\n    };\n    Component.prototype.render = function (props, context) {\n    };\n    Component.prototype.firstContext = function (context) {\n    };\n    Component.prototype.beforeUpdate = function () {\n    };\n    Component.prototype.afterUpdate = function () {\n    };\n    // after destroy is called, this component won't ever be used again\n    Component.prototype.destroy = function () {\n    };\n    return Component;\n}());\nComponent.prototype.equalityFuncs = {};\n/*\nReuses old values when equal. If anything is unequal, returns newProps as-is.\nGreat for PureComponent, but won't be feasible with React, so just eliminate and use React's DOM diffing.\n*/\nfunction recycleProps(oldProps, newProps, equalityFuncs) {\n    var comboProps = {}; // some old, some new\n    var anyChanges = false;\n    for (var key in newProps) {\n        if (key in oldProps && (oldProps[key] === newProps[key] ||\n            (equalityFuncs[key] && equalityFuncs[key](oldProps[key], newProps[key])))) {\n            // equal to old? use old prop\n            comboProps[key] = oldProps[key];\n        }\n        else {\n            comboProps[key] = newProps[key];\n            anyChanges = true;\n        }\n    }\n    for (var key in oldProps) {\n        if (!(key in newProps)) {\n            anyChanges = true;\n            break;\n        }\n    }\n    return { anyChanges: anyChanges, comboProps: comboProps };\n}\n\n/*\nPURPOSES:\n- hook up to fg, fill, and mirror renderers\n- interface for dragging and hits\n*/\nvar DateComponent = /** @class */ (function (_super) {\n    __extends(DateComponent, _super);\n    function DateComponent(el) {\n        var _this = _super.call(this) || this;\n        _this.el = el;\n        return _this;\n    }\n    DateComponent.prototype.destroy = function () {\n        _super.prototype.destroy.call(this);\n        removeElement(this.el);\n    };\n    // Hit System\n    // -----------------------------------------------------------------------------------------------------------------\n    DateComponent.prototype.buildPositionCaches = function () {\n    };\n    DateComponent.prototype.queryHit = function (positionLeft, positionTop, elWidth, elHeight) {\n        return null; // this should be abstract\n    };\n    // Validation\n    // -----------------------------------------------------------------------------------------------------------------\n    DateComponent.prototype.isInteractionValid = function (interaction) {\n        var calendar = this.context.calendar;\n        var dateProfile = this.props.dateProfile; // HACK\n        var instances = interaction.mutatedEvents.instances;\n        if (dateProfile) { // HACK for DayTile\n            for (var instanceId in instances) {\n                if (!rangeContainsRange(dateProfile.validRange, instances[instanceId].range)) {\n                    return false;\n                }\n            }\n        }\n        return isInteractionValid(interaction, calendar);\n    };\n    DateComponent.prototype.isDateSelectionValid = function (selection) {\n        var calendar = this.context.calendar;\n        var dateProfile = this.props.dateProfile; // HACK\n        if (dateProfile && // HACK for DayTile\n            !rangeContainsRange(dateProfile.validRange, selection.range)) {\n            return false;\n        }\n        return isDateSelectionValid(selection, calendar);\n    };\n    // Pointer Interaction Utils\n    // -----------------------------------------------------------------------------------------------------------------\n    DateComponent.prototype.isValidSegDownEl = function (el) {\n        return !this.props.eventDrag && // HACK\n            !this.props.eventResize && // HACK\n            !elementClosest(el, '.fc-mirror') &&\n            (this.isPopover() || !this.isInPopover(el));\n        // ^above line ensures we don't detect a seg interaction within a nested component.\n        // it's a HACK because it only supports a popover as the nested component.\n    };\n    DateComponent.prototype.isValidDateDownEl = function (el) {\n        var segEl = elementClosest(el, this.fgSegSelector);\n        return (!segEl || segEl.classList.contains('fc-mirror')) &&\n            !elementClosest(el, '.fc-more') && // a \"more..\" link\n            !elementClosest(el, 'a[data-goto]') && // a clickable nav link\n            !this.isInPopover(el);\n    };\n    DateComponent.prototype.isPopover = function () {\n        return this.el.classList.contains('fc-popover');\n    };\n    DateComponent.prototype.isInPopover = function (el) {\n        return Boolean(elementClosest(el, '.fc-popover'));\n    };\n    return DateComponent;\n}(Component));\nDateComponent.prototype.fgSegSelector = '.fc-event-container > *';\nDateComponent.prototype.bgSegSelector = '.fc-bgevent:not(.fc-nonbusiness)';\n\nvar uid$1 = 0;\nfunction createPlugin(input) {\n    return {\n        id: String(uid$1++),\n        deps: input.deps || [],\n        reducers: input.reducers || [],\n        eventDefParsers: input.eventDefParsers || [],\n        isDraggableTransformers: input.isDraggableTransformers || [],\n        eventDragMutationMassagers: input.eventDragMutationMassagers || [],\n        eventDefMutationAppliers: input.eventDefMutationAppliers || [],\n        dateSelectionTransformers: input.dateSelectionTransformers || [],\n        datePointTransforms: input.datePointTransforms || [],\n        dateSpanTransforms: input.dateSpanTransforms || [],\n        views: input.views || {},\n        viewPropsTransformers: input.viewPropsTransformers || [],\n        isPropsValid: input.isPropsValid || null,\n        externalDefTransforms: input.externalDefTransforms || [],\n        eventResizeJoinTransforms: input.eventResizeJoinTransforms || [],\n        viewContainerModifiers: input.viewContainerModifiers || [],\n        eventDropTransformers: input.eventDropTransformers || [],\n        componentInteractions: input.componentInteractions || [],\n        calendarInteractions: input.calendarInteractions || [],\n        themeClasses: input.themeClasses || {},\n        eventSourceDefs: input.eventSourceDefs || [],\n        cmdFormatter: input.cmdFormatter,\n        recurringTypes: input.recurringTypes || [],\n        namedTimeZonedImpl: input.namedTimeZonedImpl,\n        defaultView: input.defaultView || '',\n        elementDraggingImpl: input.elementDraggingImpl,\n        optionChangeHandlers: input.optionChangeHandlers || {}\n    };\n}\nvar PluginSystem = /** @class */ (function () {\n    function PluginSystem() {\n        this.hooks = {\n            reducers: [],\n            eventDefParsers: [],\n            isDraggableTransformers: [],\n            eventDragMutationMassagers: [],\n            eventDefMutationAppliers: [],\n            dateSelectionTransformers: [],\n            datePointTransforms: [],\n            dateSpanTransforms: [],\n            views: {},\n            viewPropsTransformers: [],\n            isPropsValid: null,\n            externalDefTransforms: [],\n            eventResizeJoinTransforms: [],\n            viewContainerModifiers: [],\n            eventDropTransformers: [],\n            componentInteractions: [],\n            calendarInteractions: [],\n            themeClasses: {},\n            eventSourceDefs: [],\n            cmdFormatter: null,\n            recurringTypes: [],\n            namedTimeZonedImpl: null,\n            defaultView: '',\n            elementDraggingImpl: null,\n            optionChangeHandlers: {}\n        };\n        this.addedHash = {};\n    }\n    PluginSystem.prototype.add = function (plugin) {\n        if (!this.addedHash[plugin.id]) {\n            this.addedHash[plugin.id] = true;\n            for (var _i = 0, _a = plugin.deps; _i < _a.length; _i++) {\n                var dep = _a[_i];\n                this.add(dep);\n            }\n            this.hooks = combineHooks(this.hooks, plugin);\n        }\n    };\n    return PluginSystem;\n}());\nfunction combineHooks(hooks0, hooks1) {\n    return {\n        reducers: hooks0.reducers.concat(hooks1.reducers),\n        eventDefParsers: hooks0.eventDefParsers.concat(hooks1.eventDefParsers),\n        isDraggableTransformers: hooks0.isDraggableTransformers.concat(hooks1.isDraggableTransformers),\n        eventDragMutationMassagers: hooks0.eventDragMutationMassagers.concat(hooks1.eventDragMutationMassagers),\n        eventDefMutationAppliers: hooks0.eventDefMutationAppliers.concat(hooks1.eventDefMutationAppliers),\n        dateSelectionTransformers: hooks0.dateSelectionTransformers.concat(hooks1.dateSelectionTransformers),\n        datePointTransforms: hooks0.datePointTransforms.concat(hooks1.datePointTransforms),\n        dateSpanTransforms: hooks0.dateSpanTransforms.concat(hooks1.dateSpanTransforms),\n        views: __assign({}, hooks0.views, hooks1.views),\n        viewPropsTransformers: hooks0.viewPropsTransformers.concat(hooks1.viewPropsTransformers),\n        isPropsValid: hooks1.isPropsValid || hooks0.isPropsValid,\n        externalDefTransforms: hooks0.externalDefTransforms.concat(hooks1.externalDefTransforms),\n        eventResizeJoinTransforms: hooks0.eventResizeJoinTransforms.concat(hooks1.eventResizeJoinTransforms),\n        viewContainerModifiers: hooks0.viewContainerModifiers.concat(hooks1.viewContainerModifiers),\n        eventDropTransformers: hooks0.eventDropTransformers.concat(hooks1.eventDropTransformers),\n        calendarInteractions: hooks0.calendarInteractions.concat(hooks1.calendarInteractions),\n        componentInteractions: hooks0.componentInteractions.concat(hooks1.componentInteractions),\n        themeClasses: __assign({}, hooks0.themeClasses, hooks1.themeClasses),\n        eventSourceDefs: hooks0.eventSourceDefs.concat(hooks1.eventSourceDefs),\n        cmdFormatter: hooks1.cmdFormatter || hooks0.cmdFormatter,\n        recurringTypes: hooks0.recurringTypes.concat(hooks1.recurringTypes),\n        namedTimeZonedImpl: hooks1.namedTimeZonedImpl || hooks0.namedTimeZonedImpl,\n        defaultView: hooks0.defaultView || hooks1.defaultView,\n        elementDraggingImpl: hooks0.elementDraggingImpl || hooks1.elementDraggingImpl,\n        optionChangeHandlers: __assign({}, hooks0.optionChangeHandlers, hooks1.optionChangeHandlers)\n    };\n}\n\nvar eventSourceDef = {\n    ignoreRange: true,\n    parseMeta: function (raw) {\n        if (Array.isArray(raw)) { // short form\n            return raw;\n        }\n        else if (Array.isArray(raw.events)) {\n            return raw.events;\n        }\n        return null;\n    },\n    fetch: function (arg, success) {\n        success({\n            rawEvents: arg.eventSource.meta\n        });\n    }\n};\nvar ArrayEventSourcePlugin = createPlugin({\n    eventSourceDefs: [eventSourceDef]\n});\n\nvar eventSourceDef$1 = {\n    parseMeta: function (raw) {\n        if (typeof raw === 'function') { // short form\n            return raw;\n        }\n        else if (typeof raw.events === 'function') {\n            return raw.events;\n        }\n        return null;\n    },\n    fetch: function (arg, success, failure) {\n        var dateEnv = arg.calendar.dateEnv;\n        var func = arg.eventSource.meta;\n        unpromisify(func.bind(null, {\n            start: dateEnv.toDate(arg.range.start),\n            end: dateEnv.toDate(arg.range.end),\n            startStr: dateEnv.formatIso(arg.range.start),\n            endStr: dateEnv.formatIso(arg.range.end),\n            timeZone: dateEnv.timeZone\n        }), function (rawEvents) {\n            success({ rawEvents: rawEvents }); // needs an object response\n        }, failure // send errorObj directly to failure callback\n        );\n    }\n};\nvar FuncEventSourcePlugin = createPlugin({\n    eventSourceDefs: [eventSourceDef$1]\n});\n\nfunction requestJson(method, url, params, successCallback, failureCallback) {\n    method = method.toUpperCase();\n    var body = null;\n    if (method === 'GET') {\n        url = injectQueryStringParams(url, params);\n    }\n    else {\n        body = encodeParams(params);\n    }\n    var xhr = new XMLHttpRequest();\n    xhr.open(method, url, true);\n    if (method !== 'GET') {\n        xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');\n    }\n    xhr.onload = function () {\n        if (xhr.status >= 200 && xhr.status < 400) {\n            try {\n                var res = JSON.parse(xhr.responseText);\n                successCallback(res, xhr);\n            }\n            catch (err) {\n                failureCallback('Failure parsing JSON', xhr);\n            }\n        }\n        else {\n            failureCallback('Request failed', xhr);\n        }\n    };\n    xhr.onerror = function () {\n        failureCallback('Request failed', xhr);\n    };\n    xhr.send(body);\n}\nfunction injectQueryStringParams(url, params) {\n    return url +\n        (url.indexOf('?') === -1 ? '?' : '&') +\n        encodeParams(params);\n}\nfunction encodeParams(params) {\n    var parts = [];\n    for (var key in params) {\n        parts.push(encodeURIComponent(key) + '=' + encodeURIComponent(params[key]));\n    }\n    return parts.join('&');\n}\n\nvar eventSourceDef$2 = {\n    parseMeta: function (raw) {\n        if (typeof raw === 'string') { // short form\n            raw = { url: raw };\n        }\n        else if (!raw || typeof raw !== 'object' || !raw.url) {\n            return null;\n        }\n        return {\n            url: raw.url,\n            method: (raw.method || 'GET').toUpperCase(),\n            extraParams: raw.extraParams,\n            startParam: raw.startParam,\n            endParam: raw.endParam,\n            timeZoneParam: raw.timeZoneParam\n        };\n    },\n    fetch: function (arg, success, failure) {\n        var meta = arg.eventSource.meta;\n        var requestParams = buildRequestParams(meta, arg.range, arg.calendar);\n        requestJson(meta.method, meta.url, requestParams, function (rawEvents, xhr) {\n            success({ rawEvents: rawEvents, xhr: xhr });\n        }, function (errorMessage, xhr) {\n            failure({ message: errorMessage, xhr: xhr });\n        });\n    }\n};\nvar JsonFeedEventSourcePlugin = createPlugin({\n    eventSourceDefs: [eventSourceDef$2]\n});\nfunction buildRequestParams(meta, range, calendar) {\n    var dateEnv = calendar.dateEnv;\n    var startParam;\n    var endParam;\n    var timeZoneParam;\n    var customRequestParams;\n    var params = {};\n    startParam = meta.startParam;\n    if (startParam == null) {\n        startParam = calendar.opt('startParam');\n    }\n    endParam = meta.endParam;\n    if (endParam == null) {\n        endParam = calendar.opt('endParam');\n    }\n    timeZoneParam = meta.timeZoneParam;\n    if (timeZoneParam == null) {\n        timeZoneParam = calendar.opt('timeZoneParam');\n    }\n    // retrieve any outbound GET/POST data from the options\n    if (typeof meta.extraParams === 'function') {\n        // supplied as a function that returns a key/value object\n        customRequestParams = meta.extraParams();\n    }\n    else {\n        // probably supplied as a straight key/value object\n        customRequestParams = meta.extraParams || {};\n    }\n    __assign(params, customRequestParams);\n    params[startParam] = dateEnv.formatIso(range.start);\n    params[endParam] = dateEnv.formatIso(range.end);\n    if (dateEnv.timeZone !== 'local') {\n        params[timeZoneParam] = dateEnv.timeZone;\n    }\n    return params;\n}\n\nvar recurring = {\n    parse: function (rawEvent, leftoverProps, dateEnv) {\n        var createMarker = dateEnv.createMarker.bind(dateEnv);\n        var processors = {\n            daysOfWeek: null,\n            startTime: createDuration,\n            endTime: createDuration,\n            startRecur: createMarker,\n            endRecur: createMarker\n        };\n        var props = refineProps(rawEvent, processors, {}, leftoverProps);\n        var anyValid = false;\n        for (var propName in props) {\n            if (props[propName] != null) {\n                anyValid = true;\n                break;\n            }\n        }\n        if (anyValid) {\n            var duration = null;\n            if ('duration' in leftoverProps) {\n                duration = createDuration(leftoverProps.duration);\n                delete leftoverProps.duration;\n            }\n            if (!duration && props.startTime && props.endTime) {\n                duration = subtractDurations(props.endTime, props.startTime);\n            }\n            return {\n                allDayGuess: Boolean(!props.startTime && !props.endTime),\n                duration: duration,\n                typeData: props // doesn't need endTime anymore but oh well\n            };\n        }\n        return null;\n    },\n    expand: function (typeData, framingRange, dateEnv) {\n        var clippedFramingRange = intersectRanges(framingRange, { start: typeData.startRecur, end: typeData.endRecur });\n        if (clippedFramingRange) {\n            return expandRanges(typeData.daysOfWeek, typeData.startTime, clippedFramingRange, dateEnv);\n        }\n        else {\n            return [];\n        }\n    }\n};\nvar SimpleRecurrencePlugin = createPlugin({\n    recurringTypes: [recurring]\n});\nfunction expandRanges(daysOfWeek, startTime, framingRange, dateEnv) {\n    var dowHash = daysOfWeek ? arrayToHash(daysOfWeek) : null;\n    var dayMarker = startOfDay(framingRange.start);\n    var endMarker = framingRange.end;\n    var instanceStarts = [];\n    while (dayMarker < endMarker) {\n        var instanceStart \n        // if everyday, or this particular day-of-week\n        = void 0;\n        // if everyday, or this particular day-of-week\n        if (!dowHash || dowHash[dayMarker.getUTCDay()]) {\n            if (startTime) {\n                instanceStart = dateEnv.add(dayMarker, startTime);\n            }\n            else {\n                instanceStart = dayMarker;\n            }\n            instanceStarts.push(instanceStart);\n        }\n        dayMarker = addDays(dayMarker, 1);\n    }\n    return instanceStarts;\n}\n\nvar DefaultOptionChangeHandlers = createPlugin({\n    optionChangeHandlers: {\n        events: function (events, calendar, deepEqual) {\n            handleEventSources([events], calendar, deepEqual);\n        },\n        eventSources: handleEventSources,\n        plugins: handlePlugins\n    }\n});\nfunction handleEventSources(inputs, calendar, deepEqual) {\n    var unfoundSources = hashValuesToArray(calendar.state.eventSources);\n    var newInputs = [];\n    for (var _i = 0, inputs_1 = inputs; _i < inputs_1.length; _i++) {\n        var input = inputs_1[_i];\n        var inputFound = false;\n        for (var i = 0; i < unfoundSources.length; i++) {\n            if (deepEqual(unfoundSources[i]._raw, input)) {\n                unfoundSources.splice(i, 1); // delete\n                inputFound = true;\n                break;\n            }\n        }\n        if (!inputFound) {\n            newInputs.push(input);\n        }\n    }\n    for (var _a = 0, unfoundSources_1 = unfoundSources; _a < unfoundSources_1.length; _a++) {\n        var unfoundSource = unfoundSources_1[_a];\n        calendar.dispatch({\n            type: 'REMOVE_EVENT_SOURCE',\n            sourceId: unfoundSource.sourceId\n        });\n    }\n    for (var _b = 0, newInputs_1 = newInputs; _b < newInputs_1.length; _b++) {\n        var newInput = newInputs_1[_b];\n        calendar.addEventSource(newInput);\n    }\n}\n// shortcoming: won't remove plugins\nfunction handlePlugins(inputs, calendar) {\n    calendar.addPluginInputs(inputs); // will gracefully handle duplicates\n}\n\nvar config = {}; // TODO: make these options\nvar globalDefaults = {\n    defaultRangeSeparator: ' - ',\n    titleRangeSeparator: ' \\u2013 ',\n    defaultTimedEventDuration: '01:00:00',\n    defaultAllDayEventDuration: { day: 1 },\n    forceEventDuration: false,\n    nextDayThreshold: '00:00:00',\n    // display\n    columnHeader: true,\n    defaultView: '',\n    aspectRatio: 1.35,\n    header: {\n        left: 'title',\n        center: '',\n        right: 'today prev,next'\n    },\n    weekends: true,\n    weekNumbers: false,\n    weekNumberCalculation: 'local',\n    editable: false,\n    // nowIndicator: false,\n    scrollTime: '06:00:00',\n    minTime: '00:00:00',\n    maxTime: '24:00:00',\n    showNonCurrentDates: true,\n    // event ajax\n    lazyFetching: true,\n    startParam: 'start',\n    endParam: 'end',\n    timeZoneParam: 'timeZone',\n    timeZone: 'local',\n    // allDayDefault: undefined,\n    // locale\n    locales: [],\n    locale: '',\n    // dir: will get this from the default locale\n    // buttonIcons: null,\n    // allows setting a min-height to the event segment to prevent short events overlapping each other\n    timeGridEventMinHeight: 0,\n    themeSystem: 'standard',\n    // eventResizableFromStart: false,\n    dragRevertDuration: 500,\n    dragScroll: true,\n    allDayMaintainDuration: false,\n    // selectable: false,\n    unselectAuto: true,\n    // selectMinDistance: 0,\n    dropAccept: '*',\n    eventOrder: 'start,-duration,allDay,title',\n    // ^ if start tie, longer events go before shorter. final tie-breaker is title text\n    // rerenderDelay: null,\n    eventLimit: false,\n    eventLimitClick: 'popover',\n    dayPopoverFormat: { month: 'long', day: 'numeric', year: 'numeric' },\n    handleWindowResize: true,\n    windowResizeDelay: 100,\n    longPressDelay: 1000,\n    eventDragMinDistance: 5 // only applies to mouse\n};\nvar rtlDefaults = {\n    header: {\n        left: 'next,prev today',\n        center: '',\n        right: 'title'\n    },\n    buttonIcons: {\n        // TODO: make RTL support the responibility of the theme\n        prev: 'fc-icon-chevron-right',\n        next: 'fc-icon-chevron-left',\n        prevYear: 'fc-icon-chevrons-right',\n        nextYear: 'fc-icon-chevrons-left'\n    }\n};\nvar complexOptions = [\n    'header',\n    'footer',\n    'buttonText',\n    'buttonIcons'\n];\n// Merges an array of option objects into a single object\nfunction mergeOptions(optionObjs) {\n    return mergeProps(optionObjs, complexOptions);\n}\n// TODO: move this stuff to a \"plugin\"-related file...\nvar INTERNAL_PLUGINS = [\n    ArrayEventSourcePlugin,\n    FuncEventSourcePlugin,\n    JsonFeedEventSourcePlugin,\n    SimpleRecurrencePlugin,\n    DefaultOptionChangeHandlers\n];\nfunction refinePluginDefs(pluginInputs) {\n    var plugins = [];\n    for (var _i = 0, pluginInputs_1 = pluginInputs; _i < pluginInputs_1.length; _i++) {\n        var pluginInput = pluginInputs_1[_i];\n        if (typeof pluginInput === 'string') {\n            var globalName = 'FullCalendar' + capitaliseFirstLetter(pluginInput);\n            if (!window[globalName]) {\n                console.warn('Plugin file not loaded for ' + pluginInput);\n            }\n            else {\n                plugins.push(window[globalName].default); // is an ES6 module\n            }\n        }\n        else {\n            plugins.push(pluginInput);\n        }\n    }\n    return INTERNAL_PLUGINS.concat(plugins);\n}\n\nvar RAW_EN_LOCALE = {\n    code: 'en',\n    week: {\n        dow: 0,\n        doy: 4 // 4 days need to be within the year to be considered the first week\n    },\n    dir: 'ltr',\n    buttonText: {\n        prev: 'prev',\n        next: 'next',\n        prevYear: 'prev year',\n        nextYear: 'next year',\n        year: 'year',\n        today: 'today',\n        month: 'month',\n        week: 'week',\n        day: 'day',\n        list: 'list'\n    },\n    weekLabel: 'W',\n    allDayText: 'all-day',\n    eventLimitText: 'more',\n    noEventsMessage: 'No events to display'\n};\nfunction parseRawLocales(explicitRawLocales) {\n    var defaultCode = explicitRawLocales.length > 0 ? explicitRawLocales[0].code : 'en';\n    var globalArray = window['FullCalendarLocalesAll'] || []; // from locales-all.js\n    var globalObject = window['FullCalendarLocales'] || {}; // from locales/*.js. keys are meaningless\n    var allRawLocales = globalArray.concat(// globalArray is low prio\n    hashValuesToArray(globalObject), // medium prio\n    explicitRawLocales // highest prio\n    );\n    var rawLocaleMap = {\n        en: RAW_EN_LOCALE // necessary?\n    };\n    for (var _i = 0, allRawLocales_1 = allRawLocales; _i < allRawLocales_1.length; _i++) {\n        var rawLocale = allRawLocales_1[_i];\n        rawLocaleMap[rawLocale.code] = rawLocale;\n    }\n    return {\n        map: rawLocaleMap,\n        defaultCode: defaultCode\n    };\n}\nfunction buildLocale(inputSingular, available) {\n    if (typeof inputSingular === 'object' && !Array.isArray(inputSingular)) {\n        return parseLocale(inputSingular.code, [inputSingular.code], inputSingular);\n    }\n    else {\n        return queryLocale(inputSingular, available);\n    }\n}\nfunction queryLocale(codeArg, available) {\n    var codes = [].concat(codeArg || []); // will convert to array\n    var raw = queryRawLocale(codes, available) || RAW_EN_LOCALE;\n    return parseLocale(codeArg, codes, raw);\n}\nfunction queryRawLocale(codes, available) {\n    for (var i = 0; i < codes.length; i++) {\n        var parts = codes[i].toLocaleLowerCase().split('-');\n        for (var j = parts.length; j > 0; j--) {\n            var simpleId = parts.slice(0, j).join('-');\n            if (available[simpleId]) {\n                return available[simpleId];\n            }\n        }\n    }\n    return null;\n}\nfunction parseLocale(codeArg, codes, raw) {\n    var merged = mergeProps([RAW_EN_LOCALE, raw], ['buttonText']);\n    delete merged.code; // don't want this part of the options\n    var week = merged.week;\n    delete merged.week;\n    return {\n        codeArg: codeArg,\n        codes: codes,\n        week: week,\n        simpleNumberFormat: new Intl.NumberFormat(codeArg),\n        options: merged\n    };\n}\n\nvar OptionsManager = /** @class */ (function () {\n    function OptionsManager(overrides) {\n        this.overrides = __assign({}, overrides); // make a copy\n        this.dynamicOverrides = {};\n        this.compute();\n    }\n    OptionsManager.prototype.mutate = function (updates, removals, isDynamic) {\n        if (!Object.keys(updates).length && !removals.length) {\n            return;\n        }\n        var overrideHash = isDynamic ? this.dynamicOverrides : this.overrides;\n        __assign(overrideHash, updates);\n        for (var _i = 0, removals_1 = removals; _i < removals_1.length; _i++) {\n            var propName = removals_1[_i];\n            delete overrideHash[propName];\n        }\n        this.compute();\n    };\n    // Computes the flattened options hash for the calendar and assigns to `this.options`.\n    // Assumes this.overrides and this.dynamicOverrides have already been initialized.\n    OptionsManager.prototype.compute = function () {\n        // TODO: not a very efficient system\n        var locales = firstDefined(// explicit locale option given?\n        this.dynamicOverrides.locales, this.overrides.locales, globalDefaults.locales);\n        var locale = firstDefined(// explicit locales option given?\n        this.dynamicOverrides.locale, this.overrides.locale, globalDefaults.locale);\n        var available = parseRawLocales(locales);\n        var localeDefaults = buildLocale(locale || available.defaultCode, available.map).options;\n        var dir = firstDefined(// based on options computed so far, is direction RTL?\n        this.dynamicOverrides.dir, this.overrides.dir, localeDefaults.dir);\n        var dirDefaults = dir === 'rtl' ? rtlDefaults : {};\n        this.dirDefaults = dirDefaults;\n        this.localeDefaults = localeDefaults;\n        this.computed = mergeOptions([\n            globalDefaults,\n            dirDefaults,\n            localeDefaults,\n            this.overrides,\n            this.dynamicOverrides\n        ]);\n    };\n    return OptionsManager;\n}());\n\nvar calendarSystemClassMap = {};\nfunction registerCalendarSystem(name, theClass) {\n    calendarSystemClassMap[name] = theClass;\n}\nfunction createCalendarSystem(name) {\n    return new calendarSystemClassMap[name]();\n}\nvar GregorianCalendarSystem = /** @class */ (function () {\n    function GregorianCalendarSystem() {\n    }\n    GregorianCalendarSystem.prototype.getMarkerYear = function (d) {\n        return d.getUTCFullYear();\n    };\n    GregorianCalendarSystem.prototype.getMarkerMonth = function (d) {\n        return d.getUTCMonth();\n    };\n    GregorianCalendarSystem.prototype.getMarkerDay = function (d) {\n        return d.getUTCDate();\n    };\n    GregorianCalendarSystem.prototype.arrayToMarker = function (arr) {\n        return arrayToUtcDate(arr);\n    };\n    GregorianCalendarSystem.prototype.markerToArray = function (marker) {\n        return dateToUtcArray(marker);\n    };\n    return GregorianCalendarSystem;\n}());\nregisterCalendarSystem('gregory', GregorianCalendarSystem);\n\nvar ISO_RE = /^\\s*(\\d{4})(-(\\d{2})(-(\\d{2})([T ](\\d{2}):(\\d{2})(:(\\d{2})(\\.(\\d+))?)?(Z|(([-+])(\\d{2})(:?(\\d{2}))?))?)?)?)?$/;\nfunction parse(str) {\n    var m = ISO_RE.exec(str);\n    if (m) {\n        var marker = new Date(Date.UTC(Number(m[1]), m[3] ? Number(m[3]) - 1 : 0, Number(m[5] || 1), Number(m[7] || 0), Number(m[8] || 0), Number(m[10] || 0), m[12] ? Number('0.' + m[12]) * 1000 : 0));\n        if (isValidDate(marker)) {\n            var timeZoneOffset = null;\n            if (m[13]) {\n                timeZoneOffset = (m[15] === '-' ? -1 : 1) * (Number(m[16] || 0) * 60 +\n                    Number(m[18] || 0));\n            }\n            return {\n                marker: marker,\n                isTimeUnspecified: !m[6],\n                timeZoneOffset: timeZoneOffset\n            };\n        }\n    }\n    return null;\n}\n\nvar DateEnv = /** @class */ (function () {\n    function DateEnv(settings) {\n        var timeZone = this.timeZone = settings.timeZone;\n        var isNamedTimeZone = timeZone !== 'local' && timeZone !== 'UTC';\n        if (settings.namedTimeZoneImpl && isNamedTimeZone) {\n            this.namedTimeZoneImpl = new settings.namedTimeZoneImpl(timeZone);\n        }\n        this.canComputeOffset = Boolean(!isNamedTimeZone || this.namedTimeZoneImpl);\n        this.calendarSystem = createCalendarSystem(settings.calendarSystem);\n        this.locale = settings.locale;\n        this.weekDow = settings.locale.week.dow;\n        this.weekDoy = settings.locale.week.doy;\n        if (settings.weekNumberCalculation === 'ISO') {\n            this.weekDow = 1;\n            this.weekDoy = 4;\n        }\n        if (typeof settings.firstDay === 'number') {\n            this.weekDow = settings.firstDay;\n        }\n        if (typeof settings.weekNumberCalculation === 'function') {\n            this.weekNumberFunc = settings.weekNumberCalculation;\n        }\n        this.weekLabel = settings.weekLabel != null ? settings.weekLabel : settings.locale.options.weekLabel;\n        this.cmdFormatter = settings.cmdFormatter;\n    }\n    // Creating / Parsing\n    DateEnv.prototype.createMarker = function (input) {\n        var meta = this.createMarkerMeta(input);\n        if (meta === null) {\n            return null;\n        }\n        return meta.marker;\n    };\n    DateEnv.prototype.createNowMarker = function () {\n        if (this.canComputeOffset) {\n            return this.timestampToMarker(new Date().valueOf());\n        }\n        else {\n            // if we can't compute the current date val for a timezone,\n            // better to give the current local date vals than UTC\n            return arrayToUtcDate(dateToLocalArray(new Date()));\n        }\n    };\n    DateEnv.prototype.createMarkerMeta = function (input) {\n        if (typeof input === 'string') {\n            return this.parse(input);\n        }\n        var marker = null;\n        if (typeof input === 'number') {\n            marker = this.timestampToMarker(input);\n        }\n        else if (input instanceof Date) {\n            input = input.valueOf();\n            if (!isNaN(input)) {\n                marker = this.timestampToMarker(input);\n            }\n        }\n        else if (Array.isArray(input)) {\n            marker = arrayToUtcDate(input);\n        }\n        if (marker === null || !isValidDate(marker)) {\n            return null;\n        }\n        return { marker: marker, isTimeUnspecified: false, forcedTzo: null };\n    };\n    DateEnv.prototype.parse = function (s) {\n        var parts = parse(s);\n        if (parts === null) {\n            return null;\n        }\n        var marker = parts.marker;\n        var forcedTzo = null;\n        if (parts.timeZoneOffset !== null) {\n            if (this.canComputeOffset) {\n                marker = this.timestampToMarker(marker.valueOf() - parts.timeZoneOffset * 60 * 1000);\n            }\n            else {\n                forcedTzo = parts.timeZoneOffset;\n            }\n        }\n        return { marker: marker, isTimeUnspecified: parts.isTimeUnspecified, forcedTzo: forcedTzo };\n    };\n    // Accessors\n    DateEnv.prototype.getYear = function (marker) {\n        return this.calendarSystem.getMarkerYear(marker);\n    };\n    DateEnv.prototype.getMonth = function (marker) {\n        return this.calendarSystem.getMarkerMonth(marker);\n    };\n    // Adding / Subtracting\n    DateEnv.prototype.add = function (marker, dur) {\n        var a = this.calendarSystem.markerToArray(marker);\n        a[0] += dur.years;\n        a[1] += dur.months;\n        a[2] += dur.days;\n        a[6] += dur.milliseconds;\n        return this.calendarSystem.arrayToMarker(a);\n    };\n    DateEnv.prototype.subtract = function (marker, dur) {\n        var a = this.calendarSystem.markerToArray(marker);\n        a[0] -= dur.years;\n        a[1] -= dur.months;\n        a[2] -= dur.days;\n        a[6] -= dur.milliseconds;\n        return this.calendarSystem.arrayToMarker(a);\n    };\n    DateEnv.prototype.addYears = function (marker, n) {\n        var a = this.calendarSystem.markerToArray(marker);\n        a[0] += n;\n        return this.calendarSystem.arrayToMarker(a);\n    };\n    DateEnv.prototype.addMonths = function (marker, n) {\n        var a = this.calendarSystem.markerToArray(marker);\n        a[1] += n;\n        return this.calendarSystem.arrayToMarker(a);\n    };\n    // Diffing Whole Units\n    DateEnv.prototype.diffWholeYears = function (m0, m1) {\n        var calendarSystem = this.calendarSystem;\n        if (timeAsMs(m0) === timeAsMs(m1) &&\n            calendarSystem.getMarkerDay(m0) === calendarSystem.getMarkerDay(m1) &&\n            calendarSystem.getMarkerMonth(m0) === calendarSystem.getMarkerMonth(m1)) {\n            return calendarSystem.getMarkerYear(m1) - calendarSystem.getMarkerYear(m0);\n        }\n        return null;\n    };\n    DateEnv.prototype.diffWholeMonths = function (m0, m1) {\n        var calendarSystem = this.calendarSystem;\n        if (timeAsMs(m0) === timeAsMs(m1) &&\n            calendarSystem.getMarkerDay(m0) === calendarSystem.getMarkerDay(m1)) {\n            return (calendarSystem.getMarkerMonth(m1) - calendarSystem.getMarkerMonth(m0)) +\n                (calendarSystem.getMarkerYear(m1) - calendarSystem.getMarkerYear(m0)) * 12;\n        }\n        return null;\n    };\n    // Range / Duration\n    DateEnv.prototype.greatestWholeUnit = function (m0, m1) {\n        var n = this.diffWholeYears(m0, m1);\n        if (n !== null) {\n            return { unit: 'year', value: n };\n        }\n        n = this.diffWholeMonths(m0, m1);\n        if (n !== null) {\n            return { unit: 'month', value: n };\n        }\n        n = diffWholeWeeks(m0, m1);\n        if (n !== null) {\n            return { unit: 'week', value: n };\n        }\n        n = diffWholeDays(m0, m1);\n        if (n !== null) {\n            return { unit: 'day', value: n };\n        }\n        n = diffHours(m0, m1);\n        if (isInt(n)) {\n            return { unit: 'hour', value: n };\n        }\n        n = diffMinutes(m0, m1);\n        if (isInt(n)) {\n            return { unit: 'minute', value: n };\n        }\n        n = diffSeconds(m0, m1);\n        if (isInt(n)) {\n            return { unit: 'second', value: n };\n        }\n        return { unit: 'millisecond', value: m1.valueOf() - m0.valueOf() };\n    };\n    DateEnv.prototype.countDurationsBetween = function (m0, m1, d) {\n        // TODO: can use greatestWholeUnit\n        var diff;\n        if (d.years) {\n            diff = this.diffWholeYears(m0, m1);\n            if (diff !== null) {\n                return diff / asRoughYears(d);\n            }\n        }\n        if (d.months) {\n            diff = this.diffWholeMonths(m0, m1);\n            if (diff !== null) {\n                return diff / asRoughMonths(d);\n            }\n        }\n        if (d.days) {\n            diff = diffWholeDays(m0, m1);\n            if (diff !== null) {\n                return diff / asRoughDays(d);\n            }\n        }\n        return (m1.valueOf() - m0.valueOf()) / asRoughMs(d);\n    };\n    // Start-Of\n    DateEnv.prototype.startOf = function (m, unit) {\n        if (unit === 'year') {\n            return this.startOfYear(m);\n        }\n        else if (unit === 'month') {\n            return this.startOfMonth(m);\n        }\n        else if (unit === 'week') {\n            return this.startOfWeek(m);\n        }\n        else if (unit === 'day') {\n            return startOfDay(m);\n        }\n        else if (unit === 'hour') {\n            return startOfHour(m);\n        }\n        else if (unit === 'minute') {\n            return startOfMinute(m);\n        }\n        else if (unit === 'second') {\n            return startOfSecond(m);\n        }\n    };\n    DateEnv.prototype.startOfYear = function (m) {\n        return this.calendarSystem.arrayToMarker([\n            this.calendarSystem.getMarkerYear(m)\n        ]);\n    };\n    DateEnv.prototype.startOfMonth = function (m) {\n        return this.calendarSystem.arrayToMarker([\n            this.calendarSystem.getMarkerYear(m),\n            this.calendarSystem.getMarkerMonth(m)\n        ]);\n    };\n    DateEnv.prototype.startOfWeek = function (m) {\n        return this.calendarSystem.arrayToMarker([\n            this.calendarSystem.getMarkerYear(m),\n            this.calendarSystem.getMarkerMonth(m),\n            m.getUTCDate() - ((m.getUTCDay() - this.weekDow + 7) % 7)\n        ]);\n    };\n    // Week Number\n    DateEnv.prototype.computeWeekNumber = function (marker) {\n        if (this.weekNumberFunc) {\n            return this.weekNumberFunc(this.toDate(marker));\n        }\n        else {\n            return weekOfYear(marker, this.weekDow, this.weekDoy);\n        }\n    };\n    // TODO: choke on timeZoneName: long\n    DateEnv.prototype.format = function (marker, formatter, dateOptions) {\n        if (dateOptions === void 0) { dateOptions = {}; }\n        return formatter.format({\n            marker: marker,\n            timeZoneOffset: dateOptions.forcedTzo != null ?\n                dateOptions.forcedTzo :\n                this.offsetForMarker(marker)\n        }, this);\n    };\n    DateEnv.prototype.formatRange = function (start, end, formatter, dateOptions) {\n        if (dateOptions === void 0) { dateOptions = {}; }\n        if (dateOptions.isEndExclusive) {\n            end = addMs(end, -1);\n        }\n        return formatter.formatRange({\n            marker: start,\n            timeZoneOffset: dateOptions.forcedStartTzo != null ?\n                dateOptions.forcedStartTzo :\n                this.offsetForMarker(start)\n        }, {\n            marker: end,\n            timeZoneOffset: dateOptions.forcedEndTzo != null ?\n                dateOptions.forcedEndTzo :\n                this.offsetForMarker(end)\n        }, this);\n    };\n    DateEnv.prototype.formatIso = function (marker, extraOptions) {\n        if (extraOptions === void 0) { extraOptions = {}; }\n        var timeZoneOffset = null;\n        if (!extraOptions.omitTimeZoneOffset) {\n            if (extraOptions.forcedTzo != null) {\n                timeZoneOffset = extraOptions.forcedTzo;\n            }\n            else {\n                timeZoneOffset = this.offsetForMarker(marker);\n            }\n        }\n        return buildIsoString(marker, timeZoneOffset, extraOptions.omitTime);\n    };\n    // TimeZone\n    DateEnv.prototype.timestampToMarker = function (ms) {\n        if (this.timeZone === 'local') {\n            return arrayToUtcDate(dateToLocalArray(new Date(ms)));\n        }\n        else if (this.timeZone === 'UTC' || !this.namedTimeZoneImpl) {\n            return new Date(ms);\n        }\n        else {\n            return arrayToUtcDate(this.namedTimeZoneImpl.timestampToArray(ms));\n        }\n    };\n    DateEnv.prototype.offsetForMarker = function (m) {\n        if (this.timeZone === 'local') {\n            return -arrayToLocalDate(dateToUtcArray(m)).getTimezoneOffset(); // convert \"inverse\" offset to \"normal\" offset\n        }\n        else if (this.timeZone === 'UTC') {\n            return 0;\n        }\n        else if (this.namedTimeZoneImpl) {\n            return this.namedTimeZoneImpl.offsetForArray(dateToUtcArray(m));\n        }\n        return null;\n    };\n    // Conversion\n    DateEnv.prototype.toDate = function (m, forcedTzo) {\n        if (this.timeZone === 'local') {\n            return arrayToLocalDate(dateToUtcArray(m));\n        }\n        else if (this.timeZone === 'UTC') {\n            return new Date(m.valueOf()); // make sure it's a copy\n        }\n        else if (!this.namedTimeZoneImpl) {\n            return new Date(m.valueOf() - (forcedTzo || 0));\n        }\n        else {\n            return new Date(m.valueOf() -\n                this.namedTimeZoneImpl.offsetForArray(dateToUtcArray(m)) * 1000 * 60 // convert minutes -> ms\n            );\n        }\n    };\n    return DateEnv;\n}());\n\nvar SIMPLE_SOURCE_PROPS = {\n    id: String,\n    allDayDefault: Boolean,\n    eventDataTransform: Function,\n    success: Function,\n    failure: Function\n};\nvar uid$2 = 0;\nfunction doesSourceNeedRange(eventSource, calendar) {\n    var defs = calendar.pluginSystem.hooks.eventSourceDefs;\n    return !defs[eventSource.sourceDefId].ignoreRange;\n}\nfunction parseEventSource(raw, calendar) {\n    var defs = calendar.pluginSystem.hooks.eventSourceDefs;\n    for (var i = defs.length - 1; i >= 0; i--) { // later-added plugins take precedence\n        var def = defs[i];\n        var meta = def.parseMeta(raw);\n        if (meta) {\n            var res = parseEventSourceProps(typeof raw === 'object' ? raw : {}, meta, i, calendar);\n            res._raw = raw;\n            return res;\n        }\n    }\n    return null;\n}\nfunction parseEventSourceProps(raw, meta, sourceDefId, calendar) {\n    var leftovers0 = {};\n    var props = refineProps(raw, SIMPLE_SOURCE_PROPS, {}, leftovers0);\n    var leftovers1 = {};\n    var ui = processUnscopedUiProps(leftovers0, calendar, leftovers1);\n    props.isFetching = false;\n    props.latestFetchId = '';\n    props.fetchRange = null;\n    props.publicId = String(raw.id || '');\n    props.sourceId = String(uid$2++);\n    props.sourceDefId = sourceDefId;\n    props.meta = meta;\n    props.ui = ui;\n    props.extendedProps = leftovers1;\n    return props;\n}\n\nfunction reduceEventSources (eventSources, action, dateProfile, calendar) {\n    switch (action.type) {\n        case 'ADD_EVENT_SOURCES': // already parsed\n            return addSources(eventSources, action.sources, dateProfile ? dateProfile.activeRange : null, calendar);\n        case 'REMOVE_EVENT_SOURCE':\n            return removeSource(eventSources, action.sourceId);\n        case 'PREV': // TODO: how do we track all actions that affect dateProfile :(\n        case 'NEXT':\n        case 'SET_DATE':\n        case 'SET_VIEW_TYPE':\n            if (dateProfile) {\n                return fetchDirtySources(eventSources, dateProfile.activeRange, calendar);\n            }\n            else {\n                return eventSources;\n            }\n        case 'FETCH_EVENT_SOURCES':\n        case 'CHANGE_TIMEZONE':\n            return fetchSourcesByIds(eventSources, action.sourceIds ?\n                arrayToHash(action.sourceIds) :\n                excludeStaticSources(eventSources, calendar), dateProfile ? dateProfile.activeRange : null, calendar);\n        case 'RECEIVE_EVENTS':\n        case 'RECEIVE_EVENT_ERROR':\n            return receiveResponse(eventSources, action.sourceId, action.fetchId, action.fetchRange);\n        case 'REMOVE_ALL_EVENT_SOURCES':\n            return {};\n        default:\n            return eventSources;\n    }\n}\nvar uid$3 = 0;\nfunction addSources(eventSourceHash, sources, fetchRange, calendar) {\n    var hash = {};\n    for (var _i = 0, sources_1 = sources; _i < sources_1.length; _i++) {\n        var source = sources_1[_i];\n        hash[source.sourceId] = source;\n    }\n    if (fetchRange) {\n        hash = fetchDirtySources(hash, fetchRange, calendar);\n    }\n    return __assign({}, eventSourceHash, hash);\n}\nfunction removeSource(eventSourceHash, sourceId) {\n    return filterHash(eventSourceHash, function (eventSource) {\n        return eventSource.sourceId !== sourceId;\n    });\n}\nfunction fetchDirtySources(sourceHash, fetchRange, calendar) {\n    return fetchSourcesByIds(sourceHash, filterHash(sourceHash, function (eventSource) {\n        return isSourceDirty(eventSource, fetchRange, calendar);\n    }), fetchRange, calendar);\n}\nfunction isSourceDirty(eventSource, fetchRange, calendar) {\n    if (!doesSourceNeedRange(eventSource, calendar)) {\n        return !eventSource.latestFetchId;\n    }\n    else {\n        return !calendar.opt('lazyFetching') ||\n            !eventSource.fetchRange ||\n            eventSource.isFetching || // always cancel outdated in-progress fetches\n            fetchRange.start < eventSource.fetchRange.start ||\n            fetchRange.end > eventSource.fetchRange.end;\n    }\n}\nfunction fetchSourcesByIds(prevSources, sourceIdHash, fetchRange, calendar) {\n    var nextSources = {};\n    for (var sourceId in prevSources) {\n        var source = prevSources[sourceId];\n        if (sourceIdHash[sourceId]) {\n            nextSources[sourceId] = fetchSource(source, fetchRange, calendar);\n        }\n        else {\n            nextSources[sourceId] = source;\n        }\n    }\n    return nextSources;\n}\nfunction fetchSource(eventSource, fetchRange, calendar) {\n    var sourceDef = calendar.pluginSystem.hooks.eventSourceDefs[eventSource.sourceDefId];\n    var fetchId = String(uid$3++);\n    sourceDef.fetch({\n        eventSource: eventSource,\n        calendar: calendar,\n        range: fetchRange\n    }, function (res) {\n        var rawEvents = res.rawEvents;\n        var calSuccess = calendar.opt('eventSourceSuccess');\n        var calSuccessRes;\n        var sourceSuccessRes;\n        if (eventSource.success) {\n            sourceSuccessRes = eventSource.success(rawEvents, res.xhr);\n        }\n        if (calSuccess) {\n            calSuccessRes = calSuccess(rawEvents, res.xhr);\n        }\n        rawEvents = sourceSuccessRes || calSuccessRes || rawEvents;\n        calendar.dispatch({\n            type: 'RECEIVE_EVENTS',\n            sourceId: eventSource.sourceId,\n            fetchId: fetchId,\n            fetchRange: fetchRange,\n            rawEvents: rawEvents\n        });\n    }, function (error) {\n        var callFailure = calendar.opt('eventSourceFailure');\n        console.warn(error.message, error);\n        if (eventSource.failure) {\n            eventSource.failure(error);\n        }\n        if (callFailure) {\n            callFailure(error);\n        }\n        calendar.dispatch({\n            type: 'RECEIVE_EVENT_ERROR',\n            sourceId: eventSource.sourceId,\n            fetchId: fetchId,\n            fetchRange: fetchRange,\n            error: error\n        });\n    });\n    return __assign({}, eventSource, { isFetching: true, latestFetchId: fetchId });\n}\nfunction receiveResponse(sourceHash, sourceId, fetchId, fetchRange) {\n    var _a;\n    var eventSource = sourceHash[sourceId];\n    if (eventSource && // not already removed\n        fetchId === eventSource.latestFetchId) {\n        return __assign({}, sourceHash, (_a = {}, _a[sourceId] = __assign({}, eventSource, { isFetching: false, fetchRange: fetchRange // also serves as a marker that at least one fetch has completed\n         }), _a));\n    }\n    return sourceHash;\n}\nfunction excludeStaticSources(eventSources, calendar) {\n    return filterHash(eventSources, function (eventSource) {\n        return doesSourceNeedRange(eventSource, calendar);\n    });\n}\n\nvar DateProfileGenerator = /** @class */ (function () {\n    function DateProfileGenerator(viewSpec, calendar) {\n        this.viewSpec = viewSpec;\n        this.options = viewSpec.options;\n        this.dateEnv = calendar.dateEnv;\n        this.calendar = calendar;\n        this.initHiddenDays();\n    }\n    /* Date Range Computation\n    ------------------------------------------------------------------------------------------------------------------*/\n    // Builds a structure with info about what the dates/ranges will be for the \"prev\" view.\n    DateProfileGenerator.prototype.buildPrev = function (currentDateProfile, currentDate) {\n        var dateEnv = this.dateEnv;\n        var prevDate = dateEnv.subtract(dateEnv.startOf(currentDate, currentDateProfile.currentRangeUnit), // important for start-of-month\n        currentDateProfile.dateIncrement);\n        return this.build(prevDate, -1);\n    };\n    // Builds a structure with info about what the dates/ranges will be for the \"next\" view.\n    DateProfileGenerator.prototype.buildNext = function (currentDateProfile, currentDate) {\n        var dateEnv = this.dateEnv;\n        var nextDate = dateEnv.add(dateEnv.startOf(currentDate, currentDateProfile.currentRangeUnit), // important for start-of-month\n        currentDateProfile.dateIncrement);\n        return this.build(nextDate, 1);\n    };\n    // Builds a structure holding dates/ranges for rendering around the given date.\n    // Optional direction param indicates whether the date is being incremented/decremented\n    // from its previous value. decremented = -1, incremented = 1 (default).\n    DateProfileGenerator.prototype.build = function (currentDate, direction, forceToValid) {\n        if (forceToValid === void 0) { forceToValid = false; }\n        var validRange;\n        var minTime = null;\n        var maxTime = null;\n        var currentInfo;\n        var isRangeAllDay;\n        var renderRange;\n        var activeRange;\n        var isValid;\n        validRange = this.buildValidRange();\n        validRange = this.trimHiddenDays(validRange);\n        if (forceToValid) {\n            currentDate = constrainMarkerToRange(currentDate, validRange);\n        }\n        currentInfo = this.buildCurrentRangeInfo(currentDate, direction);\n        isRangeAllDay = /^(year|month|week|day)$/.test(currentInfo.unit);\n        renderRange = this.buildRenderRange(this.trimHiddenDays(currentInfo.range), currentInfo.unit, isRangeAllDay);\n        renderRange = this.trimHiddenDays(renderRange);\n        activeRange = renderRange;\n        if (!this.options.showNonCurrentDates) {\n            activeRange = intersectRanges(activeRange, currentInfo.range);\n        }\n        minTime = createDuration(this.options.minTime);\n        maxTime = createDuration(this.options.maxTime);\n        activeRange = this.adjustActiveRange(activeRange, minTime, maxTime);\n        activeRange = intersectRanges(activeRange, validRange); // might return null\n        // it's invalid if the originally requested date is not contained,\n        // or if the range is completely outside of the valid range.\n        isValid = rangesIntersect(currentInfo.range, validRange);\n        return {\n            // constraint for where prev/next operations can go and where events can be dragged/resized to.\n            // an object with optional start and end properties.\n            validRange: validRange,\n            // range the view is formally responsible for.\n            // for example, a month view might have 1st-31st, excluding padded dates\n            currentRange: currentInfo.range,\n            // name of largest unit being displayed, like \"month\" or \"week\"\n            currentRangeUnit: currentInfo.unit,\n            isRangeAllDay: isRangeAllDay,\n            // dates that display events and accept drag-n-drop\n            // will be `null` if no dates accept events\n            activeRange: activeRange,\n            // date range with a rendered skeleton\n            // includes not-active days that need some sort of DOM\n            renderRange: renderRange,\n            // Duration object that denotes the first visible time of any given day\n            minTime: minTime,\n            // Duration object that denotes the exclusive visible end time of any given day\n            maxTime: maxTime,\n            isValid: isValid,\n            // how far the current date will move for a prev/next operation\n            dateIncrement: this.buildDateIncrement(currentInfo.duration)\n            // pass a fallback (might be null) ^\n        };\n    };\n    // Builds an object with optional start/end properties.\n    // Indicates the minimum/maximum dates to display.\n    // not responsible for trimming hidden days.\n    DateProfileGenerator.prototype.buildValidRange = function () {\n        return this.getRangeOption('validRange', this.calendar.getNow()) ||\n            { start: null, end: null }; // completely open-ended\n    };\n    // Builds a structure with info about the \"current\" range, the range that is\n    // highlighted as being the current month for example.\n    // See build() for a description of `direction`.\n    // Guaranteed to have `range` and `unit` properties. `duration` is optional.\n    DateProfileGenerator.prototype.buildCurrentRangeInfo = function (date, direction) {\n        var _a = this, viewSpec = _a.viewSpec, dateEnv = _a.dateEnv;\n        var duration = null;\n        var unit = null;\n        var range = null;\n        var dayCount;\n        if (viewSpec.duration) {\n            duration = viewSpec.duration;\n            unit = viewSpec.durationUnit;\n            range = this.buildRangeFromDuration(date, direction, duration, unit);\n        }\n        else if ((dayCount = this.options.dayCount)) {\n            unit = 'day';\n            range = this.buildRangeFromDayCount(date, direction, dayCount);\n        }\n        else if ((range = this.buildCustomVisibleRange(date))) {\n            unit = dateEnv.greatestWholeUnit(range.start, range.end).unit;\n        }\n        else {\n            duration = this.getFallbackDuration();\n            unit = greatestDurationDenominator(duration).unit;\n            range = this.buildRangeFromDuration(date, direction, duration, unit);\n        }\n        return { duration: duration, unit: unit, range: range };\n    };\n    DateProfileGenerator.prototype.getFallbackDuration = function () {\n        return createDuration({ day: 1 });\n    };\n    // Returns a new activeRange to have time values (un-ambiguate)\n    // minTime or maxTime causes the range to expand.\n    DateProfileGenerator.prototype.adjustActiveRange = function (range, minTime, maxTime) {\n        var dateEnv = this.dateEnv;\n        var start = range.start;\n        var end = range.end;\n        if (this.viewSpec.class.prototype.usesMinMaxTime) {\n            // expand active range if minTime is negative (why not when positive?)\n            if (asRoughDays(minTime) < 0) {\n                start = startOfDay(start); // necessary?\n                start = dateEnv.add(start, minTime);\n            }\n            // expand active range if maxTime is beyond one day (why not when positive?)\n            if (asRoughDays(maxTime) > 1) {\n                end = startOfDay(end); // necessary?\n                end = addDays(end, -1);\n                end = dateEnv.add(end, maxTime);\n            }\n        }\n        return { start: start, end: end };\n    };\n    // Builds the \"current\" range when it is specified as an explicit duration.\n    // `unit` is the already-computed greatestDurationDenominator unit of duration.\n    DateProfileGenerator.prototype.buildRangeFromDuration = function (date, direction, duration, unit) {\n        var dateEnv = this.dateEnv;\n        var alignment = this.options.dateAlignment;\n        var dateIncrementInput;\n        var dateIncrementDuration;\n        var start;\n        var end;\n        var res;\n        // compute what the alignment should be\n        if (!alignment) {\n            dateIncrementInput = this.options.dateIncrement;\n            if (dateIncrementInput) {\n                dateIncrementDuration = createDuration(dateIncrementInput);\n                // use the smaller of the two units\n                if (asRoughMs(dateIncrementDuration) < asRoughMs(duration)) {\n                    alignment = greatestDurationDenominator(dateIncrementDuration, !getWeeksFromInput(dateIncrementInput)).unit;\n                }\n                else {\n                    alignment = unit;\n                }\n            }\n            else {\n                alignment = unit;\n            }\n        }\n        // if the view displays a single day or smaller\n        if (asRoughDays(duration) <= 1) {\n            if (this.isHiddenDay(start)) {\n                start = this.skipHiddenDays(start, direction);\n                start = startOfDay(start);\n            }\n        }\n        function computeRes() {\n            start = dateEnv.startOf(date, alignment);\n            end = dateEnv.add(start, duration);\n            res = { start: start, end: end };\n        }\n        computeRes();\n        // if range is completely enveloped by hidden days, go past the hidden days\n        if (!this.trimHiddenDays(res)) {\n            date = this.skipHiddenDays(date, direction);\n            computeRes();\n        }\n        return res;\n    };\n    // Builds the \"current\" range when a dayCount is specified.\n    DateProfileGenerator.prototype.buildRangeFromDayCount = function (date, direction, dayCount) {\n        var dateEnv = this.dateEnv;\n        var customAlignment = this.options.dateAlignment;\n        var runningCount = 0;\n        var start = date;\n        var end;\n        if (customAlignment) {\n            start = dateEnv.startOf(start, customAlignment);\n        }\n        start = startOfDay(start);\n        start = this.skipHiddenDays(start, direction);\n        end = start;\n        do {\n            end = addDays(end, 1);\n            if (!this.isHiddenDay(end)) {\n                runningCount++;\n            }\n        } while (runningCount < dayCount);\n        return { start: start, end: end };\n    };\n    // Builds a normalized range object for the \"visible\" range,\n    // which is a way to define the currentRange and activeRange at the same time.\n    DateProfileGenerator.prototype.buildCustomVisibleRange = function (date) {\n        var dateEnv = this.dateEnv;\n        var visibleRange = this.getRangeOption('visibleRange', dateEnv.toDate(date));\n        if (visibleRange && (visibleRange.start == null || visibleRange.end == null)) {\n            return null;\n        }\n        return visibleRange;\n    };\n    // Computes the range that will represent the element/cells for *rendering*,\n    // but which may have voided days/times.\n    // not responsible for trimming hidden days.\n    DateProfileGenerator.prototype.buildRenderRange = function (currentRange, currentRangeUnit, isRangeAllDay) {\n        return currentRange;\n    };\n    // Compute the duration value that should be added/substracted to the current date\n    // when a prev/next operation happens.\n    DateProfileGenerator.prototype.buildDateIncrement = function (fallback) {\n        var dateIncrementInput = this.options.dateIncrement;\n        var customAlignment;\n        if (dateIncrementInput) {\n            return createDuration(dateIncrementInput);\n        }\n        else if ((customAlignment = this.options.dateAlignment)) {\n            return createDuration(1, customAlignment);\n        }\n        else if (fallback) {\n            return fallback;\n        }\n        else {\n            return createDuration({ days: 1 });\n        }\n    };\n    // Arguments after name will be forwarded to a hypothetical function value\n    // WARNING: passed-in arguments will be given to generator functions as-is and can cause side-effects.\n    // Always clone your objects if you fear mutation.\n    DateProfileGenerator.prototype.getRangeOption = function (name) {\n        var otherArgs = [];\n        for (var _i = 1; _i < arguments.length; _i++) {\n            otherArgs[_i - 1] = arguments[_i];\n        }\n        var val = this.options[name];\n        if (typeof val === 'function') {\n            val = val.apply(null, otherArgs);\n        }\n        if (val) {\n            val = parseRange(val, this.dateEnv);\n        }\n        if (val) {\n            val = computeVisibleDayRange(val);\n        }\n        return val;\n    };\n    /* Hidden Days\n    ------------------------------------------------------------------------------------------------------------------*/\n    // Initializes internal variables related to calculating hidden days-of-week\n    DateProfileGenerator.prototype.initHiddenDays = function () {\n        var hiddenDays = this.options.hiddenDays || []; // array of day-of-week indices that are hidden\n        var isHiddenDayHash = []; // is the day-of-week hidden? (hash with day-of-week-index -> bool)\n        var dayCnt = 0;\n        var i;\n        if (this.options.weekends === false) {\n            hiddenDays.push(0, 6); // 0=sunday, 6=saturday\n        }\n        for (i = 0; i < 7; i++) {\n            if (!(isHiddenDayHash[i] = hiddenDays.indexOf(i) !== -1)) {\n                dayCnt++;\n            }\n        }\n        if (!dayCnt) {\n            throw new Error('invalid hiddenDays'); // all days were hidden? bad.\n        }\n        this.isHiddenDayHash = isHiddenDayHash;\n    };\n    // Remove days from the beginning and end of the range that are computed as hidden.\n    // If the whole range is trimmed off, returns null\n    DateProfileGenerator.prototype.trimHiddenDays = function (range) {\n        var start = range.start;\n        var end = range.end;\n        if (start) {\n            start = this.skipHiddenDays(start);\n        }\n        if (end) {\n            end = this.skipHiddenDays(end, -1, true);\n        }\n        if (start == null || end == null || start < end) {\n            return { start: start, end: end };\n        }\n        return null;\n    };\n    // Is the current day hidden?\n    // `day` is a day-of-week index (0-6), or a Date (used for UTC)\n    DateProfileGenerator.prototype.isHiddenDay = function (day) {\n        if (day instanceof Date) {\n            day = day.getUTCDay();\n        }\n        return this.isHiddenDayHash[day];\n    };\n    // Incrementing the current day until it is no longer a hidden day, returning a copy.\n    // DOES NOT CONSIDER validRange!\n    // If the initial value of `date` is not a hidden day, don't do anything.\n    // Pass `isExclusive` as `true` if you are dealing with an end date.\n    // `inc` defaults to `1` (increment one day forward each time)\n    DateProfileGenerator.prototype.skipHiddenDays = function (date, inc, isExclusive) {\n        if (inc === void 0) { inc = 1; }\n        if (isExclusive === void 0) { isExclusive = false; }\n        while (this.isHiddenDayHash[(date.getUTCDay() + (isExclusive ? inc : 0) + 7) % 7]) {\n            date = addDays(date, inc);\n        }\n        return date;\n    };\n    return DateProfileGenerator;\n}());\n// TODO: find a way to avoid comparing DateProfiles. it's tedious\nfunction isDateProfilesEqual(p0, p1) {\n    return rangesEqual(p0.validRange, p1.validRange) &&\n        rangesEqual(p0.activeRange, p1.activeRange) &&\n        rangesEqual(p0.renderRange, p1.renderRange) &&\n        durationsEqual(p0.minTime, p1.minTime) &&\n        durationsEqual(p0.maxTime, p1.maxTime);\n    /*\n    TODO: compare more?\n      currentRange: DateRange\n      currentRangeUnit: string\n      isRangeAllDay: boolean\n      isValid: boolean\n      dateIncrement: Duration\n    */\n}\n\nfunction reduce (state, action, calendar) {\n    var viewType = reduceViewType(state.viewType, action);\n    var dateProfile = reduceDateProfile(state.dateProfile, action, state.currentDate, viewType, calendar);\n    var eventSources = reduceEventSources(state.eventSources, action, dateProfile, calendar);\n    var nextState = __assign({}, state, { viewType: viewType,\n        dateProfile: dateProfile, currentDate: reduceCurrentDate(state.currentDate, action, dateProfile), eventSources: eventSources, eventStore: reduceEventStore(state.eventStore, action, eventSources, dateProfile, calendar), dateSelection: reduceDateSelection(state.dateSelection, action, calendar), eventSelection: reduceSelectedEvent(state.eventSelection, action), eventDrag: reduceEventDrag(state.eventDrag, action, eventSources, calendar), eventResize: reduceEventResize(state.eventResize, action, eventSources, calendar), eventSourceLoadingLevel: computeLoadingLevel(eventSources), loadingLevel: computeLoadingLevel(eventSources) });\n    for (var _i = 0, _a = calendar.pluginSystem.hooks.reducers; _i < _a.length; _i++) {\n        var reducerFunc = _a[_i];\n        nextState = reducerFunc(nextState, action, calendar);\n    }\n    // console.log(action.type, nextState)\n    return nextState;\n}\nfunction reduceViewType(currentViewType, action) {\n    switch (action.type) {\n        case 'SET_VIEW_TYPE':\n            return action.viewType;\n        default:\n            return currentViewType;\n    }\n}\nfunction reduceDateProfile(currentDateProfile, action, currentDate, viewType, calendar) {\n    var newDateProfile;\n    switch (action.type) {\n        case 'PREV':\n            newDateProfile = calendar.dateProfileGenerators[viewType].buildPrev(currentDateProfile, currentDate);\n            break;\n        case 'NEXT':\n            newDateProfile = calendar.dateProfileGenerators[viewType].buildNext(currentDateProfile, currentDate);\n            break;\n        case 'SET_DATE':\n            if (!currentDateProfile.activeRange ||\n                !rangeContainsMarker(currentDateProfile.currentRange, action.dateMarker)) {\n                newDateProfile = calendar.dateProfileGenerators[viewType].build(action.dateMarker, undefined, true // forceToValid\n                );\n            }\n            break;\n        case 'SET_VIEW_TYPE':\n            var generator = calendar.dateProfileGenerators[viewType];\n            if (!generator) {\n                throw new Error(viewType ?\n                    'The FullCalendar view \"' + viewType + '\" does not exist. Make sure your plugins are loaded correctly.' :\n                    'No available FullCalendar view plugins.');\n            }\n            newDateProfile = generator.build(action.dateMarker || currentDate, undefined, true // forceToValid\n            );\n            break;\n    }\n    if (newDateProfile &&\n        newDateProfile.isValid &&\n        !(currentDateProfile && isDateProfilesEqual(currentDateProfile, newDateProfile))) {\n        return newDateProfile;\n    }\n    else {\n        return currentDateProfile;\n    }\n}\nfunction reduceCurrentDate(currentDate, action, dateProfile) {\n    switch (action.type) {\n        case 'PREV':\n        case 'NEXT':\n            if (!rangeContainsMarker(dateProfile.currentRange, currentDate)) {\n                return dateProfile.currentRange.start;\n            }\n            else {\n                return currentDate;\n            }\n        case 'SET_DATE':\n        case 'SET_VIEW_TYPE':\n            var newDate = action.dateMarker || currentDate;\n            if (dateProfile.activeRange && !rangeContainsMarker(dateProfile.activeRange, newDate)) {\n                return dateProfile.currentRange.start;\n            }\n            else {\n                return newDate;\n            }\n        default:\n            return currentDate;\n    }\n}\nfunction reduceDateSelection(currentSelection, action, calendar) {\n    switch (action.type) {\n        case 'SELECT_DATES':\n            return action.selection;\n        case 'UNSELECT_DATES':\n            return null;\n        default:\n            return currentSelection;\n    }\n}\nfunction reduceSelectedEvent(currentInstanceId, action) {\n    switch (action.type) {\n        case 'SELECT_EVENT':\n            return action.eventInstanceId;\n        case 'UNSELECT_EVENT':\n            return '';\n        default:\n            return currentInstanceId;\n    }\n}\nfunction reduceEventDrag(currentDrag, action, sources, calendar) {\n    switch (action.type) {\n        case 'SET_EVENT_DRAG':\n            var newDrag = action.state;\n            return {\n                affectedEvents: newDrag.affectedEvents,\n                mutatedEvents: newDrag.mutatedEvents,\n                isEvent: newDrag.isEvent,\n                origSeg: newDrag.origSeg\n            };\n        case 'UNSET_EVENT_DRAG':\n            return null;\n        default:\n            return currentDrag;\n    }\n}\nfunction reduceEventResize(currentResize, action, sources, calendar) {\n    switch (action.type) {\n        case 'SET_EVENT_RESIZE':\n            var newResize = action.state;\n            return {\n                affectedEvents: newResize.affectedEvents,\n                mutatedEvents: newResize.mutatedEvents,\n                isEvent: newResize.isEvent,\n                origSeg: newResize.origSeg\n            };\n        case 'UNSET_EVENT_RESIZE':\n            return null;\n        default:\n            return currentResize;\n    }\n}\nfunction computeLoadingLevel(eventSources) {\n    var cnt = 0;\n    for (var sourceId in eventSources) {\n        if (eventSources[sourceId].isFetching) {\n            cnt++;\n        }\n    }\n    return cnt;\n}\n\nvar STANDARD_PROPS = {\n    start: null,\n    end: null,\n    allDay: Boolean\n};\nfunction parseDateSpan(raw, dateEnv, defaultDuration) {\n    var span = parseOpenDateSpan(raw, dateEnv);\n    var range = span.range;\n    if (!range.start) {\n        return null;\n    }\n    if (!range.end) {\n        if (defaultDuration == null) {\n            return null;\n        }\n        else {\n            range.end = dateEnv.add(range.start, defaultDuration);\n        }\n    }\n    return span;\n}\n/*\nTODO: somehow combine with parseRange?\nWill return null if the start/end props were present but parsed invalidly.\n*/\nfunction parseOpenDateSpan(raw, dateEnv) {\n    var leftovers = {};\n    var standardProps = refineProps(raw, STANDARD_PROPS, {}, leftovers);\n    var startMeta = standardProps.start ? dateEnv.createMarkerMeta(standardProps.start) : null;\n    var endMeta = standardProps.end ? dateEnv.createMarkerMeta(standardProps.end) : null;\n    var allDay = standardProps.allDay;\n    if (allDay == null) {\n        allDay = (startMeta && startMeta.isTimeUnspecified) &&\n            (!endMeta || endMeta.isTimeUnspecified);\n    }\n    // use this leftover object as the selection object\n    leftovers.range = {\n        start: startMeta ? startMeta.marker : null,\n        end: endMeta ? endMeta.marker : null\n    };\n    leftovers.allDay = allDay;\n    return leftovers;\n}\nfunction isDateSpansEqual(span0, span1) {\n    return rangesEqual(span0.range, span1.range) &&\n        span0.allDay === span1.allDay &&\n        isSpanPropsEqual(span0, span1);\n}\n// the NON-DATE-RELATED props\nfunction isSpanPropsEqual(span0, span1) {\n    for (var propName in span1) {\n        if (propName !== 'range' && propName !== 'allDay') {\n            if (span0[propName] !== span1[propName]) {\n                return false;\n            }\n        }\n    }\n    // are there any props that span0 has that span1 DOESN'T have?\n    // both have range/allDay, so no need to special-case.\n    for (var propName in span0) {\n        if (!(propName in span1)) {\n            return false;\n        }\n    }\n    return true;\n}\nfunction buildDateSpanApi(span, dateEnv) {\n    return {\n        start: dateEnv.toDate(span.range.start),\n        end: dateEnv.toDate(span.range.end),\n        startStr: dateEnv.formatIso(span.range.start, { omitTime: span.allDay }),\n        endStr: dateEnv.formatIso(span.range.end, { omitTime: span.allDay }),\n        allDay: span.allDay\n    };\n}\nfunction buildDatePointApi(span, dateEnv) {\n    return {\n        date: dateEnv.toDate(span.range.start),\n        dateStr: dateEnv.formatIso(span.range.start, { omitTime: span.allDay }),\n        allDay: span.allDay\n    };\n}\nfunction fabricateEventRange(dateSpan, eventUiBases, calendar) {\n    var def = parseEventDef({ editable: false }, '', // sourceId\n    dateSpan.allDay, true, // hasEnd\n    calendar);\n    return {\n        def: def,\n        ui: compileEventUi(def, eventUiBases),\n        instance: createEventInstance(def.defId, dateSpan.range),\n        range: dateSpan.range,\n        isStart: true,\n        isEnd: true\n    };\n}\n\nfunction compileViewDefs(defaultConfigs, overrideConfigs) {\n    var hash = {};\n    var viewType;\n    for (viewType in defaultConfigs) {\n        ensureViewDef(viewType, hash, defaultConfigs, overrideConfigs);\n    }\n    for (viewType in overrideConfigs) {\n        ensureViewDef(viewType, hash, defaultConfigs, overrideConfigs);\n    }\n    return hash;\n}\nfunction ensureViewDef(viewType, hash, defaultConfigs, overrideConfigs) {\n    if (hash[viewType]) {\n        return hash[viewType];\n    }\n    var viewDef = buildViewDef(viewType, hash, defaultConfigs, overrideConfigs);\n    if (viewDef) {\n        hash[viewType] = viewDef;\n    }\n    return viewDef;\n}\nfunction buildViewDef(viewType, hash, defaultConfigs, overrideConfigs) {\n    var defaultConfig = defaultConfigs[viewType];\n    var overrideConfig = overrideConfigs[viewType];\n    var queryProp = function (name) {\n        return (defaultConfig && defaultConfig[name] !== null) ? defaultConfig[name] :\n            ((overrideConfig && overrideConfig[name] !== null) ? overrideConfig[name] : null);\n    };\n    var theClass = queryProp('class');\n    var superType = queryProp('superType');\n    if (!superType && theClass) {\n        superType =\n            findViewNameBySubclass(theClass, overrideConfigs) ||\n                findViewNameBySubclass(theClass, defaultConfigs);\n    }\n    var superDef = null;\n    if (superType) {\n        if (superType === viewType) {\n            throw new Error('Can\\'t have a custom view type that references itself');\n        }\n        superDef = ensureViewDef(superType, hash, defaultConfigs, overrideConfigs);\n    }\n    if (!theClass && superDef) {\n        theClass = superDef.class;\n    }\n    if (!theClass) {\n        return null; // don't throw a warning, might be settings for a single-unit view\n    }\n    return {\n        type: viewType,\n        class: theClass,\n        defaults: __assign({}, (superDef ? superDef.defaults : {}), (defaultConfig ? defaultConfig.options : {})),\n        overrides: __assign({}, (superDef ? superDef.overrides : {}), (overrideConfig ? overrideConfig.options : {}))\n    };\n}\nfunction findViewNameBySubclass(viewSubclass, configs) {\n    var superProto = Object.getPrototypeOf(viewSubclass.prototype);\n    for (var viewType in configs) {\n        var parsed = configs[viewType];\n        // need DIRECT subclass, so instanceof won't do it\n        if (parsed.class && parsed.class.prototype === superProto) {\n            return viewType;\n        }\n    }\n    return '';\n}\n\nfunction parseViewConfigs(inputs) {\n    return mapHash(inputs, parseViewConfig);\n}\nvar VIEW_DEF_PROPS = {\n    type: String,\n    class: null\n};\nfunction parseViewConfig(input) {\n    if (typeof input === 'function') {\n        input = { class: input };\n    }\n    var options = {};\n    var props = refineProps(input, VIEW_DEF_PROPS, {}, options);\n    return {\n        superType: props.type,\n        class: props.class,\n        options: options\n    };\n}\n\nfunction buildViewSpecs(defaultInputs, optionsManager) {\n    var defaultConfigs = parseViewConfigs(defaultInputs);\n    var overrideConfigs = parseViewConfigs(optionsManager.overrides.views);\n    var viewDefs = compileViewDefs(defaultConfigs, overrideConfigs);\n    return mapHash(viewDefs, function (viewDef) {\n        return buildViewSpec(viewDef, overrideConfigs, optionsManager);\n    });\n}\nfunction buildViewSpec(viewDef, overrideConfigs, optionsManager) {\n    var durationInput = viewDef.overrides.duration ||\n        viewDef.defaults.duration ||\n        optionsManager.dynamicOverrides.duration ||\n        optionsManager.overrides.duration;\n    var duration = null;\n    var durationUnit = '';\n    var singleUnit = '';\n    var singleUnitOverrides = {};\n    if (durationInput) {\n        duration = createDuration(durationInput);\n        if (duration) { // valid?\n            var denom = greatestDurationDenominator(duration, !getWeeksFromInput(durationInput));\n            durationUnit = denom.unit;\n            if (denom.value === 1) {\n                singleUnit = durationUnit;\n                singleUnitOverrides = overrideConfigs[durationUnit] ? overrideConfigs[durationUnit].options : {};\n            }\n        }\n    }\n    var queryButtonText = function (options) {\n        var buttonTextMap = options.buttonText || {};\n        var buttonTextKey = viewDef.defaults.buttonTextKey;\n        if (buttonTextKey != null && buttonTextMap[buttonTextKey] != null) {\n            return buttonTextMap[buttonTextKey];\n        }\n        if (buttonTextMap[viewDef.type] != null) {\n            return buttonTextMap[viewDef.type];\n        }\n        if (buttonTextMap[singleUnit] != null) {\n            return buttonTextMap[singleUnit];\n        }\n    };\n    return {\n        type: viewDef.type,\n        class: viewDef.class,\n        duration: duration,\n        durationUnit: durationUnit,\n        singleUnit: singleUnit,\n        options: __assign({}, globalDefaults, viewDef.defaults, optionsManager.dirDefaults, optionsManager.localeDefaults, optionsManager.overrides, singleUnitOverrides, viewDef.overrides, optionsManager.dynamicOverrides),\n        buttonTextOverride: queryButtonText(optionsManager.dynamicOverrides) ||\n            queryButtonText(optionsManager.overrides) || // constructor-specified buttonText lookup hash takes precedence\n            viewDef.overrides.buttonText,\n        buttonTextDefault: queryButtonText(optionsManager.localeDefaults) ||\n            queryButtonText(optionsManager.dirDefaults) ||\n            viewDef.defaults.buttonText ||\n            queryButtonText(globalDefaults) ||\n            viewDef.type // fall back to given view name\n    };\n}\n\nvar Toolbar = /** @class */ (function (_super) {\n    __extends(Toolbar, _super);\n    function Toolbar(extraClassName) {\n        var _this = _super.call(this) || this;\n        _this._renderLayout = memoizeRendering(_this.renderLayout, _this.unrenderLayout);\n        _this._updateTitle = memoizeRendering(_this.updateTitle, null, [_this._renderLayout]);\n        _this._updateActiveButton = memoizeRendering(_this.updateActiveButton, null, [_this._renderLayout]);\n        _this._updateToday = memoizeRendering(_this.updateToday, null, [_this._renderLayout]);\n        _this._updatePrev = memoizeRendering(_this.updatePrev, null, [_this._renderLayout]);\n        _this._updateNext = memoizeRendering(_this.updateNext, null, [_this._renderLayout]);\n        _this.el = createElement('div', { className: 'fc-toolbar ' + extraClassName });\n        return _this;\n    }\n    Toolbar.prototype.destroy = function () {\n        _super.prototype.destroy.call(this);\n        this._renderLayout.unrender(); // should unrender everything else\n        removeElement(this.el);\n    };\n    Toolbar.prototype.render = function (props) {\n        this._renderLayout(props.layout);\n        this._updateTitle(props.title);\n        this._updateActiveButton(props.activeButton);\n        this._updateToday(props.isTodayEnabled);\n        this._updatePrev(props.isPrevEnabled);\n        this._updateNext(props.isNextEnabled);\n    };\n    Toolbar.prototype.renderLayout = function (layout) {\n        var el = this.el;\n        this.viewsWithButtons = [];\n        appendToElement(el, this.renderSection('left', layout.left));\n        appendToElement(el, this.renderSection('center', layout.center));\n        appendToElement(el, this.renderSection('right', layout.right));\n    };\n    Toolbar.prototype.unrenderLayout = function () {\n        this.el.innerHTML = '';\n    };\n    Toolbar.prototype.renderSection = function (position, buttonStr) {\n        var _this = this;\n        var _a = this.context, theme = _a.theme, calendar = _a.calendar;\n        var optionsManager = calendar.optionsManager;\n        var viewSpecs = calendar.viewSpecs;\n        var sectionEl = createElement('div', { className: 'fc-' + position });\n        var calendarCustomButtons = optionsManager.computed.customButtons || {};\n        var calendarButtonTextOverrides = optionsManager.overrides.buttonText || {};\n        var calendarButtonText = optionsManager.computed.buttonText || {};\n        if (buttonStr) {\n            buttonStr.split(' ').forEach(function (buttonGroupStr, i) {\n                var groupChildren = [];\n                var isOnlyButtons = true;\n                var groupEl;\n                buttonGroupStr.split(',').forEach(function (buttonName, j) {\n                    var customButtonProps;\n                    var viewSpec;\n                    var buttonClick;\n                    var buttonIcon; // only one of these will be set\n                    var buttonText; // \"\n                    var buttonInnerHtml;\n                    var buttonClasses;\n                    var buttonEl;\n                    var buttonAriaAttr;\n                    if (buttonName === 'title') {\n                        groupChildren.push(htmlToElement('<h2>&nbsp;</h2>')); // we always want it to take up height\n                        isOnlyButtons = false;\n                    }\n                    else {\n                        if ((customButtonProps = calendarCustomButtons[buttonName])) {\n                            buttonClick = function (ev) {\n                                if (customButtonProps.click) {\n                                    customButtonProps.click.call(buttonEl, ev);\n                                }\n                            };\n                            (buttonIcon = theme.getCustomButtonIconClass(customButtonProps)) ||\n                                (buttonIcon = theme.getIconClass(buttonName)) ||\n                                (buttonText = customButtonProps.text);\n                        }\n                        else if ((viewSpec = viewSpecs[buttonName])) {\n                            _this.viewsWithButtons.push(buttonName);\n                            buttonClick = function () {\n                                calendar.changeView(buttonName);\n                            };\n                            (buttonText = viewSpec.buttonTextOverride) ||\n                                (buttonIcon = theme.getIconClass(buttonName)) ||\n                                (buttonText = viewSpec.buttonTextDefault);\n                        }\n                        else if (calendar[buttonName]) { // a calendar method\n                            buttonClick = function () {\n                                calendar[buttonName]();\n                            };\n                            (buttonText = calendarButtonTextOverrides[buttonName]) ||\n                                (buttonIcon = theme.getIconClass(buttonName)) ||\n                                (buttonText = calendarButtonText[buttonName]);\n                            //            ^ everything else is considered default\n                        }\n                        if (buttonClick) {\n                            buttonClasses = [\n                                'fc-' + buttonName + '-button',\n                                theme.getClass('button')\n                            ];\n                            if (buttonText) {\n                                buttonInnerHtml = htmlEscape(buttonText);\n                                buttonAriaAttr = '';\n                            }\n                            else if (buttonIcon) {\n                                buttonInnerHtml = \"<span class='\" + buttonIcon + \"'></span>\";\n                                buttonAriaAttr = ' aria-label=\"' + buttonName + '\"';\n                            }\n                            buttonEl = htmlToElement(// type=\"button\" so that it doesn't submit a form\n                            '<button type=\"button\" class=\"' + buttonClasses.join(' ') + '\"' +\n                                buttonAriaAttr +\n                                '>' + buttonInnerHtml + '</button>');\n                            buttonEl.addEventListener('click', buttonClick);\n                            groupChildren.push(buttonEl);\n                        }\n                    }\n                });\n                if (groupChildren.length > 1) {\n                    groupEl = document.createElement('div');\n                    var buttonGroupClassName = theme.getClass('buttonGroup');\n                    if (isOnlyButtons && buttonGroupClassName) {\n                        groupEl.classList.add(buttonGroupClassName);\n                    }\n                    appendToElement(groupEl, groupChildren);\n                    sectionEl.appendChild(groupEl);\n                }\n                else {\n                    appendToElement(sectionEl, groupChildren); // 1 or 0 children\n                }\n            });\n        }\n        return sectionEl;\n    };\n    Toolbar.prototype.updateToday = function (isTodayEnabled) {\n        this.toggleButtonEnabled('today', isTodayEnabled);\n    };\n    Toolbar.prototype.updatePrev = function (isPrevEnabled) {\n        this.toggleButtonEnabled('prev', isPrevEnabled);\n    };\n    Toolbar.prototype.updateNext = function (isNextEnabled) {\n        this.toggleButtonEnabled('next', isNextEnabled);\n    };\n    Toolbar.prototype.updateTitle = function (text) {\n        findElements(this.el, 'h2').forEach(function (titleEl) {\n            titleEl.innerText = text;\n        });\n    };\n    Toolbar.prototype.updateActiveButton = function (buttonName) {\n        var theme = this.context.theme;\n        var className = theme.getClass('buttonActive');\n        findElements(this.el, 'button').forEach(function (buttonEl) {\n            if (buttonName && buttonEl.classList.contains('fc-' + buttonName + '-button')) {\n                buttonEl.classList.add(className);\n            }\n            else {\n                buttonEl.classList.remove(className);\n            }\n        });\n    };\n    Toolbar.prototype.toggleButtonEnabled = function (buttonName, bool) {\n        findElements(this.el, '.fc-' + buttonName + '-button').forEach(function (buttonEl) {\n            buttonEl.disabled = !bool;\n        });\n    };\n    return Toolbar;\n}(Component));\n\nvar CalendarComponent = /** @class */ (function (_super) {\n    __extends(CalendarComponent, _super);\n    function CalendarComponent(el) {\n        var _this = _super.call(this) || this;\n        _this.elClassNames = [];\n        _this.renderSkeleton = memoizeRendering(_this._renderSkeleton, _this._unrenderSkeleton);\n        _this.renderToolbars = memoizeRendering(_this._renderToolbars, _this._unrenderToolbars, [_this.renderSkeleton]);\n        _this.buildComponentContext = memoize(buildComponentContext);\n        _this.buildViewPropTransformers = memoize(buildViewPropTransformers);\n        _this.el = el;\n        _this.computeTitle = memoize(computeTitle);\n        _this.parseBusinessHours = memoize(function (input) {\n            return parseBusinessHours(input, _this.context.calendar);\n        });\n        return _this;\n    }\n    CalendarComponent.prototype.render = function (props, context) {\n        this.freezeHeight();\n        var title = this.computeTitle(props.dateProfile, props.viewSpec.options);\n        this.renderSkeleton(context);\n        this.renderToolbars(props.viewSpec, props.dateProfile, props.currentDate, title);\n        this.renderView(props, title);\n        this.updateSize();\n        this.thawHeight();\n    };\n    CalendarComponent.prototype.destroy = function () {\n        if (this.header) {\n            this.header.destroy();\n        }\n        if (this.footer) {\n            this.footer.destroy();\n        }\n        this.renderSkeleton.unrender(); // will call destroyView\n        _super.prototype.destroy.call(this);\n    };\n    CalendarComponent.prototype._renderSkeleton = function (context) {\n        this.updateElClassNames(context);\n        prependToElement(this.el, this.contentEl = createElement('div', { className: 'fc-view-container' }));\n        var calendar = context.calendar;\n        for (var _i = 0, _a = calendar.pluginSystem.hooks.viewContainerModifiers; _i < _a.length; _i++) {\n            var modifyViewContainer = _a[_i];\n            modifyViewContainer(this.contentEl, calendar);\n        }\n    };\n    CalendarComponent.prototype._unrenderSkeleton = function () {\n        // weird to have this here\n        if (this.view) {\n            this.savedScroll = this.view.queryScroll();\n            this.view.destroy();\n            this.view = null;\n        }\n        removeElement(this.contentEl);\n        this.removeElClassNames();\n    };\n    CalendarComponent.prototype.removeElClassNames = function () {\n        var classList = this.el.classList;\n        for (var _i = 0, _a = this.elClassNames; _i < _a.length; _i++) {\n            var className = _a[_i];\n            classList.remove(className);\n        }\n        this.elClassNames = [];\n    };\n    CalendarComponent.prototype.updateElClassNames = function (context) {\n        this.removeElClassNames();\n        var theme = context.theme, options = context.options;\n        this.elClassNames = [\n            'fc',\n            'fc-' + options.dir,\n            theme.getClass('widget')\n        ];\n        var classList = this.el.classList;\n        for (var _i = 0, _a = this.elClassNames; _i < _a.length; _i++) {\n            var className = _a[_i];\n            classList.add(className);\n        }\n    };\n    CalendarComponent.prototype._renderToolbars = function (viewSpec, dateProfile, currentDate, title) {\n        var _a = this, context = _a.context, header = _a.header, footer = _a.footer;\n        var options = context.options, calendar = context.calendar;\n        var headerLayout = options.header;\n        var footerLayout = options.footer;\n        var dateProfileGenerator = this.props.dateProfileGenerator;\n        var now = calendar.getNow();\n        var todayInfo = dateProfileGenerator.build(now);\n        var prevInfo = dateProfileGenerator.buildPrev(dateProfile, currentDate);\n        var nextInfo = dateProfileGenerator.buildNext(dateProfile, currentDate);\n        var toolbarProps = {\n            title: title,\n            activeButton: viewSpec.type,\n            isTodayEnabled: todayInfo.isValid && !rangeContainsMarker(dateProfile.currentRange, now),\n            isPrevEnabled: prevInfo.isValid,\n            isNextEnabled: nextInfo.isValid\n        };\n        if (headerLayout) {\n            if (!header) {\n                header = this.header = new Toolbar('fc-header-toolbar');\n                prependToElement(this.el, header.el);\n            }\n            header.receiveProps(__assign({ layout: headerLayout }, toolbarProps), context);\n        }\n        else if (header) {\n            header.destroy();\n            header = this.header = null;\n        }\n        if (footerLayout) {\n            if (!footer) {\n                footer = this.footer = new Toolbar('fc-footer-toolbar');\n                appendToElement(this.el, footer.el);\n            }\n            footer.receiveProps(__assign({ layout: footerLayout }, toolbarProps), context);\n        }\n        else if (footer) {\n            footer.destroy();\n            footer = this.footer = null;\n        }\n    };\n    CalendarComponent.prototype._unrenderToolbars = function () {\n        if (this.header) {\n            this.header.destroy();\n            this.header = null;\n        }\n        if (this.footer) {\n            this.footer.destroy();\n            this.footer = null;\n        }\n    };\n    CalendarComponent.prototype.renderView = function (props, title) {\n        var view = this.view;\n        var _a = this.context, calendar = _a.calendar, options = _a.options;\n        var viewSpec = props.viewSpec, dateProfileGenerator = props.dateProfileGenerator;\n        if (!view || view.viewSpec !== viewSpec) {\n            if (view) {\n                view.destroy();\n            }\n            view = this.view = new viewSpec['class'](viewSpec, this.contentEl);\n            if (this.savedScroll) {\n                view.addScroll(this.savedScroll, true);\n                this.savedScroll = null;\n            }\n        }\n        view.title = title; // for the API\n        var viewProps = {\n            dateProfileGenerator: dateProfileGenerator,\n            dateProfile: props.dateProfile,\n            businessHours: this.parseBusinessHours(viewSpec.options.businessHours),\n            eventStore: props.eventStore,\n            eventUiBases: props.eventUiBases,\n            dateSelection: props.dateSelection,\n            eventSelection: props.eventSelection,\n            eventDrag: props.eventDrag,\n            eventResize: props.eventResize\n        };\n        var transformers = this.buildViewPropTransformers(calendar.pluginSystem.hooks.viewPropsTransformers);\n        for (var _i = 0, transformers_1 = transformers; _i < transformers_1.length; _i++) {\n            var transformer = transformers_1[_i];\n            __assign(viewProps, transformer.transform(viewProps, viewSpec, props, options));\n        }\n        view.receiveProps(viewProps, this.buildComponentContext(this.context, viewSpec, view));\n    };\n    // Sizing\n    // -----------------------------------------------------------------------------------------------------------------\n    CalendarComponent.prototype.updateSize = function (isResize) {\n        if (isResize === void 0) { isResize = false; }\n        var view = this.view;\n        if (!view) {\n            return; // why?\n        }\n        if (isResize || this.isHeightAuto == null) {\n            this.computeHeightVars();\n        }\n        view.updateSize(isResize, this.viewHeight, this.isHeightAuto);\n        view.updateNowIndicator(); // we need to guarantee this will run after updateSize\n        view.popScroll(isResize);\n    };\n    CalendarComponent.prototype.computeHeightVars = function () {\n        var calendar = this.context.calendar; // yuck. need to handle dynamic options\n        var heightInput = calendar.opt('height');\n        var contentHeightInput = calendar.opt('contentHeight');\n        this.isHeightAuto = heightInput === 'auto' || contentHeightInput === 'auto';\n        if (typeof contentHeightInput === 'number') { // exists and not 'auto'\n            this.viewHeight = contentHeightInput;\n        }\n        else if (typeof contentHeightInput === 'function') { // exists and is a function\n            this.viewHeight = contentHeightInput();\n        }\n        else if (typeof heightInput === 'number') { // exists and not 'auto'\n            this.viewHeight = heightInput - this.queryToolbarsHeight();\n        }\n        else if (typeof heightInput === 'function') { // exists and is a function\n            this.viewHeight = heightInput() - this.queryToolbarsHeight();\n        }\n        else if (heightInput === 'parent') { // set to height of parent element\n            var parentEl = this.el.parentNode;\n            this.viewHeight = parentEl.getBoundingClientRect().height - this.queryToolbarsHeight();\n        }\n        else {\n            this.viewHeight = Math.round(this.contentEl.getBoundingClientRect().width /\n                Math.max(calendar.opt('aspectRatio'), .5));\n        }\n    };\n    CalendarComponent.prototype.queryToolbarsHeight = function () {\n        var height = 0;\n        if (this.header) {\n            height += computeHeightAndMargins(this.header.el);\n        }\n        if (this.footer) {\n            height += computeHeightAndMargins(this.footer.el);\n        }\n        return height;\n    };\n    // Height \"Freezing\"\n    // -----------------------------------------------------------------------------------------------------------------\n    CalendarComponent.prototype.freezeHeight = function () {\n        applyStyle(this.el, {\n            height: this.el.getBoundingClientRect().height,\n            overflow: 'hidden'\n        });\n    };\n    CalendarComponent.prototype.thawHeight = function () {\n        applyStyle(this.el, {\n            height: '',\n            overflow: ''\n        });\n    };\n    return CalendarComponent;\n}(Component));\n// Title and Date Formatting\n// -----------------------------------------------------------------------------------------------------------------\n// Computes what the title at the top of the calendar should be for this view\nfunction computeTitle(dateProfile, viewOptions) {\n    var range;\n    // for views that span a large unit of time, show the proper interval, ignoring stray days before and after\n    if (/^(year|month)$/.test(dateProfile.currentRangeUnit)) {\n        range = dateProfile.currentRange;\n    }\n    else { // for day units or smaller, use the actual day range\n        range = dateProfile.activeRange;\n    }\n    return this.context.dateEnv.formatRange(range.start, range.end, createFormatter(viewOptions.titleFormat || computeTitleFormat(dateProfile), viewOptions.titleRangeSeparator), { isEndExclusive: dateProfile.isRangeAllDay });\n}\n// Generates the format string that should be used to generate the title for the current date range.\n// Attempts to compute the most appropriate format if not explicitly specified with `titleFormat`.\nfunction computeTitleFormat(dateProfile) {\n    var currentRangeUnit = dateProfile.currentRangeUnit;\n    if (currentRangeUnit === 'year') {\n        return { year: 'numeric' };\n    }\n    else if (currentRangeUnit === 'month') {\n        return { year: 'numeric', month: 'long' }; // like \"September 2014\"\n    }\n    else {\n        var days = diffWholeDays(dateProfile.currentRange.start, dateProfile.currentRange.end);\n        if (days !== null && days > 1) {\n            // multi-day range. shorter, like \"Sep 9 - 10 2014\"\n            return { year: 'numeric', month: 'short', day: 'numeric' };\n        }\n        else {\n            // one day. longer, like \"September 9 2014\"\n            return { year: 'numeric', month: 'long', day: 'numeric' };\n        }\n    }\n}\n// build a context scoped to the view\nfunction buildComponentContext(context, viewSpec, view) {\n    return context.extend(viewSpec.options, view);\n}\n// Plugin\n// -----------------------------------------------------------------------------------------------------------------\nfunction buildViewPropTransformers(theClasses) {\n    return theClasses.map(function (theClass) {\n        return new theClass();\n    });\n}\n\nvar Interaction = /** @class */ (function () {\n    function Interaction(settings) {\n        this.component = settings.component;\n    }\n    Interaction.prototype.destroy = function () {\n    };\n    return Interaction;\n}());\nfunction parseInteractionSettings(component, input) {\n    return {\n        component: component,\n        el: input.el,\n        useEventCenter: input.useEventCenter != null ? input.useEventCenter : true\n    };\n}\nfunction interactionSettingsToStore(settings) {\n    var _a;\n    return _a = {},\n        _a[settings.component.uid] = settings,\n        _a;\n}\n// global state\nvar interactionSettingsStore = {};\n\n/*\nDetects when the user clicks on an event within a DateComponent\n*/\nvar EventClicking = /** @class */ (function (_super) {\n    __extends(EventClicking, _super);\n    function EventClicking(settings) {\n        var _this = _super.call(this, settings) || this;\n        _this.handleSegClick = function (ev, segEl) {\n            var component = _this.component;\n            var _a = component.context, calendar = _a.calendar, view = _a.view;\n            var seg = getElSeg(segEl);\n            if (seg && // might be the <div> surrounding the more link\n                component.isValidSegDownEl(ev.target)) {\n                // our way to simulate a link click for elements that can't be <a> tags\n                // grab before trigger fired in case trigger trashes DOM thru rerendering\n                var hasUrlContainer = elementClosest(ev.target, '.fc-has-url');\n                var url = hasUrlContainer ? hasUrlContainer.querySelector('a[href]').href : '';\n                calendar.publiclyTrigger('eventClick', [\n                    {\n                        el: segEl,\n                        event: new EventApi(component.context.calendar, seg.eventRange.def, seg.eventRange.instance),\n                        jsEvent: ev,\n                        view: view\n                    }\n                ]);\n                if (url && !ev.defaultPrevented) {\n                    window.location.href = url;\n                }\n            }\n        };\n        var component = settings.component;\n        _this.destroy = listenBySelector(component.el, 'click', component.fgSegSelector + ',' + component.bgSegSelector, _this.handleSegClick);\n        return _this;\n    }\n    return EventClicking;\n}(Interaction));\n\n/*\nTriggers events and adds/removes core classNames when the user's pointer\nenters/leaves event-elements of a component.\n*/\nvar EventHovering = /** @class */ (function (_super) {\n    __extends(EventHovering, _super);\n    function EventHovering(settings) {\n        var _this = _super.call(this, settings) || this;\n        // for simulating an eventMouseLeave when the event el is destroyed while mouse is over it\n        _this.handleEventElRemove = function (el) {\n            if (el === _this.currentSegEl) {\n                _this.handleSegLeave(null, _this.currentSegEl);\n            }\n        };\n        _this.handleSegEnter = function (ev, segEl) {\n            if (getElSeg(segEl)) { // TODO: better way to make sure not hovering over more+ link or its wrapper\n                segEl.classList.add('fc-allow-mouse-resize');\n                _this.currentSegEl = segEl;\n                _this.triggerEvent('eventMouseEnter', ev, segEl);\n            }\n        };\n        _this.handleSegLeave = function (ev, segEl) {\n            if (_this.currentSegEl) {\n                segEl.classList.remove('fc-allow-mouse-resize');\n                _this.currentSegEl = null;\n                _this.triggerEvent('eventMouseLeave', ev, segEl);\n            }\n        };\n        var component = settings.component;\n        _this.removeHoverListeners = listenToHoverBySelector(component.el, component.fgSegSelector + ',' + component.bgSegSelector, _this.handleSegEnter, _this.handleSegLeave);\n        // how to make sure component already has context?\n        component.context.calendar.on('eventElRemove', _this.handleEventElRemove);\n        return _this;\n    }\n    EventHovering.prototype.destroy = function () {\n        this.removeHoverListeners();\n        this.component.context.calendar.off('eventElRemove', this.handleEventElRemove);\n    };\n    EventHovering.prototype.triggerEvent = function (publicEvName, ev, segEl) {\n        var component = this.component;\n        var _a = component.context, calendar = _a.calendar, view = _a.view;\n        var seg = getElSeg(segEl);\n        if (!ev || component.isValidSegDownEl(ev.target)) {\n            calendar.publiclyTrigger(publicEvName, [\n                {\n                    el: segEl,\n                    event: new EventApi(calendar, seg.eventRange.def, seg.eventRange.instance),\n                    jsEvent: ev,\n                    view: view\n                }\n            ]);\n        }\n    };\n    return EventHovering;\n}(Interaction));\n\nvar StandardTheme = /** @class */ (function (_super) {\n    __extends(StandardTheme, _super);\n    function StandardTheme() {\n        return _super !== null && _super.apply(this, arguments) || this;\n    }\n    return StandardTheme;\n}(Theme));\nStandardTheme.prototype.classes = {\n    widget: 'fc-unthemed',\n    widgetHeader: 'fc-widget-header',\n    widgetContent: 'fc-widget-content',\n    buttonGroup: 'fc-button-group',\n    button: 'fc-button fc-button-primary',\n    buttonActive: 'fc-button-active',\n    popoverHeader: 'fc-widget-header',\n    popoverContent: 'fc-widget-content',\n    // day grid\n    headerRow: 'fc-widget-header',\n    dayRow: 'fc-widget-content',\n    // list view\n    listView: 'fc-widget-content'\n};\nStandardTheme.prototype.baseIconClass = 'fc-icon';\nStandardTheme.prototype.iconClasses = {\n    close: 'fc-icon-x',\n    prev: 'fc-icon-chevron-left',\n    next: 'fc-icon-chevron-right',\n    prevYear: 'fc-icon-chevrons-left',\n    nextYear: 'fc-icon-chevrons-right'\n};\nStandardTheme.prototype.iconOverrideOption = 'buttonIcons';\nStandardTheme.prototype.iconOverrideCustomButtonOption = 'icon';\nStandardTheme.prototype.iconOverridePrefix = 'fc-icon-';\n\nvar Calendar = /** @class */ (function () {\n    function Calendar(el, overrides) {\n        var _this = this;\n        this.buildComponentContext = memoize(buildComponentContext$1);\n        this.parseRawLocales = memoize(parseRawLocales);\n        this.buildLocale = memoize(buildLocale);\n        this.buildDateEnv = memoize(buildDateEnv);\n        this.buildTheme = memoize(buildTheme);\n        this.buildEventUiSingleBase = memoize(this._buildEventUiSingleBase);\n        this.buildSelectionConfig = memoize(this._buildSelectionConfig);\n        this.buildEventUiBySource = memoizeOutput(buildEventUiBySource, isPropsEqual);\n        this.buildEventUiBases = memoize(buildEventUiBases);\n        this.interactionsStore = {};\n        this.actionQueue = [];\n        this.isReducing = false;\n        // isDisplaying: boolean = false // installed in DOM? accepting renders?\n        this.needsRerender = false; // needs a render?\n        this.isRendering = false; // currently in the executeRender function?\n        this.renderingPauseDepth = 0;\n        this.buildDelayedRerender = memoize(buildDelayedRerender);\n        this.afterSizingTriggers = {};\n        this.isViewUpdated = false;\n        this.isDatesUpdated = false;\n        this.isEventsUpdated = false;\n        this.el = el;\n        this.optionsManager = new OptionsManager(overrides || {});\n        this.pluginSystem = new PluginSystem();\n        // only do once. don't do in handleOptions. because can't remove plugins\n        this.addPluginInputs(this.optionsManager.computed.plugins || []);\n        this.handleOptions(this.optionsManager.computed);\n        this.publiclyTrigger('_init'); // for tests\n        this.hydrate();\n        this.calendarInteractions = this.pluginSystem.hooks.calendarInteractions\n            .map(function (calendarInteractionClass) {\n            return new calendarInteractionClass(_this);\n        });\n    }\n    Calendar.prototype.addPluginInputs = function (pluginInputs) {\n        var pluginDefs = refinePluginDefs(pluginInputs);\n        for (var _i = 0, pluginDefs_1 = pluginDefs; _i < pluginDefs_1.length; _i++) {\n            var pluginDef = pluginDefs_1[_i];\n            this.pluginSystem.add(pluginDef);\n        }\n    };\n    Object.defineProperty(Calendar.prototype, \"view\", {\n        // public API\n        get: function () {\n            return this.component ? this.component.view : null;\n        },\n        enumerable: true,\n        configurable: true\n    });\n    // Public API for rendering\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.render = function () {\n        if (!this.component) {\n            this.component = new CalendarComponent(this.el);\n            this.renderableEventStore = createEmptyEventStore();\n            this.bindHandlers();\n            this.executeRender();\n        }\n        else {\n            this.requestRerender();\n        }\n    };\n    Calendar.prototype.destroy = function () {\n        if (this.component) {\n            this.unbindHandlers();\n            this.component.destroy(); // don't null-out. in case API needs access\n            this.component = null; // umm ???\n            for (var _i = 0, _a = this.calendarInteractions; _i < _a.length; _i++) {\n                var interaction = _a[_i];\n                interaction.destroy();\n            }\n            this.publiclyTrigger('_destroyed');\n        }\n    };\n    // Handlers\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.bindHandlers = function () {\n        var _this = this;\n        // event delegation for nav links\n        this.removeNavLinkListener = listenBySelector(this.el, 'click', 'a[data-goto]', function (ev, anchorEl) {\n            var gotoOptions = anchorEl.getAttribute('data-goto');\n            gotoOptions = gotoOptions ? JSON.parse(gotoOptions) : {};\n            var dateEnv = _this.dateEnv;\n            var dateMarker = dateEnv.createMarker(gotoOptions.date);\n            var viewType = gotoOptions.type;\n            // property like \"navLinkDayClick\". might be a string or a function\n            var customAction = _this.viewOpt('navLink' + capitaliseFirstLetter(viewType) + 'Click');\n            if (typeof customAction === 'function') {\n                customAction(dateEnv.toDate(dateMarker), ev);\n            }\n            else {\n                if (typeof customAction === 'string') {\n                    viewType = customAction;\n                }\n                _this.zoomTo(dateMarker, viewType);\n            }\n        });\n        if (this.opt('handleWindowResize')) {\n            window.addEventListener('resize', this.windowResizeProxy = debounce(// prevents rapid calls\n            this.windowResize.bind(this), this.opt('windowResizeDelay')));\n        }\n    };\n    Calendar.prototype.unbindHandlers = function () {\n        this.removeNavLinkListener();\n        if (this.windowResizeProxy) {\n            window.removeEventListener('resize', this.windowResizeProxy);\n            this.windowResizeProxy = null;\n        }\n    };\n    // Dispatcher\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.hydrate = function () {\n        var _this = this;\n        this.state = this.buildInitialState();\n        var rawSources = this.opt('eventSources') || [];\n        var singleRawSource = this.opt('events');\n        var sources = []; // parsed\n        if (singleRawSource) {\n            rawSources.unshift(singleRawSource);\n        }\n        for (var _i = 0, rawSources_1 = rawSources; _i < rawSources_1.length; _i++) {\n            var rawSource = rawSources_1[_i];\n            var source = parseEventSource(rawSource, this);\n            if (source) {\n                sources.push(source);\n            }\n        }\n        this.batchRendering(function () {\n            _this.dispatch({ type: 'INIT' }); // pass in sources here?\n            _this.dispatch({ type: 'ADD_EVENT_SOURCES', sources: sources });\n            _this.dispatch({\n                type: 'SET_VIEW_TYPE',\n                viewType: _this.opt('defaultView') || _this.pluginSystem.hooks.defaultView\n            });\n        });\n    };\n    Calendar.prototype.buildInitialState = function () {\n        return {\n            viewType: null,\n            loadingLevel: 0,\n            eventSourceLoadingLevel: 0,\n            currentDate: this.getInitialDate(),\n            dateProfile: null,\n            eventSources: {},\n            eventStore: createEmptyEventStore(),\n            dateSelection: null,\n            eventSelection: '',\n            eventDrag: null,\n            eventResize: null\n        };\n    };\n    Calendar.prototype.dispatch = function (action) {\n        this.actionQueue.push(action);\n        if (!this.isReducing) {\n            this.isReducing = true;\n            var oldState = this.state;\n            while (this.actionQueue.length) {\n                this.state = this.reduce(this.state, this.actionQueue.shift(), this);\n            }\n            var newState = this.state;\n            this.isReducing = false;\n            if (!oldState.loadingLevel && newState.loadingLevel) {\n                this.publiclyTrigger('loading', [true]);\n            }\n            else if (oldState.loadingLevel && !newState.loadingLevel) {\n                this.publiclyTrigger('loading', [false]);\n            }\n            var view = this.component && this.component.view;\n            if (oldState.eventStore !== newState.eventStore) {\n                if (oldState.eventStore) {\n                    this.isEventsUpdated = true;\n                }\n            }\n            if (oldState.dateProfile !== newState.dateProfile) {\n                if (oldState.dateProfile && view) { // why would view be null!?\n                    this.publiclyTrigger('datesDestroy', [\n                        {\n                            view: view,\n                            el: view.el\n                        }\n                    ]);\n                }\n                this.isDatesUpdated = true;\n            }\n            if (oldState.viewType !== newState.viewType) {\n                if (oldState.viewType && view) { // why would view be null!?\n                    this.publiclyTrigger('viewSkeletonDestroy', [\n                        {\n                            view: view,\n                            el: view.el\n                        }\n                    ]);\n                }\n                this.isViewUpdated = true;\n            }\n            this.requestRerender();\n        }\n    };\n    Calendar.prototype.reduce = function (state, action, calendar) {\n        return reduce(state, action, calendar);\n    };\n    // Render Queue\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.requestRerender = function () {\n        this.needsRerender = true;\n        this.delayedRerender(); // will call a debounced-version of tryRerender\n    };\n    Calendar.prototype.tryRerender = function () {\n        if (this.component && // must be accepting renders\n            this.needsRerender && // indicates that a rerender was requested\n            !this.renderingPauseDepth && // not paused\n            !this.isRendering // not currently in the render loop\n        ) {\n            this.executeRender();\n        }\n    };\n    Calendar.prototype.batchRendering = function (func) {\n        this.renderingPauseDepth++;\n        func();\n        this.renderingPauseDepth--;\n        if (this.needsRerender) {\n            this.requestRerender();\n        }\n    };\n    // Rendering\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.executeRender = function () {\n        // clear these BEFORE the render so that new values will accumulate during render\n        this.needsRerender = false;\n        this.isRendering = true;\n        this.renderComponent();\n        this.isRendering = false;\n        // received a rerender request while rendering\n        if (this.needsRerender) {\n            this.delayedRerender();\n        }\n    };\n    /*\n    don't call this directly. use executeRender instead\n    */\n    Calendar.prototype.renderComponent = function () {\n        var _a = this, state = _a.state, component = _a.component;\n        var viewType = state.viewType;\n        var viewSpec = this.viewSpecs[viewType];\n        if (!viewSpec) {\n            throw new Error(\"View type \\\"\" + viewType + \"\\\" is not valid\");\n        }\n        // if event sources are still loading and progressive rendering hasn't been enabled,\n        // keep rendering the last fully loaded set of events\n        var renderableEventStore = this.renderableEventStore =\n            (state.eventSourceLoadingLevel && !this.opt('progressiveEventRendering')) ?\n                this.renderableEventStore :\n                state.eventStore;\n        var eventUiSingleBase = this.buildEventUiSingleBase(viewSpec.options);\n        var eventUiBySource = this.buildEventUiBySource(state.eventSources);\n        var eventUiBases = this.eventUiBases = this.buildEventUiBases(renderableEventStore.defs, eventUiSingleBase, eventUiBySource);\n        component.receiveProps(__assign({}, state, { viewSpec: viewSpec, dateProfileGenerator: this.dateProfileGenerators[viewType], dateProfile: state.dateProfile, eventStore: renderableEventStore, eventUiBases: eventUiBases, dateSelection: state.dateSelection, eventSelection: state.eventSelection, eventDrag: state.eventDrag, eventResize: state.eventResize }), this.buildComponentContext(this.theme, this.dateEnv, this.optionsManager.computed));\n        if (this.isViewUpdated) {\n            this.isViewUpdated = false;\n            this.publiclyTrigger('viewSkeletonRender', [\n                {\n                    view: component.view,\n                    el: component.view.el\n                }\n            ]);\n        }\n        if (this.isDatesUpdated) {\n            this.isDatesUpdated = false;\n            this.publiclyTrigger('datesRender', [\n                {\n                    view: component.view,\n                    el: component.view.el\n                }\n            ]);\n        }\n        if (this.isEventsUpdated) {\n            this.isEventsUpdated = false;\n        }\n        this.releaseAfterSizingTriggers();\n    };\n    // Options\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.setOption = function (name, val) {\n        var _a;\n        this.mutateOptions((_a = {}, _a[name] = val, _a), [], true);\n    };\n    Calendar.prototype.getOption = function (name) {\n        return this.optionsManager.computed[name];\n    };\n    Calendar.prototype.opt = function (name) {\n        return this.optionsManager.computed[name];\n    };\n    Calendar.prototype.viewOpt = function (name) {\n        return this.viewOpts()[name];\n    };\n    Calendar.prototype.viewOpts = function () {\n        return this.viewSpecs[this.state.viewType].options;\n    };\n    /*\n    handles option changes (like a diff)\n    */\n    Calendar.prototype.mutateOptions = function (updates, removals, isDynamic, deepEqual) {\n        var _this = this;\n        var changeHandlers = this.pluginSystem.hooks.optionChangeHandlers;\n        var normalUpdates = {};\n        var specialUpdates = {};\n        var oldDateEnv = this.dateEnv; // do this before handleOptions\n        var isTimeZoneDirty = false;\n        var isSizeDirty = false;\n        var anyDifficultOptions = Boolean(removals.length);\n        for (var name_1 in updates) {\n            if (changeHandlers[name_1]) {\n                specialUpdates[name_1] = updates[name_1];\n            }\n            else {\n                normalUpdates[name_1] = updates[name_1];\n            }\n        }\n        for (var name_2 in normalUpdates) {\n            if (/^(height|contentHeight|aspectRatio)$/.test(name_2)) {\n                isSizeDirty = true;\n            }\n            else if (/^(defaultDate|defaultView)$/.test(name_2)) ;\n            else {\n                anyDifficultOptions = true;\n                if (name_2 === 'timeZone') {\n                    isTimeZoneDirty = true;\n                }\n            }\n        }\n        this.optionsManager.mutate(normalUpdates, removals, isDynamic);\n        if (anyDifficultOptions) {\n            this.handleOptions(this.optionsManager.computed);\n        }\n        this.batchRendering(function () {\n            if (anyDifficultOptions) {\n                if (isTimeZoneDirty) {\n                    _this.dispatch({\n                        type: 'CHANGE_TIMEZONE',\n                        oldDateEnv: oldDateEnv\n                    });\n                }\n                /* HACK\n                has the same effect as calling this.requestRerender()\n                but recomputes the state's dateProfile\n                */\n                _this.dispatch({\n                    type: 'SET_VIEW_TYPE',\n                    viewType: _this.state.viewType\n                });\n            }\n            else if (isSizeDirty) {\n                _this.updateSize();\n            }\n            // special updates\n            if (deepEqual) {\n                for (var name_3 in specialUpdates) {\n                    changeHandlers[name_3](specialUpdates[name_3], _this, deepEqual);\n                }\n            }\n        });\n    };\n    /*\n    rebuilds things based off of a complete set of refined options\n    */\n    Calendar.prototype.handleOptions = function (options) {\n        var _this = this;\n        var pluginHooks = this.pluginSystem.hooks;\n        this.defaultAllDayEventDuration = createDuration(options.defaultAllDayEventDuration);\n        this.defaultTimedEventDuration = createDuration(options.defaultTimedEventDuration);\n        this.delayedRerender = this.buildDelayedRerender(options.rerenderDelay);\n        this.theme = this.buildTheme(options);\n        var available = this.parseRawLocales(options.locales);\n        this.availableRawLocales = available.map;\n        var locale = this.buildLocale(options.locale || available.defaultCode, available.map);\n        this.dateEnv = this.buildDateEnv(locale, options.timeZone, pluginHooks.namedTimeZonedImpl, options.firstDay, options.weekNumberCalculation, options.weekLabel, pluginHooks.cmdFormatter);\n        this.selectionConfig = this.buildSelectionConfig(options); // needs dateEnv. do after :(\n        // ineffecient to do every time?\n        this.viewSpecs = buildViewSpecs(pluginHooks.views, this.optionsManager);\n        // ineffecient to do every time?\n        this.dateProfileGenerators = mapHash(this.viewSpecs, function (viewSpec) {\n            return new viewSpec.class.prototype.dateProfileGeneratorClass(viewSpec, _this);\n        });\n    };\n    Calendar.prototype.getAvailableLocaleCodes = function () {\n        return Object.keys(this.availableRawLocales);\n    };\n    Calendar.prototype._buildSelectionConfig = function (rawOpts) {\n        return processScopedUiProps('select', rawOpts, this);\n    };\n    Calendar.prototype._buildEventUiSingleBase = function (rawOpts) {\n        if (rawOpts.editable) { // so 'editable' affected events\n            rawOpts = __assign({}, rawOpts, { eventEditable: true });\n        }\n        return processScopedUiProps('event', rawOpts, this);\n    };\n    // Trigger\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.hasPublicHandlers = function (name) {\n        return this.hasHandlers(name) ||\n            this.opt(name); // handler specified in options\n    };\n    Calendar.prototype.publiclyTrigger = function (name, args) {\n        var optHandler = this.opt(name);\n        this.triggerWith(name, this, args);\n        if (optHandler) {\n            return optHandler.apply(this, args);\n        }\n    };\n    Calendar.prototype.publiclyTriggerAfterSizing = function (name, args) {\n        var afterSizingTriggers = this.afterSizingTriggers;\n        (afterSizingTriggers[name] || (afterSizingTriggers[name] = [])).push(args);\n    };\n    Calendar.prototype.releaseAfterSizingTriggers = function () {\n        var afterSizingTriggers = this.afterSizingTriggers;\n        for (var name_4 in afterSizingTriggers) {\n            for (var _i = 0, _a = afterSizingTriggers[name_4]; _i < _a.length; _i++) {\n                var args = _a[_i];\n                this.publiclyTrigger(name_4, args);\n            }\n        }\n        this.afterSizingTriggers = {};\n    };\n    // View\n    // -----------------------------------------------------------------------------------------------------------------\n    // Returns a boolean about whether the view is okay to instantiate at some point\n    Calendar.prototype.isValidViewType = function (viewType) {\n        return Boolean(this.viewSpecs[viewType]);\n    };\n    Calendar.prototype.changeView = function (viewType, dateOrRange) {\n        var dateMarker = null;\n        if (dateOrRange) {\n            if (dateOrRange.start && dateOrRange.end) { // a range\n                this.optionsManager.mutate({ visibleRange: dateOrRange }, []); // will not rerender\n                this.handleOptions(this.optionsManager.computed); // ...but yuck\n            }\n            else { // a date\n                dateMarker = this.dateEnv.createMarker(dateOrRange); // just like gotoDate\n            }\n        }\n        this.unselect();\n        this.dispatch({\n            type: 'SET_VIEW_TYPE',\n            viewType: viewType,\n            dateMarker: dateMarker\n        });\n    };\n    // Forces navigation to a view for the given date.\n    // `viewType` can be a specific view name or a generic one like \"week\" or \"day\".\n    // needs to change\n    Calendar.prototype.zoomTo = function (dateMarker, viewType) {\n        var spec;\n        viewType = viewType || 'day'; // day is default zoom\n        spec = this.viewSpecs[viewType] ||\n            this.getUnitViewSpec(viewType);\n        this.unselect();\n        if (spec) {\n            this.dispatch({\n                type: 'SET_VIEW_TYPE',\n                viewType: spec.type,\n                dateMarker: dateMarker\n            });\n        }\n        else {\n            this.dispatch({\n                type: 'SET_DATE',\n                dateMarker: dateMarker\n            });\n        }\n    };\n    // Given a duration singular unit, like \"week\" or \"day\", finds a matching view spec.\n    // Preference is given to views that have corresponding buttons.\n    Calendar.prototype.getUnitViewSpec = function (unit) {\n        var component = this.component;\n        var viewTypes = [];\n        var i;\n        var spec;\n        // put views that have buttons first. there will be duplicates, but oh\n        if (component.header) {\n            viewTypes.push.apply(viewTypes, component.header.viewsWithButtons);\n        }\n        if (component.footer) {\n            viewTypes.push.apply(viewTypes, component.footer.viewsWithButtons);\n        }\n        for (var viewType in this.viewSpecs) {\n            viewTypes.push(viewType);\n        }\n        for (i = 0; i < viewTypes.length; i++) {\n            spec = this.viewSpecs[viewTypes[i]];\n            if (spec) {\n                if (spec.singleUnit === unit) {\n                    return spec;\n                }\n            }\n        }\n    };\n    // Current Date\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.getInitialDate = function () {\n        var defaultDateInput = this.opt('defaultDate');\n        // compute the initial ambig-timezone date\n        if (defaultDateInput != null) {\n            return this.dateEnv.createMarker(defaultDateInput);\n        }\n        else {\n            return this.getNow(); // getNow already returns unzoned\n        }\n    };\n    Calendar.prototype.prev = function () {\n        this.unselect();\n        this.dispatch({ type: 'PREV' });\n    };\n    Calendar.prototype.next = function () {\n        this.unselect();\n        this.dispatch({ type: 'NEXT' });\n    };\n    Calendar.prototype.prevYear = function () {\n        this.unselect();\n        this.dispatch({\n            type: 'SET_DATE',\n            dateMarker: this.dateEnv.addYears(this.state.currentDate, -1)\n        });\n    };\n    Calendar.prototype.nextYear = function () {\n        this.unselect();\n        this.dispatch({\n            type: 'SET_DATE',\n            dateMarker: this.dateEnv.addYears(this.state.currentDate, 1)\n        });\n    };\n    Calendar.prototype.today = function () {\n        this.unselect();\n        this.dispatch({\n            type: 'SET_DATE',\n            dateMarker: this.getNow()\n        });\n    };\n    Calendar.prototype.gotoDate = function (zonedDateInput) {\n        this.unselect();\n        this.dispatch({\n            type: 'SET_DATE',\n            dateMarker: this.dateEnv.createMarker(zonedDateInput)\n        });\n    };\n    Calendar.prototype.incrementDate = function (deltaInput) {\n        var delta = createDuration(deltaInput);\n        if (delta) { // else, warn about invalid input?\n            this.unselect();\n            this.dispatch({\n                type: 'SET_DATE',\n                dateMarker: this.dateEnv.add(this.state.currentDate, delta)\n            });\n        }\n    };\n    // for external API\n    Calendar.prototype.getDate = function () {\n        return this.dateEnv.toDate(this.state.currentDate);\n    };\n    // Date Formatting Utils\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.formatDate = function (d, formatter) {\n        var dateEnv = this.dateEnv;\n        return dateEnv.format(dateEnv.createMarker(d), createFormatter(formatter));\n    };\n    // `settings` is for formatter AND isEndExclusive\n    Calendar.prototype.formatRange = function (d0, d1, settings) {\n        var dateEnv = this.dateEnv;\n        return dateEnv.formatRange(dateEnv.createMarker(d0), dateEnv.createMarker(d1), createFormatter(settings, this.opt('defaultRangeSeparator')), settings);\n    };\n    Calendar.prototype.formatIso = function (d, omitTime) {\n        var dateEnv = this.dateEnv;\n        return dateEnv.formatIso(dateEnv.createMarker(d), { omitTime: omitTime });\n    };\n    // Sizing\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.windowResize = function (ev) {\n        if (!this.isHandlingWindowResize &&\n            this.component && // why?\n            ev.target === window // not a jqui resize event\n        ) {\n            this.isHandlingWindowResize = true;\n            this.updateSize();\n            this.publiclyTrigger('windowResize', [this.view]);\n            this.isHandlingWindowResize = false;\n        }\n    };\n    Calendar.prototype.updateSize = function () {\n        if (this.component) { // when?\n            this.component.updateSize(true);\n        }\n    };\n    // Component Registration\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.registerInteractiveComponent = function (component, settingsInput) {\n        var settings = parseInteractionSettings(component, settingsInput);\n        var DEFAULT_INTERACTIONS = [\n            EventClicking,\n            EventHovering\n        ];\n        var interactionClasses = DEFAULT_INTERACTIONS.concat(this.pluginSystem.hooks.componentInteractions);\n        var interactions = interactionClasses.map(function (interactionClass) {\n            return new interactionClass(settings);\n        });\n        this.interactionsStore[component.uid] = interactions;\n        interactionSettingsStore[component.uid] = settings;\n    };\n    Calendar.prototype.unregisterInteractiveComponent = function (component) {\n        for (var _i = 0, _a = this.interactionsStore[component.uid]; _i < _a.length; _i++) {\n            var listener = _a[_i];\n            listener.destroy();\n        }\n        delete this.interactionsStore[component.uid];\n        delete interactionSettingsStore[component.uid];\n    };\n    // Date Selection / Event Selection / DayClick\n    // -----------------------------------------------------------------------------------------------------------------\n    // this public method receives start/end dates in any format, with any timezone\n    // NOTE: args were changed from v3\n    Calendar.prototype.select = function (dateOrObj, endDate) {\n        var selectionInput;\n        if (endDate == null) {\n            if (dateOrObj.start != null) {\n                selectionInput = dateOrObj;\n            }\n            else {\n                selectionInput = {\n                    start: dateOrObj,\n                    end: null\n                };\n            }\n        }\n        else {\n            selectionInput = {\n                start: dateOrObj,\n                end: endDate\n            };\n        }\n        var selection = parseDateSpan(selectionInput, this.dateEnv, createDuration({ days: 1 }) // TODO: cache this?\n        );\n        if (selection) { // throw parse error otherwise?\n            this.dispatch({ type: 'SELECT_DATES', selection: selection });\n            this.triggerDateSelect(selection);\n        }\n    };\n    // public method\n    Calendar.prototype.unselect = function (pev) {\n        if (this.state.dateSelection) {\n            this.dispatch({ type: 'UNSELECT_DATES' });\n            this.triggerDateUnselect(pev);\n        }\n    };\n    Calendar.prototype.triggerDateSelect = function (selection, pev) {\n        var arg = __assign({}, this.buildDateSpanApi(selection), { jsEvent: pev ? pev.origEvent : null, view: this.view });\n        this.publiclyTrigger('select', [arg]);\n    };\n    Calendar.prototype.triggerDateUnselect = function (pev) {\n        this.publiclyTrigger('unselect', [\n            {\n                jsEvent: pev ? pev.origEvent : null,\n                view: this.view\n            }\n        ]);\n    };\n    // TODO: receive pev?\n    Calendar.prototype.triggerDateClick = function (dateSpan, dayEl, view, ev) {\n        var arg = __assign({}, this.buildDatePointApi(dateSpan), { dayEl: dayEl, jsEvent: ev, // Is this always a mouse event? See #4655\n            view: view });\n        this.publiclyTrigger('dateClick', [arg]);\n    };\n    Calendar.prototype.buildDatePointApi = function (dateSpan) {\n        var props = {};\n        for (var _i = 0, _a = this.pluginSystem.hooks.datePointTransforms; _i < _a.length; _i++) {\n            var transform = _a[_i];\n            __assign(props, transform(dateSpan, this));\n        }\n        __assign(props, buildDatePointApi(dateSpan, this.dateEnv));\n        return props;\n    };\n    Calendar.prototype.buildDateSpanApi = function (dateSpan) {\n        var props = {};\n        for (var _i = 0, _a = this.pluginSystem.hooks.dateSpanTransforms; _i < _a.length; _i++) {\n            var transform = _a[_i];\n            __assign(props, transform(dateSpan, this));\n        }\n        __assign(props, buildDateSpanApi(dateSpan, this.dateEnv));\n        return props;\n    };\n    // Date Utils\n    // -----------------------------------------------------------------------------------------------------------------\n    // Returns a DateMarker for the current date, as defined by the client's computer or from the `now` option\n    Calendar.prototype.getNow = function () {\n        var now = this.opt('now');\n        if (typeof now === 'function') {\n            now = now();\n        }\n        if (now == null) {\n            return this.dateEnv.createNowMarker();\n        }\n        return this.dateEnv.createMarker(now);\n    };\n    // Event-Date Utilities\n    // -----------------------------------------------------------------------------------------------------------------\n    // Given an event's allDay status and start date, return what its fallback end date should be.\n    // TODO: rename to computeDefaultEventEnd\n    Calendar.prototype.getDefaultEventEnd = function (allDay, marker) {\n        var end = marker;\n        if (allDay) {\n            end = startOfDay(end);\n            end = this.dateEnv.add(end, this.defaultAllDayEventDuration);\n        }\n        else {\n            end = this.dateEnv.add(end, this.defaultTimedEventDuration);\n        }\n        return end;\n    };\n    // Public Events API\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.addEvent = function (eventInput, sourceInput) {\n        if (eventInput instanceof EventApi) {\n            var def = eventInput._def;\n            var instance = eventInput._instance;\n            // not already present? don't want to add an old snapshot\n            if (!this.state.eventStore.defs[def.defId]) {\n                this.dispatch({\n                    type: 'ADD_EVENTS',\n                    eventStore: eventTupleToStore({ def: def, instance: instance }) // TODO: better util for two args?\n                });\n            }\n            return eventInput;\n        }\n        var sourceId;\n        if (sourceInput instanceof EventSourceApi) {\n            sourceId = sourceInput.internalEventSource.sourceId;\n        }\n        else if (sourceInput != null) {\n            var sourceApi = this.getEventSourceById(sourceInput); // TODO: use an internal function\n            if (!sourceApi) {\n                console.warn('Could not find an event source with ID \"' + sourceInput + '\"'); // TODO: test\n                return null;\n            }\n            else {\n                sourceId = sourceApi.internalEventSource.sourceId;\n            }\n        }\n        var tuple = parseEvent(eventInput, sourceId, this);\n        if (tuple) {\n            this.dispatch({\n                type: 'ADD_EVENTS',\n                eventStore: eventTupleToStore(tuple)\n            });\n            return new EventApi(this, tuple.def, tuple.def.recurringDef ? null : tuple.instance);\n        }\n        return null;\n    };\n    // TODO: optimize\n    Calendar.prototype.getEventById = function (id) {\n        var _a = this.state.eventStore, defs = _a.defs, instances = _a.instances;\n        id = String(id);\n        for (var defId in defs) {\n            var def = defs[defId];\n            if (def.publicId === id) {\n                if (def.recurringDef) {\n                    return new EventApi(this, def, null);\n                }\n                else {\n                    for (var instanceId in instances) {\n                        var instance = instances[instanceId];\n                        if (instance.defId === def.defId) {\n                            return new EventApi(this, def, instance);\n                        }\n                    }\n                }\n            }\n        }\n        return null;\n    };\n    Calendar.prototype.getEvents = function () {\n        var _a = this.state.eventStore, defs = _a.defs, instances = _a.instances;\n        var eventApis = [];\n        for (var id in instances) {\n            var instance = instances[id];\n            var def = defs[instance.defId];\n            eventApis.push(new EventApi(this, def, instance));\n        }\n        return eventApis;\n    };\n    Calendar.prototype.removeAllEvents = function () {\n        this.dispatch({ type: 'REMOVE_ALL_EVENTS' });\n    };\n    Calendar.prototype.rerenderEvents = function () {\n        this.dispatch({ type: 'RESET_EVENTS' });\n    };\n    // Public Event Sources API\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.getEventSources = function () {\n        var sourceHash = this.state.eventSources;\n        var sourceApis = [];\n        for (var internalId in sourceHash) {\n            sourceApis.push(new EventSourceApi(this, sourceHash[internalId]));\n        }\n        return sourceApis;\n    };\n    Calendar.prototype.getEventSourceById = function (id) {\n        var sourceHash = this.state.eventSources;\n        id = String(id);\n        for (var sourceId in sourceHash) {\n            if (sourceHash[sourceId].publicId === id) {\n                return new EventSourceApi(this, sourceHash[sourceId]);\n            }\n        }\n        return null;\n    };\n    Calendar.prototype.addEventSource = function (sourceInput) {\n        if (sourceInput instanceof EventSourceApi) {\n            // not already present? don't want to add an old snapshot\n            if (!this.state.eventSources[sourceInput.internalEventSource.sourceId]) {\n                this.dispatch({\n                    type: 'ADD_EVENT_SOURCES',\n                    sources: [sourceInput.internalEventSource]\n                });\n            }\n            return sourceInput;\n        }\n        var eventSource = parseEventSource(sourceInput, this);\n        if (eventSource) { // TODO: error otherwise?\n            this.dispatch({ type: 'ADD_EVENT_SOURCES', sources: [eventSource] });\n            return new EventSourceApi(this, eventSource);\n        }\n        return null;\n    };\n    Calendar.prototype.removeAllEventSources = function () {\n        this.dispatch({ type: 'REMOVE_ALL_EVENT_SOURCES' });\n    };\n    Calendar.prototype.refetchEvents = function () {\n        this.dispatch({ type: 'FETCH_EVENT_SOURCES' });\n    };\n    // Scroll\n    // -----------------------------------------------------------------------------------------------------------------\n    Calendar.prototype.scrollToTime = function (timeInput) {\n        var duration = createDuration(timeInput);\n        if (duration) {\n            this.component.view.scrollToDuration(duration);\n        }\n    };\n    return Calendar;\n}());\nEmitterMixin.mixInto(Calendar);\n// for memoizers\n// -----------------------------------------------------------------------------------------------------------------\nfunction buildComponentContext$1(theme, dateEnv, options) {\n    return new ComponentContext(this, theme, dateEnv, options, null);\n}\nfunction buildDateEnv(locale, timeZone, namedTimeZoneImpl, firstDay, weekNumberCalculation, weekLabel, cmdFormatter) {\n    return new DateEnv({\n        calendarSystem: 'gregory',\n        timeZone: timeZone,\n        namedTimeZoneImpl: namedTimeZoneImpl,\n        locale: locale,\n        weekNumberCalculation: weekNumberCalculation,\n        firstDay: firstDay,\n        weekLabel: weekLabel,\n        cmdFormatter: cmdFormatter\n    });\n}\nfunction buildTheme(calendarOptions) {\n    var themeClass = this.pluginSystem.hooks.themeClasses[calendarOptions.themeSystem] || StandardTheme;\n    return new themeClass(calendarOptions);\n}\nfunction buildDelayedRerender(wait) {\n    var func = this.tryRerender.bind(this);\n    if (wait != null) {\n        func = debounce(func, wait);\n    }\n    return func;\n}\nfunction buildEventUiBySource(eventSources) {\n    return mapHash(eventSources, function (eventSource) {\n        return eventSource.ui;\n    });\n}\nfunction buildEventUiBases(eventDefs, eventUiSingleBase, eventUiBySource) {\n    var eventUiBases = { '': eventUiSingleBase };\n    for (var defId in eventDefs) {\n        var def = eventDefs[defId];\n        if (def.sourceId && eventUiBySource[def.sourceId]) {\n            eventUiBases[defId] = eventUiBySource[def.sourceId];\n        }\n    }\n    return eventUiBases;\n}\n\nvar View = /** @class */ (function (_super) {\n    __extends(View, _super);\n    function View(viewSpec, parentEl) {\n        var _this = _super.call(this, createElement('div', { className: 'fc-view fc-' + viewSpec.type + '-view' })) || this;\n        _this.renderDatesMem = memoizeRendering(_this.renderDatesWrap, _this.unrenderDatesWrap);\n        _this.renderBusinessHoursMem = memoizeRendering(_this.renderBusinessHours, _this.unrenderBusinessHours, [_this.renderDatesMem]);\n        _this.renderDateSelectionMem = memoizeRendering(_this.renderDateSelectionWrap, _this.unrenderDateSelectionWrap, [_this.renderDatesMem]);\n        _this.renderEventsMem = memoizeRendering(_this.renderEvents, _this.unrenderEvents, [_this.renderDatesMem]);\n        _this.renderEventSelectionMem = memoizeRendering(_this.renderEventSelectionWrap, _this.unrenderEventSelectionWrap, [_this.renderEventsMem]);\n        _this.renderEventDragMem = memoizeRendering(_this.renderEventDragWrap, _this.unrenderEventDragWrap, [_this.renderDatesMem]);\n        _this.renderEventResizeMem = memoizeRendering(_this.renderEventResizeWrap, _this.unrenderEventResizeWrap, [_this.renderDatesMem]);\n        _this.viewSpec = viewSpec;\n        _this.type = viewSpec.type;\n        parentEl.appendChild(_this.el);\n        _this.initialize();\n        return _this;\n    }\n    View.prototype.initialize = function () {\n    };\n    Object.defineProperty(View.prototype, \"activeStart\", {\n        // Date Setting/Unsetting\n        // -----------------------------------------------------------------------------------------------------------------\n        get: function () {\n            return this.context.dateEnv.toDate(this.props.dateProfile.activeRange.start);\n        },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(View.prototype, \"activeEnd\", {\n        get: function () {\n            return this.context.dateEnv.toDate(this.props.dateProfile.activeRange.end);\n        },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(View.prototype, \"currentStart\", {\n        get: function () {\n            return this.context.dateEnv.toDate(this.props.dateProfile.currentRange.start);\n        },\n        enumerable: true,\n        configurable: true\n    });\n    Object.defineProperty(View.prototype, \"currentEnd\", {\n        get: function () {\n            return this.context.dateEnv.toDate(this.props.dateProfile.currentRange.end);\n        },\n        enumerable: true,\n        configurable: true\n    });\n    // General Rendering\n    // -----------------------------------------------------------------------------------------------------------------\n    View.prototype.render = function (props, context) {\n        this.renderDatesMem(props.dateProfile);\n        this.renderBusinessHoursMem(props.businessHours);\n        this.renderDateSelectionMem(props.dateSelection);\n        this.renderEventsMem(props.eventStore);\n        this.renderEventSelectionMem(props.eventSelection);\n        this.renderEventDragMem(props.eventDrag);\n        this.renderEventResizeMem(props.eventResize);\n    };\n    View.prototype.beforeUpdate = function () {\n        this.addScroll(this.queryScroll());\n    };\n    View.prototype.destroy = function () {\n        _super.prototype.destroy.call(this);\n        this.renderDatesMem.unrender(); // should unrender everything else\n    };\n    // Sizing\n    // -----------------------------------------------------------------------------------------------------------------\n    View.prototype.updateSize = function (isResize, viewHeight, isAuto) {\n        var calendar = this.context.calendar;\n        if (isResize) {\n            this.addScroll(this.queryScroll()); // NOTE: same code as in beforeUpdate\n        }\n        if (isResize || // HACKS...\n            calendar.isViewUpdated ||\n            calendar.isDatesUpdated ||\n            calendar.isEventsUpdated) {\n            // sort of the catch-all sizing\n            // anything that might cause dimension changes\n            this.updateBaseSize(isResize, viewHeight, isAuto);\n        }\n        // NOTE: popScroll is called by CalendarComponent\n    };\n    View.prototype.updateBaseSize = function (isResize, viewHeight, isAuto) {\n    };\n    // Date Rendering\n    // -----------------------------------------------------------------------------------------------------------------\n    View.prototype.renderDatesWrap = function (dateProfile) {\n        this.renderDates(dateProfile);\n        this.addScroll({\n            duration: createDuration(this.context.options.scrollTime)\n        });\n    };\n    View.prototype.unrenderDatesWrap = function () {\n        this.stopNowIndicator();\n        this.unrenderDates();\n    };\n    View.prototype.renderDates = function (dateProfile) { };\n    View.prototype.unrenderDates = function () { };\n    // Business Hours\n    // -----------------------------------------------------------------------------------------------------------------\n    View.prototype.renderBusinessHours = function (businessHours) { };\n    View.prototype.unrenderBusinessHours = function () { };\n    // Date Selection\n    // -----------------------------------------------------------------------------------------------------------------\n    View.prototype.renderDateSelectionWrap = function (selection) {\n        if (selection) {\n            this.renderDateSelection(selection);\n        }\n    };\n    View.prototype.unrenderDateSelectionWrap = function (selection) {\n        if (selection) {\n            this.unrenderDateSelection(selection);\n        }\n    };\n    View.prototype.renderDateSelection = function (selection) { };\n    View.prototype.unrenderDateSelection = function (selection) { };\n    // Event Rendering\n    // -----------------------------------------------------------------------------------------------------------------\n    View.prototype.renderEvents = function (eventStore) { };\n    View.prototype.unrenderEvents = function () { };\n    // util for subclasses\n    View.prototype.sliceEvents = function (eventStore, allDay) {\n        var props = this.props;\n        return sliceEventStore(eventStore, props.eventUiBases, props.dateProfile.activeRange, allDay ? this.context.nextDayThreshold : null).fg;\n    };\n    // Event Selection\n    // -----------------------------------------------------------------------------------------------------------------\n    View.prototype.renderEventSelectionWrap = function (instanceId) {\n        if (instanceId) {\n            this.renderEventSelection(instanceId);\n        }\n    };\n    View.prototype.unrenderEventSelectionWrap = function (instanceId) {\n        if (instanceId) {\n            this.unrenderEventSelection(instanceId);\n        }\n    };\n    View.prototype.renderEventSelection = function (instanceId) { };\n    View.prototype.unrenderEventSelection = function (instanceId) { };\n    // Event Drag\n    // -----------------------------------------------------------------------------------------------------------------\n    View.prototype.renderEventDragWrap = function (state) {\n        if (state) {\n            this.renderEventDrag(state);\n        }\n    };\n    View.prototype.unrenderEventDragWrap = function (state) {\n        if (state) {\n            this.unrenderEventDrag(state);\n        }\n    };\n    View.prototype.renderEventDrag = function (state) { };\n    View.prototype.unrenderEventDrag = function (state) { };\n    // Event Resize\n    // -----------------------------------------------------------------------------------------------------------------\n    View.prototype.renderEventResizeWrap = function (state) {\n        if (state) {\n            this.renderEventResize(state);\n        }\n    };\n    View.prototype.unrenderEventResizeWrap = function (state) {\n        if (state) {\n            this.unrenderEventResize(state);\n        }\n    };\n    View.prototype.renderEventResize = function (state) { };\n    View.prototype.unrenderEventResize = function (state) { };\n    /* Now Indicator\n    ------------------------------------------------------------------------------------------------------------------*/\n    // Immediately render the current time indicator and begins re-rendering it at an interval,\n    // which is defined by this.getNowIndicatorUnit().\n    // TODO: somehow do this for the current whole day's background too\n    // USAGE: must be called manually from subclasses' render methods! don't need to call stopNowIndicator tho\n    View.prototype.startNowIndicator = function (dateProfile, dateProfileGenerator) {\n        var _this = this;\n        var _a = this.context, calendar = _a.calendar, dateEnv = _a.dateEnv, options = _a.options;\n        var unit;\n        var update;\n        var delay; // ms wait value\n        if (options.nowIndicator && !this.initialNowDate) {\n            unit = this.getNowIndicatorUnit(dateProfile, dateProfileGenerator);\n            if (unit) {\n                update = this.updateNowIndicator.bind(this);\n                this.initialNowDate = calendar.getNow();\n                this.initialNowQueriedMs = new Date().valueOf();\n                // wait until the beginning of the next interval\n                delay = dateEnv.add(dateEnv.startOf(this.initialNowDate, unit), createDuration(1, unit)).valueOf() - this.initialNowDate.valueOf();\n                // TODO: maybe always use setTimeout, waiting until start of next unit\n                this.nowIndicatorTimeoutID = setTimeout(function () {\n                    _this.nowIndicatorTimeoutID = null;\n                    update();\n                    if (unit === 'second') {\n                        delay = 1000; // every second\n                    }\n                    else {\n                        delay = 1000 * 60; // otherwise, every minute\n                    }\n                    _this.nowIndicatorIntervalID = setInterval(update, delay); // update every interval\n                }, delay);\n            }\n            // rendering will be initiated in updateSize\n        }\n    };\n    // rerenders the now indicator, computing the new current time from the amount of time that has passed\n    // since the initial getNow call.\n    View.prototype.updateNowIndicator = function () {\n        if (this.props.dateProfile && // a way to determine if dates were rendered yet\n            this.initialNowDate // activated before?\n        ) {\n            this.unrenderNowIndicator(); // won't unrender if unnecessary\n            this.renderNowIndicator(addMs(this.initialNowDate, new Date().valueOf() - this.initialNowQueriedMs));\n            this.isNowIndicatorRendered = true;\n        }\n    };\n    // Immediately unrenders the view's current time indicator and stops any re-rendering timers.\n    // Won't cause side effects if indicator isn't rendered.\n    View.prototype.stopNowIndicator = function () {\n        if (this.nowIndicatorTimeoutID) {\n            clearTimeout(this.nowIndicatorTimeoutID);\n            this.nowIndicatorTimeoutID = null;\n        }\n        if (this.nowIndicatorIntervalID) {\n            clearInterval(this.nowIndicatorIntervalID);\n            this.nowIndicatorIntervalID = null;\n        }\n        if (this.isNowIndicatorRendered) {\n            this.unrenderNowIndicator();\n            this.isNowIndicatorRendered = false;\n        }\n    };\n    View.prototype.getNowIndicatorUnit = function (dateProfile, dateProfileGenerator) {\n        // subclasses should implement\n    };\n    // Renders a current time indicator at the given datetime\n    View.prototype.renderNowIndicator = function (date) {\n        // SUBCLASSES MUST PASS TO CHILDREN!\n    };\n    // Undoes the rendering actions from renderNowIndicator\n    View.prototype.unrenderNowIndicator = function () {\n        // SUBCLASSES MUST PASS TO CHILDREN!\n    };\n    /* Scroller\n    ------------------------------------------------------------------------------------------------------------------*/\n    View.prototype.addScroll = function (scroll, isForced) {\n        if (isForced) {\n            scroll.isForced = isForced;\n        }\n        __assign(this.queuedScroll || (this.queuedScroll = {}), scroll);\n    };\n    View.prototype.popScroll = function (isResize) {\n        this.applyQueuedScroll(isResize);\n        this.queuedScroll = null;\n    };\n    View.prototype.applyQueuedScroll = function (isResize) {\n        if (this.queuedScroll) {\n            this.applyScroll(this.queuedScroll, isResize);\n        }\n    };\n    View.prototype.queryScroll = function () {\n        var scroll = {};\n        if (this.props.dateProfile) { // dates rendered yet?\n            __assign(scroll, this.queryDateScroll());\n        }\n        return scroll;\n    };\n    View.prototype.applyScroll = function (scroll, isResize) {\n        var duration = scroll.duration, isForced = scroll.isForced;\n        if (duration != null && !isForced) {\n            delete scroll.duration;\n            if (this.props.dateProfile) { // dates rendered yet?\n                __assign(scroll, this.computeDateScroll(duration));\n            }\n        }\n        if (this.props.dateProfile) { // dates rendered yet?\n            this.applyDateScroll(scroll);\n        }\n    };\n    View.prototype.computeDateScroll = function (duration) {\n        return {}; // subclasses must implement\n    };\n    View.prototype.queryDateScroll = function () {\n        return {}; // subclasses must implement\n    };\n    View.prototype.applyDateScroll = function (scroll) {\n        // subclasses must implement\n    };\n    // for API\n    View.prototype.scrollToDuration = function (duration) {\n        this.applyScroll({ duration: duration }, false);\n    };\n    return View;\n}(DateComponent));\nEmitterMixin.mixInto(View);\nView.prototype.usesMinMaxTime = false;\nView.prototype.dateProfileGeneratorClass = DateProfileGenerator;\n\nvar FgEventRenderer = /** @class */ (function () {\n    function FgEventRenderer() {\n        this.segs = [];\n        this.isSizeDirty = false;\n    }\n    FgEventRenderer.prototype.renderSegs = function (context, segs, mirrorInfo) {\n        this.context = context;\n        this.rangeUpdated(); // called too frequently :(\n        // render an `.el` on each seg\n        // returns a subset of the segs. segs that were actually rendered\n        segs = this.renderSegEls(segs, mirrorInfo);\n        this.segs = segs;\n        this.attachSegs(segs, mirrorInfo);\n        this.isSizeDirty = true;\n        triggerRenderedSegs(this.context, this.segs, Boolean(mirrorInfo));\n    };\n    FgEventRenderer.prototype.unrender = function (context, _segs, mirrorInfo) {\n        triggerWillRemoveSegs(this.context, this.segs, Boolean(mirrorInfo));\n        this.detachSegs(this.segs);\n        this.segs = [];\n    };\n    // Updates values that rely on options and also relate to range\n    FgEventRenderer.prototype.rangeUpdated = function () {\n        var options = this.context.options;\n        var displayEventTime;\n        var displayEventEnd;\n        this.eventTimeFormat = createFormatter(options.eventTimeFormat || this.computeEventTimeFormat(), options.defaultRangeSeparator);\n        displayEventTime = options.displayEventTime;\n        if (displayEventTime == null) {\n            displayEventTime = this.computeDisplayEventTime(); // might be based off of range\n        }\n        displayEventEnd = options.displayEventEnd;\n        if (displayEventEnd == null) {\n            displayEventEnd = this.computeDisplayEventEnd(); // might be based off of range\n        }\n        this.displayEventTime = displayEventTime;\n        this.displayEventEnd = displayEventEnd;\n    };\n    // Renders and assigns an `el` property for each foreground event segment.\n    // Only returns segments that successfully rendered.\n    FgEventRenderer.prototype.renderSegEls = function (segs, mirrorInfo) {\n        var html = '';\n        var i;\n        if (segs.length) { // don't build an empty html string\n            // build a large concatenation of event segment HTML\n            for (i = 0; i < segs.length; i++) {\n                html += this.renderSegHtml(segs[i], mirrorInfo);\n            }\n            // Grab individual elements from the combined HTML string. Use each as the default rendering.\n            // Then, compute the 'el' for each segment. An el might be null if the eventRender callback returned false.\n            htmlToElements(html).forEach(function (el, i) {\n                var seg = segs[i];\n                if (el) {\n                    seg.el = el;\n                }\n            });\n            segs = filterSegsViaEls(this.context, segs, Boolean(mirrorInfo));\n        }\n        return segs;\n    };\n    // Generic utility for generating the HTML classNames for an event segment's element\n    FgEventRenderer.prototype.getSegClasses = function (seg, isDraggable, isResizable, mirrorInfo) {\n        var classes = [\n            'fc-event',\n            seg.isStart ? 'fc-start' : 'fc-not-start',\n            seg.isEnd ? 'fc-end' : 'fc-not-end'\n        ].concat(seg.eventRange.ui.classNames);\n        if (isDraggable) {\n            classes.push('fc-draggable');\n        }\n        if (isResizable) {\n            classes.push('fc-resizable');\n        }\n        if (mirrorInfo) {\n            classes.push('fc-mirror');\n            if (mirrorInfo.isDragging) {\n                classes.push('fc-dragging');\n            }\n            if (mirrorInfo.isResizing) {\n                classes.push('fc-resizing');\n            }\n        }\n        return classes;\n    };\n    // Compute the text that should be displayed on an event's element.\n    // `range` can be the Event object itself, or something range-like, with at least a `start`.\n    // If event times are disabled, or the event has no time, will return a blank string.\n    // If not specified, formatter will default to the eventTimeFormat setting,\n    // and displayEnd will default to the displayEventEnd setting.\n    FgEventRenderer.prototype.getTimeText = function (eventRange, formatter, displayEnd) {\n        var def = eventRange.def, instance = eventRange.instance;\n        return this._getTimeText(instance.range.start, def.hasEnd ? instance.range.end : null, def.allDay, formatter, displayEnd, instance.forcedStartTzo, instance.forcedEndTzo);\n    };\n    FgEventRenderer.prototype._getTimeText = function (start, end, allDay, formatter, displayEnd, forcedStartTzo, forcedEndTzo) {\n        var dateEnv = this.context.dateEnv;\n        if (formatter == null) {\n            formatter = this.eventTimeFormat;\n        }\n        if (displayEnd == null) {\n            displayEnd = this.displayEventEnd;\n        }\n        if (this.displayEventTime && !allDay) {\n            if (displayEnd && end) {\n                return dateEnv.formatRange(start, end, formatter, {\n                    forcedStartTzo: forcedStartTzo,\n                    forcedEndTzo: forcedEndTzo\n                });\n            }\n            else {\n                return dateEnv.format(start, formatter, {\n                    forcedTzo: forcedStartTzo\n                });\n            }\n        }\n        return '';\n    };\n    FgEventRenderer.prototype.computeEventTimeFormat = function () {\n        return {\n            hour: 'numeric',\n            minute: '2-digit',\n            omitZeroMinute: true\n        };\n    };\n    FgEventRenderer.prototype.computeDisplayEventTime = function () {\n        return true;\n    };\n    FgEventRenderer.prototype.computeDisplayEventEnd = function () {\n        return true;\n    };\n    // Utility for generating event skin-related CSS properties\n    FgEventRenderer.prototype.getSkinCss = function (ui) {\n        return {\n            'background-color': ui.backgroundColor,\n            'border-color': ui.borderColor,\n            color: ui.textColor\n        };\n    };\n    FgEventRenderer.prototype.sortEventSegs = function (segs) {\n        var specs = this.context.eventOrderSpecs;\n        var objs = segs.map(buildSegCompareObj);\n        objs.sort(function (obj0, obj1) {\n            return compareByFieldSpecs(obj0, obj1, specs);\n        });\n        return objs.map(function (c) {\n            return c._seg;\n        });\n    };\n    FgEventRenderer.prototype.computeSizes = function (force) {\n        if (force || this.isSizeDirty) {\n            this.computeSegSizes(this.segs);\n        }\n    };\n    FgEventRenderer.prototype.assignSizes = function (force) {\n        if (force || this.isSizeDirty) {\n            this.assignSegSizes(this.segs);\n            this.isSizeDirty = false;\n        }\n    };\n    FgEventRenderer.prototype.computeSegSizes = function (segs) {\n    };\n    FgEventRenderer.prototype.assignSegSizes = function (segs) {\n    };\n    // Manipulation on rendered segs\n    FgEventRenderer.prototype.hideByHash = function (hash) {\n        if (hash) {\n            for (var _i = 0, _a = this.segs; _i < _a.length; _i++) {\n                var seg = _a[_i];\n                if (hash[seg.eventRange.instance.instanceId]) {\n                    seg.el.style.visibility = 'hidden';\n                }\n            }\n        }\n    };\n    FgEventRenderer.prototype.showByHash = function (hash) {\n        if (hash) {\n            for (var _i = 0, _a = this.segs; _i < _a.length; _i++) {\n                var seg = _a[_i];\n                if (hash[seg.eventRange.instance.instanceId]) {\n                    seg.el.style.visibility = '';\n                }\n            }\n        }\n    };\n    FgEventRenderer.prototype.selectByInstanceId = function (instanceId) {\n        if (instanceId) {\n            for (var _i = 0, _a = this.segs; _i < _a.length; _i++) {\n                var seg = _a[_i];\n                var eventInstance = seg.eventRange.instance;\n                if (eventInstance && eventInstance.instanceId === instanceId &&\n                    seg.el // necessary?\n                ) {\n                    seg.el.classList.add('fc-selected');\n                }\n            }\n        }\n    };\n    FgEventRenderer.prototype.unselectByInstanceId = function (instanceId) {\n        if (instanceId) {\n            for (var _i = 0, _a = this.segs; _i < _a.length; _i++) {\n                var seg = _a[_i];\n                if (seg.el) { // necessary?\n                    seg.el.classList.remove('fc-selected');\n                }\n            }\n        }\n    };\n    return FgEventRenderer;\n}());\n// returns a object with all primitive props that can be compared\nfunction buildSegCompareObj(seg) {\n    var eventDef = seg.eventRange.def;\n    var range = seg.eventRange.instance.range;\n    var start = range.start ? range.start.valueOf() : 0; // TODO: better support for open-range events\n    var end = range.end ? range.end.valueOf() : 0; // \"\n    return __assign({}, eventDef.extendedProps, eventDef, { id: eventDef.publicId, start: start,\n        end: end, duration: end - start, allDay: Number(eventDef.allDay), _seg: seg // for later retrieval\n     });\n}\n\n/*\nTODO: when refactoring this class, make a new FillRenderer instance for each `type`\n*/\nvar FillRenderer = /** @class */ (function () {\n    function FillRenderer() {\n        this.fillSegTag = 'div';\n        this.dirtySizeFlags = {};\n        this.containerElsByType = {};\n        this.segsByType = {};\n    }\n    FillRenderer.prototype.getSegsByType = function (type) {\n        return this.segsByType[type] || [];\n    };\n    FillRenderer.prototype.renderSegs = function (type, context, segs) {\n        var _a;\n        this.context = context;\n        var renderedSegs = this.renderSegEls(type, segs); // assignes `.el` to each seg. returns successfully rendered segs\n        var containerEls = this.attachSegs(type, renderedSegs);\n        if (containerEls) {\n            (_a = (this.containerElsByType[type] || (this.containerElsByType[type] = []))).push.apply(_a, containerEls);\n        }\n        this.segsByType[type] = renderedSegs;\n        if (type === 'bgEvent') {\n            triggerRenderedSegs(context, renderedSegs, false); // isMirror=false\n        }\n        this.dirtySizeFlags[type] = true;\n    };\n    // Unrenders a specific type of fill that is currently rendered on the grid\n    FillRenderer.prototype.unrender = function (type, context) {\n        var segs = this.segsByType[type];\n        if (segs) {\n            if (type === 'bgEvent') {\n                triggerWillRemoveSegs(context, segs, false); // isMirror=false\n            }\n            this.detachSegs(type, segs);\n        }\n    };\n    // Renders and assigns an `el` property for each fill segment. Generic enough to work with different types.\n    // Only returns segments that successfully rendered.\n    FillRenderer.prototype.renderSegEls = function (type, segs) {\n        var _this = this;\n        var html = '';\n        var i;\n        if (segs.length) {\n            // build a large concatenation of segment HTML\n            for (i = 0; i < segs.length; i++) {\n                html += this.renderSegHtml(type, segs[i]);\n            }\n            // Grab individual elements from the combined HTML string. Use each as the default rendering.\n            // Then, compute the 'el' for each segment.\n            htmlToElements(html).forEach(function (el, i) {\n                var seg = segs[i];\n                if (el) {\n                    seg.el = el;\n                }\n            });\n            if (type === 'bgEvent') {\n                segs = filterSegsViaEls(this.context, segs, false // isMirror. background events can never be mirror elements\n                );\n            }\n            // correct element type? (would be bad if a non-TD were inserted into a table for example)\n            segs = segs.filter(function (seg) {\n                return elementMatches(seg.el, _this.fillSegTag);\n            });\n        }\n        return segs;\n    };\n    // Builds the HTML needed for one fill segment. Generic enough to work with different types.\n    FillRenderer.prototype.renderSegHtml = function (type, seg) {\n        var css = null;\n        var classNames = [];\n        if (type !== 'highlight' && type !== 'businessHours') {\n            css = {\n                'background-color': seg.eventRange.ui.backgroundColor\n            };\n        }\n        if (type !== 'highlight') {\n            classNames = classNames.concat(seg.eventRange.ui.classNames);\n        }\n        if (type === 'businessHours') {\n            classNames.push('fc-bgevent');\n        }\n        else {\n            classNames.push('fc-' + type.toLowerCase());\n        }\n        return '<' + this.fillSegTag +\n            (classNames.length ? ' class=\"' + classNames.join(' ') + '\"' : '') +\n            (css ? ' style=\"' + cssToStr(css) + '\"' : '') +\n            '></' + this.fillSegTag + '>';\n    };\n    FillRenderer.prototype.detachSegs = function (type, segs) {\n        var containerEls = this.containerElsByType[type];\n        if (containerEls) {\n            containerEls.forEach(removeElement);\n            delete this.containerElsByType[type];\n        }\n    };\n    FillRenderer.prototype.computeSizes = function (force) {\n        for (var type in this.segsByType) {\n            if (force || this.dirtySizeFlags[type]) {\n                this.computeSegSizes(this.segsByType[type]);\n            }\n        }\n    };\n    FillRenderer.prototype.assignSizes = function (force) {\n        for (var type in this.segsByType) {\n            if (force || this.dirtySizeFlags[type]) {\n                this.assignSegSizes(this.segsByType[type]);\n            }\n        }\n        this.dirtySizeFlags = {};\n    };\n    FillRenderer.prototype.computeSegSizes = function (segs) {\n    };\n    FillRenderer.prototype.assignSegSizes = function (segs) {\n    };\n    return FillRenderer;\n}());\n\nvar NamedTimeZoneImpl = /** @class */ (function () {\n    function NamedTimeZoneImpl(timeZoneName) {\n        this.timeZoneName = timeZoneName;\n    }\n    return NamedTimeZoneImpl;\n}());\n\n/*\nAn abstraction for a dragging interaction originating on an event.\nDoes higher-level things than PointerDragger, such as possibly:\n- a \"mirror\" that moves with the pointer\n- a minimum number of pixels or other criteria for a true drag to begin\n\nsubclasses must emit:\n- pointerdown\n- dragstart\n- dragmove\n- pointerup\n- dragend\n*/\nvar ElementDragging = /** @class */ (function () {\n    function ElementDragging(el) {\n        this.emitter = new EmitterMixin();\n    }\n    ElementDragging.prototype.destroy = function () {\n    };\n    ElementDragging.prototype.setMirrorIsVisible = function (bool) {\n        // optional if subclass doesn't want to support a mirror\n    };\n    ElementDragging.prototype.setMirrorNeedsRevert = function (bool) {\n        // optional if subclass doesn't want to support a mirror\n    };\n    ElementDragging.prototype.setAutoScrollEnabled = function (bool) {\n        // optional\n    };\n    return ElementDragging;\n}());\n\nfunction formatDate(dateInput, settings) {\n    if (settings === void 0) { settings = {}; }\n    var dateEnv = buildDateEnv$1(settings);\n    var formatter = createFormatter(settings);\n    var dateMeta = dateEnv.createMarkerMeta(dateInput);\n    if (!dateMeta) { // TODO: warning?\n        return '';\n    }\n    return dateEnv.format(dateMeta.marker, formatter, {\n        forcedTzo: dateMeta.forcedTzo\n    });\n}\nfunction formatRange(startInput, endInput, settings // mixture of env and formatter settings\n) {\n    var dateEnv = buildDateEnv$1(typeof settings === 'object' && settings ? settings : {}); // pass in if non-null object\n    var formatter = createFormatter(settings, globalDefaults.defaultRangeSeparator);\n    var startMeta = dateEnv.createMarkerMeta(startInput);\n    var endMeta = dateEnv.createMarkerMeta(endInput);\n    if (!startMeta || !endMeta) { // TODO: warning?\n        return '';\n    }\n    return dateEnv.formatRange(startMeta.marker, endMeta.marker, formatter, {\n        forcedStartTzo: startMeta.forcedTzo,\n        forcedEndTzo: endMeta.forcedTzo,\n        isEndExclusive: settings.isEndExclusive\n    });\n}\n// TODO: more DRY and optimized\nfunction buildDateEnv$1(settings) {\n    var locale = buildLocale(settings.locale || 'en', parseRawLocales([]).map); // TODO: don't hardcode 'en' everywhere\n    // ensure required settings\n    settings = __assign({ timeZone: globalDefaults.timeZone, calendarSystem: 'gregory' }, settings, { locale: locale });\n    return new DateEnv(settings);\n}\n\nvar DRAG_META_PROPS = {\n    startTime: createDuration,\n    duration: createDuration,\n    create: Boolean,\n    sourceId: String\n};\nvar DRAG_META_DEFAULTS = {\n    create: true\n};\nfunction parseDragMeta(raw) {\n    var leftoverProps = {};\n    var refined = refineProps(raw, DRAG_META_PROPS, DRAG_META_DEFAULTS, leftoverProps);\n    refined.leftoverProps = leftoverProps;\n    return refined;\n}\n\n// Computes a default column header formatting string if `colFormat` is not explicitly defined\nfunction computeFallbackHeaderFormat(datesRepDistinctDays, dayCnt) {\n    // if more than one week row, or if there are a lot of columns with not much space,\n    // put just the day numbers will be in each cell\n    if (!datesRepDistinctDays || dayCnt > 10) {\n        return { weekday: 'short' }; // \"Sat\"\n    }\n    else if (dayCnt > 1) {\n        return { weekday: 'short', month: 'numeric', day: 'numeric', omitCommas: true }; // \"Sat 11/12\"\n    }\n    else {\n        return { weekday: 'long' }; // \"Saturday\"\n    }\n}\nfunction renderDateCell(dateMarker, dateProfile, datesRepDistinctDays, colCnt, colHeadFormat, context, colspan, otherAttrs) {\n    var dateEnv = context.dateEnv, theme = context.theme, options = context.options;\n    var isDateValid = rangeContainsMarker(dateProfile.activeRange, dateMarker); // TODO: called too frequently. cache somehow.\n    var classNames = [\n        'fc-day-header',\n        theme.getClass('widgetHeader')\n    ];\n    var innerHtml;\n    if (typeof options.columnHeaderHtml === 'function') {\n        innerHtml = options.columnHeaderHtml(dateEnv.toDate(dateMarker));\n    }\n    else if (typeof options.columnHeaderText === 'function') {\n        innerHtml = htmlEscape(options.columnHeaderText(dateEnv.toDate(dateMarker)));\n    }\n    else {\n        innerHtml = htmlEscape(dateEnv.format(dateMarker, colHeadFormat));\n    }\n    // if only one row of days, the classNames on the header can represent the specific days beneath\n    if (datesRepDistinctDays) {\n        classNames = classNames.concat(\n        // includes the day-of-week class\n        // noThemeHighlight=true (don't highlight the header)\n        getDayClasses(dateMarker, dateProfile, context, true));\n    }\n    else {\n        classNames.push('fc-' + DAY_IDS[dateMarker.getUTCDay()]); // only add the day-of-week class\n    }\n    return '' +\n        '<th class=\"' + classNames.join(' ') + '\"' +\n        ((isDateValid && datesRepDistinctDays) ?\n            ' data-date=\"' + dateEnv.formatIso(dateMarker, { omitTime: true }) + '\"' :\n            '') +\n        (colspan > 1 ?\n            ' colspan=\"' + colspan + '\"' :\n            '') +\n        (otherAttrs ?\n            ' ' + otherAttrs :\n            '') +\n        '>' +\n        (isDateValid ?\n            // don't make a link if the heading could represent multiple days, or if there's only one day (forceOff)\n            buildGotoAnchorHtml(options, dateEnv, { date: dateMarker, forceOff: !datesRepDistinctDays || colCnt === 1 }, innerHtml) :\n            // if not valid, display text, but no link\n            innerHtml) +\n        '</th>';\n}\n\nvar DayHeader = /** @class */ (function (_super) {\n    __extends(DayHeader, _super);\n    function DayHeader(parentEl) {\n        var _this = _super.call(this) || this;\n        _this.renderSkeleton = memoizeRendering(_this._renderSkeleton, _this._unrenderSkeleton);\n        _this.parentEl = parentEl;\n        return _this;\n    }\n    DayHeader.prototype.render = function (props, context) {\n        var dates = props.dates, datesRepDistinctDays = props.datesRepDistinctDays;\n        var parts = [];\n        this.renderSkeleton(context);\n        if (props.renderIntroHtml) {\n            parts.push(props.renderIntroHtml());\n        }\n        var colHeadFormat = createFormatter(context.options.columnHeaderFormat ||\n            computeFallbackHeaderFormat(datesRepDistinctDays, dates.length));\n        for (var _i = 0, dates_1 = dates; _i < dates_1.length; _i++) {\n            var date = dates_1[_i];\n            parts.push(renderDateCell(date, props.dateProfile, datesRepDistinctDays, dates.length, colHeadFormat, context));\n        }\n        if (context.isRtl) {\n            parts.reverse();\n        }\n        this.thead.innerHTML = '<tr>' + parts.join('') + '</tr>';\n    };\n    DayHeader.prototype.destroy = function () {\n        _super.prototype.destroy.call(this);\n        this.renderSkeleton.unrender();\n    };\n    DayHeader.prototype._renderSkeleton = function (context) {\n        var theme = context.theme;\n        var parentEl = this.parentEl;\n        parentEl.innerHTML = ''; // because might be nbsp\n        parentEl.appendChild(this.el = htmlToElement('<div class=\"fc-row ' + theme.getClass('headerRow') + '\">' +\n            '<table class=\"' + theme.getClass('tableGrid') + '\">' +\n            '<thead></thead>' +\n            '</table>' +\n            '</div>'));\n        this.thead = this.el.querySelector('thead');\n    };\n    DayHeader.prototype._unrenderSkeleton = function () {\n        removeElement(this.el);\n    };\n    return DayHeader;\n}(Component));\n\nvar DaySeries = /** @class */ (function () {\n    function DaySeries(range, dateProfileGenerator) {\n        var date = range.start;\n        var end = range.end;\n        var indices = [];\n        var dates = [];\n        var dayIndex = -1;\n        while (date < end) { // loop each day from start to end\n            if (dateProfileGenerator.isHiddenDay(date)) {\n                indices.push(dayIndex + 0.5); // mark that it's between indices\n            }\n            else {\n                dayIndex++;\n                indices.push(dayIndex);\n                dates.push(date);\n            }\n            date = addDays(date, 1);\n        }\n        this.dates = dates;\n        this.indices = indices;\n        this.cnt = dates.length;\n    }\n    DaySeries.prototype.sliceRange = function (range) {\n        var firstIndex = this.getDateDayIndex(range.start); // inclusive first index\n        var lastIndex = this.getDateDayIndex(addDays(range.end, -1)); // inclusive last index\n        var clippedFirstIndex = Math.max(0, firstIndex);\n        var clippedLastIndex = Math.min(this.cnt - 1, lastIndex);\n        // deal with in-between indices\n        clippedFirstIndex = Math.ceil(clippedFirstIndex); // in-between starts round to next cell\n        clippedLastIndex = Math.floor(clippedLastIndex); // in-between ends round to prev cell\n        if (clippedFirstIndex <= clippedLastIndex) {\n            return {\n                firstIndex: clippedFirstIndex,\n                lastIndex: clippedLastIndex,\n                isStart: firstIndex === clippedFirstIndex,\n                isEnd: lastIndex === clippedLastIndex\n            };\n        }\n        else {\n            return null;\n        }\n    };\n    // Given a date, returns its chronolocial cell-index from the first cell of the grid.\n    // If the date lies between cells (because of hiddenDays), returns a floating-point value between offsets.\n    // If before the first offset, returns a negative number.\n    // If after the last offset, returns an offset past the last cell offset.\n    // Only works for *start* dates of cells. Will not work for exclusive end dates for cells.\n    DaySeries.prototype.getDateDayIndex = function (date) {\n        var indices = this.indices;\n        var dayOffset = Math.floor(diffDays(this.dates[0], date));\n        if (dayOffset < 0) {\n            return indices[0] - 1;\n        }\n        else if (dayOffset >= indices.length) {\n            return indices[indices.length - 1] + 1;\n        }\n        else {\n            return indices[dayOffset];\n        }\n    };\n    return DaySeries;\n}());\n\nvar DayTable = /** @class */ (function () {\n    function DayTable(daySeries, breakOnWeeks) {\n        var dates = daySeries.dates;\n        var daysPerRow;\n        var firstDay;\n        var rowCnt;\n        if (breakOnWeeks) {\n            // count columns until the day-of-week repeats\n            firstDay = dates[0].getUTCDay();\n            for (daysPerRow = 1; daysPerRow < dates.length; daysPerRow++) {\n                if (dates[daysPerRow].getUTCDay() === firstDay) {\n                    break;\n                }\n            }\n            rowCnt = Math.ceil(dates.length / daysPerRow);\n        }\n        else {\n            rowCnt = 1;\n            daysPerRow = dates.length;\n        }\n        this.rowCnt = rowCnt;\n        this.colCnt = daysPerRow;\n        this.daySeries = daySeries;\n        this.cells = this.buildCells();\n        this.headerDates = this.buildHeaderDates();\n    }\n    DayTable.prototype.buildCells = function () {\n        var rows = [];\n        for (var row = 0; row < this.rowCnt; row++) {\n            var cells = [];\n            for (var col = 0; col < this.colCnt; col++) {\n                cells.push(this.buildCell(row, col));\n            }\n            rows.push(cells);\n        }\n        return rows;\n    };\n    DayTable.prototype.buildCell = function (row, col) {\n        return {\n            date: this.daySeries.dates[row * this.colCnt + col]\n        };\n    };\n    DayTable.prototype.buildHeaderDates = function () {\n        var dates = [];\n        for (var col = 0; col < this.colCnt; col++) {\n            dates.push(this.cells[0][col].date);\n        }\n        return dates;\n    };\n    DayTable.prototype.sliceRange = function (range) {\n        var colCnt = this.colCnt;\n        var seriesSeg = this.daySeries.sliceRange(range);\n        var segs = [];\n        if (seriesSeg) {\n            var firstIndex = seriesSeg.firstIndex, lastIndex = seriesSeg.lastIndex;\n            var index = firstIndex;\n            while (index <= lastIndex) {\n                var row = Math.floor(index / colCnt);\n                var nextIndex = Math.min((row + 1) * colCnt, lastIndex + 1);\n                segs.push({\n                    row: row,\n                    firstCol: index % colCnt,\n                    lastCol: (nextIndex - 1) % colCnt,\n                    isStart: seriesSeg.isStart && index === firstIndex,\n                    isEnd: seriesSeg.isEnd && (nextIndex - 1) === lastIndex\n                });\n                index = nextIndex;\n            }\n        }\n        return segs;\n    };\n    return DayTable;\n}());\n\nvar Slicer = /** @class */ (function () {\n    function Slicer() {\n        this.sliceBusinessHours = memoize(this._sliceBusinessHours);\n        this.sliceDateSelection = memoize(this._sliceDateSpan);\n        this.sliceEventStore = memoize(this._sliceEventStore);\n        this.sliceEventDrag = memoize(this._sliceInteraction);\n        this.sliceEventResize = memoize(this._sliceInteraction);\n    }\n    Slicer.prototype.sliceProps = function (props, dateProfile, nextDayThreshold, calendar, component) {\n        var extraArgs = [];\n        for (var _i = 5; _i < arguments.length; _i++) {\n            extraArgs[_i - 5] = arguments[_i];\n        }\n        var eventUiBases = props.eventUiBases;\n        var eventSegs = this.sliceEventStore.apply(this, [props.eventStore, eventUiBases, dateProfile, nextDayThreshold, component].concat(extraArgs));\n        return {\n            dateSelectionSegs: this.sliceDateSelection.apply(this, [props.dateSelection, eventUiBases, component].concat(extraArgs)),\n            businessHourSegs: this.sliceBusinessHours.apply(this, [props.businessHours, dateProfile, nextDayThreshold, calendar, component].concat(extraArgs)),\n            fgEventSegs: eventSegs.fg,\n            bgEventSegs: eventSegs.bg,\n            eventDrag: this.sliceEventDrag.apply(this, [props.eventDrag, eventUiBases, dateProfile, nextDayThreshold, component].concat(extraArgs)),\n            eventResize: this.sliceEventResize.apply(this, [props.eventResize, eventUiBases, dateProfile, nextDayThreshold, component].concat(extraArgs)),\n            eventSelection: props.eventSelection\n        }; // TODO: give interactionSegs?\n    };\n    Slicer.prototype.sliceNowDate = function (// does not memoize\n    date, component) {\n        var extraArgs = [];\n        for (var _i = 2; _i < arguments.length; _i++) {\n            extraArgs[_i - 2] = arguments[_i];\n        }\n        return this._sliceDateSpan.apply(this, [{ range: { start: date, end: addMs(date, 1) }, allDay: false },\n            {},\n            component].concat(extraArgs));\n    };\n    Slicer.prototype._sliceBusinessHours = function (businessHours, dateProfile, nextDayThreshold, calendar, component) {\n        var extraArgs = [];\n        for (var _i = 5; _i < arguments.length; _i++) {\n            extraArgs[_i - 5] = arguments[_i];\n        }\n        if (!businessHours) {\n            return [];\n        }\n        return this._sliceEventStore.apply(this, [expandRecurring(businessHours, computeActiveRange(dateProfile, Boolean(nextDayThreshold)), calendar),\n            {},\n            dateProfile,\n            nextDayThreshold,\n            component].concat(extraArgs)).bg;\n    };\n    Slicer.prototype._sliceEventStore = function (eventStore, eventUiBases, dateProfile, nextDayThreshold, component) {\n        var extraArgs = [];\n        for (var _i = 5; _i < arguments.length; _i++) {\n            extraArgs[_i - 5] = arguments[_i];\n        }\n        if (eventStore) {\n            var rangeRes = sliceEventStore(eventStore, eventUiBases, computeActiveRange(dateProfile, Boolean(nextDayThreshold)), nextDayThreshold);\n            return {\n                bg: this.sliceEventRanges(rangeRes.bg, component, extraArgs),\n                fg: this.sliceEventRanges(rangeRes.fg, component, extraArgs)\n            };\n        }\n        else {\n            return { bg: [], fg: [] };\n        }\n    };\n    Slicer.prototype._sliceInteraction = function (interaction, eventUiBases, dateProfile, nextDayThreshold, component) {\n        var extraArgs = [];\n        for (var _i = 5; _i < arguments.length; _i++) {\n            extraArgs[_i - 5] = arguments[_i];\n        }\n        if (!interaction) {\n            return null;\n        }\n        var rangeRes = sliceEventStore(interaction.mutatedEvents, eventUiBases, computeActiveRange(dateProfile, Boolean(nextDayThreshold)), nextDayThreshold);\n        return {\n            segs: this.sliceEventRanges(rangeRes.fg, component, extraArgs),\n            affectedInstances: interaction.affectedEvents.instances,\n            isEvent: interaction.isEvent,\n            sourceSeg: interaction.origSeg\n        };\n    };\n    Slicer.prototype._sliceDateSpan = function (dateSpan, eventUiBases, component) {\n        var extraArgs = [];\n        for (var _i = 3; _i < arguments.length; _i++) {\n            extraArgs[_i - 3] = arguments[_i];\n        }\n        if (!dateSpan) {\n            return [];\n        }\n        var eventRange = fabricateEventRange(dateSpan, eventUiBases, component.context.calendar);\n        var segs = this.sliceRange.apply(this, [dateSpan.range].concat(extraArgs));\n        for (var _a = 0, segs_1 = segs; _a < segs_1.length; _a++) {\n            var seg = segs_1[_a];\n            seg.component = component;\n            seg.eventRange = eventRange;\n        }\n        return segs;\n    };\n    /*\n    \"complete\" seg means it has component and eventRange\n    */\n    Slicer.prototype.sliceEventRanges = function (eventRanges, component, // TODO: kill\n    extraArgs) {\n        var segs = [];\n        for (var _i = 0, eventRanges_1 = eventRanges; _i < eventRanges_1.length; _i++) {\n            var eventRange = eventRanges_1[_i];\n            segs.push.apply(segs, this.sliceEventRange(eventRange, component, extraArgs));\n        }\n        return segs;\n    };\n    /*\n    \"complete\" seg means it has component and eventRange\n    */\n    Slicer.prototype.sliceEventRange = function (eventRange, component, // TODO: kill\n    extraArgs) {\n        var segs = this.sliceRange.apply(this, [eventRange.range].concat(extraArgs));\n        for (var _i = 0, segs_2 = segs; _i < segs_2.length; _i++) {\n            var seg = segs_2[_i];\n            seg.component = component;\n            seg.eventRange = eventRange;\n            seg.isStart = eventRange.isStart && seg.isStart;\n            seg.isEnd = eventRange.isEnd && seg.isEnd;\n        }\n        return segs;\n    };\n    return Slicer;\n}());\n/*\nfor incorporating minTime/maxTime if appropriate\nTODO: should be part of DateProfile!\nTimelineDateProfile already does this btw\n*/\nfunction computeActiveRange(dateProfile, isComponentAllDay) {\n    var range = dateProfile.activeRange;\n    if (isComponentAllDay) {\n        return range;\n    }\n    return {\n        start: addMs(range.start, dateProfile.minTime.milliseconds),\n        end: addMs(range.end, dateProfile.maxTime.milliseconds - 864e5) // 864e5 = ms in a day\n    };\n}\n\n// exports\n// --------------------------------------------------------------------------------------------------\nvar version = '4.4.2';\n\n\n\n\n//# sourceURL=webpack:///./node_modules/@fullcalendar/core/main.esm.js?");

/***/ }),

/***/ "./node_modules/@fullcalendar/daygrid/main.css":
/*!*****************************************************!*\
  !*** ./node_modules/@fullcalendar/daygrid/main.css ***!
  \*****************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// extracted by mini-css-extract-plugin\n\n//# sourceURL=webpack:///./node_modules/@fullcalendar/daygrid/main.css?");

/***/ }),

/***/ "./node_modules/@fullcalendar/daygrid/main.esm.js":
/*!********************************************************!*\
  !*** ./node_modules/@fullcalendar/daygrid/main.esm.js ***!
  \********************************************************/
/*! exports provided: default, AbstractDayGridView, DayBgRow, DayGrid, DayGridSlicer, DayGridView, SimpleDayGrid, buildBasicDayTable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"AbstractDayGridView\", function() { return AbstractDayGridView; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"DayBgRow\", function() { return DayBgRow; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"DayGrid\", function() { return DayGrid; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"DayGridSlicer\", function() { return DayGridSlicer; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"DayGridView\", function() { return DayGridView; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"SimpleDayGrid\", function() { return SimpleDayGrid; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"buildBasicDayTable\", function() { return buildDayTable; });\n/* harmony import */ var _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @fullcalendar/core */ \"./node_modules/@fullcalendar/core/main.esm.js\");\n/*!\nFullCalendar Day Grid Plugin v4.4.2\nDocs & License: https://fullcalendar.io/\n(c) 2019 Adam Shaw\n*/\n\n\n\n/*! *****************************************************************************\r\nCopyright (c) Microsoft Corporation.\r\n\r\nPermission to use, copy, modify, and/or distribute this software for any\r\npurpose with or without fee is hereby granted.\r\n\r\nTHE SOFTWARE IS PROVIDED \"AS IS\" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH\r\nREGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY\r\nAND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,\r\nINDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM\r\nLOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR\r\nOTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR\r\nPERFORMANCE OF THIS SOFTWARE.\r\n***************************************************************************** */\r\n/* global Reflect, Promise */\r\n\r\nvar extendStatics = function(d, b) {\r\n    extendStatics = Object.setPrototypeOf ||\r\n        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||\r\n        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };\r\n    return extendStatics(d, b);\r\n};\r\n\r\nfunction __extends(d, b) {\r\n    extendStatics(d, b);\r\n    function __() { this.constructor = d; }\r\n    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());\r\n}\r\n\r\nvar __assign = function() {\r\n    __assign = Object.assign || function __assign(t) {\r\n        for (var s, i = 1, n = arguments.length; i < n; i++) {\r\n            s = arguments[i];\r\n            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];\r\n        }\r\n        return t;\r\n    };\r\n    return __assign.apply(this, arguments);\r\n};\n\nvar DayGridDateProfileGenerator = /** @class */ (function (_super) {\n    __extends(DayGridDateProfileGenerator, _super);\n    function DayGridDateProfileGenerator() {\n        return _super !== null && _super.apply(this, arguments) || this;\n    }\n    // Computes the date range that will be rendered.\n    DayGridDateProfileGenerator.prototype.buildRenderRange = function (currentRange, currentRangeUnit, isRangeAllDay) {\n        var dateEnv = this.dateEnv;\n        var renderRange = _super.prototype.buildRenderRange.call(this, currentRange, currentRangeUnit, isRangeAllDay);\n        var start = renderRange.start;\n        var end = renderRange.end;\n        var endOfWeek;\n        // year and month views should be aligned with weeks. this is already done for week\n        if (/^(year|month)$/.test(currentRangeUnit)) {\n            start = dateEnv.startOfWeek(start);\n            // make end-of-week if not already\n            endOfWeek = dateEnv.startOfWeek(end);\n            if (endOfWeek.valueOf() !== end.valueOf()) {\n                end = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"addWeeks\"])(endOfWeek, 1);\n            }\n        }\n        // ensure 6 weeks\n        if (this.options.monthMode &&\n            this.options.fixedWeekCount) {\n            var rowCnt = Math.ceil(// could be partial weeks due to hiddenDays\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"diffWeeks\"])(start, end));\n            end = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"addWeeks\"])(end, 6 - rowCnt);\n        }\n        return { start: start, end: end };\n    };\n    return DayGridDateProfileGenerator;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"DateProfileGenerator\"]));\n\n/* A rectangular panel that is absolutely positioned over other content\n------------------------------------------------------------------------------------------------------------------------\nOptions:\n  - className (string)\n  - content (HTML string, element, or element array)\n  - parentEl\n  - top\n  - left\n  - right (the x coord of where the right edge should be. not a \"CSS\" right)\n  - autoHide (boolean)\n  - show (callback)\n  - hide (callback)\n*/\nvar Popover = /** @class */ (function () {\n    function Popover(options) {\n        var _this = this;\n        this.isHidden = true;\n        this.margin = 10; // the space required between the popover and the edges of the scroll container\n        // Triggered when the user clicks *anywhere* in the document, for the autoHide feature\n        this.documentMousedown = function (ev) {\n            // only hide the popover if the click happened outside the popover\n            if (_this.el && !_this.el.contains(ev.target)) {\n                _this.hide();\n            }\n        };\n        this.options = options;\n    }\n    // Shows the popover on the specified position. Renders it if not already\n    Popover.prototype.show = function () {\n        if (this.isHidden) {\n            if (!this.el) {\n                this.render();\n            }\n            this.el.style.display = '';\n            this.position();\n            this.isHidden = false;\n            this.trigger('show');\n        }\n    };\n    // Hides the popover, through CSS, but does not remove it from the DOM\n    Popover.prototype.hide = function () {\n        if (!this.isHidden) {\n            this.el.style.display = 'none';\n            this.isHidden = true;\n            this.trigger('hide');\n        }\n    };\n    // Creates `this.el` and renders content inside of it\n    Popover.prototype.render = function () {\n        var _this = this;\n        var options = this.options;\n        var el = this.el = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createElement\"])('div', {\n            className: 'fc-popover ' + (options.className || ''),\n            style: {\n                top: '0',\n                left: '0'\n            }\n        });\n        if (typeof options.content === 'function') {\n            options.content(el);\n        }\n        options.parentEl.appendChild(el);\n        // when a click happens on anything inside with a 'fc-close' className, hide the popover\n        Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"listenBySelector\"])(el, 'click', '.fc-close', function (ev) {\n            _this.hide();\n        });\n        if (options.autoHide) {\n            document.addEventListener('mousedown', this.documentMousedown);\n        }\n    };\n    // Hides and unregisters any handlers\n    Popover.prototype.destroy = function () {\n        this.hide();\n        if (this.el) {\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"removeElement\"])(this.el);\n            this.el = null;\n        }\n        document.removeEventListener('mousedown', this.documentMousedown);\n    };\n    // Positions the popover optimally, using the top/left/right options\n    Popover.prototype.position = function () {\n        var options = this.options;\n        var el = this.el;\n        var elDims = el.getBoundingClientRect(); // only used for width,height\n        var origin = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeRect\"])(el.offsetParent);\n        var clippingRect = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeClippingRect\"])(options.parentEl);\n        var top; // the \"position\" (not \"offset\") values for the popover\n        var left; //\n        // compute top and left\n        top = options.top || 0;\n        if (options.left !== undefined) {\n            left = options.left;\n        }\n        else if (options.right !== undefined) {\n            left = options.right - elDims.width; // derive the left value from the right value\n        }\n        else {\n            left = 0;\n        }\n        // constrain to the view port. if constrained by two edges, give precedence to top/left\n        top = Math.min(top, clippingRect.bottom - elDims.height - this.margin);\n        top = Math.max(top, clippingRect.top + this.margin);\n        left = Math.min(left, clippingRect.right - elDims.width - this.margin);\n        left = Math.max(left, clippingRect.left + this.margin);\n        Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"applyStyle\"])(el, {\n            top: top - origin.top,\n            left: left - origin.left\n        });\n    };\n    // Triggers a callback. Calls a function in the option hash of the same name.\n    // Arguments beyond the first `name` are forwarded on.\n    // TODO: better code reuse for this. Repeat code\n    // can kill this???\n    Popover.prototype.trigger = function (name) {\n        if (this.options[name]) {\n            this.options[name].apply(this, Array.prototype.slice.call(arguments, 1));\n        }\n    };\n    return Popover;\n}());\n\n/* Event-rendering methods for the DayGrid class\n----------------------------------------------------------------------------------------------------------------------*/\n// \"Simple\" is bad a name. has nothing to do with SimpleDayGrid\nvar SimpleDayGridEventRenderer = /** @class */ (function (_super) {\n    __extends(SimpleDayGridEventRenderer, _super);\n    function SimpleDayGridEventRenderer() {\n        return _super !== null && _super.apply(this, arguments) || this;\n    }\n    // Builds the HTML to be used for the default element for an individual segment\n    SimpleDayGridEventRenderer.prototype.renderSegHtml = function (seg, mirrorInfo) {\n        var context = this.context;\n        var eventRange = seg.eventRange;\n        var eventDef = eventRange.def;\n        var eventUi = eventRange.ui;\n        var allDay = eventDef.allDay;\n        var isDraggable = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeEventDraggable\"])(context, eventDef, eventUi);\n        var isResizableFromStart = allDay && seg.isStart && Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeEventStartResizable\"])(context, eventDef, eventUi);\n        var isResizableFromEnd = allDay && seg.isEnd && Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeEventEndResizable\"])(context, eventDef, eventUi);\n        var classes = this.getSegClasses(seg, isDraggable, isResizableFromStart || isResizableFromEnd, mirrorInfo);\n        var skinCss = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"cssToStr\"])(this.getSkinCss(eventUi));\n        var timeHtml = '';\n        var timeText;\n        var titleHtml;\n        classes.unshift('fc-day-grid-event', 'fc-h-event');\n        // Only display a timed events time if it is the starting segment\n        if (seg.isStart) {\n            timeText = this.getTimeText(eventRange);\n            if (timeText) {\n                timeHtml = '<span class=\"fc-time\">' + Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(timeText) + '</span>';\n            }\n        }\n        titleHtml =\n            '<span class=\"fc-title\">' +\n                (Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(eventDef.title || '') || '&nbsp;') + // we always want one line of height\n                '</span>';\n        return '<a class=\"' + classes.join(' ') + '\"' +\n            (eventDef.url ?\n                ' href=\"' + Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(eventDef.url) + '\"' :\n                '') +\n            (skinCss ?\n                ' style=\"' + skinCss + '\"' :\n                '') +\n            '>' +\n            '<div class=\"fc-content\">' +\n            (context.options.dir === 'rtl' ?\n                titleHtml + ' ' + timeHtml : // put a natural space in between\n                timeHtml + ' ' + titleHtml //\n            ) +\n            '</div>' +\n            (isResizableFromStart ?\n                '<div class=\"fc-resizer fc-start-resizer\"></div>' :\n                '') +\n            (isResizableFromEnd ?\n                '<div class=\"fc-resizer fc-end-resizer\"></div>' :\n                '') +\n            '</a>';\n    };\n    // Computes a default event time formatting string if `eventTimeFormat` is not explicitly defined\n    SimpleDayGridEventRenderer.prototype.computeEventTimeFormat = function () {\n        return {\n            hour: 'numeric',\n            minute: '2-digit',\n            omitZeroMinute: true,\n            meridiem: 'narrow'\n        };\n    };\n    SimpleDayGridEventRenderer.prototype.computeDisplayEventEnd = function () {\n        return false; // TODO: somehow consider the originating DayGrid's column count\n    };\n    return SimpleDayGridEventRenderer;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"FgEventRenderer\"]));\n\n/* Event-rendering methods for the DayGrid class\n----------------------------------------------------------------------------------------------------------------------*/\nvar DayGridEventRenderer = /** @class */ (function (_super) {\n    __extends(DayGridEventRenderer, _super);\n    function DayGridEventRenderer(dayGrid) {\n        var _this = _super.call(this) || this;\n        _this.dayGrid = dayGrid;\n        return _this;\n    }\n    // Renders the given foreground event segments onto the grid\n    DayGridEventRenderer.prototype.attachSegs = function (segs, mirrorInfo) {\n        var rowStructs = this.rowStructs = this.renderSegRows(segs);\n        // append to each row's content skeleton\n        this.dayGrid.rowEls.forEach(function (rowNode, i) {\n            rowNode.querySelector('.fc-content-skeleton > table').appendChild(rowStructs[i].tbodyEl);\n        });\n        // removes the \"more..\" events popover\n        if (!mirrorInfo) {\n            this.dayGrid.removeSegPopover();\n        }\n    };\n    // Unrenders all currently rendered foreground event segments\n    DayGridEventRenderer.prototype.detachSegs = function () {\n        var rowStructs = this.rowStructs || [];\n        var rowStruct;\n        while ((rowStruct = rowStructs.pop())) {\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"removeElement\"])(rowStruct.tbodyEl);\n        }\n        this.rowStructs = null;\n    };\n    // Uses the given events array to generate <tbody> elements that should be appended to each row's content skeleton.\n    // Returns an array of rowStruct objects (see the bottom of `renderSegRow`).\n    // PRECONDITION: each segment shoud already have a rendered and assigned `.el`\n    DayGridEventRenderer.prototype.renderSegRows = function (segs) {\n        var rowStructs = [];\n        var segRows;\n        var row;\n        segRows = this.groupSegRows(segs); // group into nested arrays\n        // iterate each row of segment groupings\n        for (row = 0; row < segRows.length; row++) {\n            rowStructs.push(this.renderSegRow(row, segRows[row]));\n        }\n        return rowStructs;\n    };\n    // Given a row # and an array of segments all in the same row, render a <tbody> element, a skeleton that contains\n    // the segments. Returns object with a bunch of internal data about how the render was calculated.\n    // NOTE: modifies rowSegs\n    DayGridEventRenderer.prototype.renderSegRow = function (row, rowSegs) {\n        var isRtl = this.context.isRtl;\n        var dayGrid = this.dayGrid;\n        var colCnt = dayGrid.colCnt;\n        var segLevels = this.buildSegLevels(rowSegs); // group into sub-arrays of levels\n        var levelCnt = Math.max(1, segLevels.length); // ensure at least one level\n        var tbody = document.createElement('tbody');\n        var segMatrix = []; // lookup for which segments are rendered into which level+col cells\n        var cellMatrix = []; // lookup for all <td> elements of the level+col matrix\n        var loneCellMatrix = []; // lookup for <td> elements that only take up a single column\n        var i;\n        var levelSegs;\n        var col;\n        var tr;\n        var j;\n        var seg;\n        var td;\n        // populates empty cells from the current column (`col`) to `endCol`\n        function emptyCellsUntil(endCol) {\n            while (col < endCol) {\n                // try to grab a cell from the level above and extend its rowspan. otherwise, create a fresh cell\n                td = (loneCellMatrix[i - 1] || [])[col];\n                if (td) {\n                    td.rowSpan = (td.rowSpan || 1) + 1;\n                }\n                else {\n                    td = document.createElement('td');\n                    tr.appendChild(td);\n                }\n                cellMatrix[i][col] = td;\n                loneCellMatrix[i][col] = td;\n                col++;\n            }\n        }\n        for (i = 0; i < levelCnt; i++) { // iterate through all levels\n            levelSegs = segLevels[i];\n            col = 0;\n            tr = document.createElement('tr');\n            segMatrix.push([]);\n            cellMatrix.push([]);\n            loneCellMatrix.push([]);\n            // levelCnt might be 1 even though there are no actual levels. protect against this.\n            // this single empty row is useful for styling.\n            if (levelSegs) {\n                for (j = 0; j < levelSegs.length; j++) { // iterate through segments in level\n                    seg = levelSegs[j];\n                    var leftCol = isRtl ? (colCnt - 1 - seg.lastCol) : seg.firstCol;\n                    var rightCol = isRtl ? (colCnt - 1 - seg.firstCol) : seg.lastCol;\n                    emptyCellsUntil(leftCol);\n                    // create a container that occupies or more columns. append the event element.\n                    td = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createElement\"])('td', { className: 'fc-event-container' }, seg.el);\n                    if (leftCol !== rightCol) {\n                        td.colSpan = rightCol - leftCol + 1;\n                    }\n                    else { // a single-column segment\n                        loneCellMatrix[i][col] = td;\n                    }\n                    while (col <= rightCol) {\n                        cellMatrix[i][col] = td;\n                        segMatrix[i][col] = seg;\n                        col++;\n                    }\n                    tr.appendChild(td);\n                }\n            }\n            emptyCellsUntil(colCnt); // finish off the row\n            var introHtml = dayGrid.renderProps.renderIntroHtml();\n            if (introHtml) {\n                if (isRtl) {\n                    Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"appendToElement\"])(tr, introHtml);\n                }\n                else {\n                    Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"prependToElement\"])(tr, introHtml);\n                }\n            }\n            tbody.appendChild(tr);\n        }\n        return {\n            row: row,\n            tbodyEl: tbody,\n            cellMatrix: cellMatrix,\n            segMatrix: segMatrix,\n            segLevels: segLevels,\n            segs: rowSegs\n        };\n    };\n    // Stacks a flat array of segments, which are all assumed to be in the same row, into subarrays of vertical levels.\n    // NOTE: modifies segs\n    DayGridEventRenderer.prototype.buildSegLevels = function (segs) {\n        var isRtl = this.context.isRtl;\n        var colCnt = this.dayGrid.colCnt;\n        var levels = [];\n        var i;\n        var seg;\n        var j;\n        // Give preference to elements with certain criteria, so they have\n        // a chance to be closer to the top.\n        segs = this.sortEventSegs(segs);\n        for (i = 0; i < segs.length; i++) {\n            seg = segs[i];\n            // loop through levels, starting with the topmost, until the segment doesn't collide with other segments\n            for (j = 0; j < levels.length; j++) {\n                if (!isDaySegCollision(seg, levels[j])) {\n                    break;\n                }\n            }\n            // `j` now holds the desired subrow index\n            seg.level = j;\n            seg.leftCol = isRtl ? (colCnt - 1 - seg.lastCol) : seg.firstCol; // for sorting only\n            seg.rightCol = isRtl ? (colCnt - 1 - seg.firstCol) : seg.lastCol // for sorting only\n            ;\n            (levels[j] || (levels[j] = [])).push(seg);\n        }\n        // order segments left-to-right. very important if calendar is RTL\n        for (j = 0; j < levels.length; j++) {\n            levels[j].sort(compareDaySegCols);\n        }\n        return levels;\n    };\n    // Given a flat array of segments, return an array of sub-arrays, grouped by each segment's row\n    DayGridEventRenderer.prototype.groupSegRows = function (segs) {\n        var segRows = [];\n        var i;\n        for (i = 0; i < this.dayGrid.rowCnt; i++) {\n            segRows.push([]);\n        }\n        for (i = 0; i < segs.length; i++) {\n            segRows[segs[i].row].push(segs[i]);\n        }\n        return segRows;\n    };\n    // Computes a default `displayEventEnd` value if one is not expliclty defined\n    DayGridEventRenderer.prototype.computeDisplayEventEnd = function () {\n        return this.dayGrid.colCnt === 1; // we'll likely have space if there's only one day\n    };\n    return DayGridEventRenderer;\n}(SimpleDayGridEventRenderer));\n// Computes whether two segments' columns collide. They are assumed to be in the same row.\nfunction isDaySegCollision(seg, otherSegs) {\n    var i;\n    var otherSeg;\n    for (i = 0; i < otherSegs.length; i++) {\n        otherSeg = otherSegs[i];\n        if (otherSeg.firstCol <= seg.lastCol &&\n            otherSeg.lastCol >= seg.firstCol) {\n            return true;\n        }\n    }\n    return false;\n}\n// A cmp function for determining the leftmost event\nfunction compareDaySegCols(a, b) {\n    return a.leftCol - b.leftCol;\n}\n\nvar DayGridMirrorRenderer = /** @class */ (function (_super) {\n    __extends(DayGridMirrorRenderer, _super);\n    function DayGridMirrorRenderer() {\n        return _super !== null && _super.apply(this, arguments) || this;\n    }\n    DayGridMirrorRenderer.prototype.attachSegs = function (segs, mirrorInfo) {\n        var sourceSeg = mirrorInfo.sourceSeg;\n        var rowStructs = this.rowStructs = this.renderSegRows(segs);\n        // inject each new event skeleton into each associated row\n        this.dayGrid.rowEls.forEach(function (rowNode, row) {\n            var skeletonEl = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlToElement\"])('<div class=\"fc-mirror-skeleton\"><table></table></div>'); // will be absolutely positioned\n            var skeletonTopEl;\n            var skeletonTop;\n            // If there is an original segment, match the top position. Otherwise, put it at the row's top level\n            if (sourceSeg && sourceSeg.row === row) {\n                skeletonTopEl = sourceSeg.el;\n            }\n            else {\n                skeletonTopEl = rowNode.querySelector('.fc-content-skeleton tbody');\n                if (!skeletonTopEl) { // when no events\n                    skeletonTopEl = rowNode.querySelector('.fc-content-skeleton table');\n                }\n            }\n            skeletonTop = skeletonTopEl.getBoundingClientRect().top -\n                rowNode.getBoundingClientRect().top; // the offsetParent origin\n            skeletonEl.style.top = skeletonTop + 'px';\n            skeletonEl.querySelector('table').appendChild(rowStructs[row].tbodyEl);\n            rowNode.appendChild(skeletonEl);\n        });\n    };\n    return DayGridMirrorRenderer;\n}(DayGridEventRenderer));\n\nvar EMPTY_CELL_HTML = '<td style=\"pointer-events:none\"></td>';\nvar DayGridFillRenderer = /** @class */ (function (_super) {\n    __extends(DayGridFillRenderer, _super);\n    function DayGridFillRenderer(dayGrid) {\n        var _this = _super.call(this) || this;\n        _this.fillSegTag = 'td'; // override the default tag name\n        _this.dayGrid = dayGrid;\n        return _this;\n    }\n    DayGridFillRenderer.prototype.renderSegs = function (type, context, segs) {\n        // don't render timed background events\n        if (type === 'bgEvent') {\n            segs = segs.filter(function (seg) {\n                return seg.eventRange.def.allDay;\n            });\n        }\n        _super.prototype.renderSegs.call(this, type, context, segs);\n    };\n    DayGridFillRenderer.prototype.attachSegs = function (type, segs) {\n        var els = [];\n        var i;\n        var seg;\n        var skeletonEl;\n        for (i = 0; i < segs.length; i++) {\n            seg = segs[i];\n            skeletonEl = this.renderFillRow(type, seg);\n            this.dayGrid.rowEls[seg.row].appendChild(skeletonEl);\n            els.push(skeletonEl);\n        }\n        return els;\n    };\n    // Generates the HTML needed for one row of a fill. Requires the seg's el to be rendered.\n    DayGridFillRenderer.prototype.renderFillRow = function (type, seg) {\n        var dayGrid = this.dayGrid;\n        var isRtl = this.context.isRtl;\n        var colCnt = dayGrid.colCnt;\n        var leftCol = isRtl ? (colCnt - 1 - seg.lastCol) : seg.firstCol;\n        var rightCol = isRtl ? (colCnt - 1 - seg.firstCol) : seg.lastCol;\n        var startCol = leftCol;\n        var endCol = rightCol + 1;\n        var className;\n        var skeletonEl;\n        var trEl;\n        if (type === 'businessHours') {\n            className = 'bgevent';\n        }\n        else {\n            className = type.toLowerCase();\n        }\n        skeletonEl = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlToElement\"])('<div class=\"fc-' + className + '-skeleton\">' +\n            '<table><tr></tr></table>' +\n            '</div>');\n        trEl = skeletonEl.getElementsByTagName('tr')[0];\n        if (startCol > 0) {\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"appendToElement\"])(trEl, \n            // will create (startCol + 1) td's\n            new Array(startCol + 1).join(EMPTY_CELL_HTML));\n        }\n        seg.el.colSpan = endCol - startCol;\n        trEl.appendChild(seg.el);\n        if (endCol < colCnt) {\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"appendToElement\"])(trEl, \n            // will create (colCnt - endCol) td's\n            new Array(colCnt - endCol + 1).join(EMPTY_CELL_HTML));\n        }\n        var introHtml = dayGrid.renderProps.renderIntroHtml();\n        if (introHtml) {\n            if (isRtl) {\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"appendToElement\"])(trEl, introHtml);\n            }\n            else {\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"prependToElement\"])(trEl, introHtml);\n            }\n        }\n        return skeletonEl;\n    };\n    return DayGridFillRenderer;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"FillRenderer\"]));\n\nvar DayTile = /** @class */ (function (_super) {\n    __extends(DayTile, _super);\n    function DayTile(el) {\n        var _this = _super.call(this, el) || this;\n        var eventRenderer = _this.eventRenderer = new DayTileEventRenderer(_this);\n        var renderFrame = _this.renderFrame = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderFrame);\n        _this.renderFgEvents = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(eventRenderer.renderSegs.bind(eventRenderer), eventRenderer.unrender.bind(eventRenderer), [renderFrame]);\n        _this.renderEventSelection = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(eventRenderer.selectByInstanceId.bind(eventRenderer), eventRenderer.unselectByInstanceId.bind(eventRenderer), [_this.renderFgEvents]);\n        _this.renderEventDrag = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(eventRenderer.hideByHash.bind(eventRenderer), eventRenderer.showByHash.bind(eventRenderer), [renderFrame]);\n        _this.renderEventResize = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(eventRenderer.hideByHash.bind(eventRenderer), eventRenderer.showByHash.bind(eventRenderer), [renderFrame]);\n        return _this;\n    }\n    DayTile.prototype.firstContext = function (context) {\n        context.calendar.registerInteractiveComponent(this, {\n            el: this.el,\n            useEventCenter: false\n        });\n    };\n    DayTile.prototype.render = function (props, context) {\n        this.renderFrame(props.date);\n        this.renderFgEvents(context, props.fgSegs);\n        this.renderEventSelection(props.eventSelection);\n        this.renderEventDrag(props.eventDragInstances);\n        this.renderEventResize(props.eventResizeInstances);\n    };\n    DayTile.prototype.destroy = function () {\n        _super.prototype.destroy.call(this);\n        this.renderFrame.unrender(); // should unrender everything else\n        this.context.calendar.unregisterInteractiveComponent(this);\n    };\n    DayTile.prototype._renderFrame = function (date) {\n        var _a = this.context, theme = _a.theme, dateEnv = _a.dateEnv, options = _a.options;\n        var title = dateEnv.format(date, Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createFormatter\"])(options.dayPopoverFormat) // TODO: cache\n        );\n        this.el.innerHTML =\n            '<div class=\"fc-header ' + theme.getClass('popoverHeader') + '\">' +\n                '<span class=\"fc-title\">' +\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(title) +\n                '</span>' +\n                '<span class=\"fc-close ' + theme.getIconClass('close') + '\"></span>' +\n                '</div>' +\n                '<div class=\"fc-body ' + theme.getClass('popoverContent') + '\">' +\n                '<div class=\"fc-event-container\"></div>' +\n                '</div>';\n        this.segContainerEl = this.el.querySelector('.fc-event-container');\n    };\n    DayTile.prototype.queryHit = function (positionLeft, positionTop, elWidth, elHeight) {\n        var date = this.props.date; // HACK\n        if (positionLeft < elWidth && positionTop < elHeight) {\n            return {\n                component: this,\n                dateSpan: {\n                    allDay: true,\n                    range: { start: date, end: Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"addDays\"])(date, 1) }\n                },\n                dayEl: this.el,\n                rect: {\n                    left: 0,\n                    top: 0,\n                    right: elWidth,\n                    bottom: elHeight\n                },\n                layer: 1\n            };\n        }\n    };\n    return DayTile;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"DateComponent\"]));\nvar DayTileEventRenderer = /** @class */ (function (_super) {\n    __extends(DayTileEventRenderer, _super);\n    function DayTileEventRenderer(dayTile) {\n        var _this = _super.call(this) || this;\n        _this.dayTile = dayTile;\n        return _this;\n    }\n    DayTileEventRenderer.prototype.attachSegs = function (segs) {\n        for (var _i = 0, segs_1 = segs; _i < segs_1.length; _i++) {\n            var seg = segs_1[_i];\n            this.dayTile.segContainerEl.appendChild(seg.el);\n        }\n    };\n    DayTileEventRenderer.prototype.detachSegs = function (segs) {\n        for (var _i = 0, segs_2 = segs; _i < segs_2.length; _i++) {\n            var seg = segs_2[_i];\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"removeElement\"])(seg.el);\n        }\n    };\n    return DayTileEventRenderer;\n}(SimpleDayGridEventRenderer));\n\nvar DayBgRow = /** @class */ (function () {\n    function DayBgRow(context) {\n        this.context = context;\n    }\n    DayBgRow.prototype.renderHtml = function (props) {\n        var parts = [];\n        if (props.renderIntroHtml) {\n            parts.push(props.renderIntroHtml());\n        }\n        for (var _i = 0, _a = props.cells; _i < _a.length; _i++) {\n            var cell = _a[_i];\n            parts.push(renderCellHtml(cell.date, props.dateProfile, this.context, cell.htmlAttrs));\n        }\n        if (!props.cells.length) {\n            parts.push('<td class=\"fc-day ' + this.context.theme.getClass('widgetContent') + '\"></td>');\n        }\n        if (this.context.options.dir === 'rtl') {\n            parts.reverse();\n        }\n        return '<tr>' + parts.join('') + '</tr>';\n    };\n    return DayBgRow;\n}());\nfunction renderCellHtml(date, dateProfile, context, otherAttrs) {\n    var dateEnv = context.dateEnv, theme = context.theme;\n    var isDateValid = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"rangeContainsMarker\"])(dateProfile.activeRange, date); // TODO: called too frequently. cache somehow.\n    var classes = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"getDayClasses\"])(date, dateProfile, context);\n    classes.unshift('fc-day', theme.getClass('widgetContent'));\n    return '<td class=\"' + classes.join(' ') + '\"' +\n        (isDateValid ?\n            ' data-date=\"' + dateEnv.formatIso(date, { omitTime: true }) + '\"' :\n            '') +\n        (otherAttrs ?\n            ' ' + otherAttrs :\n            '') +\n        '></td>';\n}\n\nvar DAY_NUM_FORMAT = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createFormatter\"])({ day: 'numeric' });\nvar WEEK_NUM_FORMAT = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createFormatter\"])({ week: 'numeric' });\nvar DayGrid = /** @class */ (function (_super) {\n    __extends(DayGrid, _super);\n    function DayGrid(el, renderProps) {\n        var _this = _super.call(this, el) || this;\n        _this.bottomCoordPadding = 0; // hack for extending the hit area for the last row of the coordinate grid\n        _this.isCellSizesDirty = false;\n        _this.renderProps = renderProps;\n        var eventRenderer = _this.eventRenderer = new DayGridEventRenderer(_this);\n        var fillRenderer = _this.fillRenderer = new DayGridFillRenderer(_this);\n        _this.mirrorRenderer = new DayGridMirrorRenderer(_this);\n        var renderCells = _this.renderCells = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderCells, _this._unrenderCells);\n        _this.renderBusinessHours = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(fillRenderer.renderSegs.bind(fillRenderer, 'businessHours'), fillRenderer.unrender.bind(fillRenderer, 'businessHours'), [renderCells]);\n        _this.renderDateSelection = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(fillRenderer.renderSegs.bind(fillRenderer, 'highlight'), fillRenderer.unrender.bind(fillRenderer, 'highlight'), [renderCells]);\n        _this.renderBgEvents = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(fillRenderer.renderSegs.bind(fillRenderer, 'bgEvent'), fillRenderer.unrender.bind(fillRenderer, 'bgEvent'), [renderCells]);\n        _this.renderFgEvents = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(eventRenderer.renderSegs.bind(eventRenderer), eventRenderer.unrender.bind(eventRenderer), [renderCells]);\n        _this.renderEventSelection = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(eventRenderer.selectByInstanceId.bind(eventRenderer), eventRenderer.unselectByInstanceId.bind(eventRenderer), [_this.renderFgEvents]);\n        _this.renderEventDrag = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderEventDrag, _this._unrenderEventDrag, [renderCells]);\n        _this.renderEventResize = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderEventResize, _this._unrenderEventResize, [renderCells]);\n        return _this;\n    }\n    DayGrid.prototype.render = function (props, context) {\n        var cells = props.cells;\n        this.rowCnt = cells.length;\n        this.colCnt = cells[0].length;\n        this.renderCells(cells, props.isRigid);\n        this.renderBusinessHours(context, props.businessHourSegs);\n        this.renderDateSelection(context, props.dateSelectionSegs);\n        this.renderBgEvents(context, props.bgEventSegs);\n        this.renderFgEvents(context, props.fgEventSegs);\n        this.renderEventSelection(props.eventSelection);\n        this.renderEventDrag(props.eventDrag);\n        this.renderEventResize(props.eventResize);\n        if (this.segPopoverTile) {\n            this.updateSegPopoverTile();\n        }\n    };\n    DayGrid.prototype.destroy = function () {\n        _super.prototype.destroy.call(this);\n        this.renderCells.unrender(); // will unrender everything else\n    };\n    DayGrid.prototype.getCellRange = function (row, col) {\n        var start = this.props.cells[row][col].date;\n        var end = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"addDays\"])(start, 1);\n        return { start: start, end: end };\n    };\n    DayGrid.prototype.updateSegPopoverTile = function (date, segs) {\n        var ownProps = this.props;\n        this.segPopoverTile.receiveProps({\n            date: date || this.segPopoverTile.props.date,\n            fgSegs: segs || this.segPopoverTile.props.fgSegs,\n            eventSelection: ownProps.eventSelection,\n            eventDragInstances: ownProps.eventDrag ? ownProps.eventDrag.affectedInstances : null,\n            eventResizeInstances: ownProps.eventResize ? ownProps.eventResize.affectedInstances : null\n        }, this.context);\n    };\n    /* Date Rendering\n    ------------------------------------------------------------------------------------------------------------------*/\n    DayGrid.prototype._renderCells = function (cells, isRigid) {\n        var _a = this.context, calendar = _a.calendar, view = _a.view, isRtl = _a.isRtl, dateEnv = _a.dateEnv;\n        var _b = this, rowCnt = _b.rowCnt, colCnt = _b.colCnt;\n        var html = '';\n        var row;\n        var col;\n        for (row = 0; row < rowCnt; row++) {\n            html += this.renderDayRowHtml(row, isRigid);\n        }\n        this.el.innerHTML = html;\n        this.rowEls = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(this.el, '.fc-row');\n        this.cellEls = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(this.el, '.fc-day, .fc-disabled-day');\n        if (isRtl) {\n            this.cellEls.reverse();\n        }\n        this.rowPositions = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"PositionCache\"](this.el, this.rowEls, false, true // vertical\n        );\n        this.colPositions = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"PositionCache\"](this.el, this.cellEls.slice(0, colCnt), // only the first row\n        true, false // horizontal\n        );\n        // trigger dayRender with each cell's element\n        for (row = 0; row < rowCnt; row++) {\n            for (col = 0; col < colCnt; col++) {\n                calendar.publiclyTrigger('dayRender', [\n                    {\n                        date: dateEnv.toDate(cells[row][col].date),\n                        el: this.getCellEl(row, col),\n                        view: view\n                    }\n                ]);\n            }\n        }\n        this.isCellSizesDirty = true;\n    };\n    DayGrid.prototype._unrenderCells = function () {\n        this.removeSegPopover();\n    };\n    // Generates the HTML for a single row, which is a div that wraps a table.\n    // `row` is the row number.\n    DayGrid.prototype.renderDayRowHtml = function (row, isRigid) {\n        var theme = this.context.theme;\n        var classes = ['fc-row', 'fc-week', theme.getClass('dayRow')];\n        if (isRigid) {\n            classes.push('fc-rigid');\n        }\n        var bgRow = new DayBgRow(this.context);\n        return '' +\n            '<div class=\"' + classes.join(' ') + '\">' +\n            '<div class=\"fc-bg\">' +\n            '<table class=\"' + theme.getClass('tableGrid') + '\">' +\n            bgRow.renderHtml({\n                cells: this.props.cells[row],\n                dateProfile: this.props.dateProfile,\n                renderIntroHtml: this.renderProps.renderBgIntroHtml\n            }) +\n            '</table>' +\n            '</div>' +\n            '<div class=\"fc-content-skeleton\">' +\n            '<table>' +\n            (this.getIsNumbersVisible() ?\n                '<thead>' +\n                    this.renderNumberTrHtml(row) +\n                    '</thead>' :\n                '') +\n            '</table>' +\n            '</div>' +\n            '</div>';\n    };\n    DayGrid.prototype.getIsNumbersVisible = function () {\n        return this.getIsDayNumbersVisible() ||\n            this.renderProps.cellWeekNumbersVisible ||\n            this.renderProps.colWeekNumbersVisible;\n    };\n    DayGrid.prototype.getIsDayNumbersVisible = function () {\n        return this.rowCnt > 1;\n    };\n    /* Grid Number Rendering\n    ------------------------------------------------------------------------------------------------------------------*/\n    DayGrid.prototype.renderNumberTrHtml = function (row) {\n        var isRtl = this.context.isRtl;\n        var intro = this.renderProps.renderNumberIntroHtml(row, this);\n        return '' +\n            '<tr>' +\n            (isRtl ? '' : intro) +\n            this.renderNumberCellsHtml(row) +\n            (isRtl ? intro : '') +\n            '</tr>';\n    };\n    DayGrid.prototype.renderNumberCellsHtml = function (row) {\n        var htmls = [];\n        var col;\n        var date;\n        for (col = 0; col < this.colCnt; col++) {\n            date = this.props.cells[row][col].date;\n            htmls.push(this.renderNumberCellHtml(date));\n        }\n        if (this.context.isRtl) {\n            htmls.reverse();\n        }\n        return htmls.join('');\n    };\n    // Generates the HTML for the <td>s of the \"number\" row in the DayGrid's content skeleton.\n    // The number row will only exist if either day numbers or week numbers are turned on.\n    DayGrid.prototype.renderNumberCellHtml = function (date) {\n        var _a = this.context, dateEnv = _a.dateEnv, options = _a.options;\n        var html = '';\n        var isDateValid = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"rangeContainsMarker\"])(this.props.dateProfile.activeRange, date); // TODO: called too frequently. cache somehow.\n        var isDayNumberVisible = this.getIsDayNumbersVisible() && isDateValid;\n        var classes;\n        var weekCalcFirstDow;\n        if (!isDayNumberVisible && !this.renderProps.cellWeekNumbersVisible) {\n            // no numbers in day cell (week number must be along the side)\n            return '<td></td>'; //  will create an empty space above events :(\n        }\n        classes = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"getDayClasses\"])(date, this.props.dateProfile, this.context);\n        classes.unshift('fc-day-top');\n        if (this.renderProps.cellWeekNumbersVisible) {\n            weekCalcFirstDow = dateEnv.weekDow;\n        }\n        html += '<td class=\"' + classes.join(' ') + '\"' +\n            (isDateValid ?\n                ' data-date=\"' + dateEnv.formatIso(date, { omitTime: true }) + '\"' :\n                '') +\n            '>';\n        if (this.renderProps.cellWeekNumbersVisible && (date.getUTCDay() === weekCalcFirstDow)) {\n            html += Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"buildGotoAnchorHtml\"])(options, dateEnv, { date: date, type: 'week' }, { 'class': 'fc-week-number' }, dateEnv.format(date, WEEK_NUM_FORMAT) // inner HTML\n            );\n        }\n        if (isDayNumberVisible) {\n            html += Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"buildGotoAnchorHtml\"])(options, dateEnv, date, { 'class': 'fc-day-number' }, dateEnv.format(date, DAY_NUM_FORMAT) // inner HTML\n            );\n        }\n        html += '</td>';\n        return html;\n    };\n    /* Sizing\n    ------------------------------------------------------------------------------------------------------------------*/\n    DayGrid.prototype.updateSize = function (isResize) {\n        var calendar = this.context.calendar;\n        var _a = this, fillRenderer = _a.fillRenderer, eventRenderer = _a.eventRenderer, mirrorRenderer = _a.mirrorRenderer;\n        if (isResize ||\n            this.isCellSizesDirty ||\n            calendar.isEventsUpdated // hack\n        ) {\n            this.buildPositionCaches();\n            this.isCellSizesDirty = false;\n        }\n        fillRenderer.computeSizes(isResize);\n        eventRenderer.computeSizes(isResize);\n        mirrorRenderer.computeSizes(isResize);\n        fillRenderer.assignSizes(isResize);\n        eventRenderer.assignSizes(isResize);\n        mirrorRenderer.assignSizes(isResize);\n    };\n    DayGrid.prototype.buildPositionCaches = function () {\n        this.buildColPositions();\n        this.buildRowPositions();\n    };\n    DayGrid.prototype.buildColPositions = function () {\n        this.colPositions.build();\n    };\n    DayGrid.prototype.buildRowPositions = function () {\n        this.rowPositions.build();\n        this.rowPositions.bottoms[this.rowCnt - 1] += this.bottomCoordPadding; // hack\n    };\n    /* Hit System\n    ------------------------------------------------------------------------------------------------------------------*/\n    DayGrid.prototype.positionToHit = function (leftPosition, topPosition) {\n        var _a = this, colPositions = _a.colPositions, rowPositions = _a.rowPositions;\n        var col = colPositions.leftToIndex(leftPosition);\n        var row = rowPositions.topToIndex(topPosition);\n        if (row != null && col != null) {\n            return {\n                row: row,\n                col: col,\n                dateSpan: {\n                    range: this.getCellRange(row, col),\n                    allDay: true\n                },\n                dayEl: this.getCellEl(row, col),\n                relativeRect: {\n                    left: colPositions.lefts[col],\n                    right: colPositions.rights[col],\n                    top: rowPositions.tops[row],\n                    bottom: rowPositions.bottoms[row]\n                }\n            };\n        }\n    };\n    /* Cell System\n    ------------------------------------------------------------------------------------------------------------------*/\n    // FYI: the first column is the leftmost column, regardless of date\n    DayGrid.prototype.getCellEl = function (row, col) {\n        return this.cellEls[row * this.colCnt + col];\n    };\n    /* Event Drag Visualization\n    ------------------------------------------------------------------------------------------------------------------*/\n    DayGrid.prototype._renderEventDrag = function (state) {\n        if (state) {\n            this.eventRenderer.hideByHash(state.affectedInstances);\n            this.fillRenderer.renderSegs('highlight', this.context, state.segs);\n        }\n    };\n    DayGrid.prototype._unrenderEventDrag = function (state) {\n        if (state) {\n            this.eventRenderer.showByHash(state.affectedInstances);\n            this.fillRenderer.unrender('highlight', this.context);\n        }\n    };\n    /* Event Resize Visualization\n    ------------------------------------------------------------------------------------------------------------------*/\n    DayGrid.prototype._renderEventResize = function (state) {\n        if (state) {\n            this.eventRenderer.hideByHash(state.affectedInstances);\n            this.fillRenderer.renderSegs('highlight', this.context, state.segs);\n            this.mirrorRenderer.renderSegs(this.context, state.segs, { isResizing: true, sourceSeg: state.sourceSeg });\n        }\n    };\n    DayGrid.prototype._unrenderEventResize = function (state) {\n        if (state) {\n            this.eventRenderer.showByHash(state.affectedInstances);\n            this.fillRenderer.unrender('highlight', this.context);\n            this.mirrorRenderer.unrender(this.context, state.segs, { isResizing: true, sourceSeg: state.sourceSeg });\n        }\n    };\n    /* More+ Link Popover\n    ------------------------------------------------------------------------------------------------------------------*/\n    DayGrid.prototype.removeSegPopover = function () {\n        if (this.segPopover) {\n            this.segPopover.hide(); // in handler, will call segPopover's removeElement\n        }\n    };\n    // Limits the number of \"levels\" (vertically stacking layers of events) for each row of the grid.\n    // `levelLimit` can be false (don't limit), a number, or true (should be computed).\n    DayGrid.prototype.limitRows = function (levelLimit) {\n        var rowStructs = this.eventRenderer.rowStructs || [];\n        var row; // row #\n        var rowLevelLimit;\n        for (row = 0; row < rowStructs.length; row++) {\n            this.unlimitRow(row);\n            if (!levelLimit) {\n                rowLevelLimit = false;\n            }\n            else if (typeof levelLimit === 'number') {\n                rowLevelLimit = levelLimit;\n            }\n            else {\n                rowLevelLimit = this.computeRowLevelLimit(row);\n            }\n            if (rowLevelLimit !== false) {\n                this.limitRow(row, rowLevelLimit);\n            }\n        }\n    };\n    // Computes the number of levels a row will accomodate without going outside its bounds.\n    // Assumes the row is \"rigid\" (maintains a constant height regardless of what is inside).\n    // `row` is the row number.\n    DayGrid.prototype.computeRowLevelLimit = function (row) {\n        var rowEl = this.rowEls[row]; // the containing \"fake\" row div\n        var rowBottom = rowEl.getBoundingClientRect().bottom; // relative to viewport!\n        var trEls = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findChildren\"])(this.eventRenderer.rowStructs[row].tbodyEl);\n        var i;\n        var trEl;\n        // Reveal one level <tr> at a time and stop when we find one out of bounds\n        for (i = 0; i < trEls.length; i++) {\n            trEl = trEls[i];\n            trEl.classList.remove('fc-limited'); // reset to original state (reveal)\n            if (trEl.getBoundingClientRect().bottom > rowBottom) {\n                return i;\n            }\n        }\n        return false; // should not limit at all\n    };\n    // Limits the given grid row to the maximum number of levels and injects \"more\" links if necessary.\n    // `row` is the row number.\n    // `levelLimit` is a number for the maximum (inclusive) number of levels allowed.\n    DayGrid.prototype.limitRow = function (row, levelLimit) {\n        var _this = this;\n        var colCnt = this.colCnt;\n        var isRtl = this.context.isRtl;\n        var rowStruct = this.eventRenderer.rowStructs[row];\n        var moreNodes = []; // array of \"more\" <a> links and <td> DOM nodes\n        var col = 0; // col #, left-to-right (not chronologically)\n        var levelSegs; // array of segment objects in the last allowable level, ordered left-to-right\n        var cellMatrix; // a matrix (by level, then column) of all <td> elements in the row\n        var limitedNodes; // array of temporarily hidden level <tr> and segment <td> DOM nodes\n        var i;\n        var seg;\n        var segsBelow; // array of segment objects below `seg` in the current `col`\n        var totalSegsBelow; // total number of segments below `seg` in any of the columns `seg` occupies\n        var colSegsBelow; // array of segment arrays, below seg, one for each column (offset from segs's first column)\n        var td;\n        var rowSpan;\n        var segMoreNodes; // array of \"more\" <td> cells that will stand-in for the current seg's cell\n        var j;\n        var moreTd;\n        var moreWrap;\n        var moreLink;\n        // Iterates through empty level cells and places \"more\" links inside if need be\n        var emptyCellsUntil = function (endCol) {\n            while (col < endCol) {\n                segsBelow = _this.getCellSegs(row, col, levelLimit);\n                if (segsBelow.length) {\n                    td = cellMatrix[levelLimit - 1][col];\n                    moreLink = _this.renderMoreLink(row, col, segsBelow);\n                    moreWrap = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createElement\"])('div', null, moreLink);\n                    td.appendChild(moreWrap);\n                    moreNodes.push(moreWrap);\n                }\n                col++;\n            }\n        };\n        if (levelLimit && levelLimit < rowStruct.segLevels.length) { // is it actually over the limit?\n            levelSegs = rowStruct.segLevels[levelLimit - 1];\n            cellMatrix = rowStruct.cellMatrix;\n            limitedNodes = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findChildren\"])(rowStruct.tbodyEl).slice(levelLimit); // get level <tr> elements past the limit\n            limitedNodes.forEach(function (node) {\n                node.classList.add('fc-limited'); // hide elements and get a simple DOM-nodes array\n            });\n            // iterate though segments in the last allowable level\n            for (i = 0; i < levelSegs.length; i++) {\n                seg = levelSegs[i];\n                var leftCol = isRtl ? (colCnt - 1 - seg.lastCol) : seg.firstCol;\n                var rightCol = isRtl ? (colCnt - 1 - seg.firstCol) : seg.lastCol;\n                emptyCellsUntil(leftCol); // process empty cells before the segment\n                // determine *all* segments below `seg` that occupy the same columns\n                colSegsBelow = [];\n                totalSegsBelow = 0;\n                while (col <= rightCol) {\n                    segsBelow = this.getCellSegs(row, col, levelLimit);\n                    colSegsBelow.push(segsBelow);\n                    totalSegsBelow += segsBelow.length;\n                    col++;\n                }\n                if (totalSegsBelow) { // do we need to replace this segment with one or many \"more\" links?\n                    td = cellMatrix[levelLimit - 1][leftCol]; // the segment's parent cell\n                    rowSpan = td.rowSpan || 1;\n                    segMoreNodes = [];\n                    // make a replacement <td> for each column the segment occupies. will be one for each colspan\n                    for (j = 0; j < colSegsBelow.length; j++) {\n                        moreTd = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createElement\"])('td', { className: 'fc-more-cell', rowSpan: rowSpan });\n                        segsBelow = colSegsBelow[j];\n                        moreLink = this.renderMoreLink(row, leftCol + j, [seg].concat(segsBelow) // count seg as hidden too\n                        );\n                        moreWrap = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createElement\"])('div', null, moreLink);\n                        moreTd.appendChild(moreWrap);\n                        segMoreNodes.push(moreTd);\n                        moreNodes.push(moreTd);\n                    }\n                    td.classList.add('fc-limited');\n                    Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"insertAfterElement\"])(td, segMoreNodes);\n                    limitedNodes.push(td);\n                }\n            }\n            emptyCellsUntil(this.colCnt); // finish off the level\n            rowStruct.moreEls = moreNodes; // for easy undoing later\n            rowStruct.limitedEls = limitedNodes; // for easy undoing later\n        }\n    };\n    // Reveals all levels and removes all \"more\"-related elements for a grid's row.\n    // `row` is a row number.\n    DayGrid.prototype.unlimitRow = function (row) {\n        var rowStruct = this.eventRenderer.rowStructs[row];\n        if (rowStruct.moreEls) {\n            rowStruct.moreEls.forEach(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"removeElement\"]);\n            rowStruct.moreEls = null;\n        }\n        if (rowStruct.limitedEls) {\n            rowStruct.limitedEls.forEach(function (limitedEl) {\n                limitedEl.classList.remove('fc-limited');\n            });\n            rowStruct.limitedEls = null;\n        }\n    };\n    // Renders an <a> element that represents hidden event element for a cell.\n    // Responsible for attaching click handler as well.\n    DayGrid.prototype.renderMoreLink = function (row, col, hiddenSegs) {\n        var _this = this;\n        var _a = this.context, calendar = _a.calendar, view = _a.view, dateEnv = _a.dateEnv, options = _a.options, isRtl = _a.isRtl;\n        var a = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createElement\"])('a', { className: 'fc-more' });\n        a.innerText = this.getMoreLinkText(hiddenSegs.length);\n        a.addEventListener('click', function (ev) {\n            var clickOption = options.eventLimitClick;\n            var _col = isRtl ? _this.colCnt - col - 1 : col; // HACK: props.cells has different dir system?\n            var date = _this.props.cells[row][_col].date;\n            var moreEl = ev.currentTarget;\n            var dayEl = _this.getCellEl(row, col);\n            var allSegs = _this.getCellSegs(row, col);\n            // rescope the segments to be within the cell's date\n            var reslicedAllSegs = _this.resliceDaySegs(allSegs, date);\n            var reslicedHiddenSegs = _this.resliceDaySegs(hiddenSegs, date);\n            if (typeof clickOption === 'function') {\n                // the returned value can be an atomic option\n                clickOption = calendar.publiclyTrigger('eventLimitClick', [\n                    {\n                        date: dateEnv.toDate(date),\n                        allDay: true,\n                        dayEl: dayEl,\n                        moreEl: moreEl,\n                        segs: reslicedAllSegs,\n                        hiddenSegs: reslicedHiddenSegs,\n                        jsEvent: ev,\n                        view: view\n                    }\n                ]);\n            }\n            if (clickOption === 'popover') {\n                _this.showSegPopover(row, col, moreEl, reslicedAllSegs);\n            }\n            else if (typeof clickOption === 'string') { // a view name\n                calendar.zoomTo(date, clickOption);\n            }\n        });\n        return a;\n    };\n    // Reveals the popover that displays all events within a cell\n    DayGrid.prototype.showSegPopover = function (row, col, moreLink, segs) {\n        var _this = this;\n        var _a = this.context, calendar = _a.calendar, view = _a.view, theme = _a.theme, isRtl = _a.isRtl;\n        var _col = isRtl ? this.colCnt - col - 1 : col; // HACK: props.cells has different dir system?\n        var moreWrap = moreLink.parentNode; // the <div> wrapper around the <a>\n        var topEl; // the element we want to match the top coordinate of\n        var options;\n        if (this.rowCnt === 1) {\n            topEl = view.el; // will cause the popover to cover any sort of header\n        }\n        else {\n            topEl = this.rowEls[row]; // will align with top of row\n        }\n        options = {\n            className: 'fc-more-popover ' + theme.getClass('popover'),\n            parentEl: view.el,\n            top: Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeRect\"])(topEl).top,\n            autoHide: true,\n            content: function (el) {\n                _this.segPopoverTile = new DayTile(el);\n                _this.updateSegPopoverTile(_this.props.cells[row][_col].date, segs);\n            },\n            hide: function () {\n                _this.segPopoverTile.destroy();\n                _this.segPopoverTile = null;\n                _this.segPopover.destroy();\n                _this.segPopover = null;\n            }\n        };\n        // Determine horizontal coordinate.\n        // We use the moreWrap instead of the <td> to avoid border confusion.\n        if (isRtl) {\n            options.right = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeRect\"])(moreWrap).right + 1; // +1 to be over cell border\n        }\n        else {\n            options.left = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeRect\"])(moreWrap).left - 1; // -1 to be over cell border\n        }\n        this.segPopover = new Popover(options);\n        this.segPopover.show();\n        calendar.releaseAfterSizingTriggers(); // hack for eventPositioned\n    };\n    // Given the events within an array of segment objects, reslice them to be in a single day\n    DayGrid.prototype.resliceDaySegs = function (segs, dayDate) {\n        var dayStart = dayDate;\n        var dayEnd = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"addDays\"])(dayStart, 1);\n        var dayRange = { start: dayStart, end: dayEnd };\n        var newSegs = [];\n        for (var _i = 0, segs_1 = segs; _i < segs_1.length; _i++) {\n            var seg = segs_1[_i];\n            var eventRange = seg.eventRange;\n            var origRange = eventRange.range;\n            var slicedRange = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"intersectRanges\"])(origRange, dayRange);\n            if (slicedRange) {\n                newSegs.push(__assign({}, seg, { eventRange: {\n                        def: eventRange.def,\n                        ui: __assign({}, eventRange.ui, { durationEditable: false }),\n                        instance: eventRange.instance,\n                        range: slicedRange\n                    }, isStart: seg.isStart && slicedRange.start.valueOf() === origRange.start.valueOf(), isEnd: seg.isEnd && slicedRange.end.valueOf() === origRange.end.valueOf() }));\n            }\n        }\n        return newSegs;\n    };\n    // Generates the text that should be inside a \"more\" link, given the number of events it represents\n    DayGrid.prototype.getMoreLinkText = function (num) {\n        var opt = this.context.options.eventLimitText;\n        if (typeof opt === 'function') {\n            return opt(num);\n        }\n        else {\n            return '+' + num + ' ' + opt;\n        }\n    };\n    // Returns segments within a given cell.\n    // If `startLevel` is specified, returns only events including and below that level. Otherwise returns all segs.\n    DayGrid.prototype.getCellSegs = function (row, col, startLevel) {\n        var segMatrix = this.eventRenderer.rowStructs[row].segMatrix;\n        var level = startLevel || 0;\n        var segs = [];\n        var seg;\n        while (level < segMatrix.length) {\n            seg = segMatrix[level][col];\n            if (seg) {\n                segs.push(seg);\n            }\n            level++;\n        }\n        return segs;\n    };\n    return DayGrid;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"DateComponent\"]));\n\nvar WEEK_NUM_FORMAT$1 = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createFormatter\"])({ week: 'numeric' });\n/* An abstract class for the daygrid views, as well as month view. Renders one or more rows of day cells.\n----------------------------------------------------------------------------------------------------------------------*/\n// It is a manager for a DayGrid subcomponent, which does most of the heavy lifting.\n// It is responsible for managing width/height.\nvar AbstractDayGridView = /** @class */ (function (_super) {\n    __extends(AbstractDayGridView, _super);\n    function AbstractDayGridView() {\n        var _this = _super !== null && _super.apply(this, arguments) || this;\n        _this.processOptions = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoize\"])(_this._processOptions);\n        _this.renderSkeleton = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderSkeleton, _this._unrenderSkeleton);\n        /* Header Rendering\n        ------------------------------------------------------------------------------------------------------------------*/\n        // Generates the HTML that will go before the day-of week header cells\n        _this.renderHeadIntroHtml = function () {\n            var _a = _this.context, theme = _a.theme, options = _a.options;\n            if (_this.colWeekNumbersVisible) {\n                return '' +\n                    '<th class=\"fc-week-number ' + theme.getClass('widgetHeader') + '\" ' + _this.weekNumberStyleAttr() + '>' +\n                    '<span>' + // needed for matchCellWidths\n                    Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(options.weekLabel) +\n                    '</span>' +\n                    '</th>';\n            }\n            return '';\n        };\n        /* Day Grid Rendering\n        ------------------------------------------------------------------------------------------------------------------*/\n        // Generates the HTML that will go before content-skeleton cells that display the day/week numbers\n        _this.renderDayGridNumberIntroHtml = function (row, dayGrid) {\n            var _a = _this.context, options = _a.options, dateEnv = _a.dateEnv;\n            var weekStart = dayGrid.props.cells[row][0].date;\n            if (_this.colWeekNumbersVisible) {\n                return '' +\n                    '<td class=\"fc-week-number\" ' + _this.weekNumberStyleAttr() + '>' +\n                    Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"buildGotoAnchorHtml\"])(// aside from link, important for matchCellWidths\n                    options, dateEnv, { date: weekStart, type: 'week', forceOff: dayGrid.colCnt === 1 }, dateEnv.format(weekStart, WEEK_NUM_FORMAT$1) // inner HTML\n                    ) +\n                    '</td>';\n            }\n            return '';\n        };\n        // Generates the HTML that goes before the day bg cells for each day-row\n        _this.renderDayGridBgIntroHtml = function () {\n            var theme = _this.context.theme;\n            if (_this.colWeekNumbersVisible) {\n                return '<td class=\"fc-week-number ' + theme.getClass('widgetContent') + '\" ' + _this.weekNumberStyleAttr() + '></td>';\n            }\n            return '';\n        };\n        // Generates the HTML that goes before every other type of row generated by DayGrid.\n        // Affects mirror-skeleton and highlight-skeleton rows.\n        _this.renderDayGridIntroHtml = function () {\n            if (_this.colWeekNumbersVisible) {\n                return '<td class=\"fc-week-number\" ' + _this.weekNumberStyleAttr() + '></td>';\n            }\n            return '';\n        };\n        return _this;\n    }\n    AbstractDayGridView.prototype._processOptions = function (options) {\n        if (options.weekNumbers) {\n            if (options.weekNumbersWithinDays) {\n                this.cellWeekNumbersVisible = true;\n                this.colWeekNumbersVisible = false;\n            }\n            else {\n                this.cellWeekNumbersVisible = false;\n                this.colWeekNumbersVisible = true;\n            }\n        }\n        else {\n            this.colWeekNumbersVisible = false;\n            this.cellWeekNumbersVisible = false;\n        }\n    };\n    AbstractDayGridView.prototype.render = function (props, context) {\n        _super.prototype.render.call(this, props, context);\n        this.processOptions(context.options);\n        this.renderSkeleton(context);\n    };\n    AbstractDayGridView.prototype.destroy = function () {\n        _super.prototype.destroy.call(this);\n        this.renderSkeleton.unrender();\n    };\n    AbstractDayGridView.prototype._renderSkeleton = function (context) {\n        this.el.classList.add('fc-dayGrid-view');\n        this.el.innerHTML = this.renderSkeletonHtml();\n        this.scroller = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"ScrollComponent\"]('hidden', // overflow x\n        'auto' // overflow y\n        );\n        var dayGridContainerEl = this.scroller.el;\n        this.el.querySelector('.fc-body > tr > td').appendChild(dayGridContainerEl);\n        dayGridContainerEl.classList.add('fc-day-grid-container');\n        var dayGridEl = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createElement\"])('div', { className: 'fc-day-grid' });\n        dayGridContainerEl.appendChild(dayGridEl);\n        this.dayGrid = new DayGrid(dayGridEl, {\n            renderNumberIntroHtml: this.renderDayGridNumberIntroHtml,\n            renderBgIntroHtml: this.renderDayGridBgIntroHtml,\n            renderIntroHtml: this.renderDayGridIntroHtml,\n            colWeekNumbersVisible: this.colWeekNumbersVisible,\n            cellWeekNumbersVisible: this.cellWeekNumbersVisible\n        });\n    };\n    AbstractDayGridView.prototype._unrenderSkeleton = function () {\n        this.el.classList.remove('fc-dayGrid-view');\n        this.dayGrid.destroy();\n        this.scroller.destroy();\n    };\n    // Builds the HTML skeleton for the view.\n    // The day-grid component will render inside of a container defined by this HTML.\n    AbstractDayGridView.prototype.renderSkeletonHtml = function () {\n        var _a = this.context, theme = _a.theme, options = _a.options;\n        return '' +\n            '<table class=\"' + theme.getClass('tableGrid') + '\">' +\n            (options.columnHeader ?\n                '<thead class=\"fc-head\">' +\n                    '<tr>' +\n                    '<td class=\"fc-head-container ' + theme.getClass('widgetHeader') + '\">&nbsp;</td>' +\n                    '</tr>' +\n                    '</thead>' :\n                '') +\n            '<tbody class=\"fc-body\">' +\n            '<tr>' +\n            '<td class=\"' + theme.getClass('widgetContent') + '\"></td>' +\n            '</tr>' +\n            '</tbody>' +\n            '</table>';\n    };\n    // Generates an HTML attribute string for setting the width of the week number column, if it is known\n    AbstractDayGridView.prototype.weekNumberStyleAttr = function () {\n        if (this.weekNumberWidth != null) {\n            return 'style=\"width:' + this.weekNumberWidth + 'px\"';\n        }\n        return '';\n    };\n    // Determines whether each row should have a constant height\n    AbstractDayGridView.prototype.hasRigidRows = function () {\n        var eventLimit = this.context.options.eventLimit;\n        return eventLimit && typeof eventLimit !== 'number';\n    };\n    /* Dimensions\n    ------------------------------------------------------------------------------------------------------------------*/\n    AbstractDayGridView.prototype.updateSize = function (isResize, viewHeight, isAuto) {\n        _super.prototype.updateSize.call(this, isResize, viewHeight, isAuto); // will call updateBaseSize. important that executes first\n        this.dayGrid.updateSize(isResize);\n    };\n    // Refreshes the horizontal dimensions of the view\n    AbstractDayGridView.prototype.updateBaseSize = function (isResize, viewHeight, isAuto) {\n        var dayGrid = this.dayGrid;\n        var eventLimit = this.context.options.eventLimit;\n        var headRowEl = this.header ? this.header.el : null; // HACK\n        var scrollerHeight;\n        var scrollbarWidths;\n        // hack to give the view some height prior to dayGrid's columns being rendered\n        // TODO: separate setting height from scroller VS dayGrid.\n        if (!dayGrid.rowEls) {\n            if (!isAuto) {\n                scrollerHeight = this.computeScrollerHeight(viewHeight);\n                this.scroller.setHeight(scrollerHeight);\n            }\n            return;\n        }\n        if (this.colWeekNumbersVisible) {\n            // Make sure all week number cells running down the side have the same width.\n            this.weekNumberWidth = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"matchCellWidths\"])(Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(this.el, '.fc-week-number'));\n        }\n        // reset all heights to be natural\n        this.scroller.clear();\n        if (headRowEl) {\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"uncompensateScroll\"])(headRowEl);\n        }\n        dayGrid.removeSegPopover(); // kill the \"more\" popover if displayed\n        // is the event limit a constant level number?\n        if (eventLimit && typeof eventLimit === 'number') {\n            dayGrid.limitRows(eventLimit); // limit the levels first so the height can redistribute after\n        }\n        // distribute the height to the rows\n        // (viewHeight is a \"recommended\" value if isAuto)\n        scrollerHeight = this.computeScrollerHeight(viewHeight);\n        this.setGridHeight(scrollerHeight, isAuto);\n        // is the event limit dynamically calculated?\n        if (eventLimit && typeof eventLimit !== 'number') {\n            dayGrid.limitRows(eventLimit); // limit the levels after the grid's row heights have been set\n        }\n        if (!isAuto) { // should we force dimensions of the scroll container?\n            this.scroller.setHeight(scrollerHeight);\n            scrollbarWidths = this.scroller.getScrollbarWidths();\n            if (scrollbarWidths.left || scrollbarWidths.right) { // using scrollbars?\n                if (headRowEl) {\n                    Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"compensateScroll\"])(headRowEl, scrollbarWidths);\n                }\n                // doing the scrollbar compensation might have created text overflow which created more height. redo\n                scrollerHeight = this.computeScrollerHeight(viewHeight);\n                this.scroller.setHeight(scrollerHeight);\n            }\n            // guarantees the same scrollbar widths\n            this.scroller.lockOverflow(scrollbarWidths);\n        }\n    };\n    // given a desired total height of the view, returns what the height of the scroller should be\n    AbstractDayGridView.prototype.computeScrollerHeight = function (viewHeight) {\n        return viewHeight -\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"subtractInnerElHeight\"])(this.el, this.scroller.el); // everything that's NOT the scroller\n    };\n    // Sets the height of just the DayGrid component in this view\n    AbstractDayGridView.prototype.setGridHeight = function (height, isAuto) {\n        if (this.context.options.monthMode) {\n            // if auto, make the height of each row the height that it would be if there were 6 weeks\n            if (isAuto) {\n                height *= this.dayGrid.rowCnt / 6;\n            }\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"distributeHeight\"])(this.dayGrid.rowEls, height, !isAuto); // if auto, don't compensate for height-hogging rows\n        }\n        else {\n            if (isAuto) {\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"undistributeHeight\"])(this.dayGrid.rowEls); // let the rows be their natural height with no expanding\n            }\n            else {\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"distributeHeight\"])(this.dayGrid.rowEls, height, true); // true = compensate for height-hogging rows\n            }\n        }\n    };\n    /* Scroll\n    ------------------------------------------------------------------------------------------------------------------*/\n    AbstractDayGridView.prototype.computeDateScroll = function (duration) {\n        return { top: 0 };\n    };\n    AbstractDayGridView.prototype.queryDateScroll = function () {\n        return { top: this.scroller.getScrollTop() };\n    };\n    AbstractDayGridView.prototype.applyDateScroll = function (scroll) {\n        if (scroll.top !== undefined) {\n            this.scroller.setScrollTop(scroll.top);\n        }\n    };\n    return AbstractDayGridView;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"View\"]));\nAbstractDayGridView.prototype.dateProfileGeneratorClass = DayGridDateProfileGenerator;\n\nvar SimpleDayGrid = /** @class */ (function (_super) {\n    __extends(SimpleDayGrid, _super);\n    function SimpleDayGrid(dayGrid) {\n        var _this = _super.call(this, dayGrid.el) || this;\n        _this.slicer = new DayGridSlicer();\n        _this.dayGrid = dayGrid;\n        return _this;\n    }\n    SimpleDayGrid.prototype.firstContext = function (context) {\n        context.calendar.registerInteractiveComponent(this, { el: this.dayGrid.el });\n    };\n    SimpleDayGrid.prototype.destroy = function () {\n        _super.prototype.destroy.call(this);\n        this.context.calendar.unregisterInteractiveComponent(this);\n    };\n    SimpleDayGrid.prototype.render = function (props, context) {\n        var dayGrid = this.dayGrid;\n        var dateProfile = props.dateProfile, dayTable = props.dayTable;\n        dayGrid.receiveContext(context); // hack because context is used in sliceProps\n        dayGrid.receiveProps(__assign({}, this.slicer.sliceProps(props, dateProfile, props.nextDayThreshold, context.calendar, dayGrid, dayTable), { dateProfile: dateProfile, cells: dayTable.cells, isRigid: props.isRigid }), context);\n    };\n    SimpleDayGrid.prototype.buildPositionCaches = function () {\n        this.dayGrid.buildPositionCaches();\n    };\n    SimpleDayGrid.prototype.queryHit = function (positionLeft, positionTop) {\n        var rawHit = this.dayGrid.positionToHit(positionLeft, positionTop);\n        if (rawHit) {\n            return {\n                component: this.dayGrid,\n                dateSpan: rawHit.dateSpan,\n                dayEl: rawHit.dayEl,\n                rect: {\n                    left: rawHit.relativeRect.left,\n                    right: rawHit.relativeRect.right,\n                    top: rawHit.relativeRect.top,\n                    bottom: rawHit.relativeRect.bottom\n                },\n                layer: 0\n            };\n        }\n    };\n    return SimpleDayGrid;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"DateComponent\"]));\nvar DayGridSlicer = /** @class */ (function (_super) {\n    __extends(DayGridSlicer, _super);\n    function DayGridSlicer() {\n        return _super !== null && _super.apply(this, arguments) || this;\n    }\n    DayGridSlicer.prototype.sliceRange = function (dateRange, dayTable) {\n        return dayTable.sliceRange(dateRange);\n    };\n    return DayGridSlicer;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"Slicer\"]));\n\nvar DayGridView = /** @class */ (function (_super) {\n    __extends(DayGridView, _super);\n    function DayGridView() {\n        var _this = _super !== null && _super.apply(this, arguments) || this;\n        _this.buildDayTable = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoize\"])(buildDayTable);\n        return _this;\n    }\n    DayGridView.prototype.render = function (props, context) {\n        _super.prototype.render.call(this, props, context); // will call _renderSkeleton/_unrenderSkeleton\n        var dateProfile = this.props.dateProfile;\n        var dayTable = this.dayTable =\n            this.buildDayTable(dateProfile, props.dateProfileGenerator);\n        if (this.header) {\n            this.header.receiveProps({\n                dateProfile: dateProfile,\n                dates: dayTable.headerDates,\n                datesRepDistinctDays: dayTable.rowCnt === 1,\n                renderIntroHtml: this.renderHeadIntroHtml\n            }, context);\n        }\n        this.simpleDayGrid.receiveProps({\n            dateProfile: dateProfile,\n            dayTable: dayTable,\n            businessHours: props.businessHours,\n            dateSelection: props.dateSelection,\n            eventStore: props.eventStore,\n            eventUiBases: props.eventUiBases,\n            eventSelection: props.eventSelection,\n            eventDrag: props.eventDrag,\n            eventResize: props.eventResize,\n            isRigid: this.hasRigidRows(),\n            nextDayThreshold: this.context.nextDayThreshold\n        }, context);\n    };\n    DayGridView.prototype._renderSkeleton = function (context) {\n        _super.prototype._renderSkeleton.call(this, context);\n        if (context.options.columnHeader) {\n            this.header = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"DayHeader\"](this.el.querySelector('.fc-head-container'));\n        }\n        this.simpleDayGrid = new SimpleDayGrid(this.dayGrid);\n    };\n    DayGridView.prototype._unrenderSkeleton = function () {\n        _super.prototype._unrenderSkeleton.call(this);\n        if (this.header) {\n            this.header.destroy();\n        }\n        this.simpleDayGrid.destroy();\n    };\n    return DayGridView;\n}(AbstractDayGridView));\nfunction buildDayTable(dateProfile, dateProfileGenerator) {\n    var daySeries = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"DaySeries\"](dateProfile.renderRange, dateProfileGenerator);\n    return new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"DayTable\"](daySeries, /year|month|week/.test(dateProfile.currentRangeUnit));\n}\n\nvar main = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createPlugin\"])({\n    defaultView: 'dayGridMonth',\n    views: {\n        dayGrid: DayGridView,\n        dayGridDay: {\n            type: 'dayGrid',\n            duration: { days: 1 }\n        },\n        dayGridWeek: {\n            type: 'dayGrid',\n            duration: { weeks: 1 }\n        },\n        dayGridMonth: {\n            type: 'dayGrid',\n            duration: { months: 1 },\n            monthMode: true,\n            fixedWeekCount: true\n        }\n    }\n});\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (main);\n\n\n\n//# sourceURL=webpack:///./node_modules/@fullcalendar/daygrid/main.esm.js?");

/***/ }),

/***/ "./node_modules/@fullcalendar/google-calendar/main.esm.js":
/*!****************************************************************!*\
  !*** ./node_modules/@fullcalendar/google-calendar/main.esm.js ***!
  \****************************************************************/
/*! exports provided: default */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @fullcalendar/core */ \"./node_modules/@fullcalendar/core/main.esm.js\");\n/*!\nFullCalendar Google Calendar Plugin v4.4.2\nDocs & License: https://fullcalendar.io/\n(c) 2019 Adam Shaw\n*/\n\n\n\n/*! *****************************************************************************\r\nCopyright (c) Microsoft Corporation.\r\n\r\nPermission to use, copy, modify, and/or distribute this software for any\r\npurpose with or without fee is hereby granted.\r\n\r\nTHE SOFTWARE IS PROVIDED \"AS IS\" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH\r\nREGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY\r\nAND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,\r\nINDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM\r\nLOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR\r\nOTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR\r\nPERFORMANCE OF THIS SOFTWARE.\r\n***************************************************************************** */\r\n\r\nvar __assign = function() {\r\n    __assign = Object.assign || function __assign(t) {\r\n        for (var s, i = 1, n = arguments.length; i < n; i++) {\r\n            s = arguments[i];\r\n            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];\r\n        }\r\n        return t;\r\n    };\r\n    return __assign.apply(this, arguments);\r\n};\n\n// TODO: expose somehow\nvar API_BASE = 'https://www.googleapis.com/calendar/v3/calendars';\nvar STANDARD_PROPS = {\n    url: String,\n    googleCalendarApiKey: String,\n    googleCalendarId: String,\n    googleCalendarApiBase: String,\n    data: null\n};\nvar eventSourceDef = {\n    parseMeta: function (raw) {\n        if (typeof raw === 'string') {\n            raw = { url: raw };\n        }\n        if (typeof raw === 'object') {\n            var standardProps = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"refineProps\"])(raw, STANDARD_PROPS);\n            if (!standardProps.googleCalendarId && standardProps.url) {\n                standardProps.googleCalendarId = parseGoogleCalendarId(standardProps.url);\n            }\n            delete standardProps.url;\n            if (standardProps.googleCalendarId) {\n                return standardProps;\n            }\n        }\n        return null;\n    },\n    fetch: function (arg, onSuccess, onFailure) {\n        var calendar = arg.calendar;\n        var meta = arg.eventSource.meta;\n        var apiKey = meta.googleCalendarApiKey || calendar.opt('googleCalendarApiKey');\n        if (!apiKey) {\n            onFailure({\n                message: 'Specify a googleCalendarApiKey. See http://fullcalendar.io/docs/google_calendar/'\n            });\n        }\n        else {\n            var url = buildUrl(meta);\n            var requestParams_1 = buildRequestParams(arg.range, apiKey, meta.data, calendar.dateEnv);\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"requestJson\"])('GET', url, requestParams_1, function (body, xhr) {\n                if (body.error) {\n                    onFailure({\n                        message: 'Google Calendar API: ' + body.error.message,\n                        errors: body.error.errors,\n                        xhr: xhr\n                    });\n                }\n                else {\n                    onSuccess({\n                        rawEvents: gcalItemsToRawEventDefs(body.items, requestParams_1.timeZone),\n                        xhr: xhr\n                    });\n                }\n            }, function (message, xhr) {\n                onFailure({ message: message, xhr: xhr });\n            });\n        }\n    }\n};\nfunction parseGoogleCalendarId(url) {\n    var match;\n    // detect if the ID was specified as a single string.\n    // will match calendars like \"asdf1234@calendar.google.com\" in addition to person email calendars.\n    if (/^[^\\/]+@([^\\/\\.]+\\.)*(google|googlemail|gmail)\\.com$/.test(url)) {\n        return url;\n    }\n    else if ((match = /^https:\\/\\/www.googleapis.com\\/calendar\\/v3\\/calendars\\/([^\\/]*)/.exec(url)) ||\n        (match = /^https?:\\/\\/www.google.com\\/calendar\\/feeds\\/([^\\/]*)/.exec(url))) {\n        return decodeURIComponent(match[1]);\n    }\n}\nfunction buildUrl(meta) {\n    var apiBase = meta.googleCalendarApiBase;\n    if (!apiBase) {\n        apiBase = API_BASE;\n    }\n    return apiBase + '/' + encodeURIComponent(meta.googleCalendarId) + '/events';\n}\nfunction buildRequestParams(range, apiKey, extraParams, dateEnv) {\n    var params;\n    var startStr;\n    var endStr;\n    if (dateEnv.canComputeOffset) {\n        // strings will naturally have offsets, which GCal needs\n        startStr = dateEnv.formatIso(range.start);\n        endStr = dateEnv.formatIso(range.end);\n    }\n    else {\n        // when timezone isn't known, we don't know what the UTC offset should be, so ask for +/- 1 day\n        // from the UTC day-start to guarantee we're getting all the events\n        // (start/end will be UTC-coerced dates, so toISOString is okay)\n        startStr = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"addDays\"])(range.start, -1).toISOString();\n        endStr = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"addDays\"])(range.end, 1).toISOString();\n    }\n    params = __assign({}, (extraParams || {}), { key: apiKey, timeMin: startStr, timeMax: endStr, singleEvents: true, maxResults: 9999 });\n    if (dateEnv.timeZone !== 'local') {\n        params.timeZone = dateEnv.timeZone;\n    }\n    return params;\n}\nfunction gcalItemsToRawEventDefs(items, gcalTimezone) {\n    return items.map(function (item) {\n        return gcalItemToRawEventDef(item, gcalTimezone);\n    });\n}\nfunction gcalItemToRawEventDef(item, gcalTimezone) {\n    var url = item.htmlLink || null;\n    // make the URLs for each event show times in the correct timezone\n    if (url && gcalTimezone) {\n        url = injectQsComponent(url, 'ctz=' + gcalTimezone);\n    }\n    return {\n        id: item.id,\n        title: item.summary,\n        start: item.start.dateTime || item.start.date,\n        end: item.end.dateTime || item.end.date,\n        url: url,\n        location: item.location,\n        description: item.description\n    };\n}\n// Injects a string like \"arg=value\" into the querystring of a URL\n// TODO: move to a general util file?\nfunction injectQsComponent(url, component) {\n    // inject it after the querystring but before the fragment\n    return url.replace(/(\\?.*?)?(#|$)/, function (whole, qs, hash) {\n        return (qs ? qs + '&' : '?') + component + hash;\n    });\n}\nvar main = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createPlugin\"])({\n    eventSourceDefs: [eventSourceDef]\n});\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (main);\n\n\n//# sourceURL=webpack:///./node_modules/@fullcalendar/google-calendar/main.esm.js?");

/***/ }),

/***/ "./node_modules/@fullcalendar/interaction/main.esm.js":
/*!************************************************************!*\
  !*** ./node_modules/@fullcalendar/interaction/main.esm.js ***!
  \************************************************************/
/*! exports provided: default, Draggable, FeaturefulElementDragging, PointerDragging, ThirdPartyDraggable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"Draggable\", function() { return ExternalDraggable; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"FeaturefulElementDragging\", function() { return FeaturefulElementDragging; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"PointerDragging\", function() { return PointerDragging; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"ThirdPartyDraggable\", function() { return ThirdPartyDraggable; });\n/* harmony import */ var _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @fullcalendar/core */ \"./node_modules/@fullcalendar/core/main.esm.js\");\n/*!\nFullCalendar Interaction Plugin v4.4.2\nDocs & License: https://fullcalendar.io/\n(c) 2019 Adam Shaw\n*/\n\n\n\n/*! *****************************************************************************\r\nCopyright (c) Microsoft Corporation.\r\n\r\nPermission to use, copy, modify, and/or distribute this software for any\r\npurpose with or without fee is hereby granted.\r\n\r\nTHE SOFTWARE IS PROVIDED \"AS IS\" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH\r\nREGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY\r\nAND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,\r\nINDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM\r\nLOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR\r\nOTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR\r\nPERFORMANCE OF THIS SOFTWARE.\r\n***************************************************************************** */\r\n/* global Reflect, Promise */\r\n\r\nvar extendStatics = function(d, b) {\r\n    extendStatics = Object.setPrototypeOf ||\r\n        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||\r\n        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };\r\n    return extendStatics(d, b);\r\n};\r\n\r\nfunction __extends(d, b) {\r\n    extendStatics(d, b);\r\n    function __() { this.constructor = d; }\r\n    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());\r\n}\r\n\r\nvar __assign = function() {\r\n    __assign = Object.assign || function __assign(t) {\r\n        for (var s, i = 1, n = arguments.length; i < n; i++) {\r\n            s = arguments[i];\r\n            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];\r\n        }\r\n        return t;\r\n    };\r\n    return __assign.apply(this, arguments);\r\n};\n\n_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"config\"].touchMouseIgnoreWait = 500;\nvar ignoreMouseDepth = 0;\nvar listenerCnt = 0;\nvar isWindowTouchMoveCancelled = false;\n/*\nUses a \"pointer\" abstraction, which monitors UI events for both mouse and touch.\nTracks when the pointer \"drags\" on a certain element, meaning down+move+up.\n\nAlso, tracks if there was touch-scrolling.\nAlso, can prevent touch-scrolling from happening.\nAlso, can fire pointermove events when scrolling happens underneath, even when no real pointer movement.\n\nemits:\n- pointerdown\n- pointermove\n- pointerup\n*/\nvar PointerDragging = /** @class */ (function () {\n    function PointerDragging(containerEl) {\n        var _this = this;\n        this.subjectEl = null;\n        this.downEl = null;\n        // options that can be directly assigned by caller\n        this.selector = ''; // will cause subjectEl in all emitted events to be this element\n        this.handleSelector = '';\n        this.shouldIgnoreMove = false;\n        this.shouldWatchScroll = true; // for simulating pointermove on scroll\n        // internal states\n        this.isDragging = false;\n        this.isTouchDragging = false;\n        this.wasTouchScroll = false;\n        // Mouse\n        // ----------------------------------------------------------------------------------------------------\n        this.handleMouseDown = function (ev) {\n            if (!_this.shouldIgnoreMouse() &&\n                isPrimaryMouseButton(ev) &&\n                _this.tryStart(ev)) {\n                var pev = _this.createEventFromMouse(ev, true);\n                _this.emitter.trigger('pointerdown', pev);\n                _this.initScrollWatch(pev);\n                if (!_this.shouldIgnoreMove) {\n                    document.addEventListener('mousemove', _this.handleMouseMove);\n                }\n                document.addEventListener('mouseup', _this.handleMouseUp);\n            }\n        };\n        this.handleMouseMove = function (ev) {\n            var pev = _this.createEventFromMouse(ev);\n            _this.recordCoords(pev);\n            _this.emitter.trigger('pointermove', pev);\n        };\n        this.handleMouseUp = function (ev) {\n            document.removeEventListener('mousemove', _this.handleMouseMove);\n            document.removeEventListener('mouseup', _this.handleMouseUp);\n            _this.emitter.trigger('pointerup', _this.createEventFromMouse(ev));\n            _this.cleanup(); // call last so that pointerup has access to props\n        };\n        // Touch\n        // ----------------------------------------------------------------------------------------------------\n        this.handleTouchStart = function (ev) {\n            if (_this.tryStart(ev)) {\n                _this.isTouchDragging = true;\n                var pev = _this.createEventFromTouch(ev, true);\n                _this.emitter.trigger('pointerdown', pev);\n                _this.initScrollWatch(pev);\n                // unlike mouse, need to attach to target, not document\n                // https://stackoverflow.com/a/45760014\n                var target = ev.target;\n                if (!_this.shouldIgnoreMove) {\n                    target.addEventListener('touchmove', _this.handleTouchMove);\n                }\n                target.addEventListener('touchend', _this.handleTouchEnd);\n                target.addEventListener('touchcancel', _this.handleTouchEnd); // treat it as a touch end\n                // attach a handler to get called when ANY scroll action happens on the page.\n                // this was impossible to do with normal on/off because 'scroll' doesn't bubble.\n                // http://stackoverflow.com/a/32954565/96342\n                window.addEventListener('scroll', _this.handleTouchScroll, true // useCapture\n                );\n            }\n        };\n        this.handleTouchMove = function (ev) {\n            var pev = _this.createEventFromTouch(ev);\n            _this.recordCoords(pev);\n            _this.emitter.trigger('pointermove', pev);\n        };\n        this.handleTouchEnd = function (ev) {\n            if (_this.isDragging) { // done to guard against touchend followed by touchcancel\n                var target = ev.target;\n                target.removeEventListener('touchmove', _this.handleTouchMove);\n                target.removeEventListener('touchend', _this.handleTouchEnd);\n                target.removeEventListener('touchcancel', _this.handleTouchEnd);\n                window.removeEventListener('scroll', _this.handleTouchScroll, true); // useCaptured=true\n                _this.emitter.trigger('pointerup', _this.createEventFromTouch(ev));\n                _this.cleanup(); // call last so that pointerup has access to props\n                _this.isTouchDragging = false;\n                startIgnoringMouse();\n            }\n        };\n        this.handleTouchScroll = function () {\n            _this.wasTouchScroll = true;\n        };\n        this.handleScroll = function (ev) {\n            if (!_this.shouldIgnoreMove) {\n                var pageX = (window.pageXOffset - _this.prevScrollX) + _this.prevPageX;\n                var pageY = (window.pageYOffset - _this.prevScrollY) + _this.prevPageY;\n                _this.emitter.trigger('pointermove', {\n                    origEvent: ev,\n                    isTouch: _this.isTouchDragging,\n                    subjectEl: _this.subjectEl,\n                    pageX: pageX,\n                    pageY: pageY,\n                    deltaX: pageX - _this.origPageX,\n                    deltaY: pageY - _this.origPageY\n                });\n            }\n        };\n        this.containerEl = containerEl;\n        this.emitter = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"EmitterMixin\"]();\n        containerEl.addEventListener('mousedown', this.handleMouseDown);\n        containerEl.addEventListener('touchstart', this.handleTouchStart, { passive: true });\n        listenerCreated();\n    }\n    PointerDragging.prototype.destroy = function () {\n        this.containerEl.removeEventListener('mousedown', this.handleMouseDown);\n        this.containerEl.removeEventListener('touchstart', this.handleTouchStart, { passive: true });\n        listenerDestroyed();\n    };\n    PointerDragging.prototype.tryStart = function (ev) {\n        var subjectEl = this.querySubjectEl(ev);\n        var downEl = ev.target;\n        if (subjectEl &&\n            (!this.handleSelector || Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"elementClosest\"])(downEl, this.handleSelector))) {\n            this.subjectEl = subjectEl;\n            this.downEl = downEl;\n            this.isDragging = true; // do this first so cancelTouchScroll will work\n            this.wasTouchScroll = false;\n            return true;\n        }\n        return false;\n    };\n    PointerDragging.prototype.cleanup = function () {\n        isWindowTouchMoveCancelled = false;\n        this.isDragging = false;\n        this.subjectEl = null;\n        this.downEl = null;\n        // keep wasTouchScroll around for later access\n        this.destroyScrollWatch();\n    };\n    PointerDragging.prototype.querySubjectEl = function (ev) {\n        if (this.selector) {\n            return Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"elementClosest\"])(ev.target, this.selector);\n        }\n        else {\n            return this.containerEl;\n        }\n    };\n    PointerDragging.prototype.shouldIgnoreMouse = function () {\n        return ignoreMouseDepth || this.isTouchDragging;\n    };\n    // can be called by user of this class, to cancel touch-based scrolling for the current drag\n    PointerDragging.prototype.cancelTouchScroll = function () {\n        if (this.isDragging) {\n            isWindowTouchMoveCancelled = true;\n        }\n    };\n    // Scrolling that simulates pointermoves\n    // ----------------------------------------------------------------------------------------------------\n    PointerDragging.prototype.initScrollWatch = function (ev) {\n        if (this.shouldWatchScroll) {\n            this.recordCoords(ev);\n            window.addEventListener('scroll', this.handleScroll, true); // useCapture=true\n        }\n    };\n    PointerDragging.prototype.recordCoords = function (ev) {\n        if (this.shouldWatchScroll) {\n            this.prevPageX = ev.pageX;\n            this.prevPageY = ev.pageY;\n            this.prevScrollX = window.pageXOffset;\n            this.prevScrollY = window.pageYOffset;\n        }\n    };\n    PointerDragging.prototype.destroyScrollWatch = function () {\n        if (this.shouldWatchScroll) {\n            window.removeEventListener('scroll', this.handleScroll, true); // useCaptured=true\n        }\n    };\n    // Event Normalization\n    // ----------------------------------------------------------------------------------------------------\n    PointerDragging.prototype.createEventFromMouse = function (ev, isFirst) {\n        var deltaX = 0;\n        var deltaY = 0;\n        // TODO: repeat code\n        if (isFirst) {\n            this.origPageX = ev.pageX;\n            this.origPageY = ev.pageY;\n        }\n        else {\n            deltaX = ev.pageX - this.origPageX;\n            deltaY = ev.pageY - this.origPageY;\n        }\n        return {\n            origEvent: ev,\n            isTouch: false,\n            subjectEl: this.subjectEl,\n            pageX: ev.pageX,\n            pageY: ev.pageY,\n            deltaX: deltaX,\n            deltaY: deltaY\n        };\n    };\n    PointerDragging.prototype.createEventFromTouch = function (ev, isFirst) {\n        var touches = ev.touches;\n        var pageX;\n        var pageY;\n        var deltaX = 0;\n        var deltaY = 0;\n        // if touch coords available, prefer,\n        // because FF would give bad ev.pageX ev.pageY\n        if (touches && touches.length) {\n            pageX = touches[0].pageX;\n            pageY = touches[0].pageY;\n        }\n        else {\n            pageX = ev.pageX;\n            pageY = ev.pageY;\n        }\n        // TODO: repeat code\n        if (isFirst) {\n            this.origPageX = pageX;\n            this.origPageY = pageY;\n        }\n        else {\n            deltaX = pageX - this.origPageX;\n            deltaY = pageY - this.origPageY;\n        }\n        return {\n            origEvent: ev,\n            isTouch: true,\n            subjectEl: this.subjectEl,\n            pageX: pageX,\n            pageY: pageY,\n            deltaX: deltaX,\n            deltaY: deltaY\n        };\n    };\n    return PointerDragging;\n}());\n// Returns a boolean whether this was a left mouse click and no ctrl key (which means right click on Mac)\nfunction isPrimaryMouseButton(ev) {\n    return ev.button === 0 && !ev.ctrlKey;\n}\n// Ignoring fake mouse events generated by touch\n// ----------------------------------------------------------------------------------------------------\nfunction startIgnoringMouse() {\n    ignoreMouseDepth++;\n    setTimeout(function () {\n        ignoreMouseDepth--;\n    }, _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"config\"].touchMouseIgnoreWait);\n}\n// We want to attach touchmove as early as possible for Safari\n// ----------------------------------------------------------------------------------------------------\nfunction listenerCreated() {\n    if (!(listenerCnt++)) {\n        window.addEventListener('touchmove', onWindowTouchMove, { passive: false });\n    }\n}\nfunction listenerDestroyed() {\n    if (!(--listenerCnt)) {\n        window.removeEventListener('touchmove', onWindowTouchMove, { passive: false });\n    }\n}\nfunction onWindowTouchMove(ev) {\n    if (isWindowTouchMoveCancelled) {\n        ev.preventDefault();\n    }\n}\n\n/*\nAn effect in which an element follows the movement of a pointer across the screen.\nThe moving element is a clone of some other element.\nMust call start + handleMove + stop.\n*/\nvar ElementMirror = /** @class */ (function () {\n    function ElementMirror() {\n        this.isVisible = false; // must be explicitly enabled\n        this.sourceEl = null;\n        this.mirrorEl = null;\n        this.sourceElRect = null; // screen coords relative to viewport\n        // options that can be set directly by caller\n        this.parentNode = document.body;\n        this.zIndex = 9999;\n        this.revertDuration = 0;\n    }\n    ElementMirror.prototype.start = function (sourceEl, pageX, pageY) {\n        this.sourceEl = sourceEl;\n        this.sourceElRect = this.sourceEl.getBoundingClientRect();\n        this.origScreenX = pageX - window.pageXOffset;\n        this.origScreenY = pageY - window.pageYOffset;\n        this.deltaX = 0;\n        this.deltaY = 0;\n        this.updateElPosition();\n    };\n    ElementMirror.prototype.handleMove = function (pageX, pageY) {\n        this.deltaX = (pageX - window.pageXOffset) - this.origScreenX;\n        this.deltaY = (pageY - window.pageYOffset) - this.origScreenY;\n        this.updateElPosition();\n    };\n    // can be called before start\n    ElementMirror.prototype.setIsVisible = function (bool) {\n        if (bool) {\n            if (!this.isVisible) {\n                if (this.mirrorEl) {\n                    this.mirrorEl.style.display = '';\n                }\n                this.isVisible = bool; // needs to happen before updateElPosition\n                this.updateElPosition(); // because was not updating the position while invisible\n            }\n        }\n        else {\n            if (this.isVisible) {\n                if (this.mirrorEl) {\n                    this.mirrorEl.style.display = 'none';\n                }\n                this.isVisible = bool;\n            }\n        }\n    };\n    // always async\n    ElementMirror.prototype.stop = function (needsRevertAnimation, callback) {\n        var _this = this;\n        var done = function () {\n            _this.cleanup();\n            callback();\n        };\n        if (needsRevertAnimation &&\n            this.mirrorEl &&\n            this.isVisible &&\n            this.revertDuration && // if 0, transition won't work\n            (this.deltaX || this.deltaY) // if same coords, transition won't work\n        ) {\n            this.doRevertAnimation(done, this.revertDuration);\n        }\n        else {\n            setTimeout(done, 0);\n        }\n    };\n    ElementMirror.prototype.doRevertAnimation = function (callback, revertDuration) {\n        var mirrorEl = this.mirrorEl;\n        var finalSourceElRect = this.sourceEl.getBoundingClientRect(); // because autoscrolling might have happened\n        mirrorEl.style.transition =\n            'top ' + revertDuration + 'ms,' +\n                'left ' + revertDuration + 'ms';\n        Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"applyStyle\"])(mirrorEl, {\n            left: finalSourceElRect.left,\n            top: finalSourceElRect.top\n        });\n        Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"whenTransitionDone\"])(mirrorEl, function () {\n            mirrorEl.style.transition = '';\n            callback();\n        });\n    };\n    ElementMirror.prototype.cleanup = function () {\n        if (this.mirrorEl) {\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"removeElement\"])(this.mirrorEl);\n            this.mirrorEl = null;\n        }\n        this.sourceEl = null;\n    };\n    ElementMirror.prototype.updateElPosition = function () {\n        if (this.sourceEl && this.isVisible) {\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"applyStyle\"])(this.getMirrorEl(), {\n                left: this.sourceElRect.left + this.deltaX,\n                top: this.sourceElRect.top + this.deltaY\n            });\n        }\n    };\n    ElementMirror.prototype.getMirrorEl = function () {\n        var sourceElRect = this.sourceElRect;\n        var mirrorEl = this.mirrorEl;\n        if (!mirrorEl) {\n            mirrorEl = this.mirrorEl = this.sourceEl.cloneNode(true); // cloneChildren=true\n            // we don't want long taps or any mouse interaction causing selection/menus.\n            // would use preventSelection(), but that prevents selectstart, causing problems.\n            mirrorEl.classList.add('fc-unselectable');\n            mirrorEl.classList.add('fc-dragging');\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"applyStyle\"])(mirrorEl, {\n                position: 'fixed',\n                zIndex: this.zIndex,\n                visibility: '',\n                boxSizing: 'border-box',\n                width: sourceElRect.right - sourceElRect.left,\n                height: sourceElRect.bottom - sourceElRect.top,\n                right: 'auto',\n                bottom: 'auto',\n                margin: 0\n            });\n            this.parentNode.appendChild(mirrorEl);\n        }\n        return mirrorEl;\n    };\n    return ElementMirror;\n}());\n\n/*\nIs a cache for a given element's scroll information (all the info that ScrollController stores)\nin addition the \"client rectangle\" of the element.. the area within the scrollbars.\n\nThe cache can be in one of two modes:\n- doesListening:false - ignores when the container is scrolled by someone else\n- doesListening:true - watch for scrolling and update the cache\n*/\nvar ScrollGeomCache = /** @class */ (function (_super) {\n    __extends(ScrollGeomCache, _super);\n    function ScrollGeomCache(scrollController, doesListening) {\n        var _this = _super.call(this) || this;\n        _this.handleScroll = function () {\n            _this.scrollTop = _this.scrollController.getScrollTop();\n            _this.scrollLeft = _this.scrollController.getScrollLeft();\n            _this.handleScrollChange();\n        };\n        _this.scrollController = scrollController;\n        _this.doesListening = doesListening;\n        _this.scrollTop = _this.origScrollTop = scrollController.getScrollTop();\n        _this.scrollLeft = _this.origScrollLeft = scrollController.getScrollLeft();\n        _this.scrollWidth = scrollController.getScrollWidth();\n        _this.scrollHeight = scrollController.getScrollHeight();\n        _this.clientWidth = scrollController.getClientWidth();\n        _this.clientHeight = scrollController.getClientHeight();\n        _this.clientRect = _this.computeClientRect(); // do last in case it needs cached values\n        if (_this.doesListening) {\n            _this.getEventTarget().addEventListener('scroll', _this.handleScroll);\n        }\n        return _this;\n    }\n    ScrollGeomCache.prototype.destroy = function () {\n        if (this.doesListening) {\n            this.getEventTarget().removeEventListener('scroll', this.handleScroll);\n        }\n    };\n    ScrollGeomCache.prototype.getScrollTop = function () {\n        return this.scrollTop;\n    };\n    ScrollGeomCache.prototype.getScrollLeft = function () {\n        return this.scrollLeft;\n    };\n    ScrollGeomCache.prototype.setScrollTop = function (top) {\n        this.scrollController.setScrollTop(top);\n        if (!this.doesListening) {\n            // we are not relying on the element to normalize out-of-bounds scroll values\n            // so we need to sanitize ourselves\n            this.scrollTop = Math.max(Math.min(top, this.getMaxScrollTop()), 0);\n            this.handleScrollChange();\n        }\n    };\n    ScrollGeomCache.prototype.setScrollLeft = function (top) {\n        this.scrollController.setScrollLeft(top);\n        if (!this.doesListening) {\n            // we are not relying on the element to normalize out-of-bounds scroll values\n            // so we need to sanitize ourselves\n            this.scrollLeft = Math.max(Math.min(top, this.getMaxScrollLeft()), 0);\n            this.handleScrollChange();\n        }\n    };\n    ScrollGeomCache.prototype.getClientWidth = function () {\n        return this.clientWidth;\n    };\n    ScrollGeomCache.prototype.getClientHeight = function () {\n        return this.clientHeight;\n    };\n    ScrollGeomCache.prototype.getScrollWidth = function () {\n        return this.scrollWidth;\n    };\n    ScrollGeomCache.prototype.getScrollHeight = function () {\n        return this.scrollHeight;\n    };\n    ScrollGeomCache.prototype.handleScrollChange = function () {\n    };\n    return ScrollGeomCache;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"ScrollController\"]));\nvar ElementScrollGeomCache = /** @class */ (function (_super) {\n    __extends(ElementScrollGeomCache, _super);\n    function ElementScrollGeomCache(el, doesListening) {\n        return _super.call(this, new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"ElementScrollController\"](el), doesListening) || this;\n    }\n    ElementScrollGeomCache.prototype.getEventTarget = function () {\n        return this.scrollController.el;\n    };\n    ElementScrollGeomCache.prototype.computeClientRect = function () {\n        return Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeInnerRect\"])(this.scrollController.el);\n    };\n    return ElementScrollGeomCache;\n}(ScrollGeomCache));\nvar WindowScrollGeomCache = /** @class */ (function (_super) {\n    __extends(WindowScrollGeomCache, _super);\n    function WindowScrollGeomCache(doesListening) {\n        return _super.call(this, new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"WindowScrollController\"](), doesListening) || this;\n    }\n    WindowScrollGeomCache.prototype.getEventTarget = function () {\n        return window;\n    };\n    WindowScrollGeomCache.prototype.computeClientRect = function () {\n        return {\n            left: this.scrollLeft,\n            right: this.scrollLeft + this.clientWidth,\n            top: this.scrollTop,\n            bottom: this.scrollTop + this.clientHeight\n        };\n    };\n    // the window is the only scroll object that changes it's rectangle relative\n    // to the document's topleft as it scrolls\n    WindowScrollGeomCache.prototype.handleScrollChange = function () {\n        this.clientRect = this.computeClientRect();\n    };\n    return WindowScrollGeomCache;\n}(ScrollGeomCache));\n\n// If available we are using native \"performance\" API instead of \"Date\"\n// Read more about it on MDN:\n// https://developer.mozilla.org/en-US/docs/Web/API/Performance\nvar getTime = typeof performance === 'function' ? performance.now : Date.now;\n/*\nFor a pointer interaction, automatically scrolls certain scroll containers when the pointer\napproaches the edge.\n\nThe caller must call start + handleMove + stop.\n*/\nvar AutoScroller = /** @class */ (function () {\n    function AutoScroller() {\n        var _this = this;\n        // options that can be set by caller\n        this.isEnabled = true;\n        this.scrollQuery = [window, '.fc-scroller'];\n        this.edgeThreshold = 50; // pixels\n        this.maxVelocity = 300; // pixels per second\n        // internal state\n        this.pointerScreenX = null;\n        this.pointerScreenY = null;\n        this.isAnimating = false;\n        this.scrollCaches = null;\n        // protect against the initial pointerdown being too close to an edge and starting the scroll\n        this.everMovedUp = false;\n        this.everMovedDown = false;\n        this.everMovedLeft = false;\n        this.everMovedRight = false;\n        this.animate = function () {\n            if (_this.isAnimating) { // wasn't cancelled between animation calls\n                var edge = _this.computeBestEdge(_this.pointerScreenX + window.pageXOffset, _this.pointerScreenY + window.pageYOffset);\n                if (edge) {\n                    var now = getTime();\n                    _this.handleSide(edge, (now - _this.msSinceRequest) / 1000);\n                    _this.requestAnimation(now);\n                }\n                else {\n                    _this.isAnimating = false; // will stop animation\n                }\n            }\n        };\n    }\n    AutoScroller.prototype.start = function (pageX, pageY) {\n        if (this.isEnabled) {\n            this.scrollCaches = this.buildCaches();\n            this.pointerScreenX = null;\n            this.pointerScreenY = null;\n            this.everMovedUp = false;\n            this.everMovedDown = false;\n            this.everMovedLeft = false;\n            this.everMovedRight = false;\n            this.handleMove(pageX, pageY);\n        }\n    };\n    AutoScroller.prototype.handleMove = function (pageX, pageY) {\n        if (this.isEnabled) {\n            var pointerScreenX = pageX - window.pageXOffset;\n            var pointerScreenY = pageY - window.pageYOffset;\n            var yDelta = this.pointerScreenY === null ? 0 : pointerScreenY - this.pointerScreenY;\n            var xDelta = this.pointerScreenX === null ? 0 : pointerScreenX - this.pointerScreenX;\n            if (yDelta < 0) {\n                this.everMovedUp = true;\n            }\n            else if (yDelta > 0) {\n                this.everMovedDown = true;\n            }\n            if (xDelta < 0) {\n                this.everMovedLeft = true;\n            }\n            else if (xDelta > 0) {\n                this.everMovedRight = true;\n            }\n            this.pointerScreenX = pointerScreenX;\n            this.pointerScreenY = pointerScreenY;\n            if (!this.isAnimating) {\n                this.isAnimating = true;\n                this.requestAnimation(getTime());\n            }\n        }\n    };\n    AutoScroller.prototype.stop = function () {\n        if (this.isEnabled) {\n            this.isAnimating = false; // will stop animation\n            for (var _i = 0, _a = this.scrollCaches; _i < _a.length; _i++) {\n                var scrollCache = _a[_i];\n                scrollCache.destroy();\n            }\n            this.scrollCaches = null;\n        }\n    };\n    AutoScroller.prototype.requestAnimation = function (now) {\n        this.msSinceRequest = now;\n        requestAnimationFrame(this.animate);\n    };\n    AutoScroller.prototype.handleSide = function (edge, seconds) {\n        var scrollCache = edge.scrollCache;\n        var edgeThreshold = this.edgeThreshold;\n        var invDistance = edgeThreshold - edge.distance;\n        var velocity = // the closer to the edge, the faster we scroll\n         (invDistance * invDistance) / (edgeThreshold * edgeThreshold) * // quadratic\n            this.maxVelocity * seconds;\n        var sign = 1;\n        switch (edge.name) {\n            case 'left':\n                sign = -1;\n            // falls through\n            case 'right':\n                scrollCache.setScrollLeft(scrollCache.getScrollLeft() + velocity * sign);\n                break;\n            case 'top':\n                sign = -1;\n            // falls through\n            case 'bottom':\n                scrollCache.setScrollTop(scrollCache.getScrollTop() + velocity * sign);\n                break;\n        }\n    };\n    // left/top are relative to document topleft\n    AutoScroller.prototype.computeBestEdge = function (left, top) {\n        var edgeThreshold = this.edgeThreshold;\n        var bestSide = null;\n        for (var _i = 0, _a = this.scrollCaches; _i < _a.length; _i++) {\n            var scrollCache = _a[_i];\n            var rect = scrollCache.clientRect;\n            var leftDist = left - rect.left;\n            var rightDist = rect.right - left;\n            var topDist = top - rect.top;\n            var bottomDist = rect.bottom - top;\n            // completely within the rect?\n            if (leftDist >= 0 && rightDist >= 0 && topDist >= 0 && bottomDist >= 0) {\n                if (topDist <= edgeThreshold && this.everMovedUp && scrollCache.canScrollUp() &&\n                    (!bestSide || bestSide.distance > topDist)) {\n                    bestSide = { scrollCache: scrollCache, name: 'top', distance: topDist };\n                }\n                if (bottomDist <= edgeThreshold && this.everMovedDown && scrollCache.canScrollDown() &&\n                    (!bestSide || bestSide.distance > bottomDist)) {\n                    bestSide = { scrollCache: scrollCache, name: 'bottom', distance: bottomDist };\n                }\n                if (leftDist <= edgeThreshold && this.everMovedLeft && scrollCache.canScrollLeft() &&\n                    (!bestSide || bestSide.distance > leftDist)) {\n                    bestSide = { scrollCache: scrollCache, name: 'left', distance: leftDist };\n                }\n                if (rightDist <= edgeThreshold && this.everMovedRight && scrollCache.canScrollRight() &&\n                    (!bestSide || bestSide.distance > rightDist)) {\n                    bestSide = { scrollCache: scrollCache, name: 'right', distance: rightDist };\n                }\n            }\n        }\n        return bestSide;\n    };\n    AutoScroller.prototype.buildCaches = function () {\n        return this.queryScrollEls().map(function (el) {\n            if (el === window) {\n                return new WindowScrollGeomCache(false); // false = don't listen to user-generated scrolls\n            }\n            else {\n                return new ElementScrollGeomCache(el, false); // false = don't listen to user-generated scrolls\n            }\n        });\n    };\n    AutoScroller.prototype.queryScrollEls = function () {\n        var els = [];\n        for (var _i = 0, _a = this.scrollQuery; _i < _a.length; _i++) {\n            var query = _a[_i];\n            if (typeof query === 'object') {\n                els.push(query);\n            }\n            else {\n                els.push.apply(els, Array.prototype.slice.call(document.querySelectorAll(query)));\n            }\n        }\n        return els;\n    };\n    return AutoScroller;\n}());\n\n/*\nMonitors dragging on an element. Has a number of high-level features:\n- minimum distance required before dragging\n- minimum wait time (\"delay\") before dragging\n- a mirror element that follows the pointer\n*/\nvar FeaturefulElementDragging = /** @class */ (function (_super) {\n    __extends(FeaturefulElementDragging, _super);\n    function FeaturefulElementDragging(containerEl) {\n        var _this = _super.call(this, containerEl) || this;\n        // options that can be directly set by caller\n        // the caller can also set the PointerDragging's options as well\n        _this.delay = null;\n        _this.minDistance = 0;\n        _this.touchScrollAllowed = true; // prevents drag from starting and blocks scrolling during drag\n        _this.mirrorNeedsRevert = false;\n        _this.isInteracting = false; // is the user validly moving the pointer? lasts until pointerup\n        _this.isDragging = false; // is it INTENTFULLY dragging? lasts until after revert animation\n        _this.isDelayEnded = false;\n        _this.isDistanceSurpassed = false;\n        _this.delayTimeoutId = null;\n        _this.onPointerDown = function (ev) {\n            if (!_this.isDragging) { // so new drag doesn't happen while revert animation is going\n                _this.isInteracting = true;\n                _this.isDelayEnded = false;\n                _this.isDistanceSurpassed = false;\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"preventSelection\"])(document.body);\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"preventContextMenu\"])(document.body);\n                // prevent links from being visited if there's an eventual drag.\n                // also prevents selection in older browsers (maybe?).\n                // not necessary for touch, besides, browser would complain about passiveness.\n                if (!ev.isTouch) {\n                    ev.origEvent.preventDefault();\n                }\n                _this.emitter.trigger('pointerdown', ev);\n                if (!_this.pointer.shouldIgnoreMove) {\n                    // actions related to initiating dragstart+dragmove+dragend...\n                    _this.mirror.setIsVisible(false); // reset. caller must set-visible\n                    _this.mirror.start(ev.subjectEl, ev.pageX, ev.pageY); // must happen on first pointer down\n                    _this.startDelay(ev);\n                    if (!_this.minDistance) {\n                        _this.handleDistanceSurpassed(ev);\n                    }\n                }\n            }\n        };\n        _this.onPointerMove = function (ev) {\n            if (_this.isInteracting) { // if false, still waiting for previous drag's revert\n                _this.emitter.trigger('pointermove', ev);\n                if (!_this.isDistanceSurpassed) {\n                    var minDistance = _this.minDistance;\n                    var distanceSq = void 0; // current distance from the origin, squared\n                    var deltaX = ev.deltaX, deltaY = ev.deltaY;\n                    distanceSq = deltaX * deltaX + deltaY * deltaY;\n                    if (distanceSq >= minDistance * minDistance) { // use pythagorean theorem\n                        _this.handleDistanceSurpassed(ev);\n                    }\n                }\n                if (_this.isDragging) {\n                    // a real pointer move? (not one simulated by scrolling)\n                    if (ev.origEvent.type !== 'scroll') {\n                        _this.mirror.handleMove(ev.pageX, ev.pageY);\n                        _this.autoScroller.handleMove(ev.pageX, ev.pageY);\n                    }\n                    _this.emitter.trigger('dragmove', ev);\n                }\n            }\n        };\n        _this.onPointerUp = function (ev) {\n            if (_this.isInteracting) { // if false, still waiting for previous drag's revert\n                _this.isInteracting = false;\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"allowSelection\"])(document.body);\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"allowContextMenu\"])(document.body);\n                _this.emitter.trigger('pointerup', ev); // can potentially set mirrorNeedsRevert\n                if (_this.isDragging) {\n                    _this.autoScroller.stop();\n                    _this.tryStopDrag(ev); // which will stop the mirror\n                }\n                if (_this.delayTimeoutId) {\n                    clearTimeout(_this.delayTimeoutId);\n                    _this.delayTimeoutId = null;\n                }\n            }\n        };\n        var pointer = _this.pointer = new PointerDragging(containerEl);\n        pointer.emitter.on('pointerdown', _this.onPointerDown);\n        pointer.emitter.on('pointermove', _this.onPointerMove);\n        pointer.emitter.on('pointerup', _this.onPointerUp);\n        _this.mirror = new ElementMirror();\n        _this.autoScroller = new AutoScroller();\n        return _this;\n    }\n    FeaturefulElementDragging.prototype.destroy = function () {\n        this.pointer.destroy();\n    };\n    FeaturefulElementDragging.prototype.startDelay = function (ev) {\n        var _this = this;\n        if (typeof this.delay === 'number') {\n            this.delayTimeoutId = setTimeout(function () {\n                _this.delayTimeoutId = null;\n                _this.handleDelayEnd(ev);\n            }, this.delay); // not assignable to number!\n        }\n        else {\n            this.handleDelayEnd(ev);\n        }\n    };\n    FeaturefulElementDragging.prototype.handleDelayEnd = function (ev) {\n        this.isDelayEnded = true;\n        this.tryStartDrag(ev);\n    };\n    FeaturefulElementDragging.prototype.handleDistanceSurpassed = function (ev) {\n        this.isDistanceSurpassed = true;\n        this.tryStartDrag(ev);\n    };\n    FeaturefulElementDragging.prototype.tryStartDrag = function (ev) {\n        if (this.isDelayEnded && this.isDistanceSurpassed) {\n            if (!this.pointer.wasTouchScroll || this.touchScrollAllowed) {\n                this.isDragging = true;\n                this.mirrorNeedsRevert = false;\n                this.autoScroller.start(ev.pageX, ev.pageY);\n                this.emitter.trigger('dragstart', ev);\n                if (this.touchScrollAllowed === false) {\n                    this.pointer.cancelTouchScroll();\n                }\n            }\n        }\n    };\n    FeaturefulElementDragging.prototype.tryStopDrag = function (ev) {\n        // .stop() is ALWAYS asynchronous, which we NEED because we want all pointerup events\n        // that come from the document to fire beforehand. much more convenient this way.\n        this.mirror.stop(this.mirrorNeedsRevert, this.stopDrag.bind(this, ev) // bound with args\n        );\n    };\n    FeaturefulElementDragging.prototype.stopDrag = function (ev) {\n        this.isDragging = false;\n        this.emitter.trigger('dragend', ev);\n    };\n    // fill in the implementations...\n    FeaturefulElementDragging.prototype.setIgnoreMove = function (bool) {\n        this.pointer.shouldIgnoreMove = bool;\n    };\n    FeaturefulElementDragging.prototype.setMirrorIsVisible = function (bool) {\n        this.mirror.setIsVisible(bool);\n    };\n    FeaturefulElementDragging.prototype.setMirrorNeedsRevert = function (bool) {\n        this.mirrorNeedsRevert = bool;\n    };\n    FeaturefulElementDragging.prototype.setAutoScrollEnabled = function (bool) {\n        this.autoScroller.isEnabled = bool;\n    };\n    return FeaturefulElementDragging;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"ElementDragging\"]));\n\n/*\nWhen this class is instantiated, it records the offset of an element (relative to the document topleft),\nand continues to monitor scrolling, updating the cached coordinates if it needs to.\nDoes not access the DOM after instantiation, so highly performant.\n\nAlso keeps track of all scrolling/overflow:hidden containers that are parents of the given element\nand an determine if a given point is inside the combined clipping rectangle.\n*/\nvar OffsetTracker = /** @class */ (function () {\n    function OffsetTracker(el) {\n        this.origRect = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeRect\"])(el);\n        // will work fine for divs that have overflow:hidden\n        this.scrollCaches = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"getClippingParents\"])(el).map(function (el) {\n            return new ElementScrollGeomCache(el, true); // listen=true\n        });\n    }\n    OffsetTracker.prototype.destroy = function () {\n        for (var _i = 0, _a = this.scrollCaches; _i < _a.length; _i++) {\n            var scrollCache = _a[_i];\n            scrollCache.destroy();\n        }\n    };\n    OffsetTracker.prototype.computeLeft = function () {\n        var left = this.origRect.left;\n        for (var _i = 0, _a = this.scrollCaches; _i < _a.length; _i++) {\n            var scrollCache = _a[_i];\n            left += scrollCache.origScrollLeft - scrollCache.getScrollLeft();\n        }\n        return left;\n    };\n    OffsetTracker.prototype.computeTop = function () {\n        var top = this.origRect.top;\n        for (var _i = 0, _a = this.scrollCaches; _i < _a.length; _i++) {\n            var scrollCache = _a[_i];\n            top += scrollCache.origScrollTop - scrollCache.getScrollTop();\n        }\n        return top;\n    };\n    OffsetTracker.prototype.isWithinClipping = function (pageX, pageY) {\n        var point = { left: pageX, top: pageY };\n        for (var _i = 0, _a = this.scrollCaches; _i < _a.length; _i++) {\n            var scrollCache = _a[_i];\n            if (!isIgnoredClipping(scrollCache.getEventTarget()) &&\n                !Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"pointInsideRect\"])(point, scrollCache.clientRect)) {\n                return false;\n            }\n        }\n        return true;\n    };\n    return OffsetTracker;\n}());\n// certain clipping containers should never constrain interactions, like <html> and <body>\n// https://github.com/fullcalendar/fullcalendar/issues/3615\nfunction isIgnoredClipping(node) {\n    var tagName = node.tagName;\n    return tagName === 'HTML' || tagName === 'BODY';\n}\n\n/*\nTracks movement over multiple droppable areas (aka \"hits\")\nthat exist in one or more DateComponents.\nRelies on an existing draggable.\n\nemits:\n- pointerdown\n- dragstart\n- hitchange - fires initially, even if not over a hit\n- pointerup\n- (hitchange - again, to null, if ended over a hit)\n- dragend\n*/\nvar HitDragging = /** @class */ (function () {\n    function HitDragging(dragging, droppableStore) {\n        var _this = this;\n        // options that can be set by caller\n        this.useSubjectCenter = false;\n        this.requireInitial = true; // if doesn't start out on a hit, won't emit any events\n        this.initialHit = null;\n        this.movingHit = null;\n        this.finalHit = null; // won't ever be populated if shouldIgnoreMove\n        this.handlePointerDown = function (ev) {\n            var dragging = _this.dragging;\n            _this.initialHit = null;\n            _this.movingHit = null;\n            _this.finalHit = null;\n            _this.prepareHits();\n            _this.processFirstCoord(ev);\n            if (_this.initialHit || !_this.requireInitial) {\n                dragging.setIgnoreMove(false);\n                _this.emitter.trigger('pointerdown', ev); // TODO: fire this before computing processFirstCoord, so listeners can cancel. this gets fired by almost every handler :(\n            }\n            else {\n                dragging.setIgnoreMove(true);\n            }\n        };\n        this.handleDragStart = function (ev) {\n            _this.emitter.trigger('dragstart', ev);\n            _this.handleMove(ev, true); // force = fire even if initially null\n        };\n        this.handleDragMove = function (ev) {\n            _this.emitter.trigger('dragmove', ev);\n            _this.handleMove(ev);\n        };\n        this.handlePointerUp = function (ev) {\n            _this.releaseHits();\n            _this.emitter.trigger('pointerup', ev);\n        };\n        this.handleDragEnd = function (ev) {\n            if (_this.movingHit) {\n                _this.emitter.trigger('hitupdate', null, true, ev);\n            }\n            _this.finalHit = _this.movingHit;\n            _this.movingHit = null;\n            _this.emitter.trigger('dragend', ev);\n        };\n        this.droppableStore = droppableStore;\n        dragging.emitter.on('pointerdown', this.handlePointerDown);\n        dragging.emitter.on('dragstart', this.handleDragStart);\n        dragging.emitter.on('dragmove', this.handleDragMove);\n        dragging.emitter.on('pointerup', this.handlePointerUp);\n        dragging.emitter.on('dragend', this.handleDragEnd);\n        this.dragging = dragging;\n        this.emitter = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"EmitterMixin\"]();\n    }\n    // sets initialHit\n    // sets coordAdjust\n    HitDragging.prototype.processFirstCoord = function (ev) {\n        var origPoint = { left: ev.pageX, top: ev.pageY };\n        var adjustedPoint = origPoint;\n        var subjectEl = ev.subjectEl;\n        var subjectRect;\n        if (subjectEl !== document) {\n            subjectRect = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeRect\"])(subjectEl);\n            adjustedPoint = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"constrainPoint\"])(adjustedPoint, subjectRect);\n        }\n        var initialHit = this.initialHit = this.queryHitForOffset(adjustedPoint.left, adjustedPoint.top);\n        if (initialHit) {\n            if (this.useSubjectCenter && subjectRect) {\n                var slicedSubjectRect = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"intersectRects\"])(subjectRect, initialHit.rect);\n                if (slicedSubjectRect) {\n                    adjustedPoint = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"getRectCenter\"])(slicedSubjectRect);\n                }\n            }\n            this.coordAdjust = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"diffPoints\"])(adjustedPoint, origPoint);\n        }\n        else {\n            this.coordAdjust = { left: 0, top: 0 };\n        }\n    };\n    HitDragging.prototype.handleMove = function (ev, forceHandle) {\n        var hit = this.queryHitForOffset(ev.pageX + this.coordAdjust.left, ev.pageY + this.coordAdjust.top);\n        if (forceHandle || !isHitsEqual(this.movingHit, hit)) {\n            this.movingHit = hit;\n            this.emitter.trigger('hitupdate', hit, false, ev);\n        }\n    };\n    HitDragging.prototype.prepareHits = function () {\n        this.offsetTrackers = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"mapHash\"])(this.droppableStore, function (interactionSettings) {\n            interactionSettings.component.buildPositionCaches();\n            return new OffsetTracker(interactionSettings.el);\n        });\n    };\n    HitDragging.prototype.releaseHits = function () {\n        var offsetTrackers = this.offsetTrackers;\n        for (var id in offsetTrackers) {\n            offsetTrackers[id].destroy();\n        }\n        this.offsetTrackers = {};\n    };\n    HitDragging.prototype.queryHitForOffset = function (offsetLeft, offsetTop) {\n        var _a = this, droppableStore = _a.droppableStore, offsetTrackers = _a.offsetTrackers;\n        var bestHit = null;\n        for (var id in droppableStore) {\n            var component = droppableStore[id].component;\n            var offsetTracker = offsetTrackers[id];\n            if (offsetTracker.isWithinClipping(offsetLeft, offsetTop)) {\n                var originLeft = offsetTracker.computeLeft();\n                var originTop = offsetTracker.computeTop();\n                var positionLeft = offsetLeft - originLeft;\n                var positionTop = offsetTop - originTop;\n                var origRect = offsetTracker.origRect;\n                var width = origRect.right - origRect.left;\n                var height = origRect.bottom - origRect.top;\n                if (\n                // must be within the element's bounds\n                positionLeft >= 0 && positionLeft < width &&\n                    positionTop >= 0 && positionTop < height) {\n                    var hit = component.queryHit(positionLeft, positionTop, width, height);\n                    if (hit &&\n                        (\n                        // make sure the hit is within activeRange, meaning it's not a deal cell\n                        !component.props.dateProfile || // hack for DayTile\n                            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"rangeContainsRange\"])(component.props.dateProfile.activeRange, hit.dateSpan.range)) &&\n                        (!bestHit || hit.layer > bestHit.layer)) {\n                        // TODO: better way to re-orient rectangle\n                        hit.rect.left += originLeft;\n                        hit.rect.right += originLeft;\n                        hit.rect.top += originTop;\n                        hit.rect.bottom += originTop;\n                        bestHit = hit;\n                    }\n                }\n            }\n        }\n        return bestHit;\n    };\n    return HitDragging;\n}());\nfunction isHitsEqual(hit0, hit1) {\n    if (!hit0 && !hit1) {\n        return true;\n    }\n    if (Boolean(hit0) !== Boolean(hit1)) {\n        return false;\n    }\n    return Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"isDateSpansEqual\"])(hit0.dateSpan, hit1.dateSpan);\n}\n\n/*\nMonitors when the user clicks on a specific date/time of a component.\nA pointerdown+pointerup on the same \"hit\" constitutes a click.\n*/\nvar DateClicking = /** @class */ (function (_super) {\n    __extends(DateClicking, _super);\n    function DateClicking(settings) {\n        var _this = _super.call(this, settings) || this;\n        _this.handlePointerDown = function (ev) {\n            var dragging = _this.dragging;\n            // do this in pointerdown (not dragend) because DOM might be mutated by the time dragend is fired\n            dragging.setIgnoreMove(!_this.component.isValidDateDownEl(dragging.pointer.downEl));\n        };\n        // won't even fire if moving was ignored\n        _this.handleDragEnd = function (ev) {\n            var component = _this.component;\n            var _a = component.context, calendar = _a.calendar, view = _a.view;\n            var pointer = _this.dragging.pointer;\n            if (!pointer.wasTouchScroll) {\n                var _b = _this.hitDragging, initialHit = _b.initialHit, finalHit = _b.finalHit;\n                if (initialHit && finalHit && isHitsEqual(initialHit, finalHit)) {\n                    calendar.triggerDateClick(initialHit.dateSpan, initialHit.dayEl, view, ev.origEvent);\n                }\n            }\n        };\n        var component = settings.component;\n        // we DO want to watch pointer moves because otherwise finalHit won't get populated\n        _this.dragging = new FeaturefulElementDragging(component.el);\n        _this.dragging.autoScroller.isEnabled = false;\n        var hitDragging = _this.hitDragging = new HitDragging(_this.dragging, Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"interactionSettingsToStore\"])(settings));\n        hitDragging.emitter.on('pointerdown', _this.handlePointerDown);\n        hitDragging.emitter.on('dragend', _this.handleDragEnd);\n        return _this;\n    }\n    DateClicking.prototype.destroy = function () {\n        this.dragging.destroy();\n    };\n    return DateClicking;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"Interaction\"]));\n\n/*\nTracks when the user selects a portion of time of a component,\nconstituted by a drag over date cells, with a possible delay at the beginning of the drag.\n*/\nvar DateSelecting = /** @class */ (function (_super) {\n    __extends(DateSelecting, _super);\n    function DateSelecting(settings) {\n        var _this = _super.call(this, settings) || this;\n        _this.dragSelection = null;\n        _this.handlePointerDown = function (ev) {\n            var _a = _this, component = _a.component, dragging = _a.dragging;\n            var options = component.context.options;\n            var canSelect = options.selectable &&\n                component.isValidDateDownEl(ev.origEvent.target);\n            // don't bother to watch expensive moves if component won't do selection\n            dragging.setIgnoreMove(!canSelect);\n            // if touch, require user to hold down\n            dragging.delay = ev.isTouch ? getComponentTouchDelay(component) : null;\n        };\n        _this.handleDragStart = function (ev) {\n            _this.component.context.calendar.unselect(ev); // unselect previous selections\n        };\n        _this.handleHitUpdate = function (hit, isFinal) {\n            var calendar = _this.component.context.calendar;\n            var dragSelection = null;\n            var isInvalid = false;\n            if (hit) {\n                dragSelection = joinHitsIntoSelection(_this.hitDragging.initialHit, hit, calendar.pluginSystem.hooks.dateSelectionTransformers);\n                if (!dragSelection || !_this.component.isDateSelectionValid(dragSelection)) {\n                    isInvalid = true;\n                    dragSelection = null;\n                }\n            }\n            if (dragSelection) {\n                calendar.dispatch({ type: 'SELECT_DATES', selection: dragSelection });\n            }\n            else if (!isFinal) { // only unselect if moved away while dragging\n                calendar.dispatch({ type: 'UNSELECT_DATES' });\n            }\n            if (!isInvalid) {\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"enableCursor\"])();\n            }\n            else {\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"disableCursor\"])();\n            }\n            if (!isFinal) {\n                _this.dragSelection = dragSelection; // only clear if moved away from all hits while dragging\n            }\n        };\n        _this.handlePointerUp = function (pev) {\n            if (_this.dragSelection) {\n                // selection is already rendered, so just need to report selection\n                _this.component.context.calendar.triggerDateSelect(_this.dragSelection, pev);\n                _this.dragSelection = null;\n            }\n        };\n        var component = settings.component;\n        var options = component.context.options;\n        var dragging = _this.dragging = new FeaturefulElementDragging(component.el);\n        dragging.touchScrollAllowed = false;\n        dragging.minDistance = options.selectMinDistance || 0;\n        dragging.autoScroller.isEnabled = options.dragScroll;\n        var hitDragging = _this.hitDragging = new HitDragging(_this.dragging, Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"interactionSettingsToStore\"])(settings));\n        hitDragging.emitter.on('pointerdown', _this.handlePointerDown);\n        hitDragging.emitter.on('dragstart', _this.handleDragStart);\n        hitDragging.emitter.on('hitupdate', _this.handleHitUpdate);\n        hitDragging.emitter.on('pointerup', _this.handlePointerUp);\n        return _this;\n    }\n    DateSelecting.prototype.destroy = function () {\n        this.dragging.destroy();\n    };\n    return DateSelecting;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"Interaction\"]));\nfunction getComponentTouchDelay(component) {\n    var options = component.context.options;\n    var delay = options.selectLongPressDelay;\n    if (delay == null) {\n        delay = options.longPressDelay;\n    }\n    return delay;\n}\nfunction joinHitsIntoSelection(hit0, hit1, dateSelectionTransformers) {\n    var dateSpan0 = hit0.dateSpan;\n    var dateSpan1 = hit1.dateSpan;\n    var ms = [\n        dateSpan0.range.start,\n        dateSpan0.range.end,\n        dateSpan1.range.start,\n        dateSpan1.range.end\n    ];\n    ms.sort(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"compareNumbers\"]);\n    var props = {};\n    for (var _i = 0, dateSelectionTransformers_1 = dateSelectionTransformers; _i < dateSelectionTransformers_1.length; _i++) {\n        var transformer = dateSelectionTransformers_1[_i];\n        var res = transformer(hit0, hit1);\n        if (res === false) {\n            return null;\n        }\n        else if (res) {\n            __assign(props, res);\n        }\n    }\n    props.range = { start: ms[0], end: ms[3] };\n    props.allDay = dateSpan0.allDay;\n    return props;\n}\n\nvar EventDragging = /** @class */ (function (_super) {\n    __extends(EventDragging, _super);\n    function EventDragging(settings) {\n        var _this = _super.call(this, settings) || this;\n        // internal state\n        _this.subjectSeg = null; // the seg being selected/dragged\n        _this.isDragging = false;\n        _this.eventRange = null;\n        _this.relevantEvents = null; // the events being dragged\n        _this.receivingCalendar = null;\n        _this.validMutation = null;\n        _this.mutatedRelevantEvents = null;\n        _this.handlePointerDown = function (ev) {\n            var origTarget = ev.origEvent.target;\n            var _a = _this, component = _a.component, dragging = _a.dragging;\n            var mirror = dragging.mirror;\n            var options = component.context.options;\n            var initialCalendar = component.context.calendar;\n            var subjectSeg = _this.subjectSeg = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"getElSeg\"])(ev.subjectEl);\n            var eventRange = _this.eventRange = subjectSeg.eventRange;\n            var eventInstanceId = eventRange.instance.instanceId;\n            _this.relevantEvents = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"getRelevantEvents\"])(initialCalendar.state.eventStore, eventInstanceId);\n            dragging.minDistance = ev.isTouch ? 0 : options.eventDragMinDistance;\n            dragging.delay =\n                // only do a touch delay if touch and this event hasn't been selected yet\n                (ev.isTouch && eventInstanceId !== component.props.eventSelection) ?\n                    getComponentTouchDelay$1(component) :\n                    null;\n            mirror.parentNode = initialCalendar.el;\n            mirror.revertDuration = options.dragRevertDuration;\n            var isValid = component.isValidSegDownEl(origTarget) &&\n                !Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"elementClosest\"])(origTarget, '.fc-resizer'); // NOT on a resizer\n            dragging.setIgnoreMove(!isValid);\n            // disable dragging for elements that are resizable (ie, selectable)\n            // but are not draggable\n            _this.isDragging = isValid &&\n                ev.subjectEl.classList.contains('fc-draggable');\n        };\n        _this.handleDragStart = function (ev) {\n            var context = _this.component.context;\n            var initialCalendar = context.calendar;\n            var eventRange = _this.eventRange;\n            var eventInstanceId = eventRange.instance.instanceId;\n            if (ev.isTouch) {\n                // need to select a different event?\n                if (eventInstanceId !== _this.component.props.eventSelection) {\n                    initialCalendar.dispatch({ type: 'SELECT_EVENT', eventInstanceId: eventInstanceId });\n                }\n            }\n            else {\n                // if now using mouse, but was previous touch interaction, clear selected event\n                initialCalendar.dispatch({ type: 'UNSELECT_EVENT' });\n            }\n            if (_this.isDragging) {\n                initialCalendar.unselect(ev); // unselect *date* selection\n                initialCalendar.publiclyTrigger('eventDragStart', [\n                    {\n                        el: _this.subjectSeg.el,\n                        event: new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"EventApi\"](initialCalendar, eventRange.def, eventRange.instance),\n                        jsEvent: ev.origEvent,\n                        view: context.view\n                    }\n                ]);\n            }\n        };\n        _this.handleHitUpdate = function (hit, isFinal) {\n            if (!_this.isDragging) {\n                return;\n            }\n            var relevantEvents = _this.relevantEvents;\n            var initialHit = _this.hitDragging.initialHit;\n            var initialCalendar = _this.component.context.calendar;\n            // states based on new hit\n            var receivingCalendar = null;\n            var mutation = null;\n            var mutatedRelevantEvents = null;\n            var isInvalid = false;\n            var interaction = {\n                affectedEvents: relevantEvents,\n                mutatedEvents: Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createEmptyEventStore\"])(),\n                isEvent: true,\n                origSeg: _this.subjectSeg\n            };\n            if (hit) {\n                var receivingComponent = hit.component;\n                receivingCalendar = receivingComponent.context.calendar;\n                var receivingOptions = receivingComponent.context.options;\n                if (initialCalendar === receivingCalendar ||\n                    receivingOptions.editable && receivingOptions.droppable) {\n                    mutation = computeEventMutation(initialHit, hit, receivingCalendar.pluginSystem.hooks.eventDragMutationMassagers);\n                    if (mutation) {\n                        mutatedRelevantEvents = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"applyMutationToEventStore\"])(relevantEvents, receivingCalendar.eventUiBases, mutation, receivingCalendar);\n                        interaction.mutatedEvents = mutatedRelevantEvents;\n                        if (!receivingComponent.isInteractionValid(interaction)) {\n                            isInvalid = true;\n                            mutation = null;\n                            mutatedRelevantEvents = null;\n                            interaction.mutatedEvents = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createEmptyEventStore\"])();\n                        }\n                    }\n                }\n                else {\n                    receivingCalendar = null;\n                }\n            }\n            _this.displayDrag(receivingCalendar, interaction);\n            if (!isInvalid) {\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"enableCursor\"])();\n            }\n            else {\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"disableCursor\"])();\n            }\n            if (!isFinal) {\n                if (initialCalendar === receivingCalendar && // TODO: write test for this\n                    isHitsEqual(initialHit, hit)) {\n                    mutation = null;\n                }\n                _this.dragging.setMirrorNeedsRevert(!mutation);\n                // render the mirror if no already-rendered mirror\n                // TODO: wish we could somehow wait for dispatch to guarantee render\n                _this.dragging.setMirrorIsVisible(!hit || !document.querySelector('.fc-mirror'));\n                // assign states based on new hit\n                _this.receivingCalendar = receivingCalendar;\n                _this.validMutation = mutation;\n                _this.mutatedRelevantEvents = mutatedRelevantEvents;\n            }\n        };\n        _this.handlePointerUp = function () {\n            if (!_this.isDragging) {\n                _this.cleanup(); // because handleDragEnd won't fire\n            }\n        };\n        _this.handleDragEnd = function (ev) {\n            if (_this.isDragging) {\n                var context = _this.component.context;\n                var initialCalendar_1 = context.calendar;\n                var initialView = context.view;\n                var _a = _this, receivingCalendar = _a.receivingCalendar, validMutation = _a.validMutation;\n                var eventDef = _this.eventRange.def;\n                var eventInstance = _this.eventRange.instance;\n                var eventApi = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"EventApi\"](initialCalendar_1, eventDef, eventInstance);\n                var relevantEvents_1 = _this.relevantEvents;\n                var mutatedRelevantEvents = _this.mutatedRelevantEvents;\n                var finalHit = _this.hitDragging.finalHit;\n                _this.clearDrag(); // must happen after revert animation\n                initialCalendar_1.publiclyTrigger('eventDragStop', [\n                    {\n                        el: _this.subjectSeg.el,\n                        event: eventApi,\n                        jsEvent: ev.origEvent,\n                        view: initialView\n                    }\n                ]);\n                if (validMutation) {\n                    // dropped within same calendar\n                    if (receivingCalendar === initialCalendar_1) {\n                        initialCalendar_1.dispatch({\n                            type: 'MERGE_EVENTS',\n                            eventStore: mutatedRelevantEvents\n                        });\n                        var transformed = {};\n                        for (var _i = 0, _b = initialCalendar_1.pluginSystem.hooks.eventDropTransformers; _i < _b.length; _i++) {\n                            var transformer = _b[_i];\n                            __assign(transformed, transformer(validMutation, initialCalendar_1));\n                        }\n                        var eventDropArg = __assign({}, transformed, { el: ev.subjectEl, delta: validMutation.datesDelta, oldEvent: eventApi, event: new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"EventApi\"](// the data AFTER the mutation\n                            initialCalendar_1, mutatedRelevantEvents.defs[eventDef.defId], eventInstance ? mutatedRelevantEvents.instances[eventInstance.instanceId] : null), revert: function () {\n                                initialCalendar_1.dispatch({\n                                    type: 'MERGE_EVENTS',\n                                    eventStore: relevantEvents_1\n                                });\n                            }, jsEvent: ev.origEvent, view: initialView });\n                        initialCalendar_1.publiclyTrigger('eventDrop', [eventDropArg]);\n                        // dropped in different calendar\n                    }\n                    else if (receivingCalendar) {\n                        initialCalendar_1.publiclyTrigger('eventLeave', [\n                            {\n                                draggedEl: ev.subjectEl,\n                                event: eventApi,\n                                view: initialView\n                            }\n                        ]);\n                        initialCalendar_1.dispatch({\n                            type: 'REMOVE_EVENT_INSTANCES',\n                            instances: _this.mutatedRelevantEvents.instances\n                        });\n                        receivingCalendar.dispatch({\n                            type: 'MERGE_EVENTS',\n                            eventStore: _this.mutatedRelevantEvents\n                        });\n                        if (ev.isTouch) {\n                            receivingCalendar.dispatch({\n                                type: 'SELECT_EVENT',\n                                eventInstanceId: eventInstance.instanceId\n                            });\n                        }\n                        var dropArg = __assign({}, receivingCalendar.buildDatePointApi(finalHit.dateSpan), { draggedEl: ev.subjectEl, jsEvent: ev.origEvent, view: finalHit.component // should this be finalHit.component.view? See #4644\n                         });\n                        receivingCalendar.publiclyTrigger('drop', [dropArg]);\n                        receivingCalendar.publiclyTrigger('eventReceive', [\n                            {\n                                draggedEl: ev.subjectEl,\n                                event: new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"EventApi\"](// the data AFTER the mutation\n                                receivingCalendar, mutatedRelevantEvents.defs[eventDef.defId], mutatedRelevantEvents.instances[eventInstance.instanceId]),\n                                view: finalHit.component // should this be finalHit.component.view? See #4644\n                            }\n                        ]);\n                    }\n                }\n                else {\n                    initialCalendar_1.publiclyTrigger('_noEventDrop');\n                }\n            }\n            _this.cleanup();\n        };\n        var component = _this.component;\n        var options = component.context.options;\n        var dragging = _this.dragging = new FeaturefulElementDragging(component.el);\n        dragging.pointer.selector = EventDragging.SELECTOR;\n        dragging.touchScrollAllowed = false;\n        dragging.autoScroller.isEnabled = options.dragScroll;\n        var hitDragging = _this.hitDragging = new HitDragging(_this.dragging, _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"interactionSettingsStore\"]);\n        hitDragging.useSubjectCenter = settings.useEventCenter;\n        hitDragging.emitter.on('pointerdown', _this.handlePointerDown);\n        hitDragging.emitter.on('dragstart', _this.handleDragStart);\n        hitDragging.emitter.on('hitupdate', _this.handleHitUpdate);\n        hitDragging.emitter.on('pointerup', _this.handlePointerUp);\n        hitDragging.emitter.on('dragend', _this.handleDragEnd);\n        return _this;\n    }\n    EventDragging.prototype.destroy = function () {\n        this.dragging.destroy();\n    };\n    // render a drag state on the next receivingCalendar\n    EventDragging.prototype.displayDrag = function (nextCalendar, state) {\n        var initialCalendar = this.component.context.calendar;\n        var prevCalendar = this.receivingCalendar;\n        // does the previous calendar need to be cleared?\n        if (prevCalendar && prevCalendar !== nextCalendar) {\n            // does the initial calendar need to be cleared?\n            // if so, don't clear all the way. we still need to to hide the affectedEvents\n            if (prevCalendar === initialCalendar) {\n                prevCalendar.dispatch({\n                    type: 'SET_EVENT_DRAG',\n                    state: {\n                        affectedEvents: state.affectedEvents,\n                        mutatedEvents: Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createEmptyEventStore\"])(),\n                        isEvent: true,\n                        origSeg: state.origSeg\n                    }\n                });\n                // completely clear the old calendar if it wasn't the initial\n            }\n            else {\n                prevCalendar.dispatch({ type: 'UNSET_EVENT_DRAG' });\n            }\n        }\n        if (nextCalendar) {\n            nextCalendar.dispatch({ type: 'SET_EVENT_DRAG', state: state });\n        }\n    };\n    EventDragging.prototype.clearDrag = function () {\n        var initialCalendar = this.component.context.calendar;\n        var receivingCalendar = this.receivingCalendar;\n        if (receivingCalendar) {\n            receivingCalendar.dispatch({ type: 'UNSET_EVENT_DRAG' });\n        }\n        // the initial calendar might have an dummy drag state from displayDrag\n        if (initialCalendar !== receivingCalendar) {\n            initialCalendar.dispatch({ type: 'UNSET_EVENT_DRAG' });\n        }\n    };\n    EventDragging.prototype.cleanup = function () {\n        this.subjectSeg = null;\n        this.isDragging = false;\n        this.eventRange = null;\n        this.relevantEvents = null;\n        this.receivingCalendar = null;\n        this.validMutation = null;\n        this.mutatedRelevantEvents = null;\n    };\n    EventDragging.SELECTOR = '.fc-draggable, .fc-resizable'; // TODO: test this in IE11\n    return EventDragging;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"Interaction\"]));\nfunction computeEventMutation(hit0, hit1, massagers) {\n    var dateSpan0 = hit0.dateSpan;\n    var dateSpan1 = hit1.dateSpan;\n    var date0 = dateSpan0.range.start;\n    var date1 = dateSpan1.range.start;\n    var standardProps = {};\n    if (dateSpan0.allDay !== dateSpan1.allDay) {\n        standardProps.allDay = dateSpan1.allDay;\n        standardProps.hasEnd = hit1.component.context.options.allDayMaintainDuration;\n        if (dateSpan1.allDay) {\n            // means date1 is already start-of-day,\n            // but date0 needs to be converted\n            date0 = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"startOfDay\"])(date0);\n        }\n    }\n    var delta = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"diffDates\"])(date0, date1, hit0.component.context.dateEnv, hit0.component === hit1.component ?\n        hit0.component.largeUnit :\n        null);\n    if (delta.milliseconds) { // has hours/minutes/seconds\n        standardProps.allDay = false;\n    }\n    var mutation = {\n        datesDelta: delta,\n        standardProps: standardProps\n    };\n    for (var _i = 0, massagers_1 = massagers; _i < massagers_1.length; _i++) {\n        var massager = massagers_1[_i];\n        massager(mutation, hit0, hit1);\n    }\n    return mutation;\n}\nfunction getComponentTouchDelay$1(component) {\n    var options = component.context.options;\n    var delay = options.eventLongPressDelay;\n    if (delay == null) {\n        delay = options.longPressDelay;\n    }\n    return delay;\n}\n\nvar EventDragging$1 = /** @class */ (function (_super) {\n    __extends(EventDragging, _super);\n    function EventDragging(settings) {\n        var _this = _super.call(this, settings) || this;\n        // internal state\n        _this.draggingSeg = null; // TODO: rename to resizingSeg? subjectSeg?\n        _this.eventRange = null;\n        _this.relevantEvents = null;\n        _this.validMutation = null;\n        _this.mutatedRelevantEvents = null;\n        _this.handlePointerDown = function (ev) {\n            var component = _this.component;\n            var seg = _this.querySeg(ev);\n            var eventRange = _this.eventRange = seg.eventRange;\n            _this.dragging.minDistance = component.context.options.eventDragMinDistance;\n            // if touch, need to be working with a selected event\n            _this.dragging.setIgnoreMove(!_this.component.isValidSegDownEl(ev.origEvent.target) ||\n                (ev.isTouch && _this.component.props.eventSelection !== eventRange.instance.instanceId));\n        };\n        _this.handleDragStart = function (ev) {\n            var _a = _this.component.context, calendar = _a.calendar, view = _a.view;\n            var eventRange = _this.eventRange;\n            _this.relevantEvents = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"getRelevantEvents\"])(calendar.state.eventStore, _this.eventRange.instance.instanceId);\n            _this.draggingSeg = _this.querySeg(ev);\n            calendar.unselect();\n            calendar.publiclyTrigger('eventResizeStart', [\n                {\n                    el: _this.draggingSeg.el,\n                    event: new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"EventApi\"](calendar, eventRange.def, eventRange.instance),\n                    jsEvent: ev.origEvent,\n                    view: view\n                }\n            ]);\n        };\n        _this.handleHitUpdate = function (hit, isFinal, ev) {\n            var calendar = _this.component.context.calendar;\n            var relevantEvents = _this.relevantEvents;\n            var initialHit = _this.hitDragging.initialHit;\n            var eventInstance = _this.eventRange.instance;\n            var mutation = null;\n            var mutatedRelevantEvents = null;\n            var isInvalid = false;\n            var interaction = {\n                affectedEvents: relevantEvents,\n                mutatedEvents: Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createEmptyEventStore\"])(),\n                isEvent: true,\n                origSeg: _this.draggingSeg\n            };\n            if (hit) {\n                mutation = computeMutation(initialHit, hit, ev.subjectEl.classList.contains('fc-start-resizer'), eventInstance.range, calendar.pluginSystem.hooks.eventResizeJoinTransforms);\n            }\n            if (mutation) {\n                mutatedRelevantEvents = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"applyMutationToEventStore\"])(relevantEvents, calendar.eventUiBases, mutation, calendar);\n                interaction.mutatedEvents = mutatedRelevantEvents;\n                if (!_this.component.isInteractionValid(interaction)) {\n                    isInvalid = true;\n                    mutation = null;\n                    mutatedRelevantEvents = null;\n                    interaction.mutatedEvents = null;\n                }\n            }\n            if (mutatedRelevantEvents) {\n                calendar.dispatch({\n                    type: 'SET_EVENT_RESIZE',\n                    state: interaction\n                });\n            }\n            else {\n                calendar.dispatch({ type: 'UNSET_EVENT_RESIZE' });\n            }\n            if (!isInvalid) {\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"enableCursor\"])();\n            }\n            else {\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"disableCursor\"])();\n            }\n            if (!isFinal) {\n                if (mutation && isHitsEqual(initialHit, hit)) {\n                    mutation = null;\n                }\n                _this.validMutation = mutation;\n                _this.mutatedRelevantEvents = mutatedRelevantEvents;\n            }\n        };\n        _this.handleDragEnd = function (ev) {\n            var _a = _this.component.context, calendar = _a.calendar, view = _a.view;\n            var eventDef = _this.eventRange.def;\n            var eventInstance = _this.eventRange.instance;\n            var eventApi = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"EventApi\"](calendar, eventDef, eventInstance);\n            var relevantEvents = _this.relevantEvents;\n            var mutatedRelevantEvents = _this.mutatedRelevantEvents;\n            calendar.publiclyTrigger('eventResizeStop', [\n                {\n                    el: _this.draggingSeg.el,\n                    event: eventApi,\n                    jsEvent: ev.origEvent,\n                    view: view\n                }\n            ]);\n            if (_this.validMutation) {\n                calendar.dispatch({\n                    type: 'MERGE_EVENTS',\n                    eventStore: mutatedRelevantEvents\n                });\n                calendar.publiclyTrigger('eventResize', [\n                    {\n                        el: _this.draggingSeg.el,\n                        startDelta: _this.validMutation.startDelta || Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createDuration\"])(0),\n                        endDelta: _this.validMutation.endDelta || Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createDuration\"])(0),\n                        prevEvent: eventApi,\n                        event: new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"EventApi\"](// the data AFTER the mutation\n                        calendar, mutatedRelevantEvents.defs[eventDef.defId], eventInstance ? mutatedRelevantEvents.instances[eventInstance.instanceId] : null),\n                        revert: function () {\n                            calendar.dispatch({\n                                type: 'MERGE_EVENTS',\n                                eventStore: relevantEvents\n                            });\n                        },\n                        jsEvent: ev.origEvent,\n                        view: view\n                    }\n                ]);\n            }\n            else {\n                calendar.publiclyTrigger('_noEventResize');\n            }\n            // reset all internal state\n            _this.draggingSeg = null;\n            _this.relevantEvents = null;\n            _this.validMutation = null;\n            // okay to keep eventInstance around. useful to set it in handlePointerDown\n        };\n        var component = settings.component;\n        var dragging = _this.dragging = new FeaturefulElementDragging(component.el);\n        dragging.pointer.selector = '.fc-resizer';\n        dragging.touchScrollAllowed = false;\n        dragging.autoScroller.isEnabled = component.context.options.dragScroll;\n        var hitDragging = _this.hitDragging = new HitDragging(_this.dragging, Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"interactionSettingsToStore\"])(settings));\n        hitDragging.emitter.on('pointerdown', _this.handlePointerDown);\n        hitDragging.emitter.on('dragstart', _this.handleDragStart);\n        hitDragging.emitter.on('hitupdate', _this.handleHitUpdate);\n        hitDragging.emitter.on('dragend', _this.handleDragEnd);\n        return _this;\n    }\n    EventDragging.prototype.destroy = function () {\n        this.dragging.destroy();\n    };\n    EventDragging.prototype.querySeg = function (ev) {\n        return Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"getElSeg\"])(Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"elementClosest\"])(ev.subjectEl, this.component.fgSegSelector));\n    };\n    return EventDragging;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"Interaction\"]));\nfunction computeMutation(hit0, hit1, isFromStart, instanceRange, transforms) {\n    var dateEnv = hit0.component.context.dateEnv;\n    var date0 = hit0.dateSpan.range.start;\n    var date1 = hit1.dateSpan.range.start;\n    var delta = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"diffDates\"])(date0, date1, dateEnv, hit0.component.largeUnit);\n    var props = {};\n    for (var _i = 0, transforms_1 = transforms; _i < transforms_1.length; _i++) {\n        var transform = transforms_1[_i];\n        var res = transform(hit0, hit1);\n        if (res === false) {\n            return null;\n        }\n        else if (res) {\n            __assign(props, res);\n        }\n    }\n    if (isFromStart) {\n        if (dateEnv.add(instanceRange.start, delta) < instanceRange.end) {\n            props.startDelta = delta;\n            return props;\n        }\n    }\n    else {\n        if (dateEnv.add(instanceRange.end, delta) > instanceRange.start) {\n            props.endDelta = delta;\n            return props;\n        }\n    }\n    return null;\n}\n\nvar UnselectAuto = /** @class */ (function () {\n    function UnselectAuto(calendar) {\n        var _this = this;\n        this.isRecentPointerDateSelect = false; // wish we could use a selector to detect date selection, but uses hit system\n        this.onSelect = function (selectInfo) {\n            if (selectInfo.jsEvent) {\n                _this.isRecentPointerDateSelect = true;\n            }\n        };\n        this.onDocumentPointerUp = function (pev) {\n            var _a = _this, calendar = _a.calendar, documentPointer = _a.documentPointer;\n            var state = calendar.state;\n            // touch-scrolling should never unfocus any type of selection\n            if (!documentPointer.wasTouchScroll) {\n                if (state.dateSelection && // an existing date selection?\n                    !_this.isRecentPointerDateSelect // a new pointer-initiated date selection since last onDocumentPointerUp?\n                ) {\n                    var unselectAuto = calendar.viewOpt('unselectAuto');\n                    var unselectCancel = calendar.viewOpt('unselectCancel');\n                    if (unselectAuto && (!unselectAuto || !Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"elementClosest\"])(documentPointer.downEl, unselectCancel))) {\n                        calendar.unselect(pev);\n                    }\n                }\n                if (state.eventSelection && // an existing event selected?\n                    !Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"elementClosest\"])(documentPointer.downEl, EventDragging.SELECTOR) // interaction DIDN'T start on an event\n                ) {\n                    calendar.dispatch({ type: 'UNSELECT_EVENT' });\n                }\n            }\n            _this.isRecentPointerDateSelect = false;\n        };\n        this.calendar = calendar;\n        var documentPointer = this.documentPointer = new PointerDragging(document);\n        documentPointer.shouldIgnoreMove = true;\n        documentPointer.shouldWatchScroll = false;\n        documentPointer.emitter.on('pointerup', this.onDocumentPointerUp);\n        /*\n        TODO: better way to know about whether there was a selection with the pointer\n        */\n        calendar.on('select', this.onSelect);\n    }\n    UnselectAuto.prototype.destroy = function () {\n        this.calendar.off('select', this.onSelect);\n        this.documentPointer.destroy();\n    };\n    return UnselectAuto;\n}());\n\n/*\nGiven an already instantiated draggable object for one-or-more elements,\nInterprets any dragging as an attempt to drag an events that lives outside\nof a calendar onto a calendar.\n*/\nvar ExternalElementDragging = /** @class */ (function () {\n    function ExternalElementDragging(dragging, suppliedDragMeta) {\n        var _this = this;\n        this.receivingCalendar = null;\n        this.droppableEvent = null; // will exist for all drags, even if create:false\n        this.suppliedDragMeta = null;\n        this.dragMeta = null;\n        this.handleDragStart = function (ev) {\n            _this.dragMeta = _this.buildDragMeta(ev.subjectEl);\n        };\n        this.handleHitUpdate = function (hit, isFinal, ev) {\n            var dragging = _this.hitDragging.dragging;\n            var receivingCalendar = null;\n            var droppableEvent = null;\n            var isInvalid = false;\n            var interaction = {\n                affectedEvents: Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createEmptyEventStore\"])(),\n                mutatedEvents: Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createEmptyEventStore\"])(),\n                isEvent: _this.dragMeta.create,\n                origSeg: null\n            };\n            if (hit) {\n                receivingCalendar = hit.component.context.calendar;\n                if (_this.canDropElOnCalendar(ev.subjectEl, receivingCalendar)) {\n                    droppableEvent = computeEventForDateSpan(hit.dateSpan, _this.dragMeta, receivingCalendar);\n                    interaction.mutatedEvents = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"eventTupleToStore\"])(droppableEvent);\n                    isInvalid = !Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"isInteractionValid\"])(interaction, receivingCalendar);\n                    if (isInvalid) {\n                        interaction.mutatedEvents = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createEmptyEventStore\"])();\n                        droppableEvent = null;\n                    }\n                }\n            }\n            _this.displayDrag(receivingCalendar, interaction);\n            // show mirror if no already-rendered mirror element OR if we are shutting down the mirror (?)\n            // TODO: wish we could somehow wait for dispatch to guarantee render\n            dragging.setMirrorIsVisible(isFinal || !droppableEvent || !document.querySelector('.fc-mirror'));\n            if (!isInvalid) {\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"enableCursor\"])();\n            }\n            else {\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"disableCursor\"])();\n            }\n            if (!isFinal) {\n                dragging.setMirrorNeedsRevert(!droppableEvent);\n                _this.receivingCalendar = receivingCalendar;\n                _this.droppableEvent = droppableEvent;\n            }\n        };\n        this.handleDragEnd = function (pev) {\n            var _a = _this, receivingCalendar = _a.receivingCalendar, droppableEvent = _a.droppableEvent;\n            _this.clearDrag();\n            if (receivingCalendar && droppableEvent) {\n                var finalHit = _this.hitDragging.finalHit;\n                var finalView = finalHit.component.context.view;\n                var dragMeta = _this.dragMeta;\n                var arg = __assign({}, receivingCalendar.buildDatePointApi(finalHit.dateSpan), { draggedEl: pev.subjectEl, jsEvent: pev.origEvent, view: finalView });\n                receivingCalendar.publiclyTrigger('drop', [arg]);\n                if (dragMeta.create) {\n                    receivingCalendar.dispatch({\n                        type: 'MERGE_EVENTS',\n                        eventStore: Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"eventTupleToStore\"])(droppableEvent)\n                    });\n                    if (pev.isTouch) {\n                        receivingCalendar.dispatch({\n                            type: 'SELECT_EVENT',\n                            eventInstanceId: droppableEvent.instance.instanceId\n                        });\n                    }\n                    // signal that an external event landed\n                    receivingCalendar.publiclyTrigger('eventReceive', [\n                        {\n                            draggedEl: pev.subjectEl,\n                            event: new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"EventApi\"](receivingCalendar, droppableEvent.def, droppableEvent.instance),\n                            view: finalView\n                        }\n                    ]);\n                }\n            }\n            _this.receivingCalendar = null;\n            _this.droppableEvent = null;\n        };\n        var hitDragging = this.hitDragging = new HitDragging(dragging, _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"interactionSettingsStore\"]);\n        hitDragging.requireInitial = false; // will start outside of a component\n        hitDragging.emitter.on('dragstart', this.handleDragStart);\n        hitDragging.emitter.on('hitupdate', this.handleHitUpdate);\n        hitDragging.emitter.on('dragend', this.handleDragEnd);\n        this.suppliedDragMeta = suppliedDragMeta;\n    }\n    ExternalElementDragging.prototype.buildDragMeta = function (subjectEl) {\n        if (typeof this.suppliedDragMeta === 'object') {\n            return Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"parseDragMeta\"])(this.suppliedDragMeta);\n        }\n        else if (typeof this.suppliedDragMeta === 'function') {\n            return Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"parseDragMeta\"])(this.suppliedDragMeta(subjectEl));\n        }\n        else {\n            return getDragMetaFromEl(subjectEl);\n        }\n    };\n    ExternalElementDragging.prototype.displayDrag = function (nextCalendar, state) {\n        var prevCalendar = this.receivingCalendar;\n        if (prevCalendar && prevCalendar !== nextCalendar) {\n            prevCalendar.dispatch({ type: 'UNSET_EVENT_DRAG' });\n        }\n        if (nextCalendar) {\n            nextCalendar.dispatch({ type: 'SET_EVENT_DRAG', state: state });\n        }\n    };\n    ExternalElementDragging.prototype.clearDrag = function () {\n        if (this.receivingCalendar) {\n            this.receivingCalendar.dispatch({ type: 'UNSET_EVENT_DRAG' });\n        }\n    };\n    ExternalElementDragging.prototype.canDropElOnCalendar = function (el, receivingCalendar) {\n        var dropAccept = receivingCalendar.opt('dropAccept');\n        if (typeof dropAccept === 'function') {\n            return dropAccept(el);\n        }\n        else if (typeof dropAccept === 'string' && dropAccept) {\n            return Boolean(Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"elementMatches\"])(el, dropAccept));\n        }\n        return true;\n    };\n    return ExternalElementDragging;\n}());\n// Utils for computing event store from the DragMeta\n// ----------------------------------------------------------------------------------------------------\nfunction computeEventForDateSpan(dateSpan, dragMeta, calendar) {\n    var defProps = __assign({}, dragMeta.leftoverProps);\n    for (var _i = 0, _a = calendar.pluginSystem.hooks.externalDefTransforms; _i < _a.length; _i++) {\n        var transform = _a[_i];\n        __assign(defProps, transform(dateSpan, dragMeta));\n    }\n    var def = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"parseEventDef\"])(defProps, dragMeta.sourceId, dateSpan.allDay, calendar.opt('forceEventDuration') || Boolean(dragMeta.duration), // hasEnd\n    calendar);\n    var start = dateSpan.range.start;\n    // only rely on time info if drop zone is all-day,\n    // otherwise, we already know the time\n    if (dateSpan.allDay && dragMeta.startTime) {\n        start = calendar.dateEnv.add(start, dragMeta.startTime);\n    }\n    var end = dragMeta.duration ?\n        calendar.dateEnv.add(start, dragMeta.duration) :\n        calendar.getDefaultEventEnd(dateSpan.allDay, start);\n    var instance = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createEventInstance\"])(def.defId, { start: start, end: end });\n    return { def: def, instance: instance };\n}\n// Utils for extracting data from element\n// ----------------------------------------------------------------------------------------------------\nfunction getDragMetaFromEl(el) {\n    var str = getEmbeddedElData(el, 'event');\n    var obj = str ?\n        JSON.parse(str) :\n        { create: false }; // if no embedded data, assume no event creation\n    return Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"parseDragMeta\"])(obj);\n}\n_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"config\"].dataAttrPrefix = '';\nfunction getEmbeddedElData(el, name) {\n    var prefix = _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"config\"].dataAttrPrefix;\n    var prefixedName = (prefix ? prefix + '-' : '') + name;\n    return el.getAttribute('data-' + prefixedName) || '';\n}\n\n/*\nMakes an element (that is *external* to any calendar) draggable.\nCan pass in data that determines how an event will be created when dropped onto a calendar.\nLeverages FullCalendar's internal drag-n-drop functionality WITHOUT a third-party drag system.\n*/\nvar ExternalDraggable = /** @class */ (function () {\n    function ExternalDraggable(el, settings) {\n        var _this = this;\n        if (settings === void 0) { settings = {}; }\n        this.handlePointerDown = function (ev) {\n            var dragging = _this.dragging;\n            var _a = _this.settings, minDistance = _a.minDistance, longPressDelay = _a.longPressDelay;\n            dragging.minDistance =\n                minDistance != null ?\n                    minDistance :\n                    (ev.isTouch ? 0 : _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"globalDefaults\"].eventDragMinDistance);\n            dragging.delay =\n                ev.isTouch ? // TODO: eventually read eventLongPressDelay instead vvv\n                    (longPressDelay != null ? longPressDelay : _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"globalDefaults\"].longPressDelay) :\n                    0;\n        };\n        this.handleDragStart = function (ev) {\n            if (ev.isTouch &&\n                _this.dragging.delay &&\n                ev.subjectEl.classList.contains('fc-event')) {\n                _this.dragging.mirror.getMirrorEl().classList.add('fc-selected');\n            }\n        };\n        this.settings = settings;\n        var dragging = this.dragging = new FeaturefulElementDragging(el);\n        dragging.touchScrollAllowed = false;\n        if (settings.itemSelector != null) {\n            dragging.pointer.selector = settings.itemSelector;\n        }\n        if (settings.appendTo != null) {\n            dragging.mirror.parentNode = settings.appendTo; // TODO: write tests\n        }\n        dragging.emitter.on('pointerdown', this.handlePointerDown);\n        dragging.emitter.on('dragstart', this.handleDragStart);\n        new ExternalElementDragging(dragging, settings.eventData);\n    }\n    ExternalDraggable.prototype.destroy = function () {\n        this.dragging.destroy();\n    };\n    return ExternalDraggable;\n}());\n\n/*\nDetects when a *THIRD-PARTY* drag-n-drop system interacts with elements.\nThe third-party system is responsible for drawing the visuals effects of the drag.\nThis class simply monitors for pointer movements and fires events.\nIt also has the ability to hide the moving element (the \"mirror\") during the drag.\n*/\nvar InferredElementDragging = /** @class */ (function (_super) {\n    __extends(InferredElementDragging, _super);\n    function InferredElementDragging(containerEl) {\n        var _this = _super.call(this, containerEl) || this;\n        _this.shouldIgnoreMove = false;\n        _this.mirrorSelector = '';\n        _this.currentMirrorEl = null;\n        _this.handlePointerDown = function (ev) {\n            _this.emitter.trigger('pointerdown', ev);\n            if (!_this.shouldIgnoreMove) {\n                // fire dragstart right away. does not support delay or min-distance\n                _this.emitter.trigger('dragstart', ev);\n            }\n        };\n        _this.handlePointerMove = function (ev) {\n            if (!_this.shouldIgnoreMove) {\n                _this.emitter.trigger('dragmove', ev);\n            }\n        };\n        _this.handlePointerUp = function (ev) {\n            _this.emitter.trigger('pointerup', ev);\n            if (!_this.shouldIgnoreMove) {\n                // fire dragend right away. does not support a revert animation\n                _this.emitter.trigger('dragend', ev);\n            }\n        };\n        var pointer = _this.pointer = new PointerDragging(containerEl);\n        pointer.emitter.on('pointerdown', _this.handlePointerDown);\n        pointer.emitter.on('pointermove', _this.handlePointerMove);\n        pointer.emitter.on('pointerup', _this.handlePointerUp);\n        return _this;\n    }\n    InferredElementDragging.prototype.destroy = function () {\n        this.pointer.destroy();\n    };\n    InferredElementDragging.prototype.setIgnoreMove = function (bool) {\n        this.shouldIgnoreMove = bool;\n    };\n    InferredElementDragging.prototype.setMirrorIsVisible = function (bool) {\n        if (bool) {\n            // restore a previously hidden element.\n            // use the reference in case the selector class has already been removed.\n            if (this.currentMirrorEl) {\n                this.currentMirrorEl.style.visibility = '';\n                this.currentMirrorEl = null;\n            }\n        }\n        else {\n            var mirrorEl = this.mirrorSelector ?\n                document.querySelector(this.mirrorSelector) :\n                null;\n            if (mirrorEl) {\n                this.currentMirrorEl = mirrorEl;\n                mirrorEl.style.visibility = 'hidden';\n            }\n        }\n    };\n    return InferredElementDragging;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"ElementDragging\"]));\n\n/*\nBridges third-party drag-n-drop systems with FullCalendar.\nMust be instantiated and destroyed by caller.\n*/\nvar ThirdPartyDraggable = /** @class */ (function () {\n    function ThirdPartyDraggable(containerOrSettings, settings) {\n        var containerEl = document;\n        if (\n        // wish we could just test instanceof EventTarget, but doesn't work in IE11\n        containerOrSettings === document ||\n            containerOrSettings instanceof Element) {\n            containerEl = containerOrSettings;\n            settings = settings || {};\n        }\n        else {\n            settings = (containerOrSettings || {});\n        }\n        var dragging = this.dragging = new InferredElementDragging(containerEl);\n        if (typeof settings.itemSelector === 'string') {\n            dragging.pointer.selector = settings.itemSelector;\n        }\n        else if (containerEl === document) {\n            dragging.pointer.selector = '[data-event]';\n        }\n        if (typeof settings.mirrorSelector === 'string') {\n            dragging.mirrorSelector = settings.mirrorSelector;\n        }\n        new ExternalElementDragging(dragging, settings.eventData);\n    }\n    ThirdPartyDraggable.prototype.destroy = function () {\n        this.dragging.destroy();\n    };\n    return ThirdPartyDraggable;\n}());\n\nvar main = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createPlugin\"])({\n    componentInteractions: [DateClicking, DateSelecting, EventDragging, EventDragging$1],\n    calendarInteractions: [UnselectAuto],\n    elementDraggingImpl: FeaturefulElementDragging\n});\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (main);\n\n\n\n//# sourceURL=webpack:///./node_modules/@fullcalendar/interaction/main.esm.js?");

/***/ }),

/***/ "./node_modules/@fullcalendar/list/main.css":
/*!**************************************************!*\
  !*** ./node_modules/@fullcalendar/list/main.css ***!
  \**************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// extracted by mini-css-extract-plugin\n\n//# sourceURL=webpack:///./node_modules/@fullcalendar/list/main.css?");

/***/ }),

/***/ "./node_modules/@fullcalendar/list/main.esm.js":
/*!*****************************************************!*\
  !*** ./node_modules/@fullcalendar/list/main.esm.js ***!
  \*****************************************************/
/*! exports provided: default, ListView */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"ListView\", function() { return ListView; });\n/* harmony import */ var _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @fullcalendar/core */ \"./node_modules/@fullcalendar/core/main.esm.js\");\n/*!\nFullCalendar List View Plugin v4.4.2\nDocs & License: https://fullcalendar.io/\n(c) 2019 Adam Shaw\n*/\n\n\n\n/*! *****************************************************************************\r\nCopyright (c) Microsoft Corporation.\r\n\r\nPermission to use, copy, modify, and/or distribute this software for any\r\npurpose with or without fee is hereby granted.\r\n\r\nTHE SOFTWARE IS PROVIDED \"AS IS\" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH\r\nREGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY\r\nAND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,\r\nINDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM\r\nLOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR\r\nOTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR\r\nPERFORMANCE OF THIS SOFTWARE.\r\n***************************************************************************** */\r\n/* global Reflect, Promise */\r\n\r\nvar extendStatics = function(d, b) {\r\n    extendStatics = Object.setPrototypeOf ||\r\n        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||\r\n        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };\r\n    return extendStatics(d, b);\r\n};\r\n\r\nfunction __extends(d, b) {\r\n    extendStatics(d, b);\r\n    function __() { this.constructor = d; }\r\n    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());\r\n}\n\nvar ListEventRenderer = /** @class */ (function (_super) {\n    __extends(ListEventRenderer, _super);\n    function ListEventRenderer(listView) {\n        var _this = _super.call(this) || this;\n        _this.listView = listView;\n        return _this;\n    }\n    ListEventRenderer.prototype.attachSegs = function (segs) {\n        if (!segs.length) {\n            this.listView.renderEmptyMessage();\n        }\n        else {\n            this.listView.renderSegList(segs);\n        }\n    };\n    ListEventRenderer.prototype.detachSegs = function () {\n    };\n    // generates the HTML for a single event row\n    ListEventRenderer.prototype.renderSegHtml = function (seg) {\n        var _a = this.context, theme = _a.theme, options = _a.options;\n        var eventRange = seg.eventRange;\n        var eventDef = eventRange.def;\n        var eventInstance = eventRange.instance;\n        var eventUi = eventRange.ui;\n        var url = eventDef.url;\n        var classes = ['fc-list-item'].concat(eventUi.classNames);\n        var bgColor = eventUi.backgroundColor;\n        var timeHtml;\n        if (eventDef.allDay) {\n            timeHtml = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"getAllDayHtml\"])(options);\n        }\n        else if (Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"isMultiDayRange\"])(eventRange.range)) {\n            if (seg.isStart) {\n                timeHtml = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(this._getTimeText(eventInstance.range.start, seg.end, false // allDay\n                ));\n            }\n            else if (seg.isEnd) {\n                timeHtml = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(this._getTimeText(seg.start, eventInstance.range.end, false // allDay\n                ));\n            }\n            else { // inner segment that lasts the whole day\n                timeHtml = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"getAllDayHtml\"])(options);\n            }\n        }\n        else {\n            // Display the normal time text for the *event's* times\n            timeHtml = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(this.getTimeText(eventRange));\n        }\n        if (url) {\n            classes.push('fc-has-url');\n        }\n        return '<tr class=\"' + classes.join(' ') + '\">' +\n            (this.displayEventTime ?\n                '<td class=\"fc-list-item-time ' + theme.getClass('widgetContent') + '\">' +\n                    (timeHtml || '') +\n                    '</td>' :\n                '') +\n            '<td class=\"fc-list-item-marker ' + theme.getClass('widgetContent') + '\">' +\n            '<span class=\"fc-event-dot\"' +\n            (bgColor ?\n                ' style=\"background-color:' + bgColor + '\"' :\n                '') +\n            '></span>' +\n            '</td>' +\n            '<td class=\"fc-list-item-title ' + theme.getClass('widgetContent') + '\">' +\n            '<a' + (url ? ' href=\"' + Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(url) + '\"' : '') + '>' +\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(eventDef.title || '') +\n            '</a>' +\n            '</td>' +\n            '</tr>';\n    };\n    // like \"4:00am\"\n    ListEventRenderer.prototype.computeEventTimeFormat = function () {\n        return {\n            hour: 'numeric',\n            minute: '2-digit',\n            meridiem: 'short'\n        };\n    };\n    return ListEventRenderer;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"FgEventRenderer\"]));\n\n/*\nResponsible for the scroller, and forwarding event-related actions into the \"grid\".\n*/\nvar ListView = /** @class */ (function (_super) {\n    __extends(ListView, _super);\n    function ListView(viewSpec, parentEl) {\n        var _this = _super.call(this, viewSpec, parentEl) || this;\n        _this.computeDateVars = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoize\"])(computeDateVars);\n        _this.eventStoreToSegs = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoize\"])(_this._eventStoreToSegs);\n        _this.renderSkeleton = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderSkeleton, _this._unrenderSkeleton);\n        var eventRenderer = _this.eventRenderer = new ListEventRenderer(_this);\n        _this.renderContent = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(eventRenderer.renderSegs.bind(eventRenderer), eventRenderer.unrender.bind(eventRenderer), [_this.renderSkeleton]);\n        return _this;\n    }\n    ListView.prototype.firstContext = function (context) {\n        context.calendar.registerInteractiveComponent(this, {\n            el: this.el\n            // TODO: make aware that it doesn't do Hits\n        });\n    };\n    ListView.prototype.render = function (props, context) {\n        _super.prototype.render.call(this, props, context);\n        var _a = this.computeDateVars(props.dateProfile), dayDates = _a.dayDates, dayRanges = _a.dayRanges;\n        this.dayDates = dayDates;\n        this.renderSkeleton(context);\n        this.renderContent(context, this.eventStoreToSegs(props.eventStore, props.eventUiBases, dayRanges));\n    };\n    ListView.prototype.destroy = function () {\n        _super.prototype.destroy.call(this);\n        this.renderSkeleton.unrender();\n        this.renderContent.unrender();\n        this.context.calendar.unregisterInteractiveComponent(this);\n    };\n    ListView.prototype._renderSkeleton = function (context) {\n        var theme = context.theme;\n        this.el.classList.add('fc-list-view');\n        var listViewClassNames = (theme.getClass('listView') || '').split(' '); // wish we didn't have to do this\n        for (var _i = 0, listViewClassNames_1 = listViewClassNames; _i < listViewClassNames_1.length; _i++) {\n            var listViewClassName = listViewClassNames_1[_i];\n            if (listViewClassName) { // in case input was empty string\n                this.el.classList.add(listViewClassName);\n            }\n        }\n        this.scroller = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"ScrollComponent\"]('hidden', // overflow x\n        'auto' // overflow y\n        );\n        this.el.appendChild(this.scroller.el);\n        this.contentEl = this.scroller.el; // shortcut\n    };\n    ListView.prototype._unrenderSkeleton = function () {\n        // TODO: remove classNames\n        this.scroller.destroy(); // will remove the Grid too\n    };\n    ListView.prototype.updateSize = function (isResize, viewHeight, isAuto) {\n        _super.prototype.updateSize.call(this, isResize, viewHeight, isAuto);\n        this.eventRenderer.computeSizes(isResize);\n        this.eventRenderer.assignSizes(isResize);\n        this.scroller.clear(); // sets height to 'auto' and clears overflow\n        if (!isAuto) {\n            this.scroller.setHeight(this.computeScrollerHeight(viewHeight));\n        }\n    };\n    ListView.prototype.computeScrollerHeight = function (viewHeight) {\n        return viewHeight -\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"subtractInnerElHeight\"])(this.el, this.scroller.el); // everything that's NOT the scroller\n    };\n    ListView.prototype._eventStoreToSegs = function (eventStore, eventUiBases, dayRanges) {\n        return this.eventRangesToSegs(Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"sliceEventStore\"])(eventStore, eventUiBases, this.props.dateProfile.activeRange, this.context.nextDayThreshold).fg, dayRanges);\n    };\n    ListView.prototype.eventRangesToSegs = function (eventRanges, dayRanges) {\n        var segs = [];\n        for (var _i = 0, eventRanges_1 = eventRanges; _i < eventRanges_1.length; _i++) {\n            var eventRange = eventRanges_1[_i];\n            segs.push.apply(segs, this.eventRangeToSegs(eventRange, dayRanges));\n        }\n        return segs;\n    };\n    ListView.prototype.eventRangeToSegs = function (eventRange, dayRanges) {\n        var _a = this.context, dateEnv = _a.dateEnv, nextDayThreshold = _a.nextDayThreshold;\n        var range = eventRange.range;\n        var allDay = eventRange.def.allDay;\n        var dayIndex;\n        var segRange;\n        var seg;\n        var segs = [];\n        for (dayIndex = 0; dayIndex < dayRanges.length; dayIndex++) {\n            segRange = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"intersectRanges\"])(range, dayRanges[dayIndex]);\n            if (segRange) {\n                seg = {\n                    component: this,\n                    eventRange: eventRange,\n                    start: segRange.start,\n                    end: segRange.end,\n                    isStart: eventRange.isStart && segRange.start.valueOf() === range.start.valueOf(),\n                    isEnd: eventRange.isEnd && segRange.end.valueOf() === range.end.valueOf(),\n                    dayIndex: dayIndex\n                };\n                segs.push(seg);\n                // detect when range won't go fully into the next day,\n                // and mutate the latest seg to the be the end.\n                if (!seg.isEnd && !allDay &&\n                    dayIndex + 1 < dayRanges.length &&\n                    range.end <\n                        dateEnv.add(dayRanges[dayIndex + 1].start, nextDayThreshold)) {\n                    seg.end = range.end;\n                    seg.isEnd = true;\n                    break;\n                }\n            }\n        }\n        return segs;\n    };\n    ListView.prototype.renderEmptyMessage = function () {\n        this.contentEl.innerHTML =\n            '<div class=\"fc-list-empty-wrap2\">' + // TODO: try less wraps\n                '<div class=\"fc-list-empty-wrap1\">' +\n                '<div class=\"fc-list-empty\">' +\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(this.context.options.noEventsMessage) +\n                '</div>' +\n                '</div>' +\n                '</div>';\n    };\n    // called by ListEventRenderer\n    ListView.prototype.renderSegList = function (allSegs) {\n        var theme = this.context.theme;\n        var segsByDay = this.groupSegsByDay(allSegs); // sparse array\n        var dayIndex;\n        var daySegs;\n        var i;\n        var tableEl = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlToElement\"])('<table class=\"fc-list-table ' + theme.getClass('tableList') + '\"><tbody></tbody></table>');\n        var tbodyEl = tableEl.querySelector('tbody');\n        for (dayIndex = 0; dayIndex < segsByDay.length; dayIndex++) {\n            daySegs = segsByDay[dayIndex];\n            if (daySegs) { // sparse array, so might be undefined\n                // append a day header\n                tbodyEl.appendChild(this.buildDayHeaderRow(this.dayDates[dayIndex]));\n                daySegs = this.eventRenderer.sortEventSegs(daySegs);\n                for (i = 0; i < daySegs.length; i++) {\n                    tbodyEl.appendChild(daySegs[i].el); // append event row\n                }\n            }\n        }\n        this.contentEl.innerHTML = '';\n        this.contentEl.appendChild(tableEl);\n    };\n    // Returns a sparse array of arrays, segs grouped by their dayIndex\n    ListView.prototype.groupSegsByDay = function (segs) {\n        var segsByDay = []; // sparse array\n        var i;\n        var seg;\n        for (i = 0; i < segs.length; i++) {\n            seg = segs[i];\n            (segsByDay[seg.dayIndex] || (segsByDay[seg.dayIndex] = []))\n                .push(seg);\n        }\n        return segsByDay;\n    };\n    // generates the HTML for the day headers that live amongst the event rows\n    ListView.prototype.buildDayHeaderRow = function (dayDate) {\n        var _a = this.context, theme = _a.theme, dateEnv = _a.dateEnv, options = _a.options;\n        var mainFormat = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createFormatter\"])(options.listDayFormat); // TODO: cache\n        var altFormat = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createFormatter\"])(options.listDayAltFormat); // TODO: cache\n        return Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createElement\"])('tr', {\n            className: 'fc-list-heading',\n            'data-date': dateEnv.formatIso(dayDate, { omitTime: true })\n        }, '<td class=\"' + (theme.getClass('tableListHeading') ||\n            theme.getClass('widgetHeader')) + '\" colspan=\"3\">' +\n            (mainFormat ?\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"buildGotoAnchorHtml\"])(options, dateEnv, dayDate, { 'class': 'fc-list-heading-main' }, Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(dateEnv.format(dayDate, mainFormat)) // inner HTML\n                ) :\n                '') +\n            (altFormat ?\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"buildGotoAnchorHtml\"])(options, dateEnv, dayDate, { 'class': 'fc-list-heading-alt' }, Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(dateEnv.format(dayDate, altFormat)) // inner HTML\n                ) :\n                '') +\n            '</td>');\n    };\n    return ListView;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"View\"]));\nListView.prototype.fgSegSelector = '.fc-list-item'; // which elements accept event actions\nfunction computeDateVars(dateProfile) {\n    var dayStart = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"startOfDay\"])(dateProfile.renderRange.start);\n    var viewEnd = dateProfile.renderRange.end;\n    var dayDates = [];\n    var dayRanges = [];\n    while (dayStart < viewEnd) {\n        dayDates.push(dayStart);\n        dayRanges.push({\n            start: dayStart,\n            end: Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"addDays\"])(dayStart, 1)\n        });\n        dayStart = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"addDays\"])(dayStart, 1);\n    }\n    return { dayDates: dayDates, dayRanges: dayRanges };\n}\n\nvar main = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createPlugin\"])({\n    views: {\n        list: {\n            class: ListView,\n            buttonTextKey: 'list',\n            listDayFormat: { month: 'long', day: 'numeric', year: 'numeric' } // like \"January 1, 2016\"\n        },\n        listDay: {\n            type: 'list',\n            duration: { days: 1 },\n            listDayFormat: { weekday: 'long' } // day-of-week is all we need. full date is probably in header\n        },\n        listWeek: {\n            type: 'list',\n            duration: { weeks: 1 },\n            listDayFormat: { weekday: 'long' },\n            listDayAltFormat: { month: 'long', day: 'numeric', year: 'numeric' }\n        },\n        listMonth: {\n            type: 'list',\n            duration: { month: 1 },\n            listDayAltFormat: { weekday: 'long' } // day-of-week is nice-to-have\n        },\n        listYear: {\n            type: 'list',\n            duration: { year: 1 },\n            listDayAltFormat: { weekday: 'long' } // day-of-week is nice-to-have\n        }\n    }\n});\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (main);\n\n\n\n//# sourceURL=webpack:///./node_modules/@fullcalendar/list/main.esm.js?");

/***/ }),

/***/ "./node_modules/@fullcalendar/timegrid/main.css":
/*!******************************************************!*\
  !*** ./node_modules/@fullcalendar/timegrid/main.css ***!
  \******************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

eval("// extracted by mini-css-extract-plugin\n\n//# sourceURL=webpack:///./node_modules/@fullcalendar/timegrid/main.css?");

/***/ }),

/***/ "./node_modules/@fullcalendar/timegrid/main.esm.js":
/*!*********************************************************!*\
  !*** ./node_modules/@fullcalendar/timegrid/main.esm.js ***!
  \*********************************************************/
/*! exports provided: default, AbstractTimeGridView, TimeGrid, TimeGridSlicer, TimeGridView, buildDayRanges, buildDayTable */
/***/ (function(module, __webpack_exports__, __webpack_require__) {

"use strict";
eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"AbstractTimeGridView\", function() { return AbstractTimeGridView; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"TimeGrid\", function() { return TimeGrid; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"TimeGridSlicer\", function() { return TimeGridSlicer; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"TimeGridView\", function() { return TimeGridView; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"buildDayRanges\", function() { return buildDayRanges; });\n/* harmony export (binding) */ __webpack_require__.d(__webpack_exports__, \"buildDayTable\", function() { return buildDayTable; });\n/* harmony import */ var _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! @fullcalendar/core */ \"./node_modules/@fullcalendar/core/main.esm.js\");\n/* harmony import */ var _fullcalendar_daygrid__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! @fullcalendar/daygrid */ \"./node_modules/@fullcalendar/daygrid/main.esm.js\");\n/*!\nFullCalendar Time Grid Plugin v4.4.2\nDocs & License: https://fullcalendar.io/\n(c) 2019 Adam Shaw\n*/\n\n\n\n\n/*! *****************************************************************************\r\nCopyright (c) Microsoft Corporation.\r\n\r\nPermission to use, copy, modify, and/or distribute this software for any\r\npurpose with or without fee is hereby granted.\r\n\r\nTHE SOFTWARE IS PROVIDED \"AS IS\" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH\r\nREGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY\r\nAND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,\r\nINDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM\r\nLOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR\r\nOTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR\r\nPERFORMANCE OF THIS SOFTWARE.\r\n***************************************************************************** */\r\n/* global Reflect, Promise */\r\n\r\nvar extendStatics = function(d, b) {\r\n    extendStatics = Object.setPrototypeOf ||\r\n        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||\r\n        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };\r\n    return extendStatics(d, b);\r\n};\r\n\r\nfunction __extends(d, b) {\r\n    extendStatics(d, b);\r\n    function __() { this.constructor = d; }\r\n    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());\r\n}\r\n\r\nvar __assign = function() {\r\n    __assign = Object.assign || function __assign(t) {\r\n        for (var s, i = 1, n = arguments.length; i < n; i++) {\r\n            s = arguments[i];\r\n            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];\r\n        }\r\n        return t;\r\n    };\r\n    return __assign.apply(this, arguments);\r\n};\n\n/*\nOnly handles foreground segs.\nDoes not own rendering. Use for low-level util methods by TimeGrid.\n*/\nvar TimeGridEventRenderer = /** @class */ (function (_super) {\n    __extends(TimeGridEventRenderer, _super);\n    function TimeGridEventRenderer(timeGrid) {\n        var _this = _super.call(this) || this;\n        _this.timeGrid = timeGrid;\n        return _this;\n    }\n    TimeGridEventRenderer.prototype.renderSegs = function (context, segs, mirrorInfo) {\n        _super.prototype.renderSegs.call(this, context, segs, mirrorInfo);\n        // TODO: dont do every time. memoize\n        this.fullTimeFormat = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createFormatter\"])({\n            hour: 'numeric',\n            minute: '2-digit',\n            separator: this.context.options.defaultRangeSeparator\n        });\n    };\n    // Given an array of foreground segments, render a DOM element for each, computes position,\n    // and attaches to the column inner-container elements.\n    TimeGridEventRenderer.prototype.attachSegs = function (segs, mirrorInfo) {\n        var segsByCol = this.timeGrid.groupSegsByCol(segs);\n        // order the segs within each column\n        // TODO: have groupSegsByCol do this?\n        for (var col = 0; col < segsByCol.length; col++) {\n            segsByCol[col] = this.sortEventSegs(segsByCol[col]);\n        }\n        this.segsByCol = segsByCol;\n        this.timeGrid.attachSegsByCol(segsByCol, this.timeGrid.fgContainerEls);\n    };\n    TimeGridEventRenderer.prototype.detachSegs = function (segs) {\n        segs.forEach(function (seg) {\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"removeElement\"])(seg.el);\n        });\n        this.segsByCol = null;\n    };\n    TimeGridEventRenderer.prototype.computeSegSizes = function (allSegs) {\n        var _a = this, timeGrid = _a.timeGrid, segsByCol = _a.segsByCol;\n        var colCnt = timeGrid.colCnt;\n        timeGrid.computeSegVerticals(allSegs); // horizontals relies on this\n        if (segsByCol) {\n            for (var col = 0; col < colCnt; col++) {\n                this.computeSegHorizontals(segsByCol[col]); // compute horizontal coordinates, z-index's, and reorder the array\n            }\n        }\n    };\n    TimeGridEventRenderer.prototype.assignSegSizes = function (allSegs) {\n        var _a = this, timeGrid = _a.timeGrid, segsByCol = _a.segsByCol;\n        var colCnt = timeGrid.colCnt;\n        timeGrid.assignSegVerticals(allSegs); // horizontals relies on this\n        if (segsByCol) {\n            for (var col = 0; col < colCnt; col++) {\n                this.assignSegCss(segsByCol[col]);\n            }\n        }\n    };\n    // Computes a default event time formatting string if `eventTimeFormat` is not explicitly defined\n    TimeGridEventRenderer.prototype.computeEventTimeFormat = function () {\n        return {\n            hour: 'numeric',\n            minute: '2-digit',\n            meridiem: false\n        };\n    };\n    // Computes a default `displayEventEnd` value if one is not expliclty defined\n    TimeGridEventRenderer.prototype.computeDisplayEventEnd = function () {\n        return true;\n    };\n    // Renders the HTML for a single event segment's default rendering\n    TimeGridEventRenderer.prototype.renderSegHtml = function (seg, mirrorInfo) {\n        var eventRange = seg.eventRange;\n        var eventDef = eventRange.def;\n        var eventUi = eventRange.ui;\n        var allDay = eventDef.allDay;\n        var isDraggable = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeEventDraggable\"])(this.context, eventDef, eventUi);\n        var isResizableFromStart = seg.isStart && Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeEventStartResizable\"])(this.context, eventDef, eventUi);\n        var isResizableFromEnd = seg.isEnd && Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"computeEventEndResizable\"])(this.context, eventDef, eventUi);\n        var classes = this.getSegClasses(seg, isDraggable, isResizableFromStart || isResizableFromEnd, mirrorInfo);\n        var skinCss = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"cssToStr\"])(this.getSkinCss(eventUi));\n        var timeText;\n        var fullTimeText; // more verbose time text. for the print stylesheet\n        var startTimeText; // just the start time text\n        classes.unshift('fc-time-grid-event');\n        // if the event appears to span more than one day...\n        if (Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"isMultiDayRange\"])(eventRange.range)) {\n            // Don't display time text on segments that run entirely through a day.\n            // That would appear as midnight-midnight and would look dumb.\n            // Otherwise, display the time text for the *segment's* times (like 6pm-midnight or midnight-10am)\n            if (seg.isStart || seg.isEnd) {\n                var unzonedStart = seg.start;\n                var unzonedEnd = seg.end;\n                timeText = this._getTimeText(unzonedStart, unzonedEnd, allDay); // TODO: give the timezones\n                fullTimeText = this._getTimeText(unzonedStart, unzonedEnd, allDay, this.fullTimeFormat);\n                startTimeText = this._getTimeText(unzonedStart, unzonedEnd, allDay, null, false); // displayEnd=false\n            }\n        }\n        else {\n            // Display the normal time text for the *event's* times\n            timeText = this.getTimeText(eventRange);\n            fullTimeText = this.getTimeText(eventRange, this.fullTimeFormat);\n            startTimeText = this.getTimeText(eventRange, null, false); // displayEnd=false\n        }\n        return '<a class=\"' + classes.join(' ') + '\"' +\n            (eventDef.url ?\n                ' href=\"' + Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(eventDef.url) + '\"' :\n                '') +\n            (skinCss ?\n                ' style=\"' + skinCss + '\"' :\n                '') +\n            '>' +\n            '<div class=\"fc-content\">' +\n            (timeText ?\n                '<div class=\"fc-time\"' +\n                    ' data-start=\"' + Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(startTimeText) + '\"' +\n                    ' data-full=\"' + Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(fullTimeText) + '\"' +\n                    '>' +\n                    '<span>' + Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(timeText) + '</span>' +\n                    '</div>' :\n                '') +\n            (eventDef.title ?\n                '<div class=\"fc-title\">' +\n                    Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(eventDef.title) +\n                    '</div>' :\n                '') +\n            '</div>' +\n            /* TODO: write CSS for this\n            (isResizableFromStart ?\n              '<div class=\"fc-resizer fc-start-resizer\"></div>' :\n              ''\n              ) +\n            */\n            (isResizableFromEnd ?\n                '<div class=\"fc-resizer fc-end-resizer\"></div>' :\n                '') +\n            '</a>';\n    };\n    // Given an array of segments that are all in the same column, sets the backwardCoord and forwardCoord on each.\n    // Assumed the segs are already ordered.\n    // NOTE: Also reorders the given array by date!\n    TimeGridEventRenderer.prototype.computeSegHorizontals = function (segs) {\n        var levels;\n        var level0;\n        var i;\n        levels = buildSlotSegLevels(segs);\n        computeForwardSlotSegs(levels);\n        if ((level0 = levels[0])) {\n            for (i = 0; i < level0.length; i++) {\n                computeSlotSegPressures(level0[i]);\n            }\n            for (i = 0; i < level0.length; i++) {\n                this.computeSegForwardBack(level0[i], 0, 0);\n            }\n        }\n    };\n    // Calculate seg.forwardCoord and seg.backwardCoord for the segment, where both values range\n    // from 0 to 1. If the calendar is left-to-right, the seg.backwardCoord maps to \"left\" and\n    // seg.forwardCoord maps to \"right\" (via percentage). Vice-versa if the calendar is right-to-left.\n    //\n    // The segment might be part of a \"series\", which means consecutive segments with the same pressure\n    // who's width is unknown until an edge has been hit. `seriesBackwardPressure` is the number of\n    // segments behind this one in the current series, and `seriesBackwardCoord` is the starting\n    // coordinate of the first segment in the series.\n    TimeGridEventRenderer.prototype.computeSegForwardBack = function (seg, seriesBackwardPressure, seriesBackwardCoord) {\n        var forwardSegs = seg.forwardSegs;\n        var i;\n        if (seg.forwardCoord === undefined) { // not already computed\n            if (!forwardSegs.length) {\n                // if there are no forward segments, this segment should butt up against the edge\n                seg.forwardCoord = 1;\n            }\n            else {\n                // sort highest pressure first\n                this.sortForwardSegs(forwardSegs);\n                // this segment's forwardCoord will be calculated from the backwardCoord of the\n                // highest-pressure forward segment.\n                this.computeSegForwardBack(forwardSegs[0], seriesBackwardPressure + 1, seriesBackwardCoord);\n                seg.forwardCoord = forwardSegs[0].backwardCoord;\n            }\n            // calculate the backwardCoord from the forwardCoord. consider the series\n            seg.backwardCoord = seg.forwardCoord -\n                (seg.forwardCoord - seriesBackwardCoord) / // available width for series\n                    (seriesBackwardPressure + 1); // # of segments in the series\n            // use this segment's coordinates to computed the coordinates of the less-pressurized\n            // forward segments\n            for (i = 0; i < forwardSegs.length; i++) {\n                this.computeSegForwardBack(forwardSegs[i], 0, seg.forwardCoord);\n            }\n        }\n    };\n    TimeGridEventRenderer.prototype.sortForwardSegs = function (forwardSegs) {\n        var objs = forwardSegs.map(buildTimeGridSegCompareObj);\n        var specs = [\n            // put higher-pressure first\n            { field: 'forwardPressure', order: -1 },\n            // put segments that are closer to initial edge first (and favor ones with no coords yet)\n            { field: 'backwardCoord', order: 1 }\n        ].concat(this.context.eventOrderSpecs);\n        objs.sort(function (obj0, obj1) {\n            return Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"compareByFieldSpecs\"])(obj0, obj1, specs);\n        });\n        return objs.map(function (c) {\n            return c._seg;\n        });\n    };\n    // Given foreground event segments that have already had their position coordinates computed,\n    // assigns position-related CSS values to their elements.\n    TimeGridEventRenderer.prototype.assignSegCss = function (segs) {\n        for (var _i = 0, segs_1 = segs; _i < segs_1.length; _i++) {\n            var seg = segs_1[_i];\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"applyStyle\"])(seg.el, this.generateSegCss(seg));\n            if (seg.level > 0) {\n                seg.el.classList.add('fc-time-grid-event-inset');\n            }\n            // if the event is short that the title will be cut off,\n            // attach a className that condenses the title into the time area.\n            if (seg.eventRange.def.title && seg.bottom - seg.top < 30) {\n                seg.el.classList.add('fc-short'); // TODO: \"condensed\" is a better name\n            }\n        }\n    };\n    // Generates an object with CSS properties/values that should be applied to an event segment element.\n    // Contains important positioning-related properties that should be applied to any event element, customized or not.\n    TimeGridEventRenderer.prototype.generateSegCss = function (seg) {\n        var shouldOverlap = this.context.options.slotEventOverlap;\n        var backwardCoord = seg.backwardCoord; // the left side if LTR. the right side if RTL. floating-point\n        var forwardCoord = seg.forwardCoord; // the right side if LTR. the left side if RTL. floating-point\n        var props = this.timeGrid.generateSegVerticalCss(seg); // get top/bottom first\n        var isRtl = this.context.isRtl;\n        var left; // amount of space from left edge, a fraction of the total width\n        var right; // amount of space from right edge, a fraction of the total width\n        if (shouldOverlap) {\n            // double the width, but don't go beyond the maximum forward coordinate (1.0)\n            forwardCoord = Math.min(1, backwardCoord + (forwardCoord - backwardCoord) * 2);\n        }\n        if (isRtl) {\n            left = 1 - forwardCoord;\n            right = backwardCoord;\n        }\n        else {\n            left = backwardCoord;\n            right = 1 - forwardCoord;\n        }\n        props.zIndex = seg.level + 1; // convert from 0-base to 1-based\n        props.left = left * 100 + '%';\n        props.right = right * 100 + '%';\n        if (shouldOverlap && seg.forwardPressure) {\n            // add padding to the edge so that forward stacked events don't cover the resizer's icon\n            props[isRtl ? 'marginLeft' : 'marginRight'] = 10 * 2; // 10 is a guesstimate of the icon's width\n        }\n        return props;\n    };\n    return TimeGridEventRenderer;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"FgEventRenderer\"]));\n// Builds an array of segments \"levels\". The first level will be the leftmost tier of segments if the calendar is\n// left-to-right, or the rightmost if the calendar is right-to-left. Assumes the segments are already ordered by date.\nfunction buildSlotSegLevels(segs) {\n    var levels = [];\n    var i;\n    var seg;\n    var j;\n    for (i = 0; i < segs.length; i++) {\n        seg = segs[i];\n        // go through all the levels and stop on the first level where there are no collisions\n        for (j = 0; j < levels.length; j++) {\n            if (!computeSlotSegCollisions(seg, levels[j]).length) {\n                break;\n            }\n        }\n        seg.level = j;\n        (levels[j] || (levels[j] = [])).push(seg);\n    }\n    return levels;\n}\n// For every segment, figure out the other segments that are in subsequent\n// levels that also occupy the same vertical space. Accumulate in seg.forwardSegs\nfunction computeForwardSlotSegs(levels) {\n    var i;\n    var level;\n    var j;\n    var seg;\n    var k;\n    for (i = 0; i < levels.length; i++) {\n        level = levels[i];\n        for (j = 0; j < level.length; j++) {\n            seg = level[j];\n            seg.forwardSegs = [];\n            for (k = i + 1; k < levels.length; k++) {\n                computeSlotSegCollisions(seg, levels[k], seg.forwardSegs);\n            }\n        }\n    }\n}\n// Figure out which path forward (via seg.forwardSegs) results in the longest path until\n// the furthest edge is reached. The number of segments in this path will be seg.forwardPressure\nfunction computeSlotSegPressures(seg) {\n    var forwardSegs = seg.forwardSegs;\n    var forwardPressure = 0;\n    var i;\n    var forwardSeg;\n    if (seg.forwardPressure === undefined) { // not already computed\n        for (i = 0; i < forwardSegs.length; i++) {\n            forwardSeg = forwardSegs[i];\n            // figure out the child's maximum forward path\n            computeSlotSegPressures(forwardSeg);\n            // either use the existing maximum, or use the child's forward pressure\n            // plus one (for the forwardSeg itself)\n            forwardPressure = Math.max(forwardPressure, 1 + forwardSeg.forwardPressure);\n        }\n        seg.forwardPressure = forwardPressure;\n    }\n}\n// Find all the segments in `otherSegs` that vertically collide with `seg`.\n// Append into an optionally-supplied `results` array and return.\nfunction computeSlotSegCollisions(seg, otherSegs, results) {\n    if (results === void 0) { results = []; }\n    for (var i = 0; i < otherSegs.length; i++) {\n        if (isSlotSegCollision(seg, otherSegs[i])) {\n            results.push(otherSegs[i]);\n        }\n    }\n    return results;\n}\n// Do these segments occupy the same vertical space?\nfunction isSlotSegCollision(seg1, seg2) {\n    return seg1.bottom > seg2.top && seg1.top < seg2.bottom;\n}\nfunction buildTimeGridSegCompareObj(seg) {\n    var obj = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"buildSegCompareObj\"])(seg);\n    obj.forwardPressure = seg.forwardPressure;\n    obj.backwardCoord = seg.backwardCoord;\n    return obj;\n}\n\nvar TimeGridMirrorRenderer = /** @class */ (function (_super) {\n    __extends(TimeGridMirrorRenderer, _super);\n    function TimeGridMirrorRenderer() {\n        return _super !== null && _super.apply(this, arguments) || this;\n    }\n    TimeGridMirrorRenderer.prototype.attachSegs = function (segs, mirrorInfo) {\n        this.segsByCol = this.timeGrid.groupSegsByCol(segs);\n        this.timeGrid.attachSegsByCol(this.segsByCol, this.timeGrid.mirrorContainerEls);\n        this.sourceSeg = mirrorInfo.sourceSeg;\n    };\n    TimeGridMirrorRenderer.prototype.generateSegCss = function (seg) {\n        var props = _super.prototype.generateSegCss.call(this, seg);\n        var sourceSeg = this.sourceSeg;\n        if (sourceSeg && sourceSeg.col === seg.col) {\n            var sourceSegProps = _super.prototype.generateSegCss.call(this, sourceSeg);\n            props.left = sourceSegProps.left;\n            props.right = sourceSegProps.right;\n            props.marginLeft = sourceSegProps.marginLeft;\n            props.marginRight = sourceSegProps.marginRight;\n        }\n        return props;\n    };\n    return TimeGridMirrorRenderer;\n}(TimeGridEventRenderer));\n\nvar TimeGridFillRenderer = /** @class */ (function (_super) {\n    __extends(TimeGridFillRenderer, _super);\n    function TimeGridFillRenderer(timeGrid) {\n        var _this = _super.call(this) || this;\n        _this.timeGrid = timeGrid;\n        return _this;\n    }\n    TimeGridFillRenderer.prototype.attachSegs = function (type, segs) {\n        var timeGrid = this.timeGrid;\n        var containerEls;\n        // TODO: more efficient lookup\n        if (type === 'bgEvent') {\n            containerEls = timeGrid.bgContainerEls;\n        }\n        else if (type === 'businessHours') {\n            containerEls = timeGrid.businessContainerEls;\n        }\n        else if (type === 'highlight') {\n            containerEls = timeGrid.highlightContainerEls;\n        }\n        timeGrid.attachSegsByCol(timeGrid.groupSegsByCol(segs), containerEls);\n        return segs.map(function (seg) {\n            return seg.el;\n        });\n    };\n    TimeGridFillRenderer.prototype.computeSegSizes = function (segs) {\n        this.timeGrid.computeSegVerticals(segs);\n    };\n    TimeGridFillRenderer.prototype.assignSegSizes = function (segs) {\n        this.timeGrid.assignSegVerticals(segs);\n    };\n    return TimeGridFillRenderer;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"FillRenderer\"]));\n\n/* A component that renders one or more columns of vertical time slots\n----------------------------------------------------------------------------------------------------------------------*/\n// potential nice values for the slot-duration and interval-duration\n// from largest to smallest\nvar AGENDA_STOCK_SUB_DURATIONS = [\n    { hours: 1 },\n    { minutes: 30 },\n    { minutes: 15 },\n    { seconds: 30 },\n    { seconds: 15 }\n];\nvar TimeGrid = /** @class */ (function (_super) {\n    __extends(TimeGrid, _super);\n    function TimeGrid(el, renderProps) {\n        var _this = _super.call(this, el) || this;\n        _this.isSlatSizesDirty = false;\n        _this.isColSizesDirty = false;\n        _this.processOptions = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoize\"])(_this._processOptions);\n        _this.renderSkeleton = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderSkeleton);\n        _this.renderSlats = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderSlats, null, [_this.renderSkeleton]);\n        _this.renderColumns = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderColumns, _this._unrenderColumns, [_this.renderSkeleton]);\n        _this.renderProps = renderProps;\n        var renderColumns = _this.renderColumns;\n        var eventRenderer = _this.eventRenderer = new TimeGridEventRenderer(_this);\n        var fillRenderer = _this.fillRenderer = new TimeGridFillRenderer(_this);\n        _this.mirrorRenderer = new TimeGridMirrorRenderer(_this);\n        _this.renderBusinessHours = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(fillRenderer.renderSegs.bind(fillRenderer, 'businessHours'), fillRenderer.unrender.bind(fillRenderer, 'businessHours'), [renderColumns]);\n        _this.renderDateSelection = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderDateSelection, _this._unrenderDateSelection, [renderColumns]);\n        _this.renderFgEvents = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(eventRenderer.renderSegs.bind(eventRenderer), eventRenderer.unrender.bind(eventRenderer), [renderColumns]);\n        _this.renderBgEvents = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(fillRenderer.renderSegs.bind(fillRenderer, 'bgEvent'), fillRenderer.unrender.bind(fillRenderer, 'bgEvent'), [renderColumns]);\n        _this.renderEventSelection = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(eventRenderer.selectByInstanceId.bind(eventRenderer), eventRenderer.unselectByInstanceId.bind(eventRenderer), [_this.renderFgEvents]);\n        _this.renderEventDrag = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderEventDrag, _this._unrenderEventDrag, [renderColumns]);\n        _this.renderEventResize = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderEventResize, _this._unrenderEventResize, [renderColumns]);\n        return _this;\n    }\n    /* Options\n    ------------------------------------------------------------------------------------------------------------------*/\n    // Parses various options into properties of this object\n    // MUST have context already set\n    TimeGrid.prototype._processOptions = function (options) {\n        var slotDuration = options.slotDuration, snapDuration = options.snapDuration;\n        var snapsPerSlot;\n        var input;\n        slotDuration = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createDuration\"])(slotDuration);\n        snapDuration = snapDuration ? Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createDuration\"])(snapDuration) : slotDuration;\n        snapsPerSlot = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"wholeDivideDurations\"])(slotDuration, snapDuration);\n        if (snapsPerSlot === null) {\n            snapDuration = slotDuration;\n            snapsPerSlot = 1;\n            // TODO: say warning?\n        }\n        this.slotDuration = slotDuration;\n        this.snapDuration = snapDuration;\n        this.snapsPerSlot = snapsPerSlot;\n        // might be an array value (for TimelineView).\n        // if so, getting the most granular entry (the last one probably).\n        input = options.slotLabelFormat;\n        if (Array.isArray(input)) {\n            input = input[input.length - 1];\n        }\n        this.labelFormat = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createFormatter\"])(input || {\n            hour: 'numeric',\n            minute: '2-digit',\n            omitZeroMinute: true,\n            meridiem: 'short'\n        });\n        input = options.slotLabelInterval;\n        this.labelInterval = input ?\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createDuration\"])(input) :\n            this.computeLabelInterval(slotDuration);\n    };\n    // Computes an automatic value for slotLabelInterval\n    TimeGrid.prototype.computeLabelInterval = function (slotDuration) {\n        var i;\n        var labelInterval;\n        var slotsPerLabel;\n        // find the smallest stock label interval that results in more than one slots-per-label\n        for (i = AGENDA_STOCK_SUB_DURATIONS.length - 1; i >= 0; i--) {\n            labelInterval = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createDuration\"])(AGENDA_STOCK_SUB_DURATIONS[i]);\n            slotsPerLabel = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"wholeDivideDurations\"])(labelInterval, slotDuration);\n            if (slotsPerLabel !== null && slotsPerLabel > 1) {\n                return labelInterval;\n            }\n        }\n        return slotDuration; // fall back\n    };\n    /* Rendering\n    ------------------------------------------------------------------------------------------------------------------*/\n    TimeGrid.prototype.render = function (props, context) {\n        this.processOptions(context.options);\n        var cells = props.cells;\n        this.colCnt = cells.length;\n        this.renderSkeleton(context.theme);\n        this.renderSlats(props.dateProfile);\n        this.renderColumns(props.cells, props.dateProfile);\n        this.renderBusinessHours(context, props.businessHourSegs);\n        this.renderDateSelection(props.dateSelectionSegs);\n        this.renderFgEvents(context, props.fgEventSegs);\n        this.renderBgEvents(context, props.bgEventSegs);\n        this.renderEventSelection(props.eventSelection);\n        this.renderEventDrag(props.eventDrag);\n        this.renderEventResize(props.eventResize);\n    };\n    TimeGrid.prototype.destroy = function () {\n        _super.prototype.destroy.call(this);\n        // should unrender everything else too\n        this.renderSlats.unrender();\n        this.renderColumns.unrender();\n        this.renderSkeleton.unrender();\n    };\n    TimeGrid.prototype.updateSize = function (isResize) {\n        var _a = this, fillRenderer = _a.fillRenderer, eventRenderer = _a.eventRenderer, mirrorRenderer = _a.mirrorRenderer;\n        if (isResize || this.isSlatSizesDirty) {\n            this.buildSlatPositions();\n            this.isSlatSizesDirty = false;\n        }\n        if (isResize || this.isColSizesDirty) {\n            this.buildColPositions();\n            this.isColSizesDirty = false;\n        }\n        fillRenderer.computeSizes(isResize);\n        eventRenderer.computeSizes(isResize);\n        mirrorRenderer.computeSizes(isResize);\n        fillRenderer.assignSizes(isResize);\n        eventRenderer.assignSizes(isResize);\n        mirrorRenderer.assignSizes(isResize);\n    };\n    TimeGrid.prototype._renderSkeleton = function (theme) {\n        var el = this.el;\n        el.innerHTML =\n            '<div class=\"fc-bg\"></div>' +\n                '<div class=\"fc-slats\"></div>' +\n                '<hr class=\"fc-divider ' + theme.getClass('widgetHeader') + '\" style=\"display:none\" />';\n        this.rootBgContainerEl = el.querySelector('.fc-bg');\n        this.slatContainerEl = el.querySelector('.fc-slats');\n        this.bottomRuleEl = el.querySelector('.fc-divider');\n    };\n    TimeGrid.prototype._renderSlats = function (dateProfile) {\n        var theme = this.context.theme;\n        this.slatContainerEl.innerHTML =\n            '<table class=\"' + theme.getClass('tableGrid') + '\">' +\n                this.renderSlatRowHtml(dateProfile) +\n                '</table>';\n        this.slatEls = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(this.slatContainerEl, 'tr');\n        this.slatPositions = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"PositionCache\"](this.el, this.slatEls, false, true // vertical\n        );\n        this.isSlatSizesDirty = true;\n    };\n    // Generates the HTML for the horizontal \"slats\" that run width-wise. Has a time axis on a side. Depends on RTL.\n    TimeGrid.prototype.renderSlatRowHtml = function (dateProfile) {\n        var _a = this.context, dateEnv = _a.dateEnv, theme = _a.theme, isRtl = _a.isRtl;\n        var html = '';\n        var dayStart = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"startOfDay\"])(dateProfile.renderRange.start);\n        var slotTime = dateProfile.minTime;\n        var slotIterator = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createDuration\"])(0);\n        var slotDate; // will be on the view's first day, but we only care about its time\n        var isLabeled;\n        var axisHtml;\n        // Calculate the time for each slot\n        while (Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"asRoughMs\"])(slotTime) < Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"asRoughMs\"])(dateProfile.maxTime)) {\n            slotDate = dateEnv.add(dayStart, slotTime);\n            isLabeled = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"wholeDivideDurations\"])(slotIterator, this.labelInterval) !== null;\n            axisHtml =\n                '<td class=\"fc-axis fc-time ' + theme.getClass('widgetContent') + '\">' +\n                    (isLabeled ?\n                        '<span>' + // for matchCellWidths\n                            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(dateEnv.format(slotDate, this.labelFormat)) +\n                            '</span>' :\n                        '') +\n                    '</td>';\n            html +=\n                '<tr data-time=\"' + Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"formatIsoTimeString\"])(slotDate) + '\"' +\n                    (isLabeled ? '' : ' class=\"fc-minor\"') +\n                    '>' +\n                    (!isRtl ? axisHtml : '') +\n                    '<td class=\"' + theme.getClass('widgetContent') + '\"></td>' +\n                    (isRtl ? axisHtml : '') +\n                    '</tr>';\n            slotTime = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"addDurations\"])(slotTime, this.slotDuration);\n            slotIterator = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"addDurations\"])(slotIterator, this.slotDuration);\n        }\n        return html;\n    };\n    TimeGrid.prototype._renderColumns = function (cells, dateProfile) {\n        var _a = this.context, calendar = _a.calendar, view = _a.view, isRtl = _a.isRtl, theme = _a.theme, dateEnv = _a.dateEnv;\n        var bgRow = new _fullcalendar_daygrid__WEBPACK_IMPORTED_MODULE_1__[\"DayBgRow\"](this.context);\n        this.rootBgContainerEl.innerHTML =\n            '<table class=\"' + theme.getClass('tableGrid') + '\">' +\n                bgRow.renderHtml({\n                    cells: cells,\n                    dateProfile: dateProfile,\n                    renderIntroHtml: this.renderProps.renderBgIntroHtml\n                }) +\n                '</table>';\n        this.colEls = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(this.el, '.fc-day, .fc-disabled-day');\n        for (var col = 0; col < this.colCnt; col++) {\n            calendar.publiclyTrigger('dayRender', [\n                {\n                    date: dateEnv.toDate(cells[col].date),\n                    el: this.colEls[col],\n                    view: view\n                }\n            ]);\n        }\n        if (isRtl) {\n            this.colEls.reverse();\n        }\n        this.colPositions = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"PositionCache\"](this.el, this.colEls, true, // horizontal\n        false);\n        this.renderContentSkeleton();\n        this.isColSizesDirty = true;\n    };\n    TimeGrid.prototype._unrenderColumns = function () {\n        this.unrenderContentSkeleton();\n    };\n    /* Content Skeleton\n    ------------------------------------------------------------------------------------------------------------------*/\n    // Renders the DOM that the view's content will live in\n    TimeGrid.prototype.renderContentSkeleton = function () {\n        var isRtl = this.context.isRtl;\n        var parts = [];\n        var skeletonEl;\n        parts.push(this.renderProps.renderIntroHtml());\n        for (var i = 0; i < this.colCnt; i++) {\n            parts.push('<td>' +\n                '<div class=\"fc-content-col\">' +\n                '<div class=\"fc-event-container fc-mirror-container\"></div>' +\n                '<div class=\"fc-event-container\"></div>' +\n                '<div class=\"fc-highlight-container\"></div>' +\n                '<div class=\"fc-bgevent-container\"></div>' +\n                '<div class=\"fc-business-container\"></div>' +\n                '</div>' +\n                '</td>');\n        }\n        if (isRtl) {\n            parts.reverse();\n        }\n        skeletonEl = this.contentSkeletonEl = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlToElement\"])('<div class=\"fc-content-skeleton\">' +\n            '<table>' +\n            '<tr>' + parts.join('') + '</tr>' +\n            '</table>' +\n            '</div>');\n        this.colContainerEls = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(skeletonEl, '.fc-content-col');\n        this.mirrorContainerEls = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(skeletonEl, '.fc-mirror-container');\n        this.fgContainerEls = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(skeletonEl, '.fc-event-container:not(.fc-mirror-container)');\n        this.bgContainerEls = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(skeletonEl, '.fc-bgevent-container');\n        this.highlightContainerEls = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(skeletonEl, '.fc-highlight-container');\n        this.businessContainerEls = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(skeletonEl, '.fc-business-container');\n        if (isRtl) {\n            this.colContainerEls.reverse();\n            this.mirrorContainerEls.reverse();\n            this.fgContainerEls.reverse();\n            this.bgContainerEls.reverse();\n            this.highlightContainerEls.reverse();\n            this.businessContainerEls.reverse();\n        }\n        this.el.appendChild(skeletonEl);\n    };\n    TimeGrid.prototype.unrenderContentSkeleton = function () {\n        Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"removeElement\"])(this.contentSkeletonEl);\n    };\n    // Given a flat array of segments, return an array of sub-arrays, grouped by each segment's col\n    TimeGrid.prototype.groupSegsByCol = function (segs) {\n        var segsByCol = [];\n        var i;\n        for (i = 0; i < this.colCnt; i++) {\n            segsByCol.push([]);\n        }\n        for (i = 0; i < segs.length; i++) {\n            segsByCol[segs[i].col].push(segs[i]);\n        }\n        return segsByCol;\n    };\n    // Given segments grouped by column, insert the segments' elements into a parallel array of container\n    // elements, each living within a column.\n    TimeGrid.prototype.attachSegsByCol = function (segsByCol, containerEls) {\n        var col;\n        var segs;\n        var i;\n        for (col = 0; col < this.colCnt; col++) { // iterate each column grouping\n            segs = segsByCol[col];\n            for (i = 0; i < segs.length; i++) {\n                containerEls[col].appendChild(segs[i].el);\n            }\n        }\n    };\n    /* Now Indicator\n    ------------------------------------------------------------------------------------------------------------------*/\n    TimeGrid.prototype.getNowIndicatorUnit = function () {\n        return 'minute'; // will refresh on the minute\n    };\n    TimeGrid.prototype.renderNowIndicator = function (segs, date) {\n        // HACK: if date columns not ready for some reason (scheduler)\n        if (!this.colContainerEls) {\n            return;\n        }\n        var top = this.computeDateTop(date);\n        var nodes = [];\n        var i;\n        // render lines within the columns\n        for (i = 0; i < segs.length; i++) {\n            var lineEl = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createElement\"])('div', { className: 'fc-now-indicator fc-now-indicator-line' });\n            lineEl.style.top = top + 'px';\n            this.colContainerEls[segs[i].col].appendChild(lineEl);\n            nodes.push(lineEl);\n        }\n        // render an arrow over the axis\n        if (segs.length > 0) { // is the current time in view?\n            var arrowEl = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createElement\"])('div', { className: 'fc-now-indicator fc-now-indicator-arrow' });\n            arrowEl.style.top = top + 'px';\n            this.contentSkeletonEl.appendChild(arrowEl);\n            nodes.push(arrowEl);\n        }\n        this.nowIndicatorEls = nodes;\n    };\n    TimeGrid.prototype.unrenderNowIndicator = function () {\n        if (this.nowIndicatorEls) {\n            this.nowIndicatorEls.forEach(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"removeElement\"]);\n            this.nowIndicatorEls = null;\n        }\n    };\n    /* Coordinates\n    ------------------------------------------------------------------------------------------------------------------*/\n    TimeGrid.prototype.getTotalSlatHeight = function () {\n        return this.slatContainerEl.getBoundingClientRect().height;\n    };\n    // Computes the top coordinate, relative to the bounds of the grid, of the given date.\n    // A `startOfDayDate` must be given for avoiding ambiguity over how to treat midnight.\n    TimeGrid.prototype.computeDateTop = function (when, startOfDayDate) {\n        if (!startOfDayDate) {\n            startOfDayDate = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"startOfDay\"])(when);\n        }\n        return this.computeTimeTop(Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createDuration\"])(when.valueOf() - startOfDayDate.valueOf()));\n    };\n    // Computes the top coordinate, relative to the bounds of the grid, of the given time (a Duration).\n    TimeGrid.prototype.computeTimeTop = function (duration) {\n        var len = this.slatEls.length;\n        var dateProfile = this.props.dateProfile;\n        var slatCoverage = (duration.milliseconds - Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"asRoughMs\"])(dateProfile.minTime)) / Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"asRoughMs\"])(this.slotDuration); // floating-point value of # of slots covered\n        var slatIndex;\n        var slatRemainder;\n        // compute a floating-point number for how many slats should be progressed through.\n        // from 0 to number of slats (inclusive)\n        // constrained because minTime/maxTime might be customized.\n        slatCoverage = Math.max(0, slatCoverage);\n        slatCoverage = Math.min(len, slatCoverage);\n        // an integer index of the furthest whole slat\n        // from 0 to number slats (*exclusive*, so len-1)\n        slatIndex = Math.floor(slatCoverage);\n        slatIndex = Math.min(slatIndex, len - 1);\n        // how much further through the slatIndex slat (from 0.0-1.0) must be covered in addition.\n        // could be 1.0 if slatCoverage is covering *all* the slots\n        slatRemainder = slatCoverage - slatIndex;\n        return this.slatPositions.tops[slatIndex] +\n            this.slatPositions.getHeight(slatIndex) * slatRemainder;\n    };\n    // For each segment in an array, computes and assigns its top and bottom properties\n    TimeGrid.prototype.computeSegVerticals = function (segs) {\n        var options = this.context.options;\n        var eventMinHeight = options.timeGridEventMinHeight;\n        var i;\n        var seg;\n        var dayDate;\n        for (i = 0; i < segs.length; i++) {\n            seg = segs[i];\n            dayDate = this.props.cells[seg.col].date;\n            seg.top = this.computeDateTop(seg.start, dayDate);\n            seg.bottom = Math.max(seg.top + eventMinHeight, this.computeDateTop(seg.end, dayDate));\n        }\n    };\n    // Given segments that already have their top/bottom properties computed, applies those values to\n    // the segments' elements.\n    TimeGrid.prototype.assignSegVerticals = function (segs) {\n        var i;\n        var seg;\n        for (i = 0; i < segs.length; i++) {\n            seg = segs[i];\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"applyStyle\"])(seg.el, this.generateSegVerticalCss(seg));\n        }\n    };\n    // Generates an object with CSS properties for the top/bottom coordinates of a segment element\n    TimeGrid.prototype.generateSegVerticalCss = function (seg) {\n        return {\n            top: seg.top,\n            bottom: -seg.bottom // flipped because needs to be space beyond bottom edge of event container\n        };\n    };\n    /* Sizing\n    ------------------------------------------------------------------------------------------------------------------*/\n    TimeGrid.prototype.buildPositionCaches = function () {\n        this.buildColPositions();\n        this.buildSlatPositions();\n    };\n    TimeGrid.prototype.buildColPositions = function () {\n        this.colPositions.build();\n    };\n    TimeGrid.prototype.buildSlatPositions = function () {\n        this.slatPositions.build();\n    };\n    /* Hit System\n    ------------------------------------------------------------------------------------------------------------------*/\n    TimeGrid.prototype.positionToHit = function (positionLeft, positionTop) {\n        var dateEnv = this.context.dateEnv;\n        var _a = this, snapsPerSlot = _a.snapsPerSlot, slatPositions = _a.slatPositions, colPositions = _a.colPositions;\n        var colIndex = colPositions.leftToIndex(positionLeft);\n        var slatIndex = slatPositions.topToIndex(positionTop);\n        if (colIndex != null && slatIndex != null) {\n            var slatTop = slatPositions.tops[slatIndex];\n            var slatHeight = slatPositions.getHeight(slatIndex);\n            var partial = (positionTop - slatTop) / slatHeight; // floating point number between 0 and 1\n            var localSnapIndex = Math.floor(partial * snapsPerSlot); // the snap # relative to start of slat\n            var snapIndex = slatIndex * snapsPerSlot + localSnapIndex;\n            var dayDate = this.props.cells[colIndex].date;\n            var time = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"addDurations\"])(this.props.dateProfile.minTime, Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"multiplyDuration\"])(this.snapDuration, snapIndex));\n            var start = dateEnv.add(dayDate, time);\n            var end = dateEnv.add(start, this.snapDuration);\n            return {\n                col: colIndex,\n                dateSpan: {\n                    range: { start: start, end: end },\n                    allDay: false\n                },\n                dayEl: this.colEls[colIndex],\n                relativeRect: {\n                    left: colPositions.lefts[colIndex],\n                    right: colPositions.rights[colIndex],\n                    top: slatTop,\n                    bottom: slatTop + slatHeight\n                }\n            };\n        }\n    };\n    /* Event Drag Visualization\n    ------------------------------------------------------------------------------------------------------------------*/\n    TimeGrid.prototype._renderEventDrag = function (state) {\n        if (state) {\n            this.eventRenderer.hideByHash(state.affectedInstances);\n            if (state.isEvent) {\n                this.mirrorRenderer.renderSegs(this.context, state.segs, { isDragging: true, sourceSeg: state.sourceSeg });\n            }\n            else {\n                this.fillRenderer.renderSegs('highlight', this.context, state.segs);\n            }\n        }\n    };\n    TimeGrid.prototype._unrenderEventDrag = function (state) {\n        if (state) {\n            this.eventRenderer.showByHash(state.affectedInstances);\n            if (state.isEvent) {\n                this.mirrorRenderer.unrender(this.context, state.segs, { isDragging: true, sourceSeg: state.sourceSeg });\n            }\n            else {\n                this.fillRenderer.unrender('highlight', this.context);\n            }\n        }\n    };\n    /* Event Resize Visualization\n    ------------------------------------------------------------------------------------------------------------------*/\n    TimeGrid.prototype._renderEventResize = function (state) {\n        if (state) {\n            this.eventRenderer.hideByHash(state.affectedInstances);\n            this.mirrorRenderer.renderSegs(this.context, state.segs, { isResizing: true, sourceSeg: state.sourceSeg });\n        }\n    };\n    TimeGrid.prototype._unrenderEventResize = function (state) {\n        if (state) {\n            this.eventRenderer.showByHash(state.affectedInstances);\n            this.mirrorRenderer.unrender(this.context, state.segs, { isResizing: true, sourceSeg: state.sourceSeg });\n        }\n    };\n    /* Selection\n    ------------------------------------------------------------------------------------------------------------------*/\n    // Renders a visual indication of a selection. Overrides the default, which was to simply render a highlight.\n    TimeGrid.prototype._renderDateSelection = function (segs) {\n        if (segs) {\n            if (this.context.options.selectMirror) {\n                this.mirrorRenderer.renderSegs(this.context, segs, { isSelecting: true });\n            }\n            else {\n                this.fillRenderer.renderSegs('highlight', this.context, segs);\n            }\n        }\n    };\n    TimeGrid.prototype._unrenderDateSelection = function (segs) {\n        if (segs) {\n            if (this.context.options.selectMirror) {\n                this.mirrorRenderer.unrender(this.context, segs, { isSelecting: true });\n            }\n            else {\n                this.fillRenderer.unrender('highlight', this.context);\n            }\n        }\n    };\n    return TimeGrid;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"DateComponent\"]));\n\nvar AllDaySplitter = /** @class */ (function (_super) {\n    __extends(AllDaySplitter, _super);\n    function AllDaySplitter() {\n        return _super !== null && _super.apply(this, arguments) || this;\n    }\n    AllDaySplitter.prototype.getKeyInfo = function () {\n        return {\n            allDay: {},\n            timed: {}\n        };\n    };\n    AllDaySplitter.prototype.getKeysForDateSpan = function (dateSpan) {\n        if (dateSpan.allDay) {\n            return ['allDay'];\n        }\n        else {\n            return ['timed'];\n        }\n    };\n    AllDaySplitter.prototype.getKeysForEventDef = function (eventDef) {\n        if (!eventDef.allDay) {\n            return ['timed'];\n        }\n        else if (Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"hasBgRendering\"])(eventDef)) {\n            return ['timed', 'allDay'];\n        }\n        else {\n            return ['allDay'];\n        }\n    };\n    return AllDaySplitter;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"Splitter\"]));\n\nvar TIMEGRID_ALL_DAY_EVENT_LIMIT = 5;\nvar WEEK_HEADER_FORMAT = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createFormatter\"])({ week: 'short' });\n/* An abstract class for all timegrid-related views. Displays one more columns with time slots running vertically.\n----------------------------------------------------------------------------------------------------------------------*/\n// Is a manager for the TimeGrid subcomponent and possibly the DayGrid subcomponent (if allDaySlot is on).\n// Responsible for managing width/height.\nvar AbstractTimeGridView = /** @class */ (function (_super) {\n    __extends(AbstractTimeGridView, _super);\n    function AbstractTimeGridView() {\n        var _this = _super !== null && _super.apply(this, arguments) || this;\n        _this.splitter = new AllDaySplitter();\n        _this.renderSkeleton = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoizeRendering\"])(_this._renderSkeleton, _this._unrenderSkeleton);\n        /* Header Render Methods\n        ------------------------------------------------------------------------------------------------------------------*/\n        // Generates the HTML that will go before the day-of week header cells\n        _this.renderHeadIntroHtml = function () {\n            var _a = _this.context, theme = _a.theme, dateEnv = _a.dateEnv, options = _a.options;\n            var range = _this.props.dateProfile.renderRange;\n            var dayCnt = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"diffDays\"])(range.start, range.end);\n            var weekText;\n            if (options.weekNumbers) {\n                weekText = dateEnv.format(range.start, WEEK_HEADER_FORMAT);\n                return '' +\n                    '<th class=\"fc-axis fc-week-number ' + theme.getClass('widgetHeader') + '\" ' + _this.axisStyleAttr() + '>' +\n                    Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"buildGotoAnchorHtml\"])(// aside from link, important for matchCellWidths\n                    options, dateEnv, { date: range.start, type: 'week', forceOff: dayCnt > 1 }, Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"htmlEscape\"])(weekText) // inner HTML\n                    ) +\n                    '</th>';\n            }\n            else {\n                return '<th class=\"fc-axis ' + theme.getClass('widgetHeader') + '\" ' + _this.axisStyleAttr() + '></th>';\n            }\n        };\n        /* Time Grid Render Methods\n        ------------------------------------------------------------------------------------------------------------------*/\n        // Generates the HTML that goes before the bg of the TimeGrid slot area. Long vertical column.\n        _this.renderTimeGridBgIntroHtml = function () {\n            var theme = _this.context.theme;\n            return '<td class=\"fc-axis ' + theme.getClass('widgetContent') + '\" ' + _this.axisStyleAttr() + '></td>';\n        };\n        // Generates the HTML that goes before all other types of cells.\n        // Affects content-skeleton, mirror-skeleton, highlight-skeleton for both the time-grid and day-grid.\n        _this.renderTimeGridIntroHtml = function () {\n            return '<td class=\"fc-axis\" ' + _this.axisStyleAttr() + '></td>';\n        };\n        /* Day Grid Render Methods\n        ------------------------------------------------------------------------------------------------------------------*/\n        // Generates the HTML that goes before the all-day cells\n        _this.renderDayGridBgIntroHtml = function () {\n            var _a = _this.context, theme = _a.theme, options = _a.options;\n            return '' +\n                '<td class=\"fc-axis ' + theme.getClass('widgetContent') + '\" ' + _this.axisStyleAttr() + '>' +\n                '<span>' + // needed for matchCellWidths\n                Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"getAllDayHtml\"])(options) +\n                '</span>' +\n                '</td>';\n        };\n        // Generates the HTML that goes before all other types of cells.\n        // Affects content-skeleton, mirror-skeleton, highlight-skeleton for both the time-grid and day-grid.\n        _this.renderDayGridIntroHtml = function () {\n            return '<td class=\"fc-axis\" ' + _this.axisStyleAttr() + '></td>';\n        };\n        return _this;\n    }\n    AbstractTimeGridView.prototype.render = function (props, context) {\n        _super.prototype.render.call(this, props, context);\n        this.renderSkeleton(context);\n    };\n    AbstractTimeGridView.prototype.destroy = function () {\n        _super.prototype.destroy.call(this);\n        this.renderSkeleton.unrender();\n    };\n    AbstractTimeGridView.prototype._renderSkeleton = function (context) {\n        this.el.classList.add('fc-timeGrid-view');\n        this.el.innerHTML = this.renderSkeletonHtml();\n        this.scroller = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"ScrollComponent\"]('hidden', // overflow x\n        'auto' // overflow y\n        );\n        var timeGridWrapEl = this.scroller.el;\n        this.el.querySelector('.fc-body > tr > td').appendChild(timeGridWrapEl);\n        timeGridWrapEl.classList.add('fc-time-grid-container');\n        var timeGridEl = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createElement\"])('div', { className: 'fc-time-grid' });\n        timeGridWrapEl.appendChild(timeGridEl);\n        this.timeGrid = new TimeGrid(timeGridEl, {\n            renderBgIntroHtml: this.renderTimeGridBgIntroHtml,\n            renderIntroHtml: this.renderTimeGridIntroHtml\n        });\n        if (context.options.allDaySlot) { // should we display the \"all-day\" area?\n            this.dayGrid = new _fullcalendar_daygrid__WEBPACK_IMPORTED_MODULE_1__[\"DayGrid\"](// the all-day subcomponent of this view\n            this.el.querySelector('.fc-day-grid'), {\n                renderNumberIntroHtml: this.renderDayGridIntroHtml,\n                renderBgIntroHtml: this.renderDayGridBgIntroHtml,\n                renderIntroHtml: this.renderDayGridIntroHtml,\n                colWeekNumbersVisible: false,\n                cellWeekNumbersVisible: false\n            });\n            // have the day-grid extend it's coordinate area over the <hr> dividing the two grids\n            var dividerEl = this.el.querySelector('.fc-divider');\n            this.dayGrid.bottomCoordPadding = dividerEl.getBoundingClientRect().height;\n        }\n    };\n    AbstractTimeGridView.prototype._unrenderSkeleton = function () {\n        this.el.classList.remove('fc-timeGrid-view');\n        this.timeGrid.destroy();\n        if (this.dayGrid) {\n            this.dayGrid.destroy();\n        }\n        this.scroller.destroy();\n    };\n    /* Rendering\n    ------------------------------------------------------------------------------------------------------------------*/\n    // Builds the HTML skeleton for the view.\n    // The day-grid and time-grid components will render inside containers defined by this HTML.\n    AbstractTimeGridView.prototype.renderSkeletonHtml = function () {\n        var _a = this.context, theme = _a.theme, options = _a.options;\n        return '' +\n            '<table class=\"' + theme.getClass('tableGrid') + '\">' +\n            (options.columnHeader ?\n                '<thead class=\"fc-head\">' +\n                    '<tr>' +\n                    '<td class=\"fc-head-container ' + theme.getClass('widgetHeader') + '\">&nbsp;</td>' +\n                    '</tr>' +\n                    '</thead>' :\n                '') +\n            '<tbody class=\"fc-body\">' +\n            '<tr>' +\n            '<td class=\"' + theme.getClass('widgetContent') + '\">' +\n            (options.allDaySlot ?\n                '<div class=\"fc-day-grid\"></div>' +\n                    '<hr class=\"fc-divider ' + theme.getClass('widgetHeader') + '\" />' :\n                '') +\n            '</td>' +\n            '</tr>' +\n            '</tbody>' +\n            '</table>';\n    };\n    /* Now Indicator\n    ------------------------------------------------------------------------------------------------------------------*/\n    AbstractTimeGridView.prototype.getNowIndicatorUnit = function () {\n        return this.timeGrid.getNowIndicatorUnit();\n    };\n    // subclasses should implement\n    // renderNowIndicator(date: DateMarker) {\n    // }\n    AbstractTimeGridView.prototype.unrenderNowIndicator = function () {\n        this.timeGrid.unrenderNowIndicator();\n    };\n    /* Dimensions\n    ------------------------------------------------------------------------------------------------------------------*/\n    AbstractTimeGridView.prototype.updateSize = function (isResize, viewHeight, isAuto) {\n        _super.prototype.updateSize.call(this, isResize, viewHeight, isAuto); // will call updateBaseSize. important that executes first\n        this.timeGrid.updateSize(isResize);\n        if (this.dayGrid) {\n            this.dayGrid.updateSize(isResize);\n        }\n    };\n    // Adjusts the vertical dimensions of the view to the specified values\n    AbstractTimeGridView.prototype.updateBaseSize = function (isResize, viewHeight, isAuto) {\n        var _this = this;\n        var eventLimit;\n        var scrollerHeight;\n        var scrollbarWidths;\n        // make all axis cells line up\n        this.axisWidth = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"matchCellWidths\"])(Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(this.el, '.fc-axis'));\n        // hack to give the view some height prior to timeGrid's columns being rendered\n        // TODO: separate setting height from scroller VS timeGrid.\n        if (!this.timeGrid.colEls) {\n            if (!isAuto) {\n                scrollerHeight = this.computeScrollerHeight(viewHeight);\n                this.scroller.setHeight(scrollerHeight);\n            }\n            return;\n        }\n        // set of fake row elements that must compensate when scroller has scrollbars\n        var noScrollRowEls = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"findElements\"])(this.el, '.fc-row').filter(function (node) {\n            return !_this.scroller.el.contains(node);\n        });\n        // reset all dimensions back to the original state\n        this.timeGrid.bottomRuleEl.style.display = 'none'; // will be shown later if this <hr> is necessary\n        this.scroller.clear(); // sets height to 'auto' and clears overflow\n        noScrollRowEls.forEach(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"uncompensateScroll\"]);\n        // limit number of events in the all-day area\n        if (this.dayGrid) {\n            this.dayGrid.removeSegPopover(); // kill the \"more\" popover if displayed\n            eventLimit = this.context.options.eventLimit;\n            if (eventLimit && typeof eventLimit !== 'number') {\n                eventLimit = TIMEGRID_ALL_DAY_EVENT_LIMIT; // make sure \"auto\" goes to a real number\n            }\n            if (eventLimit) {\n                this.dayGrid.limitRows(eventLimit);\n            }\n        }\n        if (!isAuto) { // should we force dimensions of the scroll container?\n            scrollerHeight = this.computeScrollerHeight(viewHeight);\n            this.scroller.setHeight(scrollerHeight);\n            scrollbarWidths = this.scroller.getScrollbarWidths();\n            if (scrollbarWidths.left || scrollbarWidths.right) { // using scrollbars?\n                // make the all-day and header rows lines up\n                noScrollRowEls.forEach(function (rowEl) {\n                    Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"compensateScroll\"])(rowEl, scrollbarWidths);\n                });\n                // the scrollbar compensation might have changed text flow, which might affect height, so recalculate\n                // and reapply the desired height to the scroller.\n                scrollerHeight = this.computeScrollerHeight(viewHeight);\n                this.scroller.setHeight(scrollerHeight);\n            }\n            // guarantees the same scrollbar widths\n            this.scroller.lockOverflow(scrollbarWidths);\n            // if there's any space below the slats, show the horizontal rule.\n            // this won't cause any new overflow, because lockOverflow already called.\n            if (this.timeGrid.getTotalSlatHeight() < scrollerHeight) {\n                this.timeGrid.bottomRuleEl.style.display = '';\n            }\n        }\n    };\n    // given a desired total height of the view, returns what the height of the scroller should be\n    AbstractTimeGridView.prototype.computeScrollerHeight = function (viewHeight) {\n        return viewHeight -\n            Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"subtractInnerElHeight\"])(this.el, this.scroller.el); // everything that's NOT the scroller\n    };\n    /* Scroll\n    ------------------------------------------------------------------------------------------------------------------*/\n    // Computes the initial pre-configured scroll state prior to allowing the user to change it\n    AbstractTimeGridView.prototype.computeDateScroll = function (duration) {\n        var top = this.timeGrid.computeTimeTop(duration);\n        // zoom can give weird floating-point values. rather scroll a little bit further\n        top = Math.ceil(top);\n        if (top) {\n            top++; // to overcome top border that slots beyond the first have. looks better\n        }\n        return { top: top };\n    };\n    AbstractTimeGridView.prototype.queryDateScroll = function () {\n        return { top: this.scroller.getScrollTop() };\n    };\n    AbstractTimeGridView.prototype.applyDateScroll = function (scroll) {\n        if (scroll.top !== undefined) {\n            this.scroller.setScrollTop(scroll.top);\n        }\n    };\n    // Generates an HTML attribute string for setting the width of the axis, if it is known\n    AbstractTimeGridView.prototype.axisStyleAttr = function () {\n        if (this.axisWidth != null) {\n            return 'style=\"width:' + this.axisWidth + 'px\"';\n        }\n        return '';\n    };\n    return AbstractTimeGridView;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"View\"]));\nAbstractTimeGridView.prototype.usesMinMaxTime = true; // indicates that minTime/maxTime affects rendering\n\nvar SimpleTimeGrid = /** @class */ (function (_super) {\n    __extends(SimpleTimeGrid, _super);\n    function SimpleTimeGrid(timeGrid) {\n        var _this = _super.call(this, timeGrid.el) || this;\n        _this.buildDayRanges = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoize\"])(buildDayRanges);\n        _this.slicer = new TimeGridSlicer();\n        _this.timeGrid = timeGrid;\n        return _this;\n    }\n    SimpleTimeGrid.prototype.firstContext = function (context) {\n        context.calendar.registerInteractiveComponent(this, {\n            el: this.timeGrid.el\n        });\n    };\n    SimpleTimeGrid.prototype.destroy = function () {\n        _super.prototype.destroy.call(this);\n        this.context.calendar.unregisterInteractiveComponent(this);\n    };\n    SimpleTimeGrid.prototype.render = function (props, context) {\n        var dateEnv = this.context.dateEnv;\n        var dateProfile = props.dateProfile, dayTable = props.dayTable;\n        var dayRanges = this.dayRanges = this.buildDayRanges(dayTable, dateProfile, dateEnv);\n        var timeGrid = this.timeGrid;\n        timeGrid.receiveContext(context); // hack because context is used in sliceProps\n        timeGrid.receiveProps(__assign({}, this.slicer.sliceProps(props, dateProfile, null, context.calendar, timeGrid, dayRanges), { dateProfile: dateProfile, cells: dayTable.cells[0] }), context);\n    };\n    SimpleTimeGrid.prototype.renderNowIndicator = function (date) {\n        this.timeGrid.renderNowIndicator(this.slicer.sliceNowDate(date, this.timeGrid, this.dayRanges), date);\n    };\n    SimpleTimeGrid.prototype.buildPositionCaches = function () {\n        this.timeGrid.buildPositionCaches();\n    };\n    SimpleTimeGrid.prototype.queryHit = function (positionLeft, positionTop) {\n        var rawHit = this.timeGrid.positionToHit(positionLeft, positionTop);\n        if (rawHit) {\n            return {\n                component: this.timeGrid,\n                dateSpan: rawHit.dateSpan,\n                dayEl: rawHit.dayEl,\n                rect: {\n                    left: rawHit.relativeRect.left,\n                    right: rawHit.relativeRect.right,\n                    top: rawHit.relativeRect.top,\n                    bottom: rawHit.relativeRect.bottom\n                },\n                layer: 0\n            };\n        }\n    };\n    return SimpleTimeGrid;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"DateComponent\"]));\nfunction buildDayRanges(dayTable, dateProfile, dateEnv) {\n    var ranges = [];\n    for (var _i = 0, _a = dayTable.headerDates; _i < _a.length; _i++) {\n        var date = _a[_i];\n        ranges.push({\n            start: dateEnv.add(date, dateProfile.minTime),\n            end: dateEnv.add(date, dateProfile.maxTime)\n        });\n    }\n    return ranges;\n}\nvar TimeGridSlicer = /** @class */ (function (_super) {\n    __extends(TimeGridSlicer, _super);\n    function TimeGridSlicer() {\n        return _super !== null && _super.apply(this, arguments) || this;\n    }\n    TimeGridSlicer.prototype.sliceRange = function (range, dayRanges) {\n        var segs = [];\n        for (var col = 0; col < dayRanges.length; col++) {\n            var segRange = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"intersectRanges\"])(range, dayRanges[col]);\n            if (segRange) {\n                segs.push({\n                    start: segRange.start,\n                    end: segRange.end,\n                    isStart: segRange.start.valueOf() === range.start.valueOf(),\n                    isEnd: segRange.end.valueOf() === range.end.valueOf(),\n                    col: col\n                });\n            }\n        }\n        return segs;\n    };\n    return TimeGridSlicer;\n}(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"Slicer\"]));\n\nvar TimeGridView = /** @class */ (function (_super) {\n    __extends(TimeGridView, _super);\n    function TimeGridView() {\n        var _this = _super !== null && _super.apply(this, arguments) || this;\n        _this.buildDayTable = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"memoize\"])(buildDayTable);\n        return _this;\n    }\n    TimeGridView.prototype.render = function (props, context) {\n        _super.prototype.render.call(this, props, context); // for flags for updateSize. also _renderSkeleton/_unrenderSkeleton\n        var _a = this.props, dateProfile = _a.dateProfile, dateProfileGenerator = _a.dateProfileGenerator;\n        var nextDayThreshold = context.nextDayThreshold;\n        var dayTable = this.buildDayTable(dateProfile, dateProfileGenerator);\n        var splitProps = this.splitter.splitProps(props);\n        if (this.header) {\n            this.header.receiveProps({\n                dateProfile: dateProfile,\n                dates: dayTable.headerDates,\n                datesRepDistinctDays: true,\n                renderIntroHtml: this.renderHeadIntroHtml\n            }, context);\n        }\n        this.simpleTimeGrid.receiveProps(__assign({}, splitProps['timed'], { dateProfile: dateProfile,\n            dayTable: dayTable }), context);\n        if (this.simpleDayGrid) {\n            this.simpleDayGrid.receiveProps(__assign({}, splitProps['allDay'], { dateProfile: dateProfile,\n                dayTable: dayTable,\n                nextDayThreshold: nextDayThreshold, isRigid: false }), context);\n        }\n        this.startNowIndicator(dateProfile, dateProfileGenerator);\n    };\n    TimeGridView.prototype._renderSkeleton = function (context) {\n        _super.prototype._renderSkeleton.call(this, context);\n        if (context.options.columnHeader) {\n            this.header = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"DayHeader\"](this.el.querySelector('.fc-head-container'));\n        }\n        this.simpleTimeGrid = new SimpleTimeGrid(this.timeGrid);\n        if (this.dayGrid) {\n            this.simpleDayGrid = new _fullcalendar_daygrid__WEBPACK_IMPORTED_MODULE_1__[\"SimpleDayGrid\"](this.dayGrid);\n        }\n    };\n    TimeGridView.prototype._unrenderSkeleton = function () {\n        _super.prototype._unrenderSkeleton.call(this);\n        if (this.header) {\n            this.header.destroy();\n        }\n        this.simpleTimeGrid.destroy();\n        if (this.simpleDayGrid) {\n            this.simpleDayGrid.destroy();\n        }\n    };\n    TimeGridView.prototype.renderNowIndicator = function (date) {\n        this.simpleTimeGrid.renderNowIndicator(date);\n    };\n    return TimeGridView;\n}(AbstractTimeGridView));\nfunction buildDayTable(dateProfile, dateProfileGenerator) {\n    var daySeries = new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"DaySeries\"](dateProfile.renderRange, dateProfileGenerator);\n    return new _fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"DayTable\"](daySeries, false);\n}\n\nvar main = Object(_fullcalendar_core__WEBPACK_IMPORTED_MODULE_0__[\"createPlugin\"])({\n    defaultView: 'timeGridWeek',\n    views: {\n        timeGrid: {\n            class: TimeGridView,\n            allDaySlot: true,\n            slotDuration: '00:30:00',\n            slotEventOverlap: true // a bad name. confused with overlap/constraint system\n        },\n        timeGridDay: {\n            type: 'timeGrid',\n            duration: { days: 1 }\n        },\n        timeGridWeek: {\n            type: 'timeGrid',\n            duration: { weeks: 1 }\n        }\n    }\n});\n\n/* harmony default export */ __webpack_exports__[\"default\"] = (main);\n\n\n\n//# sourceURL=webpack:///./node_modules/@fullcalendar/timegrid/main.esm.js?");

/***/ }),

/***/ "./webpack/vendors/custom/fullcalendar.js":
/*!************************************************!*\
  !*** ./webpack/vendors/custom/fullcalendar.js ***!
  \************************************************/
/*! no static exports found */
/***/ (function(module, exports, __webpack_require__) {

"use strict";
eval("\r\n\r\n/**\r\n * Define the output of this file. The output of CSS and JS file will be auto detected.\r\n *\r\n * @output plugins/custom/fullcalendar/fullcalendar.bundle\r\n */\r\n\r\n// fullcalendar\r\n__webpack_require__(/*! @fullcalendar/core/main.css */ \"./node_modules/@fullcalendar/core/main.css\");\r\n__webpack_require__(/*! @fullcalendar/daygrid/main.css */ \"./node_modules/@fullcalendar/daygrid/main.css\");\r\n__webpack_require__(/*! @fullcalendar/list/main.css */ \"./node_modules/@fullcalendar/list/main.css\");\r\n__webpack_require__(/*! @fullcalendar/timegrid/main.css */ \"./node_modules/@fullcalendar/timegrid/main.css\");\r\n\r\nwindow.FullCalendar = __webpack_require__(/*! @fullcalendar/core */ \"./node_modules/@fullcalendar/core/main.esm.js\");\r\nwindow.FullCalendarDayGrid = __webpack_require__(/*! @fullcalendar/daygrid */ \"./node_modules/@fullcalendar/daygrid/main.esm.js\");\r\nwindow.FullCalendarGoogleCalendar = __webpack_require__(/*! @fullcalendar/google-calendar */ \"./node_modules/@fullcalendar/google-calendar/main.esm.js\");\r\nwindow.FullCalendarInteraction = __webpack_require__(/*! @fullcalendar/interaction */ \"./node_modules/@fullcalendar/interaction/main.esm.js\");\r\nwindow.FullCalendarList = __webpack_require__(/*! @fullcalendar/list */ \"./node_modules/@fullcalendar/list/main.esm.js\");\r\nwindow.FullCalendarTimeGrid = __webpack_require__(/*! @fullcalendar/timegrid */ \"./node_modules/@fullcalendar/timegrid/main.esm.js\");\r\n\n\n//# sourceURL=webpack:///./webpack/vendors/custom/fullcalendar.js?");

/***/ })

/******/ });